Class: VisaAcceptanceMergedSpec::Account2
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::Account2
- Defined in:
- lib/visa_acceptance_merged_spec/models/account2.rb
Overview
Account2 Model.
Instance Attribute Summary collapse
-
#corrected_account_number ⇒ String
Corrected account number from the ACH verification service.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(corrected_account_number: SKIP, additional_properties: nil) ⇒ Account2
constructor
A new instance of Account2.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(corrected_account_number: SKIP, additional_properties: nil) ⇒ Account2
Returns a new instance of Account2.
35 36 37 38 39 40 41 |
# File 'lib/visa_acceptance_merged_spec/models/account2.rb', line 35 def initialize(corrected_account_number: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @corrected_account_number = corrected_account_number unless corrected_account_number == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#corrected_account_number ⇒ String
Corrected account number from the ACH verification service.
14 15 16 |
# File 'lib/visa_acceptance_merged_spec/models/account2.rb', line 14 def corrected_account_number @corrected_account_number end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/visa_acceptance_merged_spec/models/account2.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. corrected_account_number = hash.key?('correctedAccountNumber') ? hash['correctedAccountNumber'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Account2.new(corrected_account_number: corrected_account_number, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/visa_acceptance_merged_spec/models/account2.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['corrected_account_number'] = 'correctedAccountNumber' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/visa_acceptance_merged_spec/models/account2.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/visa_acceptance_merged_spec/models/account2.rb', line 24 def self.optionals %w[ corrected_account_number ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
71 72 73 74 75 |
# File 'lib/visa_acceptance_merged_spec/models/account2.rb', line 71 def inspect class_name = self.class.name.split('::').last "<#{class_name} corrected_account_number: #{@corrected_account_number.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
64 65 66 67 68 |
# File 'lib/visa_acceptance_merged_spec/models/account2.rb', line 64 def to_s class_name = self.class.name.split('::').last "<#{class_name} corrected_account_number: #{@corrected_account_number},"\ " additional_properties: #{@additional_properties}>" end |