Class: VisaAcceptanceMergedSpec::AccountFeatures1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/account_features1.rb

Overview

AccountFeatures1 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(category: SKIP, additional_properties: nil) ⇒ AccountFeatures1

Returns a new instance of AccountFeatures1.



65
66
67
68
69
70
71
# File 'lib/visa_acceptance_merged_spec/models/account_features1.rb', line 65

def initialize(category: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @category = category unless category == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#categoryString

GPX

Mastercard product ID associated with the primary account number (PAN). Returned by authorization service.

Visa Acceptance through VisaNet

Visa or Mastercard product ID that is associated with the primary account number (PAN). For descriptions of the Visa product IDs, see the Product ID table on the [Visa Request & Response Codes web page.]( Data Length: String (3)

GPN

Visa or Mastercard product ID that is associated with the primary account number (PAN). For descriptions of the Visa product IDs, see the Product ID table on the [Visa Request & Response Codes web page.]( Data Length: String (3)

Worldpay VAP

Important Before using this field on Worldpay VAP, you must contact Visa Acceptance Customer Support to have your account configured for this feature. Type of card used in the transaction. The only possible value is:

  • PREPAID: Prepaid Card Data Length: String (7)

RBS WorldPay Atlanta

Type of card used in the transaction. Possible values:

  • B: Business Card
  • O: Noncommercial Card
  • R: Corporate Card
  • S: Purchase Card
  • Blank: Purchase card not supported Data Length: String (1)

Returns:

  • (String)


44
45
46
# File 'lib/visa_acceptance_merged_spec/models/account_features1.rb', line 44

def category
  @category
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/visa_acceptance_merged_spec/models/account_features1.rb', line 74

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  category = hash.key?('category') ? hash['category'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AccountFeatures1.new(category: category,
                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



47
48
49
50
51
# File 'lib/visa_acceptance_merged_spec/models/account_features1.rb', line 47

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['category'] = 'category'
  @_hash
end

.nullablesObject

An array for nullable fields



61
62
63
# File 'lib/visa_acceptance_merged_spec/models/account_features1.rb', line 61

def self.nullables
  []
end

.optionalsObject

An array for optional fields



54
55
56
57
58
# File 'lib/visa_acceptance_merged_spec/models/account_features1.rb', line 54

def self.optionals
  %w[
    category
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



99
100
101
102
103
# File 'lib/visa_acceptance_merged_spec/models/account_features1.rb', line 99

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} category: #{@category.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



93
94
95
96
# File 'lib/visa_acceptance_merged_spec/models/account_features1.rb', line 93

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} category: #{@category}, additional_properties: #{@additional_properties}>"
end