Class: VisaAcceptanceMergedSpec::AchVerification

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/ach_verification.rb

Overview

AchVerification Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(result_code: SKIP, result_code_raw: SKIP, additional_properties: nil) ⇒ AchVerification

Returns a new instance of AchVerification.



41
42
43
44
45
46
47
48
49
# File 'lib/visa_acceptance_merged_spec/models/ach_verification.rb', line 41

def initialize(result_code: SKIP, result_code_raw: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @result_code = result_code unless result_code == SKIP
  @result_code_raw = result_code_raw unless result_code_raw == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#result_codeString

Results from the ACH verification service.

Returns:

  • (String)


14
15
16
# File 'lib/visa_acceptance_merged_spec/models/ach_verification.rb', line 14

def result_code
  @result_code
end

#result_code_rawString

Raw results from the ACH verification service.

Returns:

  • (String)


18
19
20
# File 'lib/visa_acceptance_merged_spec/models/ach_verification.rb', line 18

def result_code_raw
  @result_code_raw
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/visa_acceptance_merged_spec/models/ach_verification.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  result_code = hash.key?('resultCode') ? hash['resultCode'] : SKIP
  result_code_raw =
    hash.key?('resultCodeRaw') ? hash['resultCodeRaw'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AchVerification.new(result_code: result_code,
                      result_code_raw: result_code_raw,
                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/visa_acceptance_merged_spec/models/ach_verification.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['result_code'] = 'resultCode'
  @_hash['result_code_raw'] = 'resultCodeRaw'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/visa_acceptance_merged_spec/models/ach_verification.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/visa_acceptance_merged_spec/models/ach_verification.rb', line 29

def self.optionals
  %w[
    result_code
    result_code_raw
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



81
82
83
84
85
# File 'lib/visa_acceptance_merged_spec/models/ach_verification.rb', line 81

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} result_code: #{@result_code.inspect}, result_code_raw:"\
  " #{@result_code_raw.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



74
75
76
77
78
# File 'lib/visa_acceptance_merged_spec/models/ach_verification.rb', line 74

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} result_code: #{@result_code}, result_code_raw: #{@result_code_raw},"\
  " additional_properties: #{@additional_properties}>"
end