Class: VisaAcceptanceMergedSpec::AgreementInformation

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/agreement_information.rb

Overview

AgreementInformation Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(agreement_id: SKIP, id: SKIP, additional_properties: nil) ⇒ AgreementInformation

Returns a new instance of AgreementInformation.



45
46
47
48
49
50
51
52
# File 'lib/visa_acceptance_merged_spec/models/agreement_information.rb', line 45

def initialize(agreement_id: SKIP, id: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @agreement_id = agreement_id unless agreement_id == SKIP
  @id = id unless id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#agreement_idString

Identifier for the mandate being signed for. This mandate id is required for all the subsequent transactions.

Returns:

  • (String)


15
16
17
# File 'lib/visa_acceptance_merged_spec/models/agreement_information.rb', line 15

def agreement_id
  @agreement_id
end

#idString

The processor specific billing agreement ID. References an approved recurring payment for goods or services. This value is sent by merchant via Visa Acceptance to processor. The value sent in this field is procured by the merchant from the processor.

Returns:

  • (String)


22
23
24
# File 'lib/visa_acceptance_merged_spec/models/agreement_information.rb', line 22

def id
  @id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/visa_acceptance_merged_spec/models/agreement_information.rb', line 55

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  agreement_id = hash.key?('agreementId') ? hash['agreementId'] : SKIP
  id = hash.key?('id') ? hash['id'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AgreementInformation.new(agreement_id: agreement_id,
                           id: id,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
# File 'lib/visa_acceptance_merged_spec/models/agreement_information.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['agreement_id'] = 'agreementId'
  @_hash['id'] = 'id'
  @_hash
end

.nullablesObject

An array for nullable fields



41
42
43
# File 'lib/visa_acceptance_merged_spec/models/agreement_information.rb', line 41

def self.nullables
  []
end

.optionalsObject

An array for optional fields



33
34
35
36
37
38
# File 'lib/visa_acceptance_merged_spec/models/agreement_information.rb', line 33

def self.optionals
  %w[
    agreement_id
    id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



83
84
85
86
87
# File 'lib/visa_acceptance_merged_spec/models/agreement_information.rb', line 83

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} agreement_id: #{@agreement_id.inspect}, id: #{@id.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



76
77
78
79
80
# File 'lib/visa_acceptance_merged_spec/models/agreement_information.rb', line 76

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} agreement_id: #{@agreement_id}, id: #{@id}, additional_properties:"\
  " #{@additional_properties}>"
end