Class: VisaAcceptanceMergedSpec::AuthReversalRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::AuthReversalRequest
- Defined in:
- lib/visa_acceptance_merged_spec/models/auth_reversal_request.rb
Overview
AuthReversalRequest Model.
Instance Attribute Summary collapse
-
#client_reference_information ⇒ ClientReferenceInformation4
TODO: Write general description for this method.
-
#order_information ⇒ OrderInformation4
TODO: Write general description for this method.
-
#payment_information ⇒ PaymentInformation3
TODO: Write general description for this method.
-
#point_of_sale_information ⇒ PointOfSaleInformation2
TODO: Write general description for this method.
-
#processing_information ⇒ ProcessingInformation3
TODO: Write general description for this method.
-
#processor_information ⇒ ProcessorInformation3
TODO: Write general description for this method.
-
#reversal_information ⇒ ReversalInformation
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client_reference_information: SKIP, reversal_information: SKIP, processing_information: SKIP, order_information: SKIP, point_of_sale_information: SKIP, payment_information: SKIP, processor_information: SKIP, additional_properties: nil) ⇒ AuthReversalRequest
constructor
A new instance of AuthReversalRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client_reference_information: SKIP, reversal_information: SKIP, processing_information: SKIP, order_information: SKIP, point_of_sale_information: SKIP, payment_information: SKIP, processor_information: SKIP, additional_properties: nil) ⇒ AuthReversalRequest
Returns a new instance of AuthReversalRequest.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/visa_acceptance_merged_spec/models/auth_reversal_request.rb', line 71 def initialize(client_reference_information: SKIP, reversal_information: SKIP, processing_information: SKIP, order_information: SKIP, point_of_sale_information: SKIP, payment_information: SKIP, processor_information: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? unless client_reference_information == SKIP @client_reference_information = client_reference_information end @reversal_information = reversal_information unless reversal_information == SKIP @processing_information = processing_information unless processing_information == SKIP @order_information = order_information unless order_information == SKIP unless point_of_sale_information == SKIP @point_of_sale_information = point_of_sale_information end @payment_information = payment_information unless payment_information == SKIP @processor_information = processor_information unless processor_information == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_reference_information ⇒ ClientReferenceInformation4
TODO: Write general description for this method
14 15 16 |
# File 'lib/visa_acceptance_merged_spec/models/auth_reversal_request.rb', line 14 def client_reference_information @client_reference_information end |
#order_information ⇒ OrderInformation4
TODO: Write general description for this method
26 27 28 |
# File 'lib/visa_acceptance_merged_spec/models/auth_reversal_request.rb', line 26 def order_information @order_information end |
#payment_information ⇒ PaymentInformation3
TODO: Write general description for this method
34 35 36 |
# File 'lib/visa_acceptance_merged_spec/models/auth_reversal_request.rb', line 34 def payment_information @payment_information end |
#point_of_sale_information ⇒ PointOfSaleInformation2
TODO: Write general description for this method
30 31 32 |
# File 'lib/visa_acceptance_merged_spec/models/auth_reversal_request.rb', line 30 def point_of_sale_information @point_of_sale_information end |
#processing_information ⇒ ProcessingInformation3
TODO: Write general description for this method
22 23 24 |
# File 'lib/visa_acceptance_merged_spec/models/auth_reversal_request.rb', line 22 def processing_information @processing_information end |
#processor_information ⇒ ProcessorInformation3
TODO: Write general description for this method
38 39 40 |
# File 'lib/visa_acceptance_merged_spec/models/auth_reversal_request.rb', line 38 def processor_information @processor_information end |
#reversal_information ⇒ ReversalInformation
TODO: Write general description for this method
18 19 20 |
# File 'lib/visa_acceptance_merged_spec/models/auth_reversal_request.rb', line 18 def reversal_information @reversal_information end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/visa_acceptance_merged_spec/models/auth_reversal_request.rb', line 96 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. if hash['clientReferenceInformation'] client_reference_information = ClientReferenceInformation4.from_hash(hash['clientReferenceInformation']) end reversal_information = ReversalInformation.from_hash(hash['reversalInformation']) if hash['reversalInformation'] processing_information = ProcessingInformation3.from_hash(hash['processingInformation']) if hash['processingInformation'] order_information = OrderInformation4.from_hash(hash['orderInformation']) if hash['orderInformation'] if hash['pointOfSaleInformation'] point_of_sale_information = PointOfSaleInformation2.from_hash(hash['pointOfSaleInformation']) end payment_information = PaymentInformation3.from_hash(hash['paymentInformation']) if hash['paymentInformation'] processor_information = ProcessorInformation3.from_hash(hash['processorInformation']) if hash['processorInformation'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. AuthReversalRequest.new(client_reference_information: client_reference_information, reversal_information: reversal_information, processing_information: processing_information, order_information: order_information, point_of_sale_information: point_of_sale_information, payment_information: payment_information, processor_information: processor_information, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/visa_acceptance_merged_spec/models/auth_reversal_request.rb', line 41 def self.names @_hash = {} if @_hash.nil? @_hash['client_reference_information'] = 'clientReferenceInformation' @_hash['reversal_information'] = 'reversalInformation' @_hash['processing_information'] = 'processingInformation' @_hash['order_information'] = 'orderInformation' @_hash['point_of_sale_information'] = 'pointOfSaleInformation' @_hash['payment_information'] = 'paymentInformation' @_hash['processor_information'] = 'processorInformation' @_hash end |
.nullables ⇒ Object
An array for nullable fields
67 68 69 |
# File 'lib/visa_acceptance_merged_spec/models/auth_reversal_request.rb', line 67 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/visa_acceptance_merged_spec/models/auth_reversal_request.rb', line 54 def self.optionals %w[ client_reference_information reversal_information processing_information order_information point_of_sale_information payment_information processor_information ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
147 148 149 150 151 152 153 154 155 |
# File 'lib/visa_acceptance_merged_spec/models/auth_reversal_request.rb', line 147 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_reference_information: #{@client_reference_information.inspect},"\ " reversal_information: #{@reversal_information.inspect}, processing_information:"\ " #{@processing_information.inspect}, order_information: #{@order_information.inspect},"\ " point_of_sale_information: #{@point_of_sale_information.inspect}, payment_information:"\ " #{@payment_information.inspect}, processor_information: #{@processor_information.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
136 137 138 139 140 141 142 143 144 |
# File 'lib/visa_acceptance_merged_spec/models/auth_reversal_request.rb', line 136 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_reference_information: #{@client_reference_information},"\ " reversal_information: #{@reversal_information}, processing_information:"\ " #{@processing_information}, order_information: #{@order_information},"\ " point_of_sale_information: #{@point_of_sale_information}, payment_information:"\ " #{@payment_information}, processor_information: #{@processor_information},"\ " additional_properties: #{@additional_properties}>" end |