Class: VisaAcceptanceMergedSpec::Avs

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/avs.rb

Overview

Avs Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(code: SKIP, code_raw: SKIP, additional_properties: nil) ⇒ Avs

Returns a new instance of Avs.



46
47
48
49
50
51
52
53
# File 'lib/visa_acceptance_merged_spec/models/avs.rb', line 46

def initialize(code: SKIP, code_raw: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @code = code unless code == SKIP
  @code_raw = code_raw unless code_raw == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#codeString

AVS result code. Returned by authorization service.

Returns:

  • (String)


15
16
17
# File 'lib/visa_acceptance_merged_spec/models/avs.rb', line 15

def code
  @code
end

#code_rawString

AVS result code sent directly from the processor. Returned only when the processor returns this value. Important Do not use this field to evaluate the result of AVS. Use for debugging purposes only. Returned by authorization service.

Returns:

  • (String)


23
24
25
# File 'lib/visa_acceptance_merged_spec/models/avs.rb', line 23

def code_raw
  @code_raw
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/visa_acceptance_merged_spec/models/avs.rb', line 56

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  code = hash.key?('code') ? hash['code'] : SKIP
  code_raw = hash.key?('codeRaw') ? hash['codeRaw'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Avs.new(code: code,
          code_raw: code_raw,
          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
# File 'lib/visa_acceptance_merged_spec/models/avs.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['code'] = 'code'
  @_hash['code_raw'] = 'codeRaw'
  @_hash
end

.nullablesObject

An array for nullable fields



42
43
44
# File 'lib/visa_acceptance_merged_spec/models/avs.rb', line 42

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
# File 'lib/visa_acceptance_merged_spec/models/avs.rb', line 34

def self.optionals
  %w[
    code
    code_raw
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



84
85
86
87
88
# File 'lib/visa_acceptance_merged_spec/models/avs.rb', line 84

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} code: #{@code.inspect}, code_raw: #{@code_raw.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



77
78
79
80
81
# File 'lib/visa_acceptance_merged_spec/models/avs.rb', line 77

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} code: #{@code}, code_raw: #{@code_raw}, additional_properties:"\
  " #{@additional_properties}>"
end