Class: VisaAcceptanceMergedSpec::BankAccount1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::BankAccount1
- Defined in:
- lib/visa_acceptance_merged_spec/models/bank_account1.rb
Overview
BankAccount1 Model.
Instance Attribute Summary collapse
-
#number ⇒ String
Account number.
-
#routing_number ⇒ String
Bank routing number.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(number: SKIP, routing_number: SKIP, additional_properties: nil) ⇒ BankAccount1
constructor
A new instance of BankAccount1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(number: SKIP, routing_number: SKIP, additional_properties: nil) ⇒ BankAccount1
Returns a new instance of BankAccount1.
45 46 47 48 49 50 51 52 53 |
# File 'lib/visa_acceptance_merged_spec/models/bank_account1.rb', line 45 def initialize(number: SKIP, routing_number: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @number = number unless number == SKIP @routing_number = routing_number unless routing_number == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#number ⇒ String
Account number. When processing encoded account numbers, use this field for the encoded account number.
16 17 18 |
# File 'lib/visa_acceptance_merged_spec/models/bank_account1.rb', line 16 def number @number end |
#routing_number ⇒ String
Bank routing number. This is also called the transit number.
For details, see ecp_rdfi field description in the [Electronic Check
Services Using the SCMP API Guide.](
22 23 24 |
# File 'lib/visa_acceptance_merged_spec/models/bank_account1.rb', line 22 def routing_number @routing_number end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/visa_acceptance_merged_spec/models/bank_account1.rb', line 56 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. number = hash.key?('number') ? hash['number'] : SKIP routing_number = hash.key?('routingNumber') ? hash['routingNumber'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BankAccount1.new(number: number, routing_number: routing_number, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 |
# File 'lib/visa_acceptance_merged_spec/models/bank_account1.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['number'] = 'number' @_hash['routing_number'] = 'routingNumber' @_hash end |
.nullables ⇒ Object
An array for nullable fields
41 42 43 |
# File 'lib/visa_acceptance_merged_spec/models/bank_account1.rb', line 41 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
33 34 35 36 37 38 |
# File 'lib/visa_acceptance_merged_spec/models/bank_account1.rb', line 33 def self.optionals %w[ number routing_number ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
84 85 86 87 88 |
# File 'lib/visa_acceptance_merged_spec/models/bank_account1.rb', line 84 def inspect class_name = self.class.name.split('::').last "<#{class_name} number: #{@number.inspect}, routing_number: #{@routing_number.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
77 78 79 80 81 |
# File 'lib/visa_acceptance_merged_spec/models/bank_account1.rb', line 77 def to_s class_name = self.class.name.split('::').last "<#{class_name} number: #{@number}, routing_number: #{@routing_number},"\ " additional_properties: #{@additional_properties}>" end |