Class: VisaAcceptanceMergedSpec::BankTransferOptions21

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/bank_transfer_options21.rb

Overview

BankTransferOptions21 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(sec_code: SKIP, additional_properties: nil) ⇒ BankTransferOptions21

Returns a new instance of BankTransferOptions21.



42
43
44
45
46
47
48
# File 'lib/visa_acceptance_merged_spec/models/bank_transfer_options21.rb', line 42

def initialize(sec_code: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @sec_code = sec_code unless sec_code == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#sec_code ⇒ String

Specifies the authorization method for the transaction. Possible values:

  • ARC: account receivable conversion
  • CCD: corporate cash disbursement
  • POP: point of purchase conversion
  • PPD: prearranged payment and deposit entry
  • TEL: telephone-initiated entry
  • WEB: internet-initiated entry

Returns:

  • (String)


21
22
23
# File 'lib/visa_acceptance_merged_spec/models/bank_transfer_options21.rb', line 21

def sec_code
  @sec_code
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/visa_acceptance_merged_spec/models/bank_transfer_options21.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  sec_code = hash.key?('secCode') ? hash['secCode'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BankTransferOptions21.new(sec_code: sec_code,
                            additional_properties: additional_properties)
end

.names ⇒ Object

A mapping from model property names to API property names.



24
25
26
27
28
# File 'lib/visa_acceptance_merged_spec/models/bank_transfer_options21.rb', line 24

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['sec_code'] = 'secCode'
  @_hash
end

.nullables ⇒ Object

An array for nullable fields



38
39
40
# File 'lib/visa_acceptance_merged_spec/models/bank_transfer_options21.rb', line 38

def self.nullables
  []
end

.optionals ⇒ Object

An array for optional fields



31
32
33
34
35
# File 'lib/visa_acceptance_merged_spec/models/bank_transfer_options21.rb', line 31

def self.optionals
  %w[
    sec_code
  ]
end

Instance Method Details

#inspect ⇒ Object

Provides a debugging-friendly string with detailed object information.



76
77
78
79
80
# File 'lib/visa_acceptance_merged_spec/models/bank_transfer_options21.rb', line 76

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} sec_code: #{@sec_code.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_s ⇒ Object

Provides a human-readable string representation of the object.



70
71
72
73
# File 'lib/visa_acceptance_merged_spec/models/bank_transfer_options21.rb', line 70

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} sec_code: #{@sec_code}, additional_properties: #{@additional_properties}>"
end