Class: VisaAcceptanceMergedSpec::BankTransferOptions3

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/bank_transfer_options3.rb

Overview

BankTransferOptions3 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(settlement_method: SKIP, additional_properties: nil) ⇒ BankTransferOptions3

Returns a new instance of BankTransferOptions3.



42
43
44
45
46
47
48
# File 'lib/visa_acceptance_merged_spec/models/bank_transfer_options3.rb', line 42

def initialize(settlement_method: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @settlement_method = settlement_method unless settlement_method == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#settlement_methodString

Method used for settlement. Possible values:

  • A: Automated Clearing House (default for credits and for transactions using Canadian dollars)
  • F: Facsimile draft (U.S. dollars only)
  • B: Best possible (U.S. dollars only) (default if the field has not already been configured for your merchant ID)

Returns:

  • (String)


21
22
23
# File 'lib/visa_acceptance_merged_spec/models/bank_transfer_options3.rb', line 21

def settlement_method
  @settlement_method
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/visa_acceptance_merged_spec/models/bank_transfer_options3.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  settlement_method =
    hash.key?('settlementMethod') ? hash['settlementMethod'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BankTransferOptions3.new(settlement_method: settlement_method,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



24
25
26
27
28
# File 'lib/visa_acceptance_merged_spec/models/bank_transfer_options3.rb', line 24

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['settlement_method'] = 'settlementMethod'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/visa_acceptance_merged_spec/models/bank_transfer_options3.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
34
35
# File 'lib/visa_acceptance_merged_spec/models/bank_transfer_options3.rb', line 31

def self.optionals
  %w[
    settlement_method
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



78
79
80
81
82
# File 'lib/visa_acceptance_merged_spec/models/bank_transfer_options3.rb', line 78

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} settlement_method: #{@settlement_method.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



71
72
73
74
75
# File 'lib/visa_acceptance_merged_spec/models/bank_transfer_options3.rb', line 71

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} settlement_method: #{@settlement_method}, additional_properties:"\
  " #{@additional_properties}>"
end