Class: VisaAcceptanceMergedSpec::BankTransferOptions4

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/bank_transfer_options4.rb

Overview

BankTransferOptions4 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(sec_code: SKIP, additional_properties: nil) ⇒ BankTransferOptions4

Returns a new instance of BankTransferOptions4.



45
46
47
48
49
50
51
# File 'lib/visa_acceptance_merged_spec/models/bank_transfer_options4.rb', line 45

def initialize(sec_code: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @sec_code = sec_code unless sec_code == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#sec_codeString

Specifies the authorization method for the transaction.

TeleCheck

Possible Values:

  • ARC: account receivable conversion
  • CCD: corporate cash disbursement
  • POP: point of purchase conversion
  • PPD: prearranged payment and deposit entry
  • TEL: telephone-initiated entry
  • WEB: internet-initiated entry

For details, see ecp_sec_code field description in the [Electronic

Check Services Using the SCMP API Guide.](

Returns:

  • (String)


24
25
26
# File 'lib/visa_acceptance_merged_spec/models/bank_transfer_options4.rb', line 24

def sec_code
  @sec_code
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/visa_acceptance_merged_spec/models/bank_transfer_options4.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  sec_code = hash.key?('SECCode') ? hash['SECCode'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BankTransferOptions4.new(sec_code: sec_code,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



27
28
29
30
31
# File 'lib/visa_acceptance_merged_spec/models/bank_transfer_options4.rb', line 27

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['sec_code'] = 'SECCode'
  @_hash
end

.nullablesObject

An array for nullable fields



41
42
43
# File 'lib/visa_acceptance_merged_spec/models/bank_transfer_options4.rb', line 41

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
# File 'lib/visa_acceptance_merged_spec/models/bank_transfer_options4.rb', line 34

def self.optionals
  %w[
    sec_code
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



79
80
81
82
83
# File 'lib/visa_acceptance_merged_spec/models/bank_transfer_options4.rb', line 79

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} sec_code: #{@sec_code.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



73
74
75
76
# File 'lib/visa_acceptance_merged_spec/models/bank_transfer_options4.rb', line 73

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} sec_code: #{@sec_code}, additional_properties: #{@additional_properties}>"
end