Class: VisaAcceptanceMergedSpec::BillTo7

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/bill_to7.rb

Overview

BillTo7 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(address1: SKIP, address2: SKIP, administrative_area: SKIP, building_number: SKIP, company: SKIP, country: SKIP, county: SKIP, district: SKIP, email: SKIP, first_name: SKIP, middle_name: SKIP, last_name: SKIP, locality: SKIP, phone_number: SKIP, postal_code: SKIP, title: SKIP, additional_properties: nil) ⇒ BillTo7

Returns a new instance of BillTo7.



506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
# File 'lib/visa_acceptance_merged_spec/models/bill_to7.rb', line 506

def initialize(address1: SKIP, address2: SKIP, administrative_area: SKIP,
               building_number: SKIP, company: SKIP, country: SKIP,
               county: SKIP, district: SKIP, email: SKIP, first_name: SKIP,
               middle_name: SKIP, last_name: SKIP, locality: SKIP,
               phone_number: SKIP, postal_code: SKIP, title: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @address1 = address1 unless address1 == SKIP
  @address2 = address2 unless address2 == SKIP
  @administrative_area = administrative_area unless administrative_area == SKIP
  @building_number = building_number unless building_number == SKIP
  @company = company unless company == SKIP
  @country = country unless country == SKIP
  @county = county unless county == SKIP
  @district = district unless district == SKIP
  @email = email unless email == SKIP
  @first_name = first_name unless first_name == SKIP
  @middle_name = middle_name unless middle_name == SKIP
  @last_name = last_name unless last_name == SKIP
  @locality = locality unless locality == SKIP
  @phone_number = phone_number unless phone_number == SKIP
  @postal_code = postal_code unless postal_code == SKIP
  @title = title unless title == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#address1String

Payment card billing street address as it appears on the credit card issuer’s records.

SEPA

Required for Create Mandate and Import Mandate

Atos

This field must not contain colons (:).

Visa Acceptance through VisaNet

Important When you populate orderInformation.billTo.address1 and orderInformation.billTo.address2, Visa Acceptance through VisaNet concatenates the two values. If the concatenated value exceeds 40 characters, Visa Acceptance through VisaNet truncates the value at 40 characters before sending it to Visa and the issuing bank. Truncating this value affects AVS results and therefore might also affect risk decisions and chargebacks. Credit card networks cannot process transactions that contain non-ASCII characters. Visa Acceptance through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent Visa Acceptance through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, Visa Acceptance through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.

FDMS Nashville

When the street name is numeric, it must be sent in numeric format. For example, if the address is One First Street, it must be sent as 1 1st Street. Required if keyed; not used if swiped. String (20)

TSYS Acquiring Solutions

Required when processingInformation.billPaymentOptions.billPayment=true and pointOfSaleInformation.entryMode=keyed.

All other processors:

Optional. String (60)

For Payouts

This field may be sent only for FDC Compass. Important It is your responsibility to determine whether a field is required for the transaction you are requesting.

Returns:

  • (String)


53
54
55
# File 'lib/visa_acceptance_merged_spec/models/bill_to7.rb', line 53

def address1
  @address1
end

#address2String

Used for additional address information. For example: Attention: Accounts Payable Optional field. For Payouts: This field may be sent only for FDC Compass.

Atos

This field must not contain colons (:).

Visa Acceptance through VisaNet

Important When you populate orderInformation.billTo.address1 and orderInformation.billTo.address2, Visa Acceptance through VisaNet concatenates the two values. If the concatenated value exceeds 40 characters, Visa Acceptance through VisaNet truncates the value at 40 characters before sending it to Visa and the issuing bank. Truncating this value affects AVS results and therefore might also affect risk decisions and chargebacks. Credit card networks cannot process transactions that contain non-ASCII characters. Visa Acceptance through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent Visa Acceptance through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, Visa Acceptance through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.

Chase Paymentech Solutions, FDC Compass, and TSYS Acquiring Solutions

This value is used for AVS.

FDMS Nashville

orderInformation.billTo.address1 and orderInformation.billTo.address2 together cannot exceed 20 characters. String (20)

All Other Processors

String (60)

Returns:

  • (String)


88
89
90
# File 'lib/visa_acceptance_merged_spec/models/bill_to7.rb', line 88

def address2
  @address2
end

#administrative_areaString

State or province of the billing address. Use the [State, Province, and Territory Codes for the United States and Canada](

Returns:

  • (String)


93
94
95
# File 'lib/visa_acceptance_merged_spec/models/bill_to7.rb', line 93

def administrative_area
  @administrative_area
end

#building_numberString

Building number in the street address. For example, if the street address is: Rua da Quitanda 187 then the building number is 187. This field is supported only for:

  • Cielo transactions.
  • Redecard customer validation with Visa Acceptance Latin American Processing.

Returns:

  • (String)


104
105
106
# File 'lib/visa_acceptance_merged_spec/models/bill_to7.rb', line 104

def building_number
  @building_number
end

#companyString

Company's Name, e.g. VISA

Returns:

  • (String)


108
109
110
# File 'lib/visa_acceptance_merged_spec/models/bill_to7.rb', line 108

def company
  @company
end

#countryString

Payment card billing country. Use the two-character [ISO Standard Country Codes](

SEPA/BACS

Required for Create Mandate and Import Mandate

Visa Acceptance through VisaNet

Credit card networks cannot process transactions that contain non-ASCII characters. Visa Acceptance through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent Visa Acceptance through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, Visa Acceptance through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks. Important It is your responsibility to determine whether a field is required for the transaction you are requesting.

Chase Paymentech Solutions

Optional field.

Credit Mutuel-CIC

Optional field.

OmniPay Direct

Optional field.

SIX

Optional field.

TSYS Acquiring Solutions

Required when processingInformation.billPaymentOptions.billPayment=true and pointOfSaleInformation.entryMode=keyed.

Worldpay VAP

Optional field.

All other processors

Not used.

Returns:

  • (String)


142
143
144
# File 'lib/visa_acceptance_merged_spec/models/bill_to7.rb', line 142

def country
  @country
end

#countyString

U.S. county if available.

Returns:

  • (String)


146
147
148
# File 'lib/visa_acceptance_merged_spec/models/bill_to7.rb', line 146

def county
  @county
end

#districtString

Customer’s neighborhood, community, or region within the city or municipality.

SEPA/BACS

When you include this field in a request, the value for this field must be the same as the value for the billTo_state field.

Returns:

  • (String)


154
155
156
# File 'lib/visa_acceptance_merged_spec/models/bill_to7.rb', line 154

def district
  @district
end

#emailString

Customer's email address, including the full domain name.

Visa Acceptance through VisaNet

Credit card networks cannot process transactions that contain non-ASCII characters. Visa Acceptance through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent Visa Acceptance through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, Visa Acceptance through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks. Important It is your responsibility to determine whether a field is required for the transaction you are requesting.

Invoicing

Email address for the customer for sending the invoice. If the invoice is in SENT status and email is updated, the old email customer payment link won't work and you must resend the invoice with the new payment link.

Chase Paymentech Solutions

Optional field.

Credit Mutuel-CIC

Optional field.

OmniPay Direct

Optional field.

SIX

Optional field.

TSYS Acquiring Solutions

Required when processingInformation.billPaymentOptions.billPayment=true and pointOfSaleInformation.entryMode=keyed.

Worldpay VAP

Optional field.

All other processors

Not used.

Returns:

  • (String)


188
189
190
# File 'lib/visa_acceptance_merged_spec/models/bill_to7.rb', line 188

def email
  @email
end

#first_nameString

Customer’s first name. This name must be the same as the name on the card. Important It is your responsibility to determine whether a field is required for the transaction you are requesting.

SEPA

Required for Create Mandate and Import Mandate

BACS

Required for Import Mandate

Visa Acceptance Latin American Processing

Important For an authorization request, Visa Acceptance Latin American Processing concatenates orderInformation.billTo.firstName and orderInformation.billTo.lastName. If the concatenated value exceeds 30 characters, Visa Acceptance Latin American Processing declines the authorization request.
Note Visa Acceptance Latin American Processing is the name of a specific processing connection that Visa Acceptance supports. In the Visa Acceptance API documentation, Visa Acceptance Latin American Processing does not refer to the general topic of processing in Latin America. The information in this field description is for the specific processing connection called Visa Acceptance Latin American Processing. It is not for any other Latin American processors that Visa Acceptance supports.

Visa Acceptance through VisaNet

Credit card networks cannot process transactions that contain non-ASCII characters. Visa Acceptance through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent Visa Acceptance through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, Visa Acceptance through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.

For Payouts:

This field may be sent only for FDC Compass.

Chase Paymentech Solutions

Optional field.

Credit Mutuel-CIC

Optional field.

OmniPay Direct

Optional field.

SIX

Optional field.

TSYS Acquiring Solutions

Required when processingInformation.billPaymentOptions.billPayment=true and pointOfSaleInformation.entryMode=keyed.

Worldpay VAP

Optional field.

All other processors

Not used.

Returns:

  • (String)


237
238
239
# File 'lib/visa_acceptance_merged_spec/models/bill_to7.rb', line 237

def first_name
  @first_name
end

#last_nameString

Customer’s last name. This name must be the same as the name on the card. Important It is your responsibility to determine whether a field is required for the transaction you are requesting.

SEPA

Required for Create Mandate and Import Mandate

BACS

Required for Import Mandate

Chase Paymentech Solutions

Optional field.

Credit Mutuel-CIC

Optional field.

Visa Acceptance Latin American Processing

Important For an authorization request, Visa Acceptance Latin American Processing concatenates orderInformation.billTo.firstName and orderInformation.billTo.lastName. If the concatenated value exceeds 30 characters, Visa Acceptance Latin American Processing declines the authorization request.
Note Visa Acceptance Latin American Processing is the name of a specific processing connection that Visa Acceptance supports. In the Visa Acceptance API documentation, Visa Acceptance Latin American Processing does not refer to the general topic of processing in Latin America. The information in this field description is for the specific processing connection called Visa Acceptance Latin American Processing. It is not for any other Latin American processors that Visa Acceptance supports.

Visa Acceptance through VisaNet

Credit card networks cannot process transactions that contain non-ASCII characters. Visa Acceptance through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent Visa Acceptance through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, Visa Acceptance through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.

For Payouts:

This field may be sent only for FDC Compass.

OmniPay Direct

Optional field.

RBS WorldPay Atlanta

Optional field.

SIX

Optional field.

TSYS Acquiring Solutions

Required when processingInformation.billPaymentOptions.billPayment=true and pointOfSaleInformation.entryMode=keyed.

Worldpay VAP

Optional field.

All other processors

Not used.

Returns:

  • (String)


292
293
294
# File 'lib/visa_acceptance_merged_spec/models/bill_to7.rb', line 292

def last_name
  @last_name
end

#localityString

Payment card billing city.

SEPA

Required for Create Mandate and Import Mandate

Atos

This field must not contain colons (:).

Visa Acceptance through VisaNet

Credit card networks cannot process transactions that contain non-ASCII characters. Visa Acceptance through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent Visa Acceptance through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, Visa Acceptance through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.

For Payouts:

This field may be sent only for FDC Compass.

Chase Paymentech Solutions

Optional field.

Credit Mutuel-CIC

Optional field.

OmniPay Direct

Optional field.

SIX

Optional field.

TSYS Acquiring Solutions

Required when processingInformation.billPaymentOptions.billPayment=true and pointOfSaleInformation.entryMode=keyed.

Worldpay VAP

Optional field.

All other processors

Not used.

Returns:

  • (String)


326
327
328
# File 'lib/visa_acceptance_merged_spec/models/bill_to7.rb', line 326

def locality
  @locality
end

#middle_nameString

Customer’s middle name.

Returns:

  • (String)


241
242
243
# File 'lib/visa_acceptance_merged_spec/models/bill_to7.rb', line 241

def middle_name
  @middle_name
end

#phone_numberString

Customer’s phone number. It is recommended that you include the country code when the order is from outside the U.S.

Chase Paymentech Solutions

Optional field.

Credit Mutuel-CIC

Optional field.

Visa Acceptance through VisaNet

Credit card networks cannot process transactions that contain non-ASCII characters. Visa Acceptance through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent Visa Acceptance through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, Visa Acceptance through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.

For Payouts:

This field may be sent only for FDC Compass.

OmniPay Direct

Optional field.

SIX

Optional field.

TSYS Acquiring Solutions

Optional field.

Worldpay VAP

Optional field.

All other processors

Not used.

Returns:

  • (String)


357
358
359
# File 'lib/visa_acceptance_merged_spec/models/bill_to7.rb', line 357

def phone_number
  @phone_number
end

#postal_codeString

Postal code for the billing address. The postal code must consist of 5 to 9 digits. When the billing country is the U.S., the 9-digit postal code must follow this format: [5 digits][dash][4 digits] Example 12345-6789 When the billing country is Canada, the 6-digit postal code must follow this format: [alpha][numeric][alpha][space][numeric][alpha][numeric] Example A1B 2C3 Important It is your responsibility to determine whether a field is required for the transaction you are requesting.

SEPA

Required for Create Mandate and Import Mandate

For Payouts:

This field may be sent only for FDC Compass.

American Express Direct

Before sending the postal code to the processor, Visa Acceptance removes all nonalphanumeric characters and, if the remaining value is longer than nine characters, truncates the value starting from the right side.

Atos

This field must not contain colons (:).

Visa Acceptance through VisaNet

Credit card networks cannot process transactions that contain non-ASCII characters. Visa Acceptance through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent Visa Acceptance through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, Visa Acceptance through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.

FDMS Nashville

Required if pointOfSaleInformation.entryMode=keyed and the address is in the U.S. or Canada. Optional if pointOfSaleInformation.entryMode=keyed and the address is not in the U.S. or Canada. Not used if swiped.

RBS WorldPay Atlanta:

For best card-present keyed rates, send the postal code if pointOfSaleInformation.entryMode=keyed.

TSYS Acquiring Solutions

Required when processingInformation.billPaymentOptions.billPayment=true and pointOfSaleInformation.entryMode=keyed.

All other processors:

Optional field.

Returns:

  • (String)


406
407
408
# File 'lib/visa_acceptance_merged_spec/models/bill_to7.rb', line 406

def postal_code
  @postal_code
end

#titleString

Postal code for the billing address. The postal code must consist of 5 to 9 digits. When the billing country is the U.S., the 9-digit postal code must follow this format: [5 digits][dash][4 digits] Example 12345-6789 When the billing country is Canada, the 6-digit postal code must follow this format: [alpha][numeric][alpha][space][numeric][alpha][numeric] Example A1B 2C3 Important It is your responsibility to determine whether a field is required for the transaction you are requesting.

SEPA

Required for Create Mandate and Import Mandate

For Payouts:

This field may be sent only for FDC Compass.

American Express Direct

Before sending the postal code to the processor, Visa Acceptance removes all nonalphanumeric characters and, if the remaining value is longer than nine characters, truncates the value starting from the right side.

Atos

This field must not contain colons (:).

Visa Acceptance through VisaNet

Credit card networks cannot process transactions that contain non-ASCII characters. Visa Acceptance through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent Visa Acceptance through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, Visa Acceptance through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.

FDMS Nashville

Required if pointOfSaleInformation.entryMode=keyed and the address is in the U.S. or Canada. Optional if pointOfSaleInformation.entryMode=keyed and the address is not in the U.S. or Canada. Not used if swiped.

RBS WorldPay Atlanta:

For best card-present keyed rates, send the postal code if pointOfSaleInformation.entryMode=keyed.

TSYS Acquiring Solutions

Required when processingInformation.billPaymentOptions.billPayment=true and pointOfSaleInformation.entryMode=keyed.

All other processors:

Optional field.

Returns:

  • (String)


455
456
457
# File 'lib/visa_acceptance_merged_spec/models/bill_to7.rb', line 455

def title
  @title
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
# File 'lib/visa_acceptance_merged_spec/models/bill_to7.rb', line 535

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  address1 = hash.key?('address1') ? hash['address1'] : SKIP
  address2 = hash.key?('address2') ? hash['address2'] : SKIP
  administrative_area =
    hash.key?('administrativeArea') ? hash['administrativeArea'] : SKIP
  building_number =
    hash.key?('buildingNumber') ? hash['buildingNumber'] : SKIP
  company = hash.key?('company') ? hash['company'] : SKIP
  country = hash.key?('country') ? hash['country'] : SKIP
  county = hash.key?('county') ? hash['county'] : SKIP
  district = hash.key?('district') ? hash['district'] : SKIP
  email = hash.key?('email') ? hash['email'] : SKIP
  first_name = hash.key?('firstName') ? hash['firstName'] : SKIP
  middle_name = hash.key?('middleName') ? hash['middleName'] : SKIP
  last_name = hash.key?('lastName') ? hash['lastName'] : SKIP
  locality = hash.key?('locality') ? hash['locality'] : SKIP
  phone_number = hash.key?('phoneNumber') ? hash['phoneNumber'] : SKIP
  postal_code = hash.key?('postalCode') ? hash['postalCode'] : SKIP
  title = hash.key?('title') ? hash['title'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BillTo7.new(address1: address1,
              address2: address2,
              administrative_area: administrative_area,
              building_number: building_number,
              company: company,
              country: country,
              county: county,
              district: district,
              email: email,
              first_name: first_name,
              middle_name: middle_name,
              last_name: last_name,
              locality: locality,
              phone_number: phone_number,
              postal_code: postal_code,
              title: title,
              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
# File 'lib/visa_acceptance_merged_spec/models/bill_to7.rb', line 458

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['address1'] = 'address1'
  @_hash['address2'] = 'address2'
  @_hash['administrative_area'] = 'administrativeArea'
  @_hash['building_number'] = 'buildingNumber'
  @_hash['company'] = 'company'
  @_hash['country'] = 'country'
  @_hash['county'] = 'county'
  @_hash['district'] = 'district'
  @_hash['email'] = 'email'
  @_hash['first_name'] = 'firstName'
  @_hash['middle_name'] = 'middleName'
  @_hash['last_name'] = 'lastName'
  @_hash['locality'] = 'locality'
  @_hash['phone_number'] = 'phoneNumber'
  @_hash['postal_code'] = 'postalCode'
  @_hash['title'] = 'title'
  @_hash
end

.nullablesObject

An array for nullable fields



502
503
504
# File 'lib/visa_acceptance_merged_spec/models/bill_to7.rb', line 502

def self.nullables
  []
end

.optionalsObject

An array for optional fields



480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
# File 'lib/visa_acceptance_merged_spec/models/bill_to7.rb', line 480

def self.optionals
  %w[
    address1
    address2
    administrative_area
    building_number
    company
    country
    county
    district
    email
    first_name
    middle_name
    last_name
    locality
    phone_number
    postal_code
    title
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



597
598
599
600
601
602
603
604
605
606
607
# File 'lib/visa_acceptance_merged_spec/models/bill_to7.rb', line 597

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} address1: #{@address1.inspect}, address2: #{@address2.inspect},"\
  " administrative_area: #{@administrative_area.inspect}, building_number:"\
  " #{@building_number.inspect}, company: #{@company.inspect}, country: #{@country.inspect},"\
  " county: #{@county.inspect}, district: #{@district.inspect}, email: #{@email.inspect},"\
  " first_name: #{@first_name.inspect}, middle_name: #{@middle_name.inspect}, last_name:"\
  " #{@last_name.inspect}, locality: #{@locality.inspect}, phone_number:"\
  " #{@phone_number.inspect}, postal_code: #{@postal_code.inspect}, title: #{@title.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



586
587
588
589
590
591
592
593
594
# File 'lib/visa_acceptance_merged_spec/models/bill_to7.rb', line 586

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} address1: #{@address1}, address2: #{@address2}, administrative_area:"\
  " #{@administrative_area}, building_number: #{@building_number}, company: #{@company},"\
  " country: #{@country}, county: #{@county}, district: #{@district}, email: #{@email},"\
  " first_name: #{@first_name}, middle_name: #{@middle_name}, last_name: #{@last_name},"\
  " locality: #{@locality}, phone_number: #{@phone_number}, postal_code: #{@postal_code},"\
  " title: #{@title}, additional_properties: #{@additional_properties}>"
end