Class: VisaAcceptanceMergedSpec::Bonuse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/bonuse.rb

Overview

Bonuse Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(month: SKIP, amount: SKIP, additional_properties: nil) ⇒ Bonuse

Returns a new instance of Bonuse.



43
44
45
46
47
48
49
50
# File 'lib/visa_acceptance_merged_spec/models/bonuse.rb', line 43

def initialize(month: SKIP, amount: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @month = month unless month == SKIP
  @amount = amount unless amount == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#amountString

This value contains the bonus amount of the first month. Maximum value without decimal 99999999.

Returns:

  • (String)


20
21
22
# File 'lib/visa_acceptance_merged_spec/models/bonuse.rb', line 20

def amount
  @amount
end

#monthString

This value is a 2-digit code indicating the first bonus month. Valid value from 1 to 12.

Returns:

  • (String)


15
16
17
# File 'lib/visa_acceptance_merged_spec/models/bonuse.rb', line 15

def month
  @month
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/visa_acceptance_merged_spec/models/bonuse.rb', line 53

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  month = hash.key?('month') ? hash['month'] : SKIP
  amount = hash.key?('amount') ? hash['amount'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Bonuse.new(month: month,
             amount: amount,
             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/visa_acceptance_merged_spec/models/bonuse.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['month'] = 'month'
  @_hash['amount'] = 'amount'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/visa_acceptance_merged_spec/models/bonuse.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
34
35
36
# File 'lib/visa_acceptance_merged_spec/models/bonuse.rb', line 31

def self.optionals
  %w[
    month
    amount
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



81
82
83
84
85
# File 'lib/visa_acceptance_merged_spec/models/bonuse.rb', line 81

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} month: #{@month.inspect}, amount: #{@amount.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



74
75
76
77
78
# File 'lib/visa_acceptance_merged_spec/models/bonuse.rb', line 74

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} month: #{@month}, amount: #{@amount}, additional_properties:"\
  " #{@additional_properties}>"
end