Class: VisaAcceptanceMergedSpec::BuyerInformation12
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::BuyerInformation12
- Defined in:
- lib/visa_acceptance_merged_spec/models/buyer_information12.rb
Overview
BuyerInformation12 Model.
Instance Attribute Summary collapse
-
#email ⇒ String
Customer's primary email address, including the full domain name.
-
#merchant_customer_id ⇒ String
Your identifier for the customer.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(merchant_customer_id: SKIP, email: SKIP, additional_properties: nil) ⇒ BuyerInformation12
constructor
A new instance of BuyerInformation12.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(merchant_customer_id: SKIP, email: SKIP, additional_properties: nil) ⇒ BuyerInformation12
Returns a new instance of BuyerInformation12.
41 42 43 44 45 46 47 48 49 |
# File 'lib/visa_acceptance_merged_spec/models/buyer_information12.rb', line 41 def initialize(merchant_customer_id: SKIP, email: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @merchant_customer_id = merchant_customer_id unless merchant_customer_id == SKIP @email = email unless email == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#email ⇒ String
Customer's primary email address, including the full domain name.
18 19 20 |
# File 'lib/visa_acceptance_merged_spec/models/buyer_information12.rb', line 18 def email @email end |
#merchant_customer_id ⇒ String
Your identifier for the customer.
14 15 16 |
# File 'lib/visa_acceptance_merged_spec/models/buyer_information12.rb', line 14 def merchant_customer_id @merchant_customer_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/visa_acceptance_merged_spec/models/buyer_information12.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. merchant_customer_id = hash.key?('merchantCustomerID') ? hash['merchantCustomerID'] : SKIP email = hash.key?('email') ? hash['email'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BuyerInformation12.new(merchant_customer_id: merchant_customer_id, email: email, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/visa_acceptance_merged_spec/models/buyer_information12.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['merchant_customer_id'] = 'merchantCustomerID' @_hash['email'] = 'email' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/visa_acceptance_merged_spec/models/buyer_information12.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/visa_acceptance_merged_spec/models/buyer_information12.rb', line 29 def self.optionals %w[ merchant_customer_id email ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
81 82 83 84 85 |
# File 'lib/visa_acceptance_merged_spec/models/buyer_information12.rb', line 81 def inspect class_name = self.class.name.split('::').last "<#{class_name} merchant_customer_id: #{@merchant_customer_id.inspect}, email:"\ " #{@email.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
74 75 76 77 78 |
# File 'lib/visa_acceptance_merged_spec/models/buyer_information12.rb', line 74 def to_s class_name = self.class.name.split('::').last "<#{class_name} merchant_customer_id: #{@merchant_customer_id}, email: #{@email},"\ " additional_properties: #{@additional_properties}>" end |