Class: VisaAcceptanceMergedSpec::Card7

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/card7.rb

Overview

Card7 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(expiration_month: SKIP, expiration_year: SKIP, number: SKIP, security_code: SKIP, type: SKIP, additional_properties: nil) ⇒ Card7

Returns a new instance of Card7.



264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/visa_acceptance_merged_spec/models/card7.rb', line 264

def initialize(expiration_month: SKIP, expiration_year: SKIP, number: SKIP,
               security_code: SKIP, type: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @expiration_month = expiration_month unless expiration_month == SKIP
  @expiration_year = expiration_year unless expiration_year == SKIP
  @number = number unless number == SKIP
  @security_code = security_code unless security_code == SKIP
  @type = type unless type == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#expiration_monthString

Two-digit month in which the payment card expires. Format: MM. Valid values: 01 through 12. Leading 0 is required.

Barclays and Streamline

For Maestro (UK Domestic) and Maestro (International) cards on Barclays and Streamline, this must be a valid value (01 through 12) but is not required to be a valid expiration date. In other words, an expiration date that is in the past does not cause Visa Acceptance to reject your request. However, an invalid expiration date might cause the issuer to reject your request.

Encoded Account Numbers

For encoded account numbers (type=039), if there is no expiration date on the card, use 12.

FDMS Nashville

Required field.

All other processors

Required if pointOfSaleInformation.entryMode=keyed. However, this field is optional if your account is configured for relaxed requirements for address data and expiration date. Important It is your responsibility to determine whether a field is required for the transaction you are requesting.

Google Pay transactions

For PAN-based Google Pay transactions, this field is returned in the API response.

Returns:

  • (String)


38
39
40
# File 'lib/visa_acceptance_merged_spec/models/card7.rb', line 38

def expiration_month
  @expiration_month
end

#expiration_yearString

Four-digit year in which the payment card expires. Format: YYYY.

Barclays and Streamline

For Maestro (UK Domestic) and Maestro (International) cards on Barclays and Streamline, this must be a valid value (1900 through 3000) but is not required to be a valid expiration date. In other words, an expiration date that is in the past does not cause Visa Acceptance to reject your request. However, an invalid expiration date might cause the issuer to reject your request.

Encoded Account Numbers

For encoded account numbers (**type**=039), if there is no expiration date on the card, use 2021.

FDMS Nashville

Required field.

FDC Nashville Global and FDMS South

You can send in 2 digits or 4 digits. If you send in 2 digits, they must be the last 2 digits of the year.

All other processors

Required if pointOfSaleInformation.entryMode=keyed. However, this field is optional if your account is configured for relaxed requirements for address data and expiration date. Important It is your responsibility to determine whether a field is required for the transaction you are requesting.

Google Pay transactions

For PAN-based Google Pay transactions, this field is returned in the API response.

Returns:

  • (String)


67
68
69
# File 'lib/visa_acceptance_merged_spec/models/card7.rb', line 67

def expiration_year
  @expiration_year
end

#numberString

The customer’s payment card number, also known as the Primary Account Number (PAN). You can also use this field for encoded account numbers.

FDMS Nashville

Required. String (19)

GPX

Required if pointOfSaleInformation.entryMode=keyed. However, this field is optional if your account is configured for relaxed requirements for address data and expiration date. Important It is your responsibility to determine whether a field is required for the transaction you are requesting.

All other processors

Required if pointOfSaleInformation.entryMode=keyed. However, this field is optional if your account is configured for relaxed requirements for address data and expiration date. Important It is your responsibility to determine whether a field is required for the transaction you are requesting.

Returns:

  • (String)


87
88
89
# File 'lib/visa_acceptance_merged_spec/models/card7.rb', line 87

def number
  @number
end

#security_codeString

Card Verification Number.

FDMS Nashville

Required for American Express or if swiped; otherwise, optional.

Ingenico ePayments

Do not include this field when commerceIndicator=recurring. Note Ingenico ePayments was previously called Global Collect.

TSYS Acquiring Solutions

Optional if pointOfSaleInformation.entryMode=keyed; otherwise, not used.

GPX

Optional.

All other processors:

Optional.

Returns:

  • (String)


102
103
104
# File 'lib/visa_acceptance_merged_spec/models/card7.rb', line 102

def security_code
  @security_code
end

#typeString

Three-digit value that indicates the card type. IMPORTANT It is strongly recommended that you include the card type field in request messages even if it is optional for your processor and card type. Omitting the card type can cause the transaction to be processed with the wrong card type. Possible values:

  • 001: Visa. Use card type value 001 for Visa Electron.
  • 002: Mastercard, Eurocard, which is a European regional brand of Mastercard.
  • 003: American Express
  • 004: Discover
  • 005: Diners Club
  • 006: Carte Blanche
  • 007: JCB
  • 008: Optima
  • 009: GE Private Label
  • 010: Beneficial Private Label
  • 011: Twinpay Credit Card
  • 012: Twinpay Debit Card
  • 013: WalMart
  • 014: Enroute
  • 015: Lowe's Consumer
  • 016: Home Depot Consumer
  • 017: MBNA
  • 018: Dick's Sportswear
  • 019: Casual Corner
  • 020: Sears
  • 021: JAL
  • 023: Disney Card
  • 024: Maestro (UK Domestic)[^1]
  • 025: Sam's Club Consumer
  • 026: Sam's Club Business
  • 027: Nico's
  • 028: Paymentech Bill Me Later
  • 029: Bebe
  • 030: Restoration Hardware
  • 031: Delta Online
  • 032: Solo
  • 033: Visa Electron. Do not use this value. Use 001 for all Visa card types.
  • 034: Dankort
  • 035: Laser
  • 036: Cartes Bancaires
  • 037: Carta Si
  • 038: Pinless Debit
  • 039: Encoded account number
  • 040: UATP
  • 041: HOUSEHOLD
  • 042: Maestro (International)[^1]
  • 043: GE MONEY
  • 044: Korean Cards
  • 045: Style Cards
  • 046: JCrew
  • 047: Payeasecn eWallet
  • 048: Payeasecn Bank Transfer
  • 049: Meijer
  • 050: Hipercard
  • 051: Aura
  • 052: Redecard
  • 053: Orico card
  • 054: Elo
  • 055: Capitol One Private Label
  • 056: Carnet
  • 057: Costco Private Label
  • 058: Carnet
  • 059: ValueLink
  • 060: MADA
  • 061: RuPay
  • 062: China UnionPay
  • 063: Falabella Private Label
  • 064: Prompt Card
  • 065: Korean Domestic
  • 066: Banricompras
  • 067: MEEZA
  • 068: PayPak
  • 070: EFTPOS
  • 071: Codensa
  • 072: Olimpica
  • 073: Colsubsidio
  • 074: Tuya
  • 075: Sodexo
  • 076: Naranja
  • 077: Cabal
  • 078: DINELCO
  • 079: PANAL
  • 080: EPM
  • 081: Jaywan [^1]: For this card type, you must include the paymentInformation.card.type or paymentInformation.tokenizedCard.type field in your request for an authorization or a stand-alone credit. [^2]: For this card type on Cielo 3.0, you must include the paymentInformation.card.type or paymentInformation.tokenizedCard.type field in a request for an authorization or a stand-alone credit. This card type is not supported on Cielo 1.5. [^3]: For this card type on Getnet and Rede, you must include the paymentInformation.card.type or paymentInformation.tokenizedCard.type field in a request for an authorization or a stand-alone credit. [^4]: For this card type, you must include the paymentInformation.card.type in your request for any payer authentication services.

Used by

Authorization Required for Carte Blanche and JCB. Optional for all other card types.

Card Present reply

This field is included in the reply message when the client software that is installed on the POS terminal uses the token management service (TMS) to retrieve tokenized payment details. You must contact customer support to have your account enabled to receive these fields in the credit reply message. Returned by the Credit service. This reply field is only supported by the following processors:

  • American Express Direct
  • Credit Mutuel-CIC
  • FDC Nashville Global
  • OmniPay Direct
  • SIX

Google Pay transactions

For PAN-based Google Pay transactions, this field is returned in the API response.

GPX

This field only supports transactions from the following card types:

  • Visa
  • Mastercard
  • AMEX
  • Discover
  • Diners
  • JCB
  • Union Pay International

Returns:

  • (String)


235
236
237
# File 'lib/visa_acceptance_merged_spec/models/card7.rb', line 235

def type
  @type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/visa_acceptance_merged_spec/models/card7.rb', line 278

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  expiration_month =
    hash.key?('expirationMonth') ? hash['expirationMonth'] : SKIP
  expiration_year =
    hash.key?('expirationYear') ? hash['expirationYear'] : SKIP
  number = hash.key?('number') ? hash['number'] : SKIP
  security_code = hash.key?('securityCode') ? hash['securityCode'] : SKIP
  type = hash.key?('type') ? hash['type'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Card7.new(expiration_month: expiration_month,
            expiration_year: expiration_year,
            number: number,
            security_code: security_code,
            type: type,
            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



238
239
240
241
242
243
244
245
246
# File 'lib/visa_acceptance_merged_spec/models/card7.rb', line 238

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['expiration_month'] = 'expirationMonth'
  @_hash['expiration_year'] = 'expirationYear'
  @_hash['number'] = 'number'
  @_hash['security_code'] = 'securityCode'
  @_hash['type'] = 'type'
  @_hash
end

.nullablesObject

An array for nullable fields



260
261
262
# File 'lib/visa_acceptance_merged_spec/models/card7.rb', line 260

def self.nullables
  []
end

.optionalsObject

An array for optional fields



249
250
251
252
253
254
255
256
257
# File 'lib/visa_acceptance_merged_spec/models/card7.rb', line 249

def self.optionals
  %w[
    expiration_month
    expiration_year
    number
    security_code
    type
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



315
316
317
318
319
320
321
# File 'lib/visa_acceptance_merged_spec/models/card7.rb', line 315

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} expiration_month: #{@expiration_month.inspect}, expiration_year:"\
  " #{@expiration_year.inspect}, number: #{@number.inspect}, security_code:"\
  " #{@security_code.inspect}, type: #{@type.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



307
308
309
310
311
312
# File 'lib/visa_acceptance_merged_spec/models/card7.rb', line 307

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} expiration_month: #{@expiration_month}, expiration_year:"\
  " #{@expiration_year}, number: #{@number}, security_code: #{@security_code}, type: #{@type},"\
  " additional_properties: #{@additional_properties}>"
end