Class: VisaAcceptanceMergedSpec::ClientReferenceInformation39
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::ClientReferenceInformation39
- Defined in:
- lib/visa_acceptance_merged_spec/models/client_reference_information39.rb
Overview
ClientReferenceInformation39 Model.
Instance Attribute Summary collapse
-
#reconciliation_id ⇒ String
Reference number for the transaction.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(reconciliation_id: SKIP, additional_properties: nil) ⇒ ClientReferenceInformation39
constructor
A new instance of ClientReferenceInformation39.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(reconciliation_id: SKIP, additional_properties: nil) ⇒ ClientReferenceInformation39
Returns a new instance of ClientReferenceInformation39.
40 41 42 43 44 45 46 |
# File 'lib/visa_acceptance_merged_spec/models/client_reference_information39.rb', line 40 def initialize(reconciliation_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @reconciliation_id = reconciliation_id unless reconciliation_id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#reconciliation_id ⇒ String
Reference number for the transaction. Depending on how your Visa Acceptance account is configured, this value could either be provided in the API request or generated by Visa Acceptance. The actual value used in the request to the processor is provided back to you by Visa Acceptance in the response.
19 20 21 |
# File 'lib/visa_acceptance_merged_spec/models/client_reference_information39.rb', line 19 def reconciliation_id @reconciliation_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/visa_acceptance_merged_spec/models/client_reference_information39.rb', line 49 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. reconciliation_id = hash.key?('reconciliationId') ? hash['reconciliationId'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ClientReferenceInformation39.new(reconciliation_id: reconciliation_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 |
# File 'lib/visa_acceptance_merged_spec/models/client_reference_information39.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['reconciliation_id'] = 'reconciliationId' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/visa_acceptance_merged_spec/models/client_reference_information39.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 |
# File 'lib/visa_acceptance_merged_spec/models/client_reference_information39.rb', line 29 def self.optionals %w[ reconciliation_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 80 |
# File 'lib/visa_acceptance_merged_spec/models/client_reference_information39.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} reconciliation_id: #{@reconciliation_id.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 73 |
# File 'lib/visa_acceptance_merged_spec/models/client_reference_information39.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} reconciliation_id: #{@reconciliation_id}, additional_properties:"\ " #{@additional_properties}>" end |