Class: VisaAcceptanceMergedSpec::ConsumerAuthenticationInformation4

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/consumer_authentication_information4.rb

Overview

ConsumerAuthenticationInformation4 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(eci_raw: SKIP, cavv: SKIP, xid: SKIP, transaction_id: SKIP, strong_authentication: SKIP, additional_properties: nil) ⇒ ConsumerAuthenticationInformation4

Returns a new instance of ConsumerAuthenticationInformation4.



59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/visa_acceptance_merged_spec/models/consumer_authentication_information4.rb', line 59

def initialize(eci_raw: SKIP, cavv: SKIP, xid: SKIP, transaction_id: SKIP,
               strong_authentication: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @eci_raw = eci_raw unless eci_raw == SKIP
  @cavv = cavv unless cavv == SKIP
  @xid = xid unless xid == SKIP
  @transaction_id = transaction_id unless transaction_id == SKIP
  @strong_authentication = strong_authentication unless strong_authentication == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#cavvString

Cardholder authentication verification value (CAVV).

Returns:

  • (String)


18
19
20
# File 'lib/visa_acceptance_merged_spec/models/consumer_authentication_information4.rb', line 18

def cavv
  @cavv
end

#eci_rawString

Raw electronic commerce indicator (ECI).

Returns:

  • (String)


14
15
16
# File 'lib/visa_acceptance_merged_spec/models/consumer_authentication_information4.rb', line 14

def eci_raw
  @eci_raw
end

#strong_authenticationStrongAuthentication2

Payer auth Transaction identifier.



30
31
32
# File 'lib/visa_acceptance_merged_spec/models/consumer_authentication_information4.rb', line 30

def strong_authentication
  @strong_authentication
end

#transaction_idString

Payer auth Transaction identifier.

Returns:

  • (String)


26
27
28
# File 'lib/visa_acceptance_merged_spec/models/consumer_authentication_information4.rb', line 26

def transaction_id
  @transaction_id
end

#xidString

Transaction identifier.

Returns:

  • (String)


22
23
24
# File 'lib/visa_acceptance_merged_spec/models/consumer_authentication_information4.rb', line 22

def xid
  @xid
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/visa_acceptance_merged_spec/models/consumer_authentication_information4.rb', line 73

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  eci_raw = hash.key?('eciRaw') ? hash['eciRaw'] : SKIP
  cavv = hash.key?('cavv') ? hash['cavv'] : SKIP
  xid = hash.key?('xid') ? hash['xid'] : SKIP
  transaction_id = hash.key?('transactionId') ? hash['transactionId'] : SKIP
  strong_authentication = StrongAuthentication2.from_hash(hash['strongAuthentication']) if
    hash['strongAuthentication']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ConsumerAuthenticationInformation4.new(eci_raw: eci_raw,
                                         cavv: cavv,
                                         xid: xid,
                                         transaction_id: transaction_id,
                                         strong_authentication: strong_authentication,
                                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
38
39
40
41
# File 'lib/visa_acceptance_merged_spec/models/consumer_authentication_information4.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['eci_raw'] = 'eciRaw'
  @_hash['cavv'] = 'cavv'
  @_hash['xid'] = 'xid'
  @_hash['transaction_id'] = 'transactionId'
  @_hash['strong_authentication'] = 'strongAuthentication'
  @_hash
end

.nullablesObject

An array for nullable fields



55
56
57
# File 'lib/visa_acceptance_merged_spec/models/consumer_authentication_information4.rb', line 55

def self.nullables
  []
end

.optionalsObject

An array for optional fields



44
45
46
47
48
49
50
51
52
# File 'lib/visa_acceptance_merged_spec/models/consumer_authentication_information4.rb', line 44

def self.optionals
  %w[
    eci_raw
    cavv
    xid
    transaction_id
    strong_authentication
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



109
110
111
112
113
114
# File 'lib/visa_acceptance_merged_spec/models/consumer_authentication_information4.rb', line 109

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} eci_raw: #{@eci_raw.inspect}, cavv: #{@cavv.inspect}, xid: #{@xid.inspect},"\
  " transaction_id: #{@transaction_id.inspect}, strong_authentication:"\
  " #{@strong_authentication.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



101
102
103
104
105
106
# File 'lib/visa_acceptance_merged_spec/models/consumer_authentication_information4.rb', line 101

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} eci_raw: #{@eci_raw}, cavv: #{@cavv}, xid: #{@xid}, transaction_id:"\
  " #{@transaction_id}, strong_authentication: #{@strong_authentication},"\
  " additional_properties: #{@additional_properties}>"
end