Class: VisaAcceptanceMergedSpec::Content
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::Content
- Defined in:
- lib/visa_acceptance_merged_spec/models/content.rb
Overview
Content Model.
Instance Attribute Summary collapse
-
#data ⇒ String
The base64-encoded data of the Asset.
-
#height ⇒ Integer
The height of the Asset in pixels.
-
#type ⇒ String
The MIME type of the Asset.
-
#width ⇒ Integer
The width of the Asset in pixels.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(type: SKIP, data: SKIP, width: SKIP, height: SKIP, additional_properties: nil) ⇒ Content
constructor
A new instance of Content.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(type: SKIP, data: SKIP, width: SKIP, height: SKIP, additional_properties: nil) ⇒ Content
Returns a new instance of Content.
53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/visa_acceptance_merged_spec/models/content.rb', line 53 def initialize(type: SKIP, data: SKIP, width: SKIP, height: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @type = type unless type == SKIP @data = data unless data == SKIP @width = width unless width == SKIP @height = height unless height == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#data ⇒ String
The base64-encoded data of the Asset.
18 19 20 |
# File 'lib/visa_acceptance_merged_spec/models/content.rb', line 18 def data @data end |
#height ⇒ Integer
The height of the Asset in pixels.
26 27 28 |
# File 'lib/visa_acceptance_merged_spec/models/content.rb', line 26 def height @height end |
#type ⇒ String
The MIME type of the Asset.
14 15 16 |
# File 'lib/visa_acceptance_merged_spec/models/content.rb', line 14 def type @type end |
#width ⇒ Integer
The width of the Asset in pixels.
22 23 24 |
# File 'lib/visa_acceptance_merged_spec/models/content.rb', line 22 def width @width end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/visa_acceptance_merged_spec/models/content.rb', line 66 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. type = hash.key?('type') ? hash['type'] : SKIP data = hash.key?('data') ? hash['data'] : SKIP width = hash.key?('width') ? hash['width'] : SKIP height = hash.key?('height') ? hash['height'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Content.new(type: type, data: data, width: width, height: height, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/visa_acceptance_merged_spec/models/content.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['type'] = 'type' @_hash['data'] = 'data' @_hash['width'] = 'width' @_hash['height'] = 'height' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/visa_acceptance_merged_spec/models/content.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/visa_acceptance_merged_spec/models/content.rb', line 39 def self.optionals %w[ type data width height ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
98 99 100 101 102 |
# File 'lib/visa_acceptance_merged_spec/models/content.rb', line 98 def inspect class_name = self.class.name.split('::').last "<#{class_name} type: #{@type.inspect}, data: #{@data.inspect}, width: #{@width.inspect},"\ " height: #{@height.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
91 92 93 94 95 |
# File 'lib/visa_acceptance_merged_spec/models/content.rb', line 91 def to_s class_name = self.class.name.split('::').last "<#{class_name} type: #{@type}, data: #{@data}, width: #{@width}, height: #{@height},"\ " additional_properties: #{@additional_properties}>" end |