Class: VisaAcceptanceMergedSpec::CreatePaymentRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/create_payment_request.rb

Overview

CreatePaymentRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(client_reference_information: SKIP, processing_information: SKIP, issuer_information: SKIP, payment_information: SKIP, order_information: SKIP, buyer_information: SKIP, sender_information: SKIP, recipient_information: SKIP, device_information: SKIP, merchant_information: SKIP, aggregator_information: SKIP, consumer_authentication_information: SKIP, point_of_sale_information: SKIP, merchant_defined_information: SKIP, merchant_defined_secure_information: SKIP, installment_information: SKIP, travel_information: SKIP, health_care_information: SKIP, promotion_information: SKIP, token_information: SKIP, invoice_details: SKIP, processor_information: SKIP, agreement_information: SKIP, risk_information: SKIP, acquirer_information: SKIP, recurring_payment_information: SKIP, unscheduled_payment_information: SKIP, hosted_payment_information: SKIP, watchlist_screening_information: SKIP, additional_properties: nil) ⇒ CreatePaymentRequest

Returns a new instance of CreatePaymentRequest.



207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 207

def initialize(client_reference_information: SKIP,
               processing_information: SKIP, issuer_information: SKIP,
               payment_information: SKIP, order_information: SKIP,
               buyer_information: SKIP, sender_information: SKIP,
               recipient_information: SKIP, device_information: SKIP,
               merchant_information: SKIP, aggregator_information: SKIP,
               consumer_authentication_information: SKIP,
               point_of_sale_information: SKIP,
               merchant_defined_information: SKIP,
               merchant_defined_secure_information: SKIP,
               installment_information: SKIP, travel_information: SKIP,
               health_care_information: SKIP, promotion_information: SKIP,
               token_information: SKIP, invoice_details: SKIP,
               processor_information: SKIP, agreement_information: SKIP,
               risk_information: SKIP, acquirer_information: SKIP,
               recurring_payment_information: SKIP,
               unscheduled_payment_information: SKIP,
               hosted_payment_information: SKIP,
               watchlist_screening_information: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  unless client_reference_information == SKIP
    @client_reference_information =
      client_reference_information
  end
  @processing_information = processing_information unless processing_information == SKIP
  @issuer_information = issuer_information unless issuer_information == SKIP
  @payment_information = payment_information unless payment_information == SKIP
  @order_information = order_information unless order_information == SKIP
  @buyer_information = buyer_information unless buyer_information == SKIP
  @sender_information = sender_information unless sender_information == SKIP
  @recipient_information = recipient_information unless recipient_information == SKIP
  @device_information = device_information unless device_information == SKIP
  @merchant_information = merchant_information unless merchant_information == SKIP
  @aggregator_information = aggregator_information unless aggregator_information == SKIP
  unless consumer_authentication_information == SKIP
    @consumer_authentication_information =
      consumer_authentication_information
  end
  unless point_of_sale_information == SKIP
    @point_of_sale_information =
      point_of_sale_information
  end
  unless merchant_defined_information == SKIP
    @merchant_defined_information =
      merchant_defined_information
  end
  unless merchant_defined_secure_information == SKIP
    @merchant_defined_secure_information =
      merchant_defined_secure_information
  end
  @installment_information = installment_information unless installment_information == SKIP
  @travel_information = travel_information unless travel_information == SKIP
  @health_care_information = health_care_information unless health_care_information == SKIP
  @promotion_information = promotion_information unless promotion_information == SKIP
  @token_information = token_information unless token_information == SKIP
  @invoice_details = invoice_details unless invoice_details == SKIP
  @processor_information = processor_information unless processor_information == SKIP
  @agreement_information = agreement_information unless agreement_information == SKIP
  @risk_information = risk_information unless risk_information == SKIP
  @acquirer_information = acquirer_information unless acquirer_information == SKIP
  unless recurring_payment_information == SKIP
    @recurring_payment_information =
      recurring_payment_information
  end
  unless unscheduled_payment_information == SKIP
    @unscheduled_payment_information =
      unscheduled_payment_information
  end
  unless hosted_payment_information == SKIP
    @hosted_payment_information =
      hosted_payment_information
  end
  unless watchlist_screening_information == SKIP
    @watchlist_screening_information =
      watchlist_screening_information
  end
  @additional_properties = additional_properties
end

Instance Attribute Details

#acquirer_informationAcquirerInformation

The object containing the custom data that the merchant defines.

Returns:



110
111
112
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 110

def acquirer_information
  @acquirer_information
end

#aggregator_informationAggregatorInformation

TODO: Write general description for this method



54
55
56
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 54

def aggregator_information
  @aggregator_information
end

#agreement_informationAgreementInformation

The object containing the custom data that the merchant defines.



102
103
104
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 102

def agreement_information
  @agreement_information
end

#buyer_informationBuyerInformation

TODO: Write general description for this method

Returns:



34
35
36
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 34

def buyer_information
  @buyer_information
end

#client_reference_informationClientReferenceInformation

TODO: Write general description for this method



14
15
16
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 14

def client_reference_information
  @client_reference_information
end

#consumer_authentication_informationConsumerAuthenticationInformation

TODO: Write general description for this method



58
59
60
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 58

def consumer_authentication_information
  @consumer_authentication_information
end

#device_informationDeviceInformation

TODO: Write general description for this method

Returns:



46
47
48
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 46

def device_information
  @device_information
end

#health_care_informationHealthCareInformation

The object containing the custom data that the merchant defines.



82
83
84
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 82

def health_care_information
  @health_care_information
end

#hosted_payment_informationHostedPaymentInformation

The object containing the custom data that the merchant defines.



122
123
124
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 122

def hosted_payment_information
  @hosted_payment_information
end

#installment_informationInstallmentInformation

The object containing the custom data that the merchant defines.



74
75
76
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 74

def installment_information
  @installment_information
end

#invoice_detailsInvoiceDetails13

The object containing the custom data that the merchant defines.

Returns:



94
95
96
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 94

def invoice_details
  @invoice_details
end

#issuer_informationIssuerInformation

TODO: Write general description for this method

Returns:



22
23
24
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 22

def issuer_information
  @issuer_information
end

#merchant_defined_informationArray[MerchantDefinedInformation]

The object containing the custom data that the merchant defines.

Returns:



66
67
68
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 66

def merchant_defined_information
  @merchant_defined_information
end

#merchant_defined_secure_informationMerchantDefinedSecureInformation2

The object containing the custom data that the merchant defines.



70
71
72
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 70

def merchant_defined_secure_information
  @merchant_defined_secure_information
end

#merchant_informationMerchantInformation

TODO: Write general description for this method

Returns:



50
51
52
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 50

def merchant_information
  @merchant_information
end

#order_informationOrderInformation

TODO: Write general description for this method

Returns:



30
31
32
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 30

def order_information
  @order_information
end

#payment_informationPaymentInformation

TODO: Write general description for this method

Returns:



26
27
28
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 26

def payment_information
  @payment_information
end

#point_of_sale_informationPointOfSaleInformation

TODO: Write general description for this method



62
63
64
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 62

def point_of_sale_information
  @point_of_sale_information
end

#processing_informationProcessingInformation

TODO: Write general description for this method



18
19
20
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 18

def processing_information
  @processing_information
end

#processor_informationProcessorInformation5

The object containing the custom data that the merchant defines.



98
99
100
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 98

def processor_information
  @processor_information
end

#promotion_informationPromotionInformation

The object containing the custom data that the merchant defines.



86
87
88
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 86

def promotion_information
  @promotion_information
end

#recipient_informationRecipientInformation

TODO: Write general description for this method



42
43
44
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 42

def recipient_information
  @recipient_information
end

#recurring_payment_informationRecurringPaymentInformation2

The object containing the custom data that the merchant defines.



114
115
116
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 114

def recurring_payment_information
  @recurring_payment_information
end

#risk_informationRiskInformation3

The object containing the custom data that the merchant defines.

Returns:



106
107
108
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 106

def risk_information
  @risk_information
end

#sender_informationSenderInformation

TODO: Write general description for this method

Returns:



38
39
40
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 38

def sender_information
  @sender_information
end

#token_informationTokenInformation

The object containing the custom data that the merchant defines.

Returns:



90
91
92
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 90

def token_information
  @token_information
end

#travel_informationTravelInformation

The object containing the custom data that the merchant defines.

Returns:



78
79
80
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 78

def travel_information
  @travel_information
end

#unscheduled_payment_informationUnscheduledPaymentInformation

The object containing the custom data that the merchant defines.



118
119
120
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 118

def unscheduled_payment_information
  @unscheduled_payment_information
end

#watchlist_screening_informationWatchlistScreeningInformation

The object containing the custom data that the merchant defines.



126
127
128
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 126

def watchlist_screening_information
  @watchlist_screening_information
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 290

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  if hash['clientReferenceInformation']
    client_reference_information = ClientReferenceInformation.from_hash(hash['clientReferenceInformation'])
  end
  processing_information = ProcessingInformation.from_hash(hash['processingInformation']) if
    hash['processingInformation']
  issuer_information = IssuerInformation.from_hash(hash['issuerInformation']) if
    hash['issuerInformation']
  payment_information = PaymentInformation.from_hash(hash['paymentInformation']) if
    hash['paymentInformation']
  order_information = OrderInformation.from_hash(hash['orderInformation']) if
    hash['orderInformation']
  buyer_information = BuyerInformation.from_hash(hash['buyerInformation']) if
    hash['buyerInformation']
  sender_information = SenderInformation.from_hash(hash['senderInformation']) if
    hash['senderInformation']
  recipient_information = RecipientInformation.from_hash(hash['recipientInformation']) if
    hash['recipientInformation']
  device_information = DeviceInformation.from_hash(hash['deviceInformation']) if
    hash['deviceInformation']
  merchant_information = MerchantInformation.from_hash(hash['merchantInformation']) if
    hash['merchantInformation']
  aggregator_information = AggregatorInformation.from_hash(hash['aggregatorInformation']) if
    hash['aggregatorInformation']
  if hash['consumerAuthenticationInformation']
    consumer_authentication_information = ConsumerAuthenticationInformation.from_hash(hash['consumerAuthenticationInformation'])
  end
  if hash['pointOfSaleInformation']
    point_of_sale_information = PointOfSaleInformation.from_hash(hash['pointOfSaleInformation'])
  end
  # Parameter is an array, so we need to iterate through it
  merchant_defined_information = nil
  unless hash['merchantDefinedInformation'].nil?
    merchant_defined_information = []
    hash['merchantDefinedInformation'].each do |structure|
      merchant_defined_information << (MerchantDefinedInformation.from_hash(structure) if structure)
    end
  end

  merchant_defined_information = SKIP unless hash.key?('merchantDefinedInformation')
  if hash['merchantDefinedSecureInformation']
    merchant_defined_secure_information = MerchantDefinedSecureInformation2.from_hash(hash['merchantDefinedSecureInformation'])
  end
  installment_information = InstallmentInformation.from_hash(hash['installmentInformation']) if
    hash['installmentInformation']
  travel_information = TravelInformation.from_hash(hash['travelInformation']) if
    hash['travelInformation']
  health_care_information = HealthCareInformation.from_hash(hash['healthCareInformation']) if
    hash['healthCareInformation']
  promotion_information = PromotionInformation.from_hash(hash['promotionInformation']) if
    hash['promotionInformation']
  token_information = TokenInformation.from_hash(hash['tokenInformation']) if
    hash['tokenInformation']
  invoice_details = InvoiceDetails13.from_hash(hash['invoiceDetails']) if
    hash['invoiceDetails']
  processor_information = ProcessorInformation5.from_hash(hash['processorInformation']) if
    hash['processorInformation']
  agreement_information = AgreementInformation.from_hash(hash['agreementInformation']) if
    hash['agreementInformation']
  risk_information = RiskInformation3.from_hash(hash['riskInformation']) if
    hash['riskInformation']
  acquirer_information = AcquirerInformation.from_hash(hash['acquirerInformation']) if
    hash['acquirerInformation']
  if hash['recurringPaymentInformation']
    recurring_payment_information = RecurringPaymentInformation2.from_hash(hash['recurringPaymentInformation'])
  end
  if hash['unscheduledPaymentInformation']
    unscheduled_payment_information = UnscheduledPaymentInformation.from_hash(hash['unscheduledPaymentInformation'])
  end
  if hash['hostedPaymentInformation']
    hosted_payment_information = HostedPaymentInformation.from_hash(hash['hostedPaymentInformation'])
  end
  if hash['watchlistScreeningInformation']
    watchlist_screening_information = WatchlistScreeningInformation.from_hash(hash['watchlistScreeningInformation'])
  end

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CreatePaymentRequest.new(client_reference_information: client_reference_information,
                           processing_information: processing_information,
                           issuer_information: issuer_information,
                           payment_information: payment_information,
                           order_information: order_information,
                           buyer_information: buyer_information,
                           sender_information: sender_information,
                           recipient_information: recipient_information,
                           device_information: device_information,
                           merchant_information: merchant_information,
                           aggregator_information: aggregator_information,
                           consumer_authentication_information: consumer_authentication_information,
                           point_of_sale_information: point_of_sale_information,
                           merchant_defined_information: merchant_defined_information,
                           merchant_defined_secure_information: merchant_defined_secure_information,
                           installment_information: installment_information,
                           travel_information: travel_information,
                           health_care_information: health_care_information,
                           promotion_information: promotion_information,
                           token_information: token_information,
                           invoice_details: invoice_details,
                           processor_information: processor_information,
                           agreement_information: agreement_information,
                           risk_information: risk_information,
                           acquirer_information: acquirer_information,
                           recurring_payment_information: recurring_payment_information,
                           unscheduled_payment_information: unscheduled_payment_information,
                           hosted_payment_information: hosted_payment_information,
                           watchlist_screening_information: watchlist_screening_information,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 129

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_reference_information'] = 'clientReferenceInformation'
  @_hash['processing_information'] = 'processingInformation'
  @_hash['issuer_information'] = 'issuerInformation'
  @_hash['payment_information'] = 'paymentInformation'
  @_hash['order_information'] = 'orderInformation'
  @_hash['buyer_information'] = 'buyerInformation'
  @_hash['sender_information'] = 'senderInformation'
  @_hash['recipient_information'] = 'recipientInformation'
  @_hash['device_information'] = 'deviceInformation'
  @_hash['merchant_information'] = 'merchantInformation'
  @_hash['aggregator_information'] = 'aggregatorInformation'
  @_hash['consumer_authentication_information'] =
    'consumerAuthenticationInformation'
  @_hash['point_of_sale_information'] = 'pointOfSaleInformation'
  @_hash['merchant_defined_information'] = 'merchantDefinedInformation'
  @_hash['merchant_defined_secure_information'] =
    'merchantDefinedSecureInformation'
  @_hash['installment_information'] = 'installmentInformation'
  @_hash['travel_information'] = 'travelInformation'
  @_hash['health_care_information'] = 'healthCareInformation'
  @_hash['promotion_information'] = 'promotionInformation'
  @_hash['token_information'] = 'tokenInformation'
  @_hash['invoice_details'] = 'invoiceDetails'
  @_hash['processor_information'] = 'processorInformation'
  @_hash['agreement_information'] = 'agreementInformation'
  @_hash['risk_information'] = 'riskInformation'
  @_hash['acquirer_information'] = 'acquirerInformation'
  @_hash['recurring_payment_information'] = 'recurringPaymentInformation'
  @_hash['unscheduled_payment_information'] =
    'unscheduledPaymentInformation'
  @_hash['hosted_payment_information'] = 'hostedPaymentInformation'
  @_hash['watchlist_screening_information'] =
    'watchlistScreeningInformation'
  @_hash
end

.nullablesObject

An array for nullable fields



203
204
205
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 203

def self.nullables
  []
end

.optionalsObject

An array for optional fields



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 168

def self.optionals
  %w[
    client_reference_information
    processing_information
    issuer_information
    payment_information
    order_information
    buyer_information
    sender_information
    recipient_information
    device_information
    merchant_information
    aggregator_information
    consumer_authentication_information
    point_of_sale_information
    merchant_defined_information
    merchant_defined_secure_information
    installment_information
    travel_information
    health_care_information
    promotion_information
    token_information
    invoice_details
    processor_information
    agreement_information
    risk_information
    acquirer_information
    recurring_payment_information
    unscheduled_payment_information
    hosted_payment_information
    watchlist_screening_information
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 436

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_reference_information: #{@client_reference_information.inspect},"\
  " processing_information: #{@processing_information.inspect}, issuer_information:"\
  " #{@issuer_information.inspect}, payment_information: #{@payment_information.inspect},"\
  " order_information: #{@order_information.inspect}, buyer_information:"\
  " #{@buyer_information.inspect}, sender_information: #{@sender_information.inspect},"\
  " recipient_information: #{@recipient_information.inspect}, device_information:"\
  " #{@device_information.inspect}, merchant_information: #{@merchant_information.inspect},"\
  " aggregator_information: #{@aggregator_information.inspect},"\
  " consumer_authentication_information: #{@consumer_authentication_information.inspect},"\
  " point_of_sale_information: #{@point_of_sale_information.inspect},"\
  " merchant_defined_information: #{@merchant_defined_information.inspect},"\
  " merchant_defined_secure_information: #{@merchant_defined_secure_information.inspect},"\
  " installment_information: #{@installment_information.inspect}, travel_information:"\
  " #{@travel_information.inspect}, health_care_information:"\
  " #{@health_care_information.inspect}, promotion_information:"\
  " #{@promotion_information.inspect}, token_information: #{@token_information.inspect},"\
  " invoice_details: #{@invoice_details.inspect}, processor_information:"\
  " #{@processor_information.inspect}, agreement_information:"\
  " #{@agreement_information.inspect}, risk_information: #{@risk_information.inspect},"\
  " acquirer_information: #{@acquirer_information.inspect}, recurring_payment_information:"\
  " #{@recurring_payment_information.inspect}, unscheduled_payment_information:"\
  " #{@unscheduled_payment_information.inspect}, hosted_payment_information:"\
  " #{@hosted_payment_information.inspect}, watchlist_screening_information:"\
  " #{@watchlist_screening_information.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
# File 'lib/visa_acceptance_merged_spec/models/create_payment_request.rb', line 410

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_reference_information: #{@client_reference_information},"\
  " processing_information: #{@processing_information}, issuer_information:"\
  " #{@issuer_information}, payment_information: #{@payment_information}, order_information:"\
  " #{@order_information}, buyer_information: #{@buyer_information}, sender_information:"\
  " #{@sender_information}, recipient_information: #{@recipient_information},"\
  " device_information: #{@device_information}, merchant_information:"\
  " #{@merchant_information}, aggregator_information: #{@aggregator_information},"\
  " consumer_authentication_information: #{@consumer_authentication_information},"\
  " point_of_sale_information: #{@point_of_sale_information}, merchant_defined_information:"\
  " #{@merchant_defined_information}, merchant_defined_secure_information:"\
  " #{@merchant_defined_secure_information}, installment_information:"\
  " #{@installment_information}, travel_information: #{@travel_information},"\
  " health_care_information: #{@health_care_information}, promotion_information:"\
  " #{@promotion_information}, token_information: #{@token_information}, invoice_details:"\
  " #{@invoice_details}, processor_information: #{@processor_information},"\
  " agreement_information: #{@agreement_information}, risk_information: #{@risk_information},"\
  " acquirer_information: #{@acquirer_information}, recurring_payment_information:"\
  " #{@recurring_payment_information}, unscheduled_payment_information:"\
  " #{@unscheduled_payment_information}, hosted_payment_information:"\
  " #{@hosted_payment_information}, watchlist_screening_information:"\
  " #{@watchlist_screening_information}, additional_properties: #{@additional_properties}>"
end