Class: VisaAcceptanceMergedSpec::Customer10

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/customer10.rb

Overview

Customer10 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(customer_id: SKIP, additional_properties: nil) ⇒ Customer10

Returns a new instance of Customer10.



47
48
49
50
51
52
53
# File 'lib/visa_acceptance_merged_spec/models/customer10.rb', line 47

def initialize(customer_id: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @customer_id = customer_id unless customer_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#customer_idString

Unique identifier for the customer's card and billing information. When you use Payment Tokenization or Recurring Billing and you include this value in your request, many of the fields that are normally required for an authorization or credit become optional. NOTE When you use Payment Tokenization or Recurring Billing, the value for the Customer ID is actually the Visa Acceptance payment token for a customer. This token stores information such as the consumer’s card number so it can be applied towards bill payments, recurring payments, or one-time payments. By using this token in a payment API request, the merchant doesn't need to pass in data such as the card number or expiration date in the request itself.

Returns:

  • (String)


26
27
28
# File 'lib/visa_acceptance_merged_spec/models/customer10.rb', line 26

def customer_id
  @customer_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/visa_acceptance_merged_spec/models/customer10.rb', line 56

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  customer_id = hash.key?('customerId') ? hash['customerId'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Customer10.new(customer_id: customer_id,
                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
# File 'lib/visa_acceptance_merged_spec/models/customer10.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['customer_id'] = 'customerId'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/visa_acceptance_merged_spec/models/customer10.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



36
37
38
39
40
# File 'lib/visa_acceptance_merged_spec/models/customer10.rb', line 36

def self.optionals
  %w[
    customer_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



82
83
84
85
86
# File 'lib/visa_acceptance_merged_spec/models/customer10.rb', line 82

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} customer_id: #{@customer_id.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



75
76
77
78
79
# File 'lib/visa_acceptance_merged_spec/models/customer10.rb', line 75

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} customer_id: #{@customer_id}, additional_properties:"\
  " #{@additional_properties}>"
end