Class: VisaAcceptanceMergedSpec::Detail
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::Detail
- Defined in:
- lib/visa_acceptance_merged_spec/models/detail.rb
Overview
Detail Model.
Instance Attribute Summary collapse
-
#field ⇒ String
This is the flattened JSON object field name/path that is either missing or invalid.
-
#reason ⇒ String
Possible reasons for the error.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(field: SKIP, reason: SKIP, additional_properties: nil) ⇒ Detail
constructor
A new instance of Detail.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(field: SKIP, reason: SKIP, additional_properties: nil) ⇒ Detail
Returns a new instance of Detail.
45 46 47 48 49 50 51 52 |
# File 'lib/visa_acceptance_merged_spec/models/detail.rb', line 45 def initialize(field: SKIP, reason: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @field = field unless field == SKIP @reason = reason unless reason == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#field ⇒ String
This is the flattened JSON object field name/path that is either missing or invalid.
15 16 17 |
# File 'lib/visa_acceptance_merged_spec/models/detail.rb', line 15 def field @field end |
#reason ⇒ String
Possible reasons for the error. Possible values:
- MISSING_FIELD
- INVALID_DATA
22 23 24 |
# File 'lib/visa_acceptance_merged_spec/models/detail.rb', line 22 def reason @reason end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/visa_acceptance_merged_spec/models/detail.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. field = hash.key?('field') ? hash['field'] : SKIP reason = hash.key?('reason') ? hash['reason'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Detail.new(field: field, reason: reason, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 |
# File 'lib/visa_acceptance_merged_spec/models/detail.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['field'] = 'field' @_hash['reason'] = 'reason' @_hash end |
.nullables ⇒ Object
An array for nullable fields
41 42 43 |
# File 'lib/visa_acceptance_merged_spec/models/detail.rb', line 41 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
33 34 35 36 37 38 |
# File 'lib/visa_acceptance_merged_spec/models/detail.rb', line 33 def self.optionals %w[ field reason ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
83 84 85 86 87 |
# File 'lib/visa_acceptance_merged_spec/models/detail.rb', line 83 def inspect class_name = self.class.name.split('::').last "<#{class_name} field: #{@field.inspect}, reason: #{@reason.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
76 77 78 79 80 |
# File 'lib/visa_acceptance_merged_spec/models/detail.rb', line 76 def to_s class_name = self.class.name.split('::').last "<#{class_name} field: #{@field}, reason: #{@reason}, additional_properties:"\ " #{@additional_properties}>" end |