Class: VisaAcceptanceMergedSpec::EWallet1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::EWallet1
- Defined in:
- lib/visa_acceptance_merged_spec/models/e_wallet1.rb
Overview
EWallet1 Model.
Instance Attribute Summary collapse
-
#account_id ⇒ String
The ID of the customer, passed in the return_url field by PayPal after customer approval.
-
#funding_source ⇒ String
Payment mode for the reference transaction.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(funding_source: SKIP, account_id: SKIP, additional_properties: nil) ⇒ EWallet1
constructor
A new instance of EWallet1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(funding_source: SKIP, account_id: SKIP, additional_properties: nil) ⇒ EWallet1
Returns a new instance of EWallet1.
47 48 49 50 51 52 53 54 55 |
# File 'lib/visa_acceptance_merged_spec/models/e_wallet1.rb', line 47 def initialize(funding_source: SKIP, account_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @funding_source = funding_source unless funding_source == SKIP @account_id = account_id unless account_id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
The ID of the customer, passed in the return_url field by PayPal after customer approval.
24 25 26 |
# File 'lib/visa_acceptance_merged_spec/models/e_wallet1.rb', line 24 def account_id @account_id end |
#funding_source ⇒ String
Payment mode for the reference transaction. Possible values:
INSTANT_TRANSFERMANUAL_BANK_TRANSFERDELAYED_TRANSFERECHECK
19 20 21 |
# File 'lib/visa_acceptance_merged_spec/models/e_wallet1.rb', line 19 def funding_source @funding_source end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/visa_acceptance_merged_spec/models/e_wallet1.rb', line 58 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. funding_source = hash.key?('fundingSource') ? hash['fundingSource'] : SKIP account_id = hash.key?('accountId') ? hash['accountId'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. EWallet1.new(funding_source: funding_source, account_id: account_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
27 28 29 30 31 32 |
# File 'lib/visa_acceptance_merged_spec/models/e_wallet1.rb', line 27 def self.names @_hash = {} if @_hash.nil? @_hash['funding_source'] = 'fundingSource' @_hash['account_id'] = 'accountId' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/visa_acceptance_merged_spec/models/e_wallet1.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 38 39 40 |
# File 'lib/visa_acceptance_merged_spec/models/e_wallet1.rb', line 35 def self.optionals %w[ funding_source account_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
86 87 88 89 90 |
# File 'lib/visa_acceptance_merged_spec/models/e_wallet1.rb', line 86 def inspect class_name = self.class.name.split('::').last "<#{class_name} funding_source: #{@funding_source.inspect}, account_id:"\ " #{@account_id.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
79 80 81 82 83 |
# File 'lib/visa_acceptance_merged_spec/models/e_wallet1.rb', line 79 def to_s class_name = self.class.name.split('::').last "<#{class_name} funding_source: #{@funding_source}, account_id: #{@account_id},"\ " additional_properties: #{@additional_properties}>" end |