Class: VisaAcceptanceMergedSpec::EWallet7
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::EWallet7
- Defined in:
- lib/visa_acceptance_merged_spec/models/e_wallet7.rb
Overview
EWallet7 Model.
Instance Attribute Summary collapse
-
#account_id ⇒ String
The ID of the customer, passed in the return_url field by PayPal after customer approval.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_id: SKIP, additional_properties: nil) ⇒ EWallet7
constructor
A new instance of EWallet7.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_id: SKIP, additional_properties: nil) ⇒ EWallet7
Returns a new instance of EWallet7.
36 37 38 39 40 41 42 |
# File 'lib/visa_acceptance_merged_spec/models/e_wallet7.rb', line 36 def initialize(account_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @account_id = account_id unless account_id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
The ID of the customer, passed in the return_url field by PayPal after customer approval.
15 16 17 |
# File 'lib/visa_acceptance_merged_spec/models/e_wallet7.rb', line 15 def account_id @account_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/visa_acceptance_merged_spec/models/e_wallet7.rb', line 45 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_id = hash.key?('accountId') ? hash['accountId'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. EWallet7.new(account_id: account_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
18 19 20 21 22 |
# File 'lib/visa_acceptance_merged_spec/models/e_wallet7.rb', line 18 def self.names @_hash = {} if @_hash.nil? @_hash['account_id'] = 'accountId' @_hash end |
.nullables ⇒ Object
An array for nullable fields
32 33 34 |
# File 'lib/visa_acceptance_merged_spec/models/e_wallet7.rb', line 32 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
25 26 27 28 29 |
# File 'lib/visa_acceptance_merged_spec/models/e_wallet7.rb', line 25 def self.optionals %w[ account_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
71 72 73 74 75 |
# File 'lib/visa_acceptance_merged_spec/models/e_wallet7.rb', line 71 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_id: #{@account_id.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
64 65 66 67 68 |
# File 'lib/visa_acceptance_merged_spec/models/e_wallet7.rb', line 64 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_id: #{@account_id}, additional_properties:"\ " #{@additional_properties}>" end |