Class: VisaAcceptanceMergedSpec::ElectronicBenefitsTransfer1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/electronic_benefits_transfer1.rb

Overview

ElectronicBenefitsTransfer1 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(category: SKIP, additional_properties: nil) ⇒ ElectronicBenefitsTransfer1

Returns a new instance of ElectronicBenefitsTransfer1.



44
45
46
47
48
49
50
# File 'lib/visa_acceptance_merged_spec/models/electronic_benefits_transfer1.rb', line 44

def initialize(category: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @category = category unless category == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#categoryString

Flag that specifies the category for the EBT transaction. Possible values:

  • CASH: Cash benefits, which can be used to purchase any item at a participating retailer, as well as to obtain cash-back or make a cash withdrawal from a participating ATM.
  • FOOD: Food stamp benefits, which can be used only to purchase food items authorized by the USDA SNAP program.

PIN debit

Required field for EBT transactions that use PIN debit credit or PIN debit purchase; otherwise, not used.

Returns:

  • (String)


23
24
25
# File 'lib/visa_acceptance_merged_spec/models/electronic_benefits_transfer1.rb', line 23

def category
  @category
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/visa_acceptance_merged_spec/models/electronic_benefits_transfer1.rb', line 53

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  category = hash.key?('category') ? hash['category'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ElectronicBenefitsTransfer1.new(category: category,
                                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
# File 'lib/visa_acceptance_merged_spec/models/electronic_benefits_transfer1.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['category'] = 'category'
  @_hash
end

.nullablesObject

An array for nullable fields



40
41
42
# File 'lib/visa_acceptance_merged_spec/models/electronic_benefits_transfer1.rb', line 40

def self.nullables
  []
end

.optionalsObject

An array for optional fields



33
34
35
36
37
# File 'lib/visa_acceptance_merged_spec/models/electronic_benefits_transfer1.rb', line 33

def self.optionals
  %w[
    category
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



78
79
80
81
82
# File 'lib/visa_acceptance_merged_spec/models/electronic_benefits_transfer1.rb', line 78

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} category: #{@category.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
# File 'lib/visa_acceptance_merged_spec/models/electronic_benefits_transfer1.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} category: #{@category}, additional_properties: #{@additional_properties}>"
end