Class: VisaAcceptanceMergedSpec::ElectronicVerificationResults1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/electronic_verification_results1.rb

Overview

ElectronicVerificationResults1 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(email: SKIP, email_raw: SKIP, name: SKIP, name_raw: SKIP, phone_number: SKIP, phone_number_raw: SKIP, street: SKIP, street_raw: SKIP, postal_code: SKIP, postal_code_raw: SKIP, additional_properties: nil) ⇒ ElectronicVerificationResults1

Returns a new instance of ElectronicVerificationResults1.



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/visa_acceptance_merged_spec/models/electronic_verification_results1.rb', line 108

def initialize(email: SKIP, email_raw: SKIP, name: SKIP, name_raw: SKIP,
               phone_number: SKIP, phone_number_raw: SKIP, street: SKIP,
               street_raw: SKIP, postal_code: SKIP, postal_code_raw: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @email = email unless email == SKIP
  @email_raw = email_raw unless email_raw == SKIP
  @name = name unless name == SKIP
  @name_raw = name_raw unless name_raw == SKIP
  @phone_number = phone_number unless phone_number == SKIP
  @phone_number_raw = phone_number_raw unless phone_number_raw == SKIP
  @street = street unless street == SKIP
  @street_raw = street_raw unless street_raw == SKIP
  @postal_code = postal_code unless postal_code == SKIP
  @postal_code_raw = postal_code_raw unless postal_code_raw == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#emailString

Mapped Electronic Verification response code for the customer’s email address.

Returns:

  • (String)


15
16
17
# File 'lib/visa_acceptance_merged_spec/models/electronic_verification_results1.rb', line 15

def email
  @email
end

#email_rawString

Raw Electronic Verification response code from the processor for the customer’s email address.

Returns:

  • (String)


20
21
22
# File 'lib/visa_acceptance_merged_spec/models/electronic_verification_results1.rb', line 20

def email_raw
  @email_raw
end

#nameString

Visa Platform Connect

Mapped Electronic Verification response code for the customer’s name. Valid values : 'Y' Yes, the data Matches 'N' No Match 'O' Partial Match

Returns:

  • (String)


29
30
31
# File 'lib/visa_acceptance_merged_spec/models/electronic_verification_results1.rb', line 29

def name
  @name
end

#name_rawString

Visa Platform Connect

Raw Electronic Verification response code from the processor for the customer’s name. Valid values : '01' Match '50' Partial Match '99' No Match

Returns:

  • (String)


39
40
41
# File 'lib/visa_acceptance_merged_spec/models/electronic_verification_results1.rb', line 39

def name_raw
  @name_raw
end

#phone_numberString

Mapped Electronic Verification response code for the customer’s phone number.

Returns:

  • (String)


44
45
46
# File 'lib/visa_acceptance_merged_spec/models/electronic_verification_results1.rb', line 44

def phone_number
  @phone_number
end

#phone_number_rawString

Raw Electronic Verification response code from the processor for the customer’s phone number.

Returns:

  • (String)


49
50
51
# File 'lib/visa_acceptance_merged_spec/models/electronic_verification_results1.rb', line 49

def phone_number_raw
  @phone_number_raw
end

#postal_codeString

Mapped Electronic Verification response code for the customer’s postal code.

Returns:

  • (String)


64
65
66
# File 'lib/visa_acceptance_merged_spec/models/electronic_verification_results1.rb', line 64

def postal_code
  @postal_code
end

#postal_code_rawString

Raw Electronic Verification response code from the processor for the customer’s postal code.

Returns:

  • (String)


69
70
71
# File 'lib/visa_acceptance_merged_spec/models/electronic_verification_results1.rb', line 69

def postal_code_raw
  @postal_code_raw
end

#streetString

Mapped Electronic Verification response code for the customer’s street address.

Returns:

  • (String)


54
55
56
# File 'lib/visa_acceptance_merged_spec/models/electronic_verification_results1.rb', line 54

def street
  @street
end

#street_rawString

Raw Electronic Verification response code from the processor for the customer’s street address.

Returns:

  • (String)


59
60
61
# File 'lib/visa_acceptance_merged_spec/models/electronic_verification_results1.rb', line 59

def street_raw
  @street_raw
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/visa_acceptance_merged_spec/models/electronic_verification_results1.rb', line 129

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  email = hash.key?('email') ? hash['email'] : SKIP
  email_raw = hash.key?('emailRaw') ? hash['emailRaw'] : SKIP
  name = hash.key?('name') ? hash['name'] : SKIP
  name_raw = hash.key?('nameRaw') ? hash['nameRaw'] : SKIP
  phone_number = hash.key?('phoneNumber') ? hash['phoneNumber'] : SKIP
  phone_number_raw =
    hash.key?('phoneNumberRaw') ? hash['phoneNumberRaw'] : SKIP
  street = hash.key?('street') ? hash['street'] : SKIP
  street_raw = hash.key?('streetRaw') ? hash['streetRaw'] : SKIP
  postal_code = hash.key?('postalCode') ? hash['postalCode'] : SKIP
  postal_code_raw =
    hash.key?('postalCodeRaw') ? hash['postalCodeRaw'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ElectronicVerificationResults1.new(email: email,
                                     email_raw: email_raw,
                                     name: name,
                                     name_raw: name_raw,
                                     phone_number: phone_number,
                                     phone_number_raw: phone_number_raw,
                                     street: street,
                                     street_raw: street_raw,
                                     postal_code: postal_code,
                                     postal_code_raw: postal_code_raw,
                                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/visa_acceptance_merged_spec/models/electronic_verification_results1.rb', line 72

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['email'] = 'email'
  @_hash['email_raw'] = 'emailRaw'
  @_hash['name'] = 'name'
  @_hash['name_raw'] = 'nameRaw'
  @_hash['phone_number'] = 'phoneNumber'
  @_hash['phone_number_raw'] = 'phoneNumberRaw'
  @_hash['street'] = 'street'
  @_hash['street_raw'] = 'streetRaw'
  @_hash['postal_code'] = 'postalCode'
  @_hash['postal_code_raw'] = 'postalCodeRaw'
  @_hash
end

.nullablesObject

An array for nullable fields



104
105
106
# File 'lib/visa_acceptance_merged_spec/models/electronic_verification_results1.rb', line 104

def self.nullables
  []
end

.optionalsObject

An array for optional fields



88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/visa_acceptance_merged_spec/models/electronic_verification_results1.rb', line 88

def self.optionals
  %w[
    email
    email_raw
    name
    name_raw
    phone_number
    phone_number_raw
    street
    street_raw
    postal_code
    postal_code_raw
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



177
178
179
180
181
182
183
184
# File 'lib/visa_acceptance_merged_spec/models/electronic_verification_results1.rb', line 177

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} email: #{@email.inspect}, email_raw: #{@email_raw.inspect}, name:"\
  " #{@name.inspect}, name_raw: #{@name_raw.inspect}, phone_number: #{@phone_number.inspect},"\
  " phone_number_raw: #{@phone_number_raw.inspect}, street: #{@street.inspect}, street_raw:"\
  " #{@street_raw.inspect}, postal_code: #{@postal_code.inspect}, postal_code_raw:"\
  " #{@postal_code_raw.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



168
169
170
171
172
173
174
# File 'lib/visa_acceptance_merged_spec/models/electronic_verification_results1.rb', line 168

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} email: #{@email}, email_raw: #{@email_raw}, name: #{@name}, name_raw:"\
  " #{@name_raw}, phone_number: #{@phone_number}, phone_number_raw: #{@phone_number_raw},"\
  " street: #{@street}, street_raw: #{@street_raw}, postal_code: #{@postal_code},"\
  " postal_code_raw: #{@postal_code_raw}, additional_properties: #{@additional_properties}>"
end