Class: VisaAcceptanceMergedSpec::Emv2

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/emv2.rb

Overview

Emv2 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(tags: SKIP, additional_properties: nil) ⇒ Emv2

Returns a new instance of Emv2.



98
99
100
101
102
103
104
# File 'lib/visa_acceptance_merged_spec/models/emv2.rb', line 98

def initialize(tags: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @tags = tags unless tags == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#tagsString

EMV data that is transmitted from the chip card to the issuer, and from the issuer to the chip card. The EMV data is in the tag-length-value format and includes chip card tags, terminal tags, and transaction detail tags. For information about the individual tags, see the “Application Specification” section in the EMV 4.3 Specifications: Note Card present information about EMV applies only to credit card processing and PIN debit processing. All other card present information applies only to credit card processing. PIN debit processing is available only on FDC Nashville Global. Important The following tags contain sensitive information and must not be included in this field:

  • 56: Track 1 equivalent data
  • 57: Track 2 equivalent data
  • 5A: Application PAN
  • 5F20: Cardholder name
  • 5F24: Application expiration date (This sensitivity has been relaxed for Credit Mutuel-CIC, American Express Direct, FDC Nashville Global, First Data Merchant Solutions, and SIX)
  • 99: Transaction PIN
  • 9F0B: Cardholder name (extended)
  • 9F1F: Track 1 discretionary data
  • 9F20: Track 2 discretionary data For captures, this field is required for contact EMV transactions. Otherwise, it is optional. For credits, this field is required for contact EMV stand-alone credits and contactless EMV stand-alone credits. Otherwise, it is optional. Important For contact EMV captures, contact EMV stand-alone credits, and contactless EMV stand-alone credits, you must include the following tags in this field. For all other types of EMV transactions, the following tags are optional.
  • 95: Terminal verification results
  • 9F10: Issuer application data
  • 9F26: Application cryptogram

Visa Acceptance through VisaNet

  • In Japan: 199 bytes
  • In other countries: String (252) For Mastercard Transactions, Optionally Tag 9F60 (Authenticated Application Data) and Tag 96 (Kernel Identifier - Terminal) can be included in the Field.

GPX

This field only supports transactions from the following card types:

  • Visa
  • Mastercard
  • AMEX
  • Discover
  • Diners
  • JCB
  • Union Pay International

JCN Gateway

The following tags must be included:

  • 4F: Application identifier
  • 84: Dedicated file name Data length: 199 bytes

All other processors:

String (999)

Used by

Authorization: Optional Authorization Reversal: Optional Credit: Optional PIN Debit processing (purchase, credit and reversal): Optional

Returns:

  • (String)


77
78
79
# File 'lib/visa_acceptance_merged_spec/models/emv2.rb', line 77

def tags
  @tags
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/visa_acceptance_merged_spec/models/emv2.rb', line 107

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  tags = hash.key?('tags') ? hash['tags'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Emv2.new(tags: tags,
           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



80
81
82
83
84
# File 'lib/visa_acceptance_merged_spec/models/emv2.rb', line 80

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['tags'] = 'tags'
  @_hash
end

.nullablesObject

An array for nullable fields



94
95
96
# File 'lib/visa_acceptance_merged_spec/models/emv2.rb', line 94

def self.nullables
  []
end

.optionalsObject

An array for optional fields



87
88
89
90
91
# File 'lib/visa_acceptance_merged_spec/models/emv2.rb', line 87

def self.optionals
  %w[
    tags
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



132
133
134
135
# File 'lib/visa_acceptance_merged_spec/models/emv2.rb', line 132

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} tags: #{@tags.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



126
127
128
129
# File 'lib/visa_acceptance_merged_spec/models/emv2.rb', line 126

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} tags: #{@tags}, additional_properties: #{@additional_properties}>"
end