Class: VisaAcceptanceMergedSpec::Emv6
- Defined in:
- lib/visa_acceptance_merged_spec/models/emv6.rb
Overview
Emv6 Model.
Instance Attribute Summary collapse
-
#fallback ⇒ TrueClass | FalseClass
Indicates whether a fallback method was used to enter credit card information into the POS terminal.
-
#tags ⇒ String
EMV data that is transmitted from the chip card to the issuer, and from the issuer to the chip card.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(tags: SKIP, fallback: SKIP, additional_properties: nil) ⇒ Emv6
constructor
A new instance of Emv6.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tags: SKIP, fallback: SKIP, additional_properties: nil) ⇒ Emv6
Returns a new instance of Emv6.
117 118 119 120 121 122 123 124 |
# File 'lib/visa_acceptance_merged_spec/models/emv6.rb', line 117 def initialize(tags: SKIP, fallback: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @tags = unless == SKIP @fallback = fallback unless fallback == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#fallback ⇒ TrueClass | FalseClass
Indicates whether a fallback method was used to enter credit card information into the POS terminal. When a technical problem prevents a successful exchange of information between a chip card and a chip-capable terminal:
- Swipe the card or key the credit card information into the POS terminal.
- Use the pointOfSaleInformation.entryMode field to indicate whether the information was swiped or keyed. Possible values:
true: Fallback method was used.false(default): Fallback method was not used. This field is supported only on American Express Direct, Chase Paymentech Solutions, Visa Acceptance through VisaNet, FDC Nashville Global, GPN, JCN Gateway, OmniPay Direct, and SIX.
94 95 96 |
# File 'lib/visa_acceptance_merged_spec/models/emv6.rb', line 94 def fallback @fallback end |
#tags ⇒ String
EMV data that is transmitted from the chip card to the issuer, and from the issuer to the chip card. The EMV data is in the tag-length-value format and includes chip card tags, terminal tags, and transaction detail tags. For information about the individual tags, see the “Application Specification” section in the EMV 4.3 Specifications: Note Card present information about EMV applies only to credit card processing and PIN debit processing. All other card present information applies only to credit card processing. PIN debit processing is available only on FDC Nashville Global. Important The following tags contain sensitive information and must not be included in this field:
56: Track 1 equivalent data57: Track 2 equivalent data5A: Application PAN5F20: Cardholder name5F24: Application expiration date (This sensitivity has been relaxed for Credit Mutuel-CIC, American Express Direct, FDC Nashville Global, First Data Merchant Solutions, and SIX)99: Transaction PIN9F0B: Cardholder name (extended)9F1F: Track 1 discretionary data9F20: Track 2 discretionary data For captures, this field is required for contact EMV transactions. Otherwise, it is optional. For credits, this field is required for contact EMV stand-alone credits and contactless EMV stand-alone credits. Otherwise, it is optional. Important For contact EMV captures, contact EMV stand-alone credits, and contactless EMV stand-alone credits, you must include the following tags in this field. For all other types of EMV transactions, the following tags are optional.95: Terminal verification results9F10: Issuer application data9F26: Application cryptogram
Visa Acceptance through VisaNet
- In Japan: 199 bytes
- In other countries: String (252) For Mastercard Transactions, Optionally Tag 9F60 (Authenticated Application Data) and Tag 96 (Kernel Identifier - Terminal) can be included in the Field.
GPX
This field only supports transactions from the following card types:
- Visa
- Mastercard
- AMEX
- Discover
- Diners
- JCB
- Union Pay International
JCN Gateway
The following tags must be included:
4F: Application identifier84: Dedicated file name Data length: 199 bytes
All other processors:
String (999)
Used by
Authorization: Optional Authorization Reversal: Optional Credit: Optional PIN Debit processing (purchase, credit and reversal): Optional
77 78 79 |
# File 'lib/visa_acceptance_merged_spec/models/emv6.rb', line 77 def @tags end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/visa_acceptance_merged_spec/models/emv6.rb', line 127 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. = hash.key?('tags') ? hash['tags'] : SKIP fallback = hash.key?('fallback') ? hash['fallback'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Emv6.new(tags: , fallback: fallback, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
97 98 99 100 101 102 |
# File 'lib/visa_acceptance_merged_spec/models/emv6.rb', line 97 def self.names @_hash = {} if @_hash.nil? @_hash['tags'] = 'tags' @_hash['fallback'] = 'fallback' @_hash end |
.nullables ⇒ Object
An array for nullable fields
113 114 115 |
# File 'lib/visa_acceptance_merged_spec/models/emv6.rb', line 113 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
105 106 107 108 109 110 |
# File 'lib/visa_acceptance_merged_spec/models/emv6.rb', line 105 def self.optionals %w[ tags fallback ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
155 156 157 158 159 |
# File 'lib/visa_acceptance_merged_spec/models/emv6.rb', line 155 def inspect class_name = self.class.name.split('::').last "<#{class_name} tags: #{@tags.inspect}, fallback: #{@fallback.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
148 149 150 151 152 |
# File 'lib/visa_acceptance_merged_spec/models/emv6.rb', line 148 def to_s class_name = self.class.name.split('::').last "<#{class_name} tags: #{@tags}, fallback: #{@fallback}, additional_properties:"\ " #{@additional_properties}>" end |