Class: VisaAcceptanceMergedSpec::Error

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/error.rb

Overview

Error Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(type: SKIP, message: SKIP, details: SKIP, additional_properties: nil) ⇒ Error

Returns a new instance of Error.



54
55
56
57
58
59
60
61
62
63
# File 'lib/visa_acceptance_merged_spec/models/error.rb', line 54

def initialize(type: SKIP, message: SKIP, details: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @type = type unless type == SKIP
  @message = message unless message == SKIP
  @details = details unless details == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#detailsArray[Detail40]

The detailed message related to the type.

Returns:



29
30
31
# File 'lib/visa_acceptance_merged_spec/models/error.rb', line 29

def details
  @details
end

#messageString

The detailed message related to the type.

Returns:

  • (String)


25
26
27
# File 'lib/visa_acceptance_merged_spec/models/error.rb', line 25

def message
  @message
end

#typeString

The type of error. Possible Values:

- invalidHeaders
- missingHeaders
- invalidFields
- missingFields
- unsupportedPaymentMethodModification
- invalidCombination

Returns:

  • (String)


21
22
23
# File 'lib/visa_acceptance_merged_spec/models/error.rb', line 21

def type
  @type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/visa_acceptance_merged_spec/models/error.rb', line 66

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  type = hash.key?('type') ? hash['type'] : SKIP
  message = hash.key?('message') ? hash['message'] : SKIP
  # Parameter is an array, so we need to iterate through it
  details = nil
  unless hash['details'].nil?
    details = []
    hash['details'].each do |structure|
      details << (Detail40.from_hash(structure) if structure)
    end
  end

  details = SKIP unless hash.key?('details')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Error.new(type: type,
            message: message,
            details: details,
            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



32
33
34
35
36
37
38
# File 'lib/visa_acceptance_merged_spec/models/error.rb', line 32

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['type'] = 'type'
  @_hash['message'] = 'message'
  @_hash['details'] = 'details'
  @_hash
end

.nullablesObject

An array for nullable fields



50
51
52
# File 'lib/visa_acceptance_merged_spec/models/error.rb', line 50

def self.nullables
  []
end

.optionalsObject

An array for optional fields



41
42
43
44
45
46
47
# File 'lib/visa_acceptance_merged_spec/models/error.rb', line 41

def self.optionals
  %w[
    type
    message
    details
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



105
106
107
108
109
# File 'lib/visa_acceptance_merged_spec/models/error.rb', line 105

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type.inspect}, message: #{@message.inspect}, details:"\
  " #{@details.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



98
99
100
101
102
# File 'lib/visa_acceptance_merged_spec/models/error.rb', line 98

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type}, message: #{@message}, details: #{@details},"\
  " additional_properties: #{@additional_properties}>"
end