Class: VisaAcceptanceMergedSpec::Error2
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::Error2
- Defined in:
- lib/visa_acceptance_merged_spec/models/error2.rb
Overview
Error2 Model.
Instance Attribute Summary collapse
-
#message ⇒ String
The detailed message related to the type.
-
#type ⇒ String
The type of error.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(type: SKIP, message: SKIP, additional_properties: nil) ⇒ Error2
constructor
A new instance of Error2.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(type: SKIP, message: SKIP, additional_properties: nil) ⇒ Error2
Returns a new instance of Error2.
45 46 47 48 49 50 51 52 |
# File 'lib/visa_acceptance_merged_spec/models/error2.rb', line 45 def initialize(type: SKIP, message: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @type = type unless type == SKIP @message = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#message ⇒ String
The detailed message related to the type.
22 23 24 |
# File 'lib/visa_acceptance_merged_spec/models/error2.rb', line 22 def @message end |
#type ⇒ String
The type of error. Possible Values:
- instrumentIdentifierDeletionError
- tokenIdConflict
- conflict
18 19 20 |
# File 'lib/visa_acceptance_merged_spec/models/error2.rb', line 18 def type @type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/visa_acceptance_merged_spec/models/error2.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. type = hash.key?('type') ? hash['type'] : SKIP = hash.key?('message') ? hash['message'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Error2.new(type: type, message: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 |
# File 'lib/visa_acceptance_merged_spec/models/error2.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['type'] = 'type' @_hash['message'] = 'message' @_hash end |
.nullables ⇒ Object
An array for nullable fields
41 42 43 |
# File 'lib/visa_acceptance_merged_spec/models/error2.rb', line 41 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
33 34 35 36 37 38 |
# File 'lib/visa_acceptance_merged_spec/models/error2.rb', line 33 def self.optionals %w[ type message ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
83 84 85 86 87 |
# File 'lib/visa_acceptance_merged_spec/models/error2.rb', line 83 def inspect class_name = self.class.name.split('::').last "<#{class_name} type: #{@type.inspect}, message: #{@message.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
76 77 78 79 80 |
# File 'lib/visa_acceptance_merged_spec/models/error2.rb', line 76 def to_s class_name = self.class.name.split('::').last "<#{class_name} type: #{@type}, message: #{@message}, additional_properties:"\ " #{@additional_properties}>" end |