Class: VisaAcceptanceMergedSpec::ErrorInformation6

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/error_information6.rb

Overview

ErrorInformation6 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(reason: SKIP, message: SKIP, additional_properties: nil) ⇒ ErrorInformation6

Returns a new instance of ErrorInformation6.



41
42
43
44
45
46
47
48
# File 'lib/visa_acceptance_merged_spec/models/error_information6.rb', line 41

def initialize(reason: SKIP, message: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @reason = reason unless reason == SKIP
  @message = message unless message == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#messageString

The detailed message related to the status and reason listed above.

Returns:

  • (String)


18
19
20
# File 'lib/visa_acceptance_merged_spec/models/error_information6.rb', line 18

def message
  @message
end

#reasonString

The reason of status

Returns:

  • (String)


14
15
16
# File 'lib/visa_acceptance_merged_spec/models/error_information6.rb', line 14

def reason
  @reason
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/visa_acceptance_merged_spec/models/error_information6.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  reason = hash.key?('reason') ? hash['reason'] : SKIP
  message = hash.key?('message') ? hash['message'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ErrorInformation6.new(reason: reason,
                        message: message,
                        additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/visa_acceptance_merged_spec/models/error_information6.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['reason'] = 'reason'
  @_hash['message'] = 'message'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/visa_acceptance_merged_spec/models/error_information6.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/visa_acceptance_merged_spec/models/error_information6.rb', line 29

def self.optionals
  %w[
    reason
    message
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



79
80
81
82
83
# File 'lib/visa_acceptance_merged_spec/models/error_information6.rb', line 79

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} reason: #{@reason.inspect}, message: #{@message.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
76
# File 'lib/visa_acceptance_merged_spec/models/error_information6.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} reason: #{@reason}, message: #{@message}, additional_properties:"\
  " #{@additional_properties}>"
end