Class: VisaAcceptanceMergedSpec::EventInformation

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/event_information.rb

Overview

EventInformation Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(date: SKIP, type: SKIP, total_tickets: SKIP, additional_properties: nil) ⇒ EventInformation

Returns a new instance of EventInformation.



47
48
49
50
51
52
53
54
55
56
# File 'lib/visa_acceptance_merged_spec/models/event_information.rb', line 47

def initialize(date: SKIP, type: SKIP, total_tickets: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @date = date unless date == SKIP
  @type = type unless type == SKIP
  @total_tickets = total_tickets unless total_tickets == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#dateString

The date of the event.

Returns:

  • (String)


14
15
16
# File 'lib/visa_acceptance_merged_spec/models/event_information.rb', line 14

def date
  @date
end

#total_ticketsString

The total number of tickets for the event.

Returns:

  • (String)


22
23
24
# File 'lib/visa_acceptance_merged_spec/models/event_information.rb', line 22

def total_tickets
  @total_tickets
end

#typeString

The type of the event.

Returns:

  • (String)


18
19
20
# File 'lib/visa_acceptance_merged_spec/models/event_information.rb', line 18

def type
  @type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/visa_acceptance_merged_spec/models/event_information.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  date = hash.key?('date') ? hash['date'] : SKIP
  type = hash.key?('type') ? hash['type'] : SKIP
  total_tickets = hash.key?('totalTickets') ? hash['totalTickets'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  EventInformation.new(date: date,
                       type: type,
                       total_tickets: total_tickets,
                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/visa_acceptance_merged_spec/models/event_information.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['date'] = 'date'
  @_hash['type'] = 'type'
  @_hash['total_tickets'] = 'totalTickets'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/visa_acceptance_merged_spec/models/event_information.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/visa_acceptance_merged_spec/models/event_information.rb', line 34

def self.optionals
  %w[
    date
    type
    total_tickets
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/visa_acceptance_merged_spec/models/event_information.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} date: #{@date.inspect}, type: #{@type.inspect}, total_tickets:"\
  " #{@total_tickets.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/visa_acceptance_merged_spec/models/event_information.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} date: #{@date}, type: #{@type}, total_tickets: #{@total_tickets},"\
  " additional_properties: #{@additional_properties}>"
end