Class: VisaAcceptanceMergedSpec::FirstDeparture
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::FirstDeparture
- Defined in:
- lib/visa_acceptance_merged_spec/models/first_departure.rb
Overview
FirstDeparture Model.
Instance Attribute Summary collapse
-
#country ⇒ String
Country of first departure on the route.
-
#latitude ⇒ String
Latitude of first departure on the route.
-
#locality ⇒ String
City of first departure on the route.
-
#longitude ⇒ String
Longitude of first departure on the route.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(country: SKIP, locality: SKIP, latitude: SKIP, longitude: SKIP, additional_properties: nil) ⇒ FirstDeparture
constructor
A new instance of FirstDeparture.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(country: SKIP, locality: SKIP, latitude: SKIP, longitude: SKIP, additional_properties: nil) ⇒ FirstDeparture
Returns a new instance of FirstDeparture.
53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/visa_acceptance_merged_spec/models/first_departure.rb', line 53 def initialize(country: SKIP, locality: SKIP, latitude: SKIP, longitude: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @country = country unless country == SKIP @locality = locality unless locality == SKIP @latitude = latitude unless latitude == SKIP @longitude = longitude unless longitude == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#country ⇒ String
Country of first departure on the route.
14 15 16 |
# File 'lib/visa_acceptance_merged_spec/models/first_departure.rb', line 14 def country @country end |
#latitude ⇒ String
Latitude of first departure on the route.
22 23 24 |
# File 'lib/visa_acceptance_merged_spec/models/first_departure.rb', line 22 def latitude @latitude end |
#locality ⇒ String
City of first departure on the route.
18 19 20 |
# File 'lib/visa_acceptance_merged_spec/models/first_departure.rb', line 18 def locality @locality end |
#longitude ⇒ String
Longitude of first departure on the route.
26 27 28 |
# File 'lib/visa_acceptance_merged_spec/models/first_departure.rb', line 26 def longitude @longitude end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/visa_acceptance_merged_spec/models/first_departure.rb', line 66 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. country = hash.key?('country') ? hash['country'] : SKIP locality = hash.key?('locality') ? hash['locality'] : SKIP latitude = hash.key?('latitude') ? hash['latitude'] : SKIP longitude = hash.key?('longitude') ? hash['longitude'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. FirstDeparture.new(country: country, locality: locality, latitude: latitude, longitude: longitude, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/visa_acceptance_merged_spec/models/first_departure.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['country'] = 'country' @_hash['locality'] = 'locality' @_hash['latitude'] = 'latitude' @_hash['longitude'] = 'longitude' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/visa_acceptance_merged_spec/models/first_departure.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/visa_acceptance_merged_spec/models/first_departure.rb', line 39 def self.optionals %w[ country locality latitude longitude ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
98 99 100 101 102 103 |
# File 'lib/visa_acceptance_merged_spec/models/first_departure.rb', line 98 def inspect class_name = self.class.name.split('::').last "<#{class_name} country: #{@country.inspect}, locality: #{@locality.inspect}, latitude:"\ " #{@latitude.inspect}, longitude: #{@longitude.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
91 92 93 94 95 |
# File 'lib/visa_acceptance_merged_spec/models/first_departure.rb', line 91 def to_s class_name = self.class.name.split('::').last "<#{class_name} country: #{@country}, locality: #{@locality}, latitude: #{@latitude},"\ " longitude: #{@longitude}, additional_properties: #{@additional_properties}>" end |