Class: VisaAcceptanceMergedSpec::InstrumentIdentifier

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/instrument_identifier.rb

Overview

InstrumentIdentifier Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id: SKIP, additional_properties: nil) ⇒ InstrumentIdentifier

Returns a new instance of InstrumentIdentifier.



39
40
41
42
43
44
45
# File 'lib/visa_acceptance_merged_spec/models/instrument_identifier.rb', line 39

def initialize(id: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @id = id unless id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#idString

Unique identifier for the Instrument Identifier token used in the transaction. When you include this value in your request, many of the fields that can be supplied for an authorization or credit become optional.

Returns:

  • (String)


18
19
20
# File 'lib/visa_acceptance_merged_spec/models/instrument_identifier.rb', line 18

def id
  @id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/visa_acceptance_merged_spec/models/instrument_identifier.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  InstrumentIdentifier.new(id: id,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
# File 'lib/visa_acceptance_merged_spec/models/instrument_identifier.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash
end

.nullablesObject

An array for nullable fields



35
36
37
# File 'lib/visa_acceptance_merged_spec/models/instrument_identifier.rb', line 35

def self.nullables
  []
end

.optionalsObject

An array for optional fields



28
29
30
31
32
# File 'lib/visa_acceptance_merged_spec/models/instrument_identifier.rb', line 28

def self.optionals
  %w[
    id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



73
74
75
76
# File 'lib/visa_acceptance_merged_spec/models/instrument_identifier.rb', line 73

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



67
68
69
70
# File 'lib/visa_acceptance_merged_spec/models/instrument_identifier.rb', line 67

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, additional_properties: #{@additional_properties}>"
end