Class: VisaAcceptanceMergedSpec::Links219
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::Links219
- Defined in:
- lib/visa_acceptance_merged_spec/models/links219.rb
Overview
Links219 Model.
Instance Attribute Summary collapse
-
#mself ⇒ Self
TODO: Write general description for this method.
-
#related_transactions ⇒ Array[RelatedTransaction]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(mself: SKIP, related_transactions: SKIP, additional_properties: nil) ⇒ Links219
constructor
A new instance of Links219.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(mself: SKIP, related_transactions: SKIP, additional_properties: nil) ⇒ Links219
Returns a new instance of Links219.
41 42 43 44 45 46 47 48 49 |
# File 'lib/visa_acceptance_merged_spec/models/links219.rb', line 41 def initialize(mself: SKIP, related_transactions: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @mself = mself unless mself == SKIP @related_transactions = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#mself ⇒ Self
TODO: Write general description for this method
14 15 16 |
# File 'lib/visa_acceptance_merged_spec/models/links219.rb', line 14 def mself @mself end |
#related_transactions ⇒ Array[RelatedTransaction]
TODO: Write general description for this method
18 19 20 |
# File 'lib/visa_acceptance_merged_spec/models/links219.rb', line 18 def @related_transactions end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/visa_acceptance_merged_spec/models/links219.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. mself = Self.from_hash(hash['self']) if hash['self'] # Parameter is an array, so we need to iterate through it = nil unless hash['relatedTransactions'].nil? = [] hash['relatedTransactions'].each do |structure| << (RelatedTransaction.from_hash(structure) if structure) end end = SKIP unless hash.key?('relatedTransactions') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Links219.new(mself: mself, related_transactions: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/visa_acceptance_merged_spec/models/links219.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['mself'] = 'self' @_hash['related_transactions'] = 'relatedTransactions' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/visa_acceptance_merged_spec/models/links219.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/visa_acceptance_merged_spec/models/links219.rb', line 29 def self.optionals %w[ mself related_transactions ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/visa_acceptance_merged_spec/models/links219.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} mself: #{@mself.inspect}, related_transactions:"\ " #{@related_transactions.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/visa_acceptance_merged_spec/models/links219.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} mself: #{@mself}, related_transactions: #{@related_transactions},"\ " additional_properties: #{@additional_properties}>" end |