Class: VisaAcceptanceMergedSpec::Method12

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/method12.rb

Overview

Method12 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(type: SKIP, additional_properties: nil) ⇒ Method12

Returns a new instance of Method12.



44
45
46
47
48
49
50
# File 'lib/visa_acceptance_merged_spec/models/method12.rb', line 44

def initialize(type: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @type = type unless type == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#typeString

The payment channel that facilitates the transactions. This parameter can be used if the payment channels are listed on the merchant’s site, and the payment channel is known. Possible Values:

Via PPRO

  • alfaVa
  • kredivo
  • consumerBarCode
  • merchantQrCode
  • dokuWallet

Returns:

  • (String)


23
24
25
# File 'lib/visa_acceptance_merged_spec/models/method12.rb', line 23

def type
  @type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/visa_acceptance_merged_spec/models/method12.rb', line 53

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  type = hash.key?('type') ? hash['type'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Method12.new(type: type,
               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
# File 'lib/visa_acceptance_merged_spec/models/method12.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['type'] = 'type'
  @_hash
end

.nullablesObject

An array for nullable fields



40
41
42
# File 'lib/visa_acceptance_merged_spec/models/method12.rb', line 40

def self.nullables
  []
end

.optionalsObject

An array for optional fields



33
34
35
36
37
# File 'lib/visa_acceptance_merged_spec/models/method12.rb', line 33

def self.optionals
  %w[
    type
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



78
79
80
81
# File 'lib/visa_acceptance_merged_spec/models/method12.rb', line 78

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
# File 'lib/visa_acceptance_merged_spec/models/method12.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type}, additional_properties: #{@additional_properties}>"
end