Class: VisaAcceptanceMergedSpec::OrderInformation1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/order_information1.rb

Overview

OrderInformation1 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(amount_details: SKIP, invoice_details: SKIP, reward_points_details: SKIP, bill_to: SKIP, ship_to: SKIP, additional_properties: nil) ⇒ OrderInformation1

Returns a new instance of OrderInformation1.



59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/visa_acceptance_merged_spec/models/order_information1.rb', line 59

def initialize(amount_details: SKIP, invoice_details: SKIP,
               reward_points_details: SKIP, bill_to: SKIP, ship_to: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @amount_details = amount_details unless amount_details == SKIP
  @invoice_details = invoice_details unless invoice_details == SKIP
  @reward_points_details = reward_points_details unless reward_points_details == SKIP
  @bill_to = bill_to unless bill_to == SKIP
  @ship_to = ship_to unless ship_to == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#amount_detailsAmountDetails2

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/visa_acceptance_merged_spec/models/order_information1.rb', line 14

def amount_details
  @amount_details
end

#bill_toBillTo1

TODO: Write general description for this method

Returns:



26
27
28
# File 'lib/visa_acceptance_merged_spec/models/order_information1.rb', line 26

def bill_to
  @bill_to
end

#invoice_detailsInvoiceDetails2

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/visa_acceptance_merged_spec/models/order_information1.rb', line 18

def invoice_details
  @invoice_details
end

#reward_points_detailsRewardPointsDetails

TODO: Write general description for this method

Returns:



22
23
24
# File 'lib/visa_acceptance_merged_spec/models/order_information1.rb', line 22

def reward_points_details
  @reward_points_details
end

#ship_toShipTo1

TODO: Write general description for this method

Returns:



30
31
32
# File 'lib/visa_acceptance_merged_spec/models/order_information1.rb', line 30

def ship_to
  @ship_to
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/visa_acceptance_merged_spec/models/order_information1.rb', line 74

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  amount_details = AmountDetails2.from_hash(hash['amountDetails']) if hash['amountDetails']
  invoice_details = InvoiceDetails2.from_hash(hash['invoiceDetails']) if
    hash['invoiceDetails']
  reward_points_details = RewardPointsDetails.from_hash(hash['rewardPointsDetails']) if
    hash['rewardPointsDetails']
  bill_to = BillTo1.from_hash(hash['billTo']) if hash['billTo']
  ship_to = ShipTo1.from_hash(hash['shipTo']) if hash['shipTo']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  OrderInformation1.new(amount_details: amount_details,
                        invoice_details: invoice_details,
                        reward_points_details: reward_points_details,
                        bill_to: bill_to,
                        ship_to: ship_to,
                        additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
38
39
40
41
# File 'lib/visa_acceptance_merged_spec/models/order_information1.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['amount_details'] = 'amountDetails'
  @_hash['invoice_details'] = 'invoiceDetails'
  @_hash['reward_points_details'] = 'rewardPointsDetails'
  @_hash['bill_to'] = 'billTo'
  @_hash['ship_to'] = 'shipTo'
  @_hash
end

.nullablesObject

An array for nullable fields



55
56
57
# File 'lib/visa_acceptance_merged_spec/models/order_information1.rb', line 55

def self.nullables
  []
end

.optionalsObject

An array for optional fields



44
45
46
47
48
49
50
51
52
# File 'lib/visa_acceptance_merged_spec/models/order_information1.rb', line 44

def self.optionals
  %w[
    amount_details
    invoice_details
    reward_points_details
    bill_to
    ship_to
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



111
112
113
114
115
116
117
# File 'lib/visa_acceptance_merged_spec/models/order_information1.rb', line 111

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} amount_details: #{@amount_details.inspect}, invoice_details:"\
  " #{@invoice_details.inspect}, reward_points_details: #{@reward_points_details.inspect},"\
  " bill_to: #{@bill_to.inspect}, ship_to: #{@ship_to.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



103
104
105
106
107
108
# File 'lib/visa_acceptance_merged_spec/models/order_information1.rb', line 103

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} amount_details: #{@amount_details}, invoice_details: #{@invoice_details},"\
  " reward_points_details: #{@reward_points_details}, bill_to: #{@bill_to}, ship_to:"\
  " #{@ship_to}, additional_properties: #{@additional_properties}>"
end