Class: VisaAcceptanceMergedSpec::OrderInformation34

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/order_information34.rb

Overview

OrderInformation34 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(amount_details: SKIP, bill_to: SKIP, ship_to: SKIP, additional_properties: nil) ⇒ OrderInformation34

Returns a new instance of OrderInformation34.



47
48
49
50
51
52
53
54
55
56
# File 'lib/visa_acceptance_merged_spec/models/order_information34.rb', line 47

def initialize(amount_details: SKIP, bill_to: SKIP, ship_to: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @amount_details = amount_details unless amount_details == SKIP
  @bill_to = bill_to unless bill_to == SKIP
  @ship_to = ship_to unless ship_to == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#amount_detailsAmountDetails36

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/visa_acceptance_merged_spec/models/order_information34.rb', line 14

def amount_details
  @amount_details
end

#bill_toBillTo57

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/visa_acceptance_merged_spec/models/order_information34.rb', line 18

def bill_to
  @bill_to
end

#ship_toShipTo26

TODO: Write general description for this method

Returns:



22
23
24
# File 'lib/visa_acceptance_merged_spec/models/order_information34.rb', line 22

def ship_to
  @ship_to
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/visa_acceptance_merged_spec/models/order_information34.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  amount_details = AmountDetails36.from_hash(hash['amountDetails']) if hash['amountDetails']
  bill_to = BillTo57.from_hash(hash['billTo']) if hash['billTo']
  ship_to = ShipTo26.from_hash(hash['shipTo']) if hash['shipTo']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  OrderInformation34.new(amount_details: amount_details,
                         bill_to: bill_to,
                         ship_to: ship_to,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/visa_acceptance_merged_spec/models/order_information34.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['amount_details'] = 'amountDetails'
  @_hash['bill_to'] = 'billTo'
  @_hash['ship_to'] = 'shipTo'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/visa_acceptance_merged_spec/models/order_information34.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/visa_acceptance_merged_spec/models/order_information34.rb', line 34

def self.optionals
  %w[
    amount_details
    bill_to
    ship_to
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/visa_acceptance_merged_spec/models/order_information34.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} amount_details: #{@amount_details.inspect}, bill_to: #{@bill_to.inspect},"\
  " ship_to: #{@ship_to.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/visa_acceptance_merged_spec/models/order_information34.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} amount_details: #{@amount_details}, bill_to: #{@bill_to}, ship_to:"\
  " #{@ship_to}, additional_properties: #{@additional_properties}>"
end