Class: VisaAcceptanceMergedSpec::OrderInformation9
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::OrderInformation9
- Defined in:
- lib/visa_acceptance_merged_spec/models/order_information9.rb
Overview
OrderInformation9 Model.
Instance Attribute Summary collapse
-
#amount_details ⇒ AmountDetails12
TODO: Write general description for this method.
-
#invoice_details ⇒ InvoiceDetails5
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(amount_details: SKIP, invoice_details: SKIP, additional_properties: nil) ⇒ OrderInformation9
constructor
A new instance of OrderInformation9.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(amount_details: SKIP, invoice_details: SKIP, additional_properties: nil) ⇒ OrderInformation9
Returns a new instance of OrderInformation9.
41 42 43 44 45 46 47 48 49 |
# File 'lib/visa_acceptance_merged_spec/models/order_information9.rb', line 41 def initialize(amount_details: SKIP, invoice_details: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @amount_details = amount_details unless amount_details == SKIP @invoice_details = invoice_details unless invoice_details == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#amount_details ⇒ AmountDetails12
TODO: Write general description for this method
14 15 16 |
# File 'lib/visa_acceptance_merged_spec/models/order_information9.rb', line 14 def amount_details @amount_details end |
#invoice_details ⇒ InvoiceDetails5
TODO: Write general description for this method
18 19 20 |
# File 'lib/visa_acceptance_merged_spec/models/order_information9.rb', line 18 def invoice_details @invoice_details end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/visa_acceptance_merged_spec/models/order_information9.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. amount_details = AmountDetails12.from_hash(hash['amountDetails']) if hash['amountDetails'] invoice_details = InvoiceDetails5.from_hash(hash['invoiceDetails']) if hash['invoiceDetails'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. OrderInformation9.new(amount_details: amount_details, invoice_details: invoice_details, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/visa_acceptance_merged_spec/models/order_information9.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['amount_details'] = 'amountDetails' @_hash['invoice_details'] = 'invoiceDetails' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/visa_acceptance_merged_spec/models/order_information9.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/visa_acceptance_merged_spec/models/order_information9.rb', line 29 def self.optionals %w[ amount_details invoice_details ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
81 82 83 84 85 |
# File 'lib/visa_acceptance_merged_spec/models/order_information9.rb', line 81 def inspect class_name = self.class.name.split('::').last "<#{class_name} amount_details: #{@amount_details.inspect}, invoice_details:"\ " #{@invoice_details.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
74 75 76 77 78 |
# File 'lib/visa_acceptance_merged_spec/models/order_information9.rb', line 74 def to_s class_name = self.class.name.split('::').last "<#{class_name} amount_details: #{@amount_details}, invoice_details: #{@invoice_details},"\ " additional_properties: #{@additional_properties}>" end |