Class: VisaAcceptanceMergedSpec::OrderPaymentRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::OrderPaymentRequest
- Defined in:
- lib/visa_acceptance_merged_spec/models/order_payment_request.rb
Overview
OrderPaymentRequest Model.
Instance Attribute Summary collapse
-
#client_reference_information ⇒ ClientReferenceInformation3
TODO: Write general description for this method.
-
#order_information ⇒ OrderInformation24
TODO: Write general description for this method.
-
#payment_information ⇒ PaymentInformation20
TODO: Write general description for this method.
-
#processing_information ⇒ ProcessingInformation21
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client_reference_information: SKIP, processing_information: SKIP, payment_information: SKIP, order_information: SKIP, additional_properties: nil) ⇒ OrderPaymentRequest
constructor
A new instance of OrderPaymentRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client_reference_information: SKIP, processing_information: SKIP, payment_information: SKIP, order_information: SKIP, additional_properties: nil) ⇒ OrderPaymentRequest
Returns a new instance of OrderPaymentRequest.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/visa_acceptance_merged_spec/models/order_payment_request.rb', line 53 def initialize(client_reference_information: SKIP, processing_information: SKIP, payment_information: SKIP, order_information: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? unless client_reference_information == SKIP @client_reference_information = client_reference_information end @processing_information = processing_information unless processing_information == SKIP @payment_information = payment_information unless payment_information == SKIP @order_information = order_information unless order_information == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_reference_information ⇒ ClientReferenceInformation3
TODO: Write general description for this method
14 15 16 |
# File 'lib/visa_acceptance_merged_spec/models/order_payment_request.rb', line 14 def client_reference_information @client_reference_information end |
#order_information ⇒ OrderInformation24
TODO: Write general description for this method
26 27 28 |
# File 'lib/visa_acceptance_merged_spec/models/order_payment_request.rb', line 26 def order_information @order_information end |
#payment_information ⇒ PaymentInformation20
TODO: Write general description for this method
22 23 24 |
# File 'lib/visa_acceptance_merged_spec/models/order_payment_request.rb', line 22 def payment_information @payment_information end |
#processing_information ⇒ ProcessingInformation21
TODO: Write general description for this method
18 19 20 |
# File 'lib/visa_acceptance_merged_spec/models/order_payment_request.rb', line 18 def processing_information @processing_information end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/visa_acceptance_merged_spec/models/order_payment_request.rb', line 70 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. if hash['clientReferenceInformation'] client_reference_information = ClientReferenceInformation3.from_hash(hash['clientReferenceInformation']) end processing_information = ProcessingInformation21.from_hash(hash['processingInformation']) if hash['processingInformation'] payment_information = PaymentInformation20.from_hash(hash['paymentInformation']) if hash['paymentInformation'] order_information = OrderInformation24.from_hash(hash['orderInformation']) if hash['orderInformation'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. OrderPaymentRequest.new(client_reference_information: client_reference_information, processing_information: processing_information, payment_information: payment_information, order_information: order_information, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/visa_acceptance_merged_spec/models/order_payment_request.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['client_reference_information'] = 'clientReferenceInformation' @_hash['processing_information'] = 'processingInformation' @_hash['payment_information'] = 'paymentInformation' @_hash['order_information'] = 'orderInformation' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/visa_acceptance_merged_spec/models/order_payment_request.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/visa_acceptance_merged_spec/models/order_payment_request.rb', line 39 def self.optionals %w[ client_reference_information processing_information payment_information order_information ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
109 110 111 112 113 114 115 |
# File 'lib/visa_acceptance_merged_spec/models/order_payment_request.rb', line 109 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_reference_information: #{@client_reference_information.inspect},"\ " processing_information: #{@processing_information.inspect}, payment_information:"\ " #{@payment_information.inspect}, order_information: #{@order_information.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
100 101 102 103 104 105 106 |
# File 'lib/visa_acceptance_merged_spec/models/order_payment_request.rb', line 100 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_reference_information: #{@client_reference_information},"\ " processing_information: #{@processing_information}, payment_information:"\ " #{@payment_information}, order_information: #{@order_information}, additional_properties:"\ " #{@additional_properties}>" end |