Class: VisaAcceptanceMergedSpec::Partner2

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/partner2.rb

Overview

Partner2 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(developer_id: SKIP, solution_id: SKIP, third_party_certification_number: SKIP, additional_properties: nil) ⇒ Partner2

Returns a new instance of Partner2.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/visa_acceptance_merged_spec/models/partner2.rb', line 69

def initialize(developer_id: SKIP, solution_id: SKIP,
               third_party_certification_number: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @developer_id = developer_id unless developer_id == SKIP
  @solution_id = solution_id unless solution_id == SKIP
  unless third_party_certification_number == SKIP
    @third_party_certification_number =
      third_party_certification_number
  end
  @additional_properties = additional_properties
end

Instance Attribute Details

#developer_idString

Identifier for the developer that helped integrate a partner solution to Visa Acceptance. Send this value in all requests that are sent through the partner solutions built by that developer. Visa Acceptance assigns the ID to the developer. Note When you see a developer ID of 999 in reports, the developer ID that was submitted is incorrect.

Returns:

  • (String)


20
21
22
# File 'lib/visa_acceptance_merged_spec/models/partner2.rb', line 20

def developer_id
  @developer_id
end

#solution_idString

Identifier for the partner that is integrated to Visa Acceptance. Send this value in all requests that are sent through the partner solution. Visa Acceptance assigns the ID to the partner. Note When you see a solutionId of 999 in reports, the solutionId that was submitted is incorrect.

Returns:

  • (String)


28
29
30
# File 'lib/visa_acceptance_merged_spec/models/partner2.rb', line 28

def solution_id
  @solution_id
end

#third_party_certification_numberString

Value that identifies the application vendor and application version for a third party gateway. Visa Acceptance provides you with this value during testing and validation. This field is supported only on Visa Acceptance through VisaNet.

Used by

Authorization, Authorization Reversal, Capture, Credit, Incremental Authorization, and Void Optional field.

PIN debit

Required field for PIN debit credit, PIN debit purchase, or PIN debit reversal request.

Returns:

  • (String)


43
44
45
# File 'lib/visa_acceptance_merged_spec/models/partner2.rb', line 43

def third_party_certification_number
  @third_party_certification_number
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/visa_acceptance_merged_spec/models/partner2.rb', line 85

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  developer_id = hash.key?('developerId') ? hash['developerId'] : SKIP
  solution_id = hash.key?('solutionId') ? hash['solutionId'] : SKIP
  third_party_certification_number =
    hash.key?('thirdPartyCertificationNumber') ? hash['thirdPartyCertificationNumber'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Partner2.new(developer_id: developer_id,
               solution_id: solution_id,
               third_party_certification_number: third_party_certification_number,
               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



46
47
48
49
50
51
52
53
# File 'lib/visa_acceptance_merged_spec/models/partner2.rb', line 46

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['developer_id'] = 'developerId'
  @_hash['solution_id'] = 'solutionId'
  @_hash['third_party_certification_number'] =
    'thirdPartyCertificationNumber'
  @_hash
end

.nullablesObject

An array for nullable fields



65
66
67
# File 'lib/visa_acceptance_merged_spec/models/partner2.rb', line 65

def self.nullables
  []
end

.optionalsObject

An array for optional fields



56
57
58
59
60
61
62
# File 'lib/visa_acceptance_merged_spec/models/partner2.rb', line 56

def self.optionals
  %w[
    developer_id
    solution_id
    third_party_certification_number
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



117
118
119
120
121
122
123
# File 'lib/visa_acceptance_merged_spec/models/partner2.rb', line 117

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} developer_id: #{@developer_id.inspect}, solution_id:"\
  " #{@solution_id.inspect}, third_party_certification_number:"\
  " #{@third_party_certification_number.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



109
110
111
112
113
114
# File 'lib/visa_acceptance_merged_spec/models/partner2.rb', line 109

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} developer_id: #{@developer_id}, solution_id: #{@solution_id},"\
  " third_party_certification_number: #{@third_party_certification_number},"\
  " additional_properties: #{@additional_properties}>"
end