Class: VisaAcceptanceMergedSpec::PassiveProfile
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::PassiveProfile
- Defined in:
- lib/visa_acceptance_merged_spec/models/passive_profile.rb
Overview
PassiveProfile Model.
Instance Attribute Summary collapse
-
#decision ⇒ String
Decision returned by the profile; this field contains one of these values: - ACCEPT - REJECT - REVIEW.
-
#name ⇒ String
The name of the profile.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(name: SKIP, decision: SKIP, additional_properties: nil) ⇒ PassiveProfile
constructor
A new instance of PassiveProfile.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name: SKIP, decision: SKIP, additional_properties: nil) ⇒ PassiveProfile
Returns a new instance of PassiveProfile.
44 45 46 47 48 49 50 51 |
# File 'lib/visa_acceptance_merged_spec/models/passive_profile.rb', line 44 def initialize(name: SKIP, decision: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @name = name unless name == SKIP @decision = decision unless decision == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#decision ⇒ String
Decision returned by the profile; this field contains one of these values:
- ACCEPT
- REJECT
- REVIEW
21 22 23 |
# File 'lib/visa_acceptance_merged_spec/models/passive_profile.rb', line 21 def decision @decision end |
#name ⇒ String
The name of the profile.
14 15 16 |
# File 'lib/visa_acceptance_merged_spec/models/passive_profile.rb', line 14 def name @name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/visa_acceptance_merged_spec/models/passive_profile.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : SKIP decision = hash.key?('decision') ? hash['decision'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PassiveProfile.new(name: name, decision: decision, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
24 25 26 27 28 29 |
# File 'lib/visa_acceptance_merged_spec/models/passive_profile.rb', line 24 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash['decision'] = 'decision' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/visa_acceptance_merged_spec/models/passive_profile.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
32 33 34 35 36 37 |
# File 'lib/visa_acceptance_merged_spec/models/passive_profile.rb', line 32 def self.optionals %w[ name decision ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
82 83 84 85 86 |
# File 'lib/visa_acceptance_merged_spec/models/passive_profile.rb', line 82 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, decision: #{@decision.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
75 76 77 78 79 |
# File 'lib/visa_acceptance_merged_spec/models/passive_profile.rb', line 75 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, decision: #{@decision}, additional_properties:"\ " #{@additional_properties}>" end |