Class: VisaAcceptanceMergedSpec::PaymentInformation

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/payment_information.rb

Overview

PaymentInformation Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(card: SKIP, tokenized_card: SKIP, tokenized_payment_method: SKIP, direct_debit: SKIP, fluid_data: SKIP, customer: SKIP, payment_instrument: SKIP, instrument_identifier: SKIP, shipping_address: SKIP, legacy_token: SKIP, bank: SKIP, options: SKIP, payment_type: SKIP, initiation_channel: SKIP, sepa: SKIP, e_wallet: SKIP, payment_account_reference: SKIP, additional_properties: nil) ⇒ PaymentInformation

Returns a new instance of PaymentInformation.



387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
# File 'lib/visa_acceptance_merged_spec/models/payment_information.rb', line 387

def initialize(card: SKIP, tokenized_card: SKIP,
               tokenized_payment_method: SKIP, direct_debit: SKIP,
               fluid_data: SKIP, customer: SKIP, payment_instrument: SKIP,
               instrument_identifier: SKIP, shipping_address: SKIP,
               legacy_token: SKIP, bank: SKIP, options: SKIP,
               payment_type: SKIP, initiation_channel: SKIP, sepa: SKIP,
               e_wallet: SKIP, payment_account_reference: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @card = card unless card == SKIP
  @tokenized_card = tokenized_card unless tokenized_card == SKIP
  @tokenized_payment_method = tokenized_payment_method unless tokenized_payment_method == SKIP
  @direct_debit = direct_debit unless direct_debit == SKIP
  @fluid_data = fluid_data unless fluid_data == SKIP
  @customer = customer unless customer == SKIP
  @payment_instrument = payment_instrument unless payment_instrument == SKIP
  @instrument_identifier = instrument_identifier unless instrument_identifier == SKIP
  @shipping_address = shipping_address unless shipping_address == SKIP
  @legacy_token = legacy_token unless legacy_token == SKIP
  @bank = bank unless bank == SKIP
  @options = options unless options == SKIP
  @payment_type = payment_type unless payment_type == SKIP
  @initiation_channel = initiation_channel unless initiation_channel == SKIP
  @sepa = sepa unless sepa == SKIP
  @e_wallet = e_wallet unless e_wallet == SKIP
  unless  == SKIP
    @payment_account_reference =
      
  end
  @additional_properties = additional_properties
end

Instance Attribute Details

#bank ⇒ Bank

TODO: Write general description for this method

Returns:



54
55
56
# File 'lib/visa_acceptance_merged_spec/models/payment_information.rb', line 54

def bank
  @bank
end

#card ⇒ Card

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/visa_acceptance_merged_spec/models/payment_information.rb', line 14

def card
  @card
end

#customer ⇒ Customer

TODO: Write general description for this method

Returns:



34
35
36
# File 'lib/visa_acceptance_merged_spec/models/payment_information.rb', line 34

def customer
  @customer
end

#direct_debit ⇒ DirectDebit

TODO: Write general description for this method

Returns:



26
27
28
# File 'lib/visa_acceptance_merged_spec/models/payment_information.rb', line 26

def direct_debit
  @direct_debit
end

#e_wallet ⇒ EWallet

Mastercard-defined code that indicates how the account information was obtained.

  • 00: Card
  • 01: Mobile Network Operator (MNO) controlled removable secure element (SIM or UICC) personalized for use with a mobile phone or smartphone
  • 02: Key fob
  • 03: Watch using a contactless chip or a fixed (non-removable) secure element not controlled by the MNO
  • 04: Mobile tag
  • 05: Wristband
  • 06: Mobile phone case or sleeve
  • 07: Mobile phone or smartphone with a fixed (non-removable) secure element controlled by the MNO,for example, code division multiple access (CDMA)
  • 08: Removable secure element not controlled by the MNO, for example, memory card personalized forused with a mobile phone or smartphone
  • 09: Mobile Phone or smartphone with a fixed (non-removable) secure element not controlled by the MNO
  • 10: MNO controlled removable secure element (SIM or UICC) personalized for use with a tablet or e-book
  • 11: Tablet or e-book with a fixed (non-removable) secure element controlled by the MNO
  • 12: Removable secure element not controlled by the MNO, for example, memory card personalized foruse with a tablet or e-book
  • 13: Tablet or e-book with fixed (non-removable) secure element not controlled by the MNO
  • 14: Mobile phone or smartphone with a payment application running in a host processor
  • 15: Tablet or e-book with a payment application running in a host processor
  • 16: Mobile phone or smartphone with a payment application running in the Trusted ExecutionEnvironment (TEE) of a host processor
  • 17: Tablet or e-book with a payment application running in the TEE of a host processor
  • 18: Watch with a payment application running in the TEE of a host processor
  • 19: Watch with a payment application running in a host processor Values from 20–99 exclusively indicate the form factor only without also indicating the storage technology
  • 20: Card
  • 21: Phone e.g. Mobile Phone
  • 22: Tablet/e-reader
  • 23: Watch/Wristband e.g. Watch or wristband, including a fitness band, smart strap, disposable band, watch add-on, and security/ID band
  • 24: Sticker
  • 25: PC
  • 26: Device Peripheral e.g. mobile phone case or sleeve
  • 27: Tag e.g. key fob or mobile tag
  • 28: Jewelry e.g. ring, bracelet, necklace and cuff links
  • 29: Fashion Accessory e.g. handbag, bag charm and glasses
  • 30: Garment e.g. dress
  • 31: Domestic Appliance e.g refrigerator, washing machine
  • 32: Vehicle e.g. vehicle, including vehicle attached devices
  • 33: Media/Gaming Device e.g. media or gaming device, including a set top box, media player and television 34–99 are reserved for future form factors. Any value in this range may occur within form factor and transaction data without prior notice. This field is supported only for Mastercard on Visa Acceptance through VisaNet. When initiation channel is not provided via this API field, the value is extracted from EMV tag 9F6E for Mastercard transactions. To enable this feature please call support.

Used by

Authorization Optional field.

Returns:



266
267
268
# File 'lib/visa_acceptance_merged_spec/models/payment_information.rb', line 266

def e_wallet
  @e_wallet
end

#fluid_data ⇒ FluidData

TODO: Write general description for this method

Returns:



30
31
32
# File 'lib/visa_acceptance_merged_spec/models/payment_information.rb', line 30

def fluid_data
  @fluid_data
end

#initiation_channel ⇒ String

Mastercard-defined code that indicates how the account information was obtained.

  • 00: Card
  • 01: Mobile Network Operator (MNO) controlled removable secure element (SIM or UICC) personalized for use with a mobile phone or smartphone
  • 02: Key fob
  • 03: Watch using a contactless chip or a fixed (non-removable) secure element not controlled by the MNO
  • 04: Mobile tag
  • 05: Wristband
  • 06: Mobile phone case or sleeve
  • 07: Mobile phone or smartphone with a fixed (non-removable) secure element controlled by the MNO,for example, code division multiple access (CDMA)
  • 08: Removable secure element not controlled by the MNO, for example, memory card personalized forused with a mobile phone or smartphone
  • 09: Mobile Phone or smartphone with a fixed (non-removable) secure element not controlled by the MNO
  • 10: MNO controlled removable secure element (SIM or UICC) personalized for use with a tablet or e-book
  • 11: Tablet or e-book with a fixed (non-removable) secure element controlled by the MNO
  • 12: Removable secure element not controlled by the MNO, for example, memory card personalized foruse with a tablet or e-book
  • 13: Tablet or e-book with fixed (non-removable) secure element not controlled by the MNO
  • 14: Mobile phone or smartphone with a payment application running in a host processor
  • 15: Tablet or e-book with a payment application running in a host processor
  • 16: Mobile phone or smartphone with a payment application running in the Trusted ExecutionEnvironment (TEE) of a host processor
  • 17: Tablet or e-book with a payment application running in the TEE of a host processor
  • 18: Watch with a payment application running in the TEE of a host processor
  • 19: Watch with a payment application running in a host processor Values from 20–99 exclusively indicate the form factor only without also indicating the storage technology
  • 20: Card
  • 21: Phone e.g. Mobile Phone
  • 22: Tablet/e-reader
  • 23: Watch/Wristband e.g. Watch or wristband, including a fitness band, smart strap, disposable band, watch add-on, and security/ID band
  • 24: Sticker
  • 25: PC
  • 26: Device Peripheral e.g. mobile phone case or sleeve
  • 27: Tag e.g. key fob or mobile tag
  • 28: Jewelry e.g. ring, bracelet, necklace and cuff links
  • 29: Fashion Accessory e.g. handbag, bag charm and glasses
  • 30: Garment e.g. dress
  • 31: Domestic Appliance e.g refrigerator, washing machine
  • 32: Vehicle e.g. vehicle, including vehicle attached devices
  • 33: Media/Gaming Device e.g. media or gaming device, including a set top box, media player and television 34–99 are reserved for future form factors. Any value in this range may occur within form factor and transaction data without prior notice. This field is supported only for Mastercard on Visa Acceptance through VisaNet. When initiation channel is not provided via this API field, the value is extracted from EMV tag 9F6E for Mastercard transactions. To enable this feature please call support.

Used by

Authorization Optional field.

Returns:

  • (String)


130
131
132
# File 'lib/visa_acceptance_merged_spec/models/payment_information.rb', line 130

def initiation_channel
  @initiation_channel
end

#instrument_identifier ⇒ InstrumentIdentifier

TODO: Write general description for this method



42
43
44
# File 'lib/visa_acceptance_merged_spec/models/payment_information.rb', line 42

def instrument_identifier
  @instrument_identifier
end

#legacy_token ⇒ LegacyToken

TODO: Write general description for this method

Returns:



50
51
52
# File 'lib/visa_acceptance_merged_spec/models/payment_information.rb', line 50

def legacy_token
  @legacy_token
end

#options ⇒ Options

TODO: Write general description for this method

Returns:



58
59
60
# File 'lib/visa_acceptance_merged_spec/models/payment_information.rb', line 58

def options
  @options
end

#payment_account_reference ⇒ PaymentAccountReference

Mastercard-defined code that indicates how the account information was obtained.

  • 00: Card
  • 01: Mobile Network Operator (MNO) controlled removable secure element (SIM or UICC) personalized for use with a mobile phone or smartphone
  • 02: Key fob
  • 03: Watch using a contactless chip or a fixed (non-removable) secure element not controlled by the MNO
  • 04: Mobile tag
  • 05: Wristband
  • 06: Mobile phone case or sleeve
  • 07: Mobile phone or smartphone with a fixed (non-removable) secure element controlled by the MNO,for example, code division multiple access (CDMA)
  • 08: Removable secure element not controlled by the MNO, for example, memory card personalized forused with a mobile phone or smartphone
  • 09: Mobile Phone or smartphone with a fixed (non-removable) secure element not controlled by the MNO
  • 10: MNO controlled removable secure element (SIM or UICC) personalized for use with a tablet or e-book
  • 11: Tablet or e-book with a fixed (non-removable) secure element controlled by the MNO
  • 12: Removable secure element not controlled by the MNO, for example, memory card personalized foruse with a tablet or e-book
  • 13: Tablet or e-book with fixed (non-removable) secure element not controlled by the MNO
  • 14: Mobile phone or smartphone with a payment application running in a host processor
  • 15: Tablet or e-book with a payment application running in a host processor
  • 16: Mobile phone or smartphone with a payment application running in the Trusted ExecutionEnvironment (TEE) of a host processor
  • 17: Tablet or e-book with a payment application running in the TEE of a host processor
  • 18: Watch with a payment application running in the TEE of a host processor
  • 19: Watch with a payment application running in a host processor Values from 20–99 exclusively indicate the form factor only without also indicating the storage technology
  • 20: Card
  • 21: Phone e.g. Mobile Phone
  • 22: Tablet/e-reader
  • 23: Watch/Wristband e.g. Watch or wristband, including a fitness band, smart strap, disposable band, watch add-on, and security/ID band
  • 24: Sticker
  • 25: PC
  • 26: Device Peripheral e.g. mobile phone case or sleeve
  • 27: Tag e.g. key fob or mobile tag
  • 28: Jewelry e.g. ring, bracelet, necklace and cuff links
  • 29: Fashion Accessory e.g. handbag, bag charm and glasses
  • 30: Garment e.g. dress
  • 31: Domestic Appliance e.g refrigerator, washing machine
  • 32: Vehicle e.g. vehicle, including vehicle attached devices
  • 33: Media/Gaming Device e.g. media or gaming device, including a set top box, media player and television 34–99 are reserved for future form factors. Any value in this range may occur within form factor and transaction data without prior notice. This field is supported only for Mastercard on Visa Acceptance through VisaNet. When initiation channel is not provided via this API field, the value is extracted from EMV tag 9F6E for Mastercard transactions. To enable this feature please call support.

Used by

Authorization Optional field.



334
335
336
# File 'lib/visa_acceptance_merged_spec/models/payment_information.rb', line 334

def 
  @payment_account_reference
end

#payment_instrument ⇒ PaymentInstrument

TODO: Write general description for this method

Returns:



38
39
40
# File 'lib/visa_acceptance_merged_spec/models/payment_information.rb', line 38

def payment_instrument
  @payment_instrument
end

#payment_type ⇒ PaymentType

TODO: Write general description for this method

Returns:



62
63
64
# File 'lib/visa_acceptance_merged_spec/models/payment_information.rb', line 62

def payment_type
  @payment_type
end

#sepa ⇒ Sepa

Mastercard-defined code that indicates how the account information was obtained.

  • 00: Card
  • 01: Mobile Network Operator (MNO) controlled removable secure element (SIM or UICC) personalized for use with a mobile phone or smartphone
  • 02: Key fob
  • 03: Watch using a contactless chip or a fixed (non-removable) secure element not controlled by the MNO
  • 04: Mobile tag
  • 05: Wristband
  • 06: Mobile phone case or sleeve
  • 07: Mobile phone or smartphone with a fixed (non-removable) secure element controlled by the MNO,for example, code division multiple access (CDMA)
  • 08: Removable secure element not controlled by the MNO, for example, memory card personalized forused with a mobile phone or smartphone
  • 09: Mobile Phone or smartphone with a fixed (non-removable) secure element not controlled by the MNO
  • 10: MNO controlled removable secure element (SIM or UICC) personalized for use with a tablet or e-book
  • 11: Tablet or e-book with a fixed (non-removable) secure element controlled by the MNO
  • 12: Removable secure element not controlled by the MNO, for example, memory card personalized foruse with a tablet or e-book
  • 13: Tablet or e-book with fixed (non-removable) secure element not controlled by the MNO
  • 14: Mobile phone or smartphone with a payment application running in a host processor
  • 15: Tablet or e-book with a payment application running in a host processor
  • 16: Mobile phone or smartphone with a payment application running in the Trusted ExecutionEnvironment (TEE) of a host processor
  • 17: Tablet or e-book with a payment application running in the TEE of a host processor
  • 18: Watch with a payment application running in the TEE of a host processor
  • 19: Watch with a payment application running in a host processor Values from 20–99 exclusively indicate the form factor only without also indicating the storage technology
  • 20: Card
  • 21: Phone e.g. Mobile Phone
  • 22: Tablet/e-reader
  • 23: Watch/Wristband e.g. Watch or wristband, including a fitness band, smart strap, disposable band, watch add-on, and security/ID band
  • 24: Sticker
  • 25: PC
  • 26: Device Peripheral e.g. mobile phone case or sleeve
  • 27: Tag e.g. key fob or mobile tag
  • 28: Jewelry e.g. ring, bracelet, necklace and cuff links
  • 29: Fashion Accessory e.g. handbag, bag charm and glasses
  • 30: Garment e.g. dress
  • 31: Domestic Appliance e.g refrigerator, washing machine
  • 32: Vehicle e.g. vehicle, including vehicle attached devices
  • 33: Media/Gaming Device e.g. media or gaming device, including a set top box, media player and television 34–99 are reserved for future form factors. Any value in this range may occur within form factor and transaction data without prior notice. This field is supported only for Mastercard on Visa Acceptance through VisaNet. When initiation channel is not provided via this API field, the value is extracted from EMV tag 9F6E for Mastercard transactions. To enable this feature please call support.

Used by

Authorization Optional field.

Returns:



198
199
200
# File 'lib/visa_acceptance_merged_spec/models/payment_information.rb', line 198

def sepa
  @sepa
end

#shipping_address ⇒ ShippingAddress

TODO: Write general description for this method

Returns:



46
47
48
# File 'lib/visa_acceptance_merged_spec/models/payment_information.rb', line 46

def shipping_address
  @shipping_address
end

#tokenized_card ⇒ TokenizedCard

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/visa_acceptance_merged_spec/models/payment_information.rb', line 18

def tokenized_card
  @tokenized_card
end

#tokenized_payment_method ⇒ TokenizedPaymentMethod

TODO: Write general description for this method



22
23
24
# File 'lib/visa_acceptance_merged_spec/models/payment_information.rb', line 22

def tokenized_payment_method
  @tokenized_payment_method
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
# File 'lib/visa_acceptance_merged_spec/models/payment_information.rb', line 422

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  card = Card.from_hash(hash['card']) if hash['card']
  tokenized_card = TokenizedCard.from_hash(hash['tokenizedCard']) if hash['tokenizedCard']
  tokenized_payment_method = TokenizedPaymentMethod.from_hash(hash['tokenizedPaymentMethod']) if
    hash['tokenizedPaymentMethod']
  direct_debit = DirectDebit.from_hash(hash['directDebit']) if hash['directDebit']
  fluid_data = FluidData.from_hash(hash['fluidData']) if hash['fluidData']
  customer = Customer.from_hash(hash['customer']) if hash['customer']
  payment_instrument = PaymentInstrument.from_hash(hash['paymentInstrument']) if
    hash['paymentInstrument']
  instrument_identifier = InstrumentIdentifier.from_hash(hash['instrumentIdentifier']) if
    hash['instrumentIdentifier']
  shipping_address = ShippingAddress.from_hash(hash['shippingAddress']) if
    hash['shippingAddress']
  legacy_token = LegacyToken.from_hash(hash['legacyToken']) if hash['legacyToken']
  bank = Bank.from_hash(hash['bank']) if hash['bank']
  options = Options.from_hash(hash['options']) if hash['options']
  payment_type = PaymentType.from_hash(hash['paymentType']) if hash['paymentType']
  initiation_channel =
    hash.key?('initiationChannel') ? hash['initiationChannel'] : SKIP
  sepa = Sepa.from_hash(hash['sepa']) if hash['sepa']
  e_wallet = EWallet.from_hash(hash['eWallet']) if hash['eWallet']
  if hash['paymentAccountReference']
     = PaymentAccountReference.from_hash(hash['paymentAccountReference'])
  end

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PaymentInformation.new(card: card,
                         tokenized_card: tokenized_card,
                         tokenized_payment_method: tokenized_payment_method,
                         direct_debit: direct_debit,
                         fluid_data: fluid_data,
                         customer: customer,
                         payment_instrument: payment_instrument,
                         instrument_identifier: instrument_identifier,
                         shipping_address: shipping_address,
                         legacy_token: legacy_token,
                         bank: bank,
                         options: options,
                         payment_type: payment_type,
                         initiation_channel: initiation_channel,
                         sepa: sepa,
                         e_wallet: e_wallet,
                         payment_account_reference: ,
                         additional_properties: additional_properties)
end

.names ⇒ Object

A mapping from model property names to API property names.



337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
# File 'lib/visa_acceptance_merged_spec/models/payment_information.rb', line 337

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['card'] = 'card'
  @_hash['tokenized_card'] = 'tokenizedCard'
  @_hash['tokenized_payment_method'] = 'tokenizedPaymentMethod'
  @_hash['direct_debit'] = 'directDebit'
  @_hash['fluid_data'] = 'fluidData'
  @_hash['customer'] = 'customer'
  @_hash['payment_instrument'] = 'paymentInstrument'
  @_hash['instrument_identifier'] = 'instrumentIdentifier'
  @_hash['shipping_address'] = 'shippingAddress'
  @_hash['legacy_token'] = 'legacyToken'
  @_hash['bank'] = 'bank'
  @_hash['options'] = 'options'
  @_hash['payment_type'] = 'paymentType'
  @_hash['initiation_channel'] = 'initiationChannel'
  @_hash['sepa'] = 'sepa'
  @_hash['e_wallet'] = 'eWallet'
  @_hash['payment_account_reference'] = 'paymentAccountReference'
  @_hash
end

.nullables ⇒ Object

An array for nullable fields



383
384
385
# File 'lib/visa_acceptance_merged_spec/models/payment_information.rb', line 383

def self.nullables
  []
end

.optionals ⇒ Object

An array for optional fields



360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
# File 'lib/visa_acceptance_merged_spec/models/payment_information.rb', line 360

def self.optionals
  %w[
    card
    tokenized_card
    tokenized_payment_method
    direct_debit
    fluid_data
    customer
    payment_instrument
    instrument_identifier
    shipping_address
    legacy_token
    bank
    options
    payment_type
    initiation_channel
    sepa
    e_wallet
    payment_account_reference
  ]
end

Instance Method Details

#inspect ⇒ Object

Provides a debugging-friendly string with detailed object information.



493
494
495
496
497
498
499
500
501
502
503
504
505
# File 'lib/visa_acceptance_merged_spec/models/payment_information.rb', line 493

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} card: #{@card.inspect}, tokenized_card: #{@tokenized_card.inspect},"\
  " tokenized_payment_method: #{@tokenized_payment_method.inspect}, direct_debit:"\
  " #{@direct_debit.inspect}, fluid_data: #{@fluid_data.inspect}, customer:"\
  " #{@customer.inspect}, payment_instrument: #{@payment_instrument.inspect},"\
  " instrument_identifier: #{@instrument_identifier.inspect}, shipping_address:"\
  " #{@shipping_address.inspect}, legacy_token: #{@legacy_token.inspect}, bank:"\
  " #{@bank.inspect}, options: #{@options.inspect}, payment_type: #{@payment_type.inspect},"\
  " initiation_channel: #{@initiation_channel.inspect}, sepa: #{@sepa.inspect}, e_wallet:"\
  " #{@e_wallet.inspect}, payment_account_reference: #{@payment_account_reference.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_s ⇒ Object

Provides a human-readable string representation of the object.



480
481
482
483
484
485
486
487
488
489
490
# File 'lib/visa_acceptance_merged_spec/models/payment_information.rb', line 480

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} card: #{@card}, tokenized_card: #{@tokenized_card},"\
  " tokenized_payment_method: #{@tokenized_payment_method}, direct_debit: #{@direct_debit},"\
  " fluid_data: #{@fluid_data}, customer: #{@customer}, payment_instrument:"\
  " #{@payment_instrument}, instrument_identifier: #{@instrument_identifier},"\
  " shipping_address: #{@shipping_address}, legacy_token: #{@legacy_token}, bank: #{@bank},"\
  " options: #{@options}, payment_type: #{@payment_type}, initiation_channel:"\
  " #{@initiation_channel}, sepa: #{@sepa}, e_wallet: #{@e_wallet}, payment_account_reference:"\
  " #{@payment_account_reference}, additional_properties: #{@additional_properties}>"
end