Class: VisaAcceptanceMergedSpec::PaymentInformation4

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/payment_information4.rb

Overview

PaymentInformation4 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(customer: SKIP, card: SKIP, payment_type: SKIP, additional_properties: nil) ⇒ PaymentInformation4

Returns a new instance of PaymentInformation4.



47
48
49
50
51
52
53
54
55
56
# File 'lib/visa_acceptance_merged_spec/models/payment_information4.rb', line 47

def initialize(customer: SKIP, card: SKIP, payment_type: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @customer = customer unless customer == SKIP
  @card = card unless card == SKIP
  @payment_type = payment_type unless payment_type == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#cardCard3

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/visa_acceptance_merged_spec/models/payment_information4.rb', line 18

def card
  @card
end

#customerCustomer

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/visa_acceptance_merged_spec/models/payment_information4.rb', line 14

def customer
  @customer
end

#payment_typePaymentType2

TODO: Write general description for this method

Returns:



22
23
24
# File 'lib/visa_acceptance_merged_spec/models/payment_information4.rb', line 22

def payment_type
  @payment_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/visa_acceptance_merged_spec/models/payment_information4.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  customer = Customer.from_hash(hash['customer']) if hash['customer']
  card = Card3.from_hash(hash['card']) if hash['card']
  payment_type = PaymentType2.from_hash(hash['paymentType']) if hash['paymentType']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PaymentInformation4.new(customer: customer,
                          card: card,
                          payment_type: payment_type,
                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/visa_acceptance_merged_spec/models/payment_information4.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['customer'] = 'customer'
  @_hash['card'] = 'card'
  @_hash['payment_type'] = 'paymentType'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/visa_acceptance_merged_spec/models/payment_information4.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/visa_acceptance_merged_spec/models/payment_information4.rb', line 34

def self.optionals
  %w[
    customer
    card
    payment_type
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/visa_acceptance_merged_spec/models/payment_information4.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} customer: #{@customer.inspect}, card: #{@card.inspect}, payment_type:"\
  " #{@payment_type.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/visa_acceptance_merged_spec/models/payment_information4.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} customer: #{@customer}, card: #{@card}, payment_type: #{@payment_type},"\
  " additional_properties: #{@additional_properties}>"
end