Class: VisaAcceptanceMergedSpec::PaymentInsightsInformation
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::PaymentInsightsInformation
- Defined in:
- lib/visa_acceptance_merged_spec/models/payment_insights_information.rb
Overview
PaymentInsightsInformation Model.
Instance Attribute Summary collapse
-
#orchestration ⇒ Orchestration
TODO: Write general description for this method.
-
#response_insights ⇒ ResponseInsights
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(response_insights: SKIP, orchestration: SKIP, additional_properties: nil) ⇒ PaymentInsightsInformation
constructor
A new instance of PaymentInsightsInformation.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(response_insights: SKIP, orchestration: SKIP, additional_properties: nil) ⇒ PaymentInsightsInformation
Returns a new instance of PaymentInsightsInformation.
41 42 43 44 45 46 47 48 49 |
# File 'lib/visa_acceptance_merged_spec/models/payment_insights_information.rb', line 41 def initialize(response_insights: SKIP, orchestration: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @response_insights = response_insights unless response_insights == SKIP @orchestration = orchestration unless orchestration == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#orchestration ⇒ Orchestration
TODO: Write general description for this method
18 19 20 |
# File 'lib/visa_acceptance_merged_spec/models/payment_insights_information.rb', line 18 def orchestration @orchestration end |
#response_insights ⇒ ResponseInsights
TODO: Write general description for this method
14 15 16 |
# File 'lib/visa_acceptance_merged_spec/models/payment_insights_information.rb', line 14 def response_insights @response_insights end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/visa_acceptance_merged_spec/models/payment_insights_information.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. response_insights = ResponseInsights.from_hash(hash['responseInsights']) if hash['responseInsights'] orchestration = Orchestration.from_hash(hash['orchestration']) if hash['orchestration'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PaymentInsightsInformation.new(response_insights: response_insights, orchestration: orchestration, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/visa_acceptance_merged_spec/models/payment_insights_information.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['response_insights'] = 'responseInsights' @_hash['orchestration'] = 'orchestration' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/visa_acceptance_merged_spec/models/payment_insights_information.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/visa_acceptance_merged_spec/models/payment_insights_information.rb', line 29 def self.optionals %w[ response_insights orchestration ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
81 82 83 84 85 |
# File 'lib/visa_acceptance_merged_spec/models/payment_insights_information.rb', line 81 def inspect class_name = self.class.name.split('::').last "<#{class_name} response_insights: #{@response_insights.inspect}, orchestration:"\ " #{@orchestration.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
74 75 76 77 78 |
# File 'lib/visa_acceptance_merged_spec/models/payment_insights_information.rb', line 74 def to_s class_name = self.class.name.split('::').last "<#{class_name} response_insights: #{@response_insights}, orchestration: #{@orchestration},"\ " additional_properties: #{@additional_properties}>" end |