Class: VisaAcceptanceMergedSpec::PersonalIdentification2

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/personal_identification2.rb

Overview

PersonalIdentification2 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id: SKIP, additional_properties: nil) ⇒ PersonalIdentification2

Returns a new instance of PersonalIdentification2.



51
52
53
54
55
56
57
# File 'lib/visa_acceptance_merged_spec/models/personal_identification2.rb', line 51

def initialize(id: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @id = id unless id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#idString

The value of the identification type. This field is supported only on the following processors.

ComercioLatino

Set this field to the Cadastro de Pessoas Fisicas (CPF).

Visa Acceptance Latin American Processing

Supported for Redecard in Brazil. Set this field to the Cadastro de Pessoas Fisicas (CPF), which is required for AVS for Redecard in Brazil. Note Visa Acceptance Latin American Processing is the name of a specific processing connection that Visa Acceptance supports. In the Visa Acceptance API documentation, Visa Acceptance Latin American Processing does not refer to the general topic of processing in Latin America. The information in this field description is for the specific processing connection called Visa Acceptance Latin American Processing. It is not for any other Latin American processors that Visa Acceptance supports.

If type = PASSPORT, this is the cardholder's passport number. Recommended for Discover ProtectBuy.

Returns:

  • (String)


30
31
32
# File 'lib/visa_acceptance_merged_spec/models/personal_identification2.rb', line 30

def id
  @id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/visa_acceptance_merged_spec/models/personal_identification2.rb', line 60

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PersonalIdentification2.new(id: id,
                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
# File 'lib/visa_acceptance_merged_spec/models/personal_identification2.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash
end

.nullablesObject

An array for nullable fields



47
48
49
# File 'lib/visa_acceptance_merged_spec/models/personal_identification2.rb', line 47

def self.nullables
  []
end

.optionalsObject

An array for optional fields



40
41
42
43
44
# File 'lib/visa_acceptance_merged_spec/models/personal_identification2.rb', line 40

def self.optionals
  %w[
    id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



85
86
87
88
# File 'lib/visa_acceptance_merged_spec/models/personal_identification2.rb', line 85

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



79
80
81
82
# File 'lib/visa_acceptance_merged_spec/models/personal_identification2.rb', line 79

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, additional_properties: #{@additional_properties}>"
end