Class: VisaAcceptanceMergedSpec::PointOfSaleInformation7

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/point_of_sale_information7.rb

Overview

PointOfSaleInformation7 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(terminal_id: SKIP, additional_properties: nil) ⇒ PointOfSaleInformation7

Returns a new instance of PointOfSaleInformation7.



86
87
88
89
90
91
92
# File 'lib/visa_acceptance_merged_spec/models/point_of_sale_information7.rb', line 86

def initialize(terminal_id: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @terminal_id = terminal_id unless terminal_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#terminal_idString

Identifier for the terminal at your retail location. You can define this value yourself, but consult the processor for requirements.

Visa Acceptance through VisaNet

A list of all possible values is stored in your Visa Acceptance account. If terminal ID validation is enabled for your Visa Acceptance account, the value you send for this field is validated against the list each time you include the field in a request. To enable or disable terminal ID validation, contact Visa Acceptance Customer Support. When you do not include this field in a request, Visa Acceptance uses the default value that is defined in your Visa Acceptance account.

FDC Nashville Global

To have your account configured to support this field, contact Visa Acceptance Customer Support. This value must be a value that FDC Nashville Global issued to you.

For Payouts

This field is applicable for Visa Acceptance through VisaNet.

GPX

Identifier for the terminal at your retail location. A list of all possible values is stored in your account. If terminal ID validation is enabled for your account, the value you send for this field is validated against the list each time you include the field in a request. To enable or disable terminal ID validation, contact customer support. When you do not include this field in a request, the default value that is defined in your account is used. Optional for authorizations.

Used by

Authorization Optional for the following processors. When you do not include this field in a request, the default value that is defined in your account is used.

  • American Express Direct
  • Credit Mutuel-CIC
  • FDC Nashville Global
  • SIX
  • Chase Paymentech Solutions: Optional field. If you include this field in your request, you must also include pointOfSaleInformation.catLevel.
  • FDMS Nashville: The default value that is defined in your account is used.
  • GPX
  • OmniPay Direct: Optional field. For the following processors, this field is not used.
  • GPN
  • JCN Gateway
  • RBS WorldPay Atlanta
  • TSYS Acquiring Solutions
  • Worldpay VAP

Card Present reply

Terminal identifier assigned by the acquirer. This value must be printed on the receipt.

Returns:

  • (String)


65
66
67
# File 'lib/visa_acceptance_merged_spec/models/point_of_sale_information7.rb', line 65

def terminal_id
  @terminal_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/visa_acceptance_merged_spec/models/point_of_sale_information7.rb', line 95

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  terminal_id = hash.key?('terminalId') ? hash['terminalId'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PointOfSaleInformation7.new(terminal_id: terminal_id,
                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



68
69
70
71
72
# File 'lib/visa_acceptance_merged_spec/models/point_of_sale_information7.rb', line 68

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['terminal_id'] = 'terminalId'
  @_hash
end

.nullablesObject

An array for nullable fields



82
83
84
# File 'lib/visa_acceptance_merged_spec/models/point_of_sale_information7.rb', line 82

def self.nullables
  []
end

.optionalsObject

An array for optional fields



75
76
77
78
79
# File 'lib/visa_acceptance_merged_spec/models/point_of_sale_information7.rb', line 75

def self.optionals
  %w[
    terminal_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



121
122
123
124
125
# File 'lib/visa_acceptance_merged_spec/models/point_of_sale_information7.rb', line 121

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} terminal_id: #{@terminal_id.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



114
115
116
117
118
# File 'lib/visa_acceptance_merged_spec/models/point_of_sale_information7.rb', line 114

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} terminal_id: #{@terminal_id}, additional_properties:"\
  " #{@additional_properties}>"
end