Class: VisaAcceptanceMergedSpec::PointOfSaleInformation8

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/point_of_sale_information8.rb

Overview

PointOfSaleInformation8 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(emv: SKIP, terminal_category: SKIP, additional_properties: nil) ⇒ PointOfSaleInformation8

Returns a new instance of PointOfSaleInformation8.



43
44
45
46
47
48
49
50
51
# File 'lib/visa_acceptance_merged_spec/models/point_of_sale_information8.rb', line 43

def initialize(emv: SKIP, terminal_category: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @emv = emv unless emv == SKIP
  @terminal_category = terminal_category unless terminal_category == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#emvEmv6

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/visa_acceptance_merged_spec/models/point_of_sale_information8.rb', line 14

def emv
  @emv
end

#terminal_categoryString

Indicates the type of terminal. Possible values:

  • AFD: Automated Fuel Dispenser

Returns:

  • (String)


20
21
22
# File 'lib/visa_acceptance_merged_spec/models/point_of_sale_information8.rb', line 20

def terminal_category
  @terminal_category
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/visa_acceptance_merged_spec/models/point_of_sale_information8.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  emv = Emv6.from_hash(hash['emv']) if hash['emv']
  terminal_category =
    hash.key?('terminalCategory') ? hash['terminalCategory'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PointOfSaleInformation8.new(emv: emv,
                              terminal_category: terminal_category,
                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/visa_acceptance_merged_spec/models/point_of_sale_information8.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['emv'] = 'emv'
  @_hash['terminal_category'] = 'terminalCategory'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/visa_acceptance_merged_spec/models/point_of_sale_information8.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
34
35
36
# File 'lib/visa_acceptance_merged_spec/models/point_of_sale_information8.rb', line 31

def self.optionals
  %w[
    emv
    terminal_category
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



83
84
85
86
87
# File 'lib/visa_acceptance_merged_spec/models/point_of_sale_information8.rb', line 83

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} emv: #{@emv.inspect}, terminal_category: #{@terminal_category.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



76
77
78
79
80
# File 'lib/visa_acceptance_merged_spec/models/point_of_sale_information8.rb', line 76

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} emv: #{@emv}, terminal_category: #{@terminal_category},"\
  " additional_properties: #{@additional_properties}>"
end