Class: VisaAcceptanceMergedSpec::ProcessingInformation

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/processing_information.rb

Overview

ProcessingInformation Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(action_list: SKIP, enable_escrow_option: SKIP, action_token_types: SKIP, bin_source: SKIP, capture: false, processor_id: SKIP, business_application_id: SKIP, commerce_indicator: SKIP, commerce_indicator_label: SKIP, payment_solution: SKIP, reconciliation_id: SKIP, link_id: SKIP, purchase_level: SKIP, transaction_timeout: SKIP, intents_id: SKIP, report_group: SKIP, visa_checkout_id: SKIP, industry_data_type: SKIP, authorization_options: SKIP, capture_options: SKIP, recurring_options: SKIP, bank_transfer_options: SKIP, purchase_options: SKIP, electronic_benefits_transfer: SKIP, loan_options: SKIP, wallet_type: SKIP, national_net_domestic_data: SKIP, japan_payment_options: SKIP, mobile_remote_payment_type: SKIP, extended_credit_total_count: SKIP, network_routing_order: SKIP, pay_by_points_indicator: SKIP, timeout: SKIP, is_return_auth_record_enabled: SKIP, network_partner_id: SKIP, payment_type: SKIP, enabler_id: SKIP, processing_instruction: SKIP, transaction_type_indicator: SKIP, purpose_of_payment: SKIP, language_code: SKIP, original_payment_id: SKIP, additional_properties: nil) ⇒ ProcessingInformation

Returns a new instance of ProcessingInformation.



801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 801

def initialize(action_list: SKIP, enable_escrow_option: SKIP,
               action_token_types: SKIP, bin_source: SKIP, capture: false,
               processor_id: SKIP, business_application_id: SKIP,
               commerce_indicator: SKIP, commerce_indicator_label: SKIP,
               payment_solution: SKIP, reconciliation_id: SKIP,
               link_id: SKIP, purchase_level: SKIP,
               transaction_timeout: SKIP, intents_id: SKIP,
               report_group: SKIP, visa_checkout_id: SKIP,
               industry_data_type: SKIP, authorization_options: SKIP,
               capture_options: SKIP, recurring_options: SKIP,
               bank_transfer_options: SKIP, purchase_options: SKIP,
               electronic_benefits_transfer: SKIP, loan_options: SKIP,
               wallet_type: SKIP, national_net_domestic_data: SKIP,
               japan_payment_options: SKIP,
               mobile_remote_payment_type: SKIP,
               extended_credit_total_count: SKIP,
               network_routing_order: SKIP, pay_by_points_indicator: SKIP,
               timeout: SKIP, is_return_auth_record_enabled: SKIP,
               network_partner_id: SKIP, payment_type: SKIP,
               enabler_id: SKIP, processing_instruction: SKIP,
               transaction_type_indicator: SKIP, purpose_of_payment: SKIP,
               language_code: SKIP, original_payment_id: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @action_list = action_list unless action_list == SKIP
  @enable_escrow_option = enable_escrow_option unless enable_escrow_option == SKIP
  @action_token_types = action_token_types unless action_token_types == SKIP
  @bin_source = bin_source unless bin_source == SKIP
  @capture = capture unless capture == SKIP
  @processor_id = processor_id unless processor_id == SKIP
  @business_application_id = business_application_id unless business_application_id == SKIP
  @commerce_indicator = commerce_indicator unless commerce_indicator == SKIP
  @commerce_indicator_label = commerce_indicator_label unless commerce_indicator_label == SKIP
  @payment_solution = payment_solution unless payment_solution == SKIP
  @reconciliation_id = reconciliation_id unless reconciliation_id == SKIP
  @link_id = link_id unless link_id == SKIP
  @purchase_level = purchase_level unless purchase_level == SKIP
  @transaction_timeout = transaction_timeout unless transaction_timeout == SKIP
  @intents_id = intents_id unless intents_id == SKIP
  @report_group = report_group unless report_group == SKIP
  @visa_checkout_id = visa_checkout_id unless visa_checkout_id == SKIP
  @industry_data_type = industry_data_type unless industry_data_type == SKIP
  @authorization_options = authorization_options unless authorization_options == SKIP
  @capture_options = capture_options unless capture_options == SKIP
  @recurring_options = recurring_options unless recurring_options == SKIP
  @bank_transfer_options = bank_transfer_options unless bank_transfer_options == SKIP
  @purchase_options = purchase_options unless purchase_options == SKIP
  unless electronic_benefits_transfer == SKIP
    @electronic_benefits_transfer =
      electronic_benefits_transfer
  end
  @loan_options = loan_options unless loan_options == SKIP
  @wallet_type = wallet_type unless wallet_type == SKIP
  unless national_net_domestic_data == SKIP
    @national_net_domestic_data =
      national_net_domestic_data
  end
  @japan_payment_options = japan_payment_options unless japan_payment_options == SKIP
  unless mobile_remote_payment_type == SKIP
    @mobile_remote_payment_type =
      mobile_remote_payment_type
  end
  unless extended_credit_total_count == SKIP
    @extended_credit_total_count =
      extended_credit_total_count
  end
  @network_routing_order = network_routing_order unless network_routing_order == SKIP
  @pay_by_points_indicator = pay_by_points_indicator unless pay_by_points_indicator == SKIP
  @timeout = timeout unless timeout == SKIP
  unless is_return_auth_record_enabled == SKIP
    @is_return_auth_record_enabled =
      is_return_auth_record_enabled
  end
  @network_partner_id = network_partner_id unless network_partner_id == SKIP
  @payment_type = payment_type unless payment_type == SKIP
  @enabler_id = enabler_id unless enabler_id == SKIP
  @processing_instruction = processing_instruction unless processing_instruction == SKIP
  unless transaction_type_indicator == SKIP
    @transaction_type_indicator =
      transaction_type_indicator
  end
  @purpose_of_payment = purpose_of_payment unless purpose_of_payment == SKIP
  @language_code = language_code unless language_code == SKIP
  @original_payment_id = original_payment_id unless original_payment_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#action_listArray[String]

Array of actions (one or more) to be included in the payment to invoke bundled services along with payment. Possible values are one or more of follows:

  • DECISION_SKIP: Use this when you want to skip Decision Manager service(s).

  • TOKEN_CREATE: Use this when you want to create a token from the card/bank data in your payment request.

  • CONSUMER_AUTHENTICATION: Use this when you want to check if a card is enrolled in Payer Authentication along with your payment request.

  • VALIDATE_CONSUMER_AUTHENTICATION: Use this after you acquire a Payer Authentication result that needs to be included for your payment request.

  • AP_INITIATE: Use this when Alternative Payment Initiate service is requested.

  • WATCHLIST_SCREENING : Use this when you want to call Watchlist Screening service.

  • AP_SALE : Use this when Alternative Payment Sale service is requested.

  • AP_AUTH : Use this when Alternative Payment Authorize service is requested.

  • AP_REAUTH : Use this when Alternative Payment Reauthorize service is requested.

Returns:

  • (Array[String])


35
36
37
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 35

def action_list
  @action_list
end

#action_token_typesArray[String]

Visa Acceptance tokens types you are performing a create on. If not supplied the default token type for the merchants token vault will be used. Valid values:

  • customer
  • paymentInstrument
  • instrumentIdentifier
  • shippingAddress

Returns:

  • (Array[String])


53
54
55
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 53

def action_token_types
  @action_token_types
end

#authorization_optionsAuthorizationOptions

Indicates that the transaction includes industry-specific data. Possible Values:

  • airline
  • restaurant
  • lodging
  • auto_rental
  • transit
  • healthcare_medical
  • healthcare_transit
  • transit

Card Present, Airlines and Auto Rental

You must set this field to airline in order for airline data to be sent to the processor. For example, if this field is not set to airline or is not included in the request, no airline data is sent to the processor. You must set this field to restaurant in order for restaurant data to be sent to the processor. When this field is not set to restaurant or is not included in the request, no restaurant data is sent to the processor. You must set this field to auto_rental in order for auto rental data to be sent to the processor. For example, if this field is not set to auto_rental or is not included in the request, no auto rental data is sent to the processor. Restaurant data is supported only on Visa Acceptance through VisaNet.



272
273
274
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 272

def authorization_options
  @authorization_options
end

#bank_transfer_optionsBankTransferOptions

Indicates that the transaction includes industry-specific data. Possible Values:

  • airline
  • restaurant
  • lodging
  • auto_rental
  • transit
  • healthcare_medical
  • healthcare_transit
  • transit

Card Present, Airlines and Auto Rental

You must set this field to airline in order for airline data to be sent to the processor. For example, if this field is not set to airline or is not included in the request, no airline data is sent to the processor. You must set this field to restaurant in order for restaurant data to be sent to the processor. When this field is not set to restaurant or is not included in the request, no restaurant data is sent to the processor. You must set this field to auto_rental in order for auto rental data to be sent to the processor. For example, if this field is not set to auto_rental or is not included in the request, no auto rental data is sent to the processor. Restaurant data is supported only on Visa Acceptance through VisaNet.

Returns:



353
354
355
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 353

def bank_transfer_options
  @bank_transfer_options
end

#bin_sourceString

Bin Source File Identifier. Possible values:

  • itmx
  • rupay

Returns:

  • (String)


60
61
62
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 60

def bin_source
  @bin_source
end

#business_application_idString

Required for AFT and OCT transactions. Given below is a list of all the BAI values available. However, the processors may support only few specific BAI values.

  • AA : Account-to-account
  • BB : Supplier Payments
  • BI : Bank-Initiated P2P Money Transfer
  • BP : Non-Card Bill Pay/Bill Pay
  • CD : Cash Deposit
  • CP : Credit card Bill Payment
  • FD : Funds disbursement
  • FT : Funds transfer
  • GD : Government Disbursement
  • GP : Gambling payout (non-online gambling)
  • LO : Loyalty credits and rebates
  • MD : Merchant Settlement
  • OG : Online Gambling Payout
  • PD : Payroll and pension disbursement
  • PP : Person-to-Person or Peer-to-Peer
  • TU : Top up, prepaid load
  • WT : Digital wallet

Returns:

  • (String)


102
103
104
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 102

def business_application_id
  @business_application_id
end

#captureTrueClass | FalseClass

Indicates whether to also include a capture in the submitted authorization request or not. Possible values:

  • true: Include a capture with an authorization request.
  • false: (default) Do not include a capture with an authorization request.

Used by

Authorization and Capture Optional field.

Returns:

  • (TrueClass | FalseClass)


72
73
74
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 72

def capture
  @capture
end

#capture_optionsCaptureOptions

Indicates that the transaction includes industry-specific data. Possible Values:

  • airline
  • restaurant
  • lodging
  • auto_rental
  • transit
  • healthcare_medical
  • healthcare_transit
  • transit

Card Present, Airlines and Auto Rental

You must set this field to airline in order for airline data to be sent to the processor. For example, if this field is not set to airline or is not included in the request, no airline data is sent to the processor. You must set this field to restaurant in order for restaurant data to be sent to the processor. When this field is not set to restaurant or is not included in the request, no restaurant data is sent to the processor. You must set this field to auto_rental in order for auto rental data to be sent to the processor. For example, if this field is not set to auto_rental or is not included in the request, no auto rental data is sent to the processor. Restaurant data is supported only on Visa Acceptance through VisaNet.

Returns:



299
300
301
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 299

def capture_options
  @capture_options
end

#commerce_indicatorString

Type of transaction. Some payment card companies use this information when determining discount rates.

Used by

Authorization Required payer authentication transactions; otherwise, optional. Credit Required for standalone credits on Chase Paymentech solutions; otherwise, optional. The list of valid values in this field depends on your processor.

Ingenico ePayments

When you omit this field for Ingenico ePayments, the processor uses the default transaction type they have on file for you instead of the default value

Card Present

You must set this field to retail. This field is required for a card-present transaction. Note that this should ONLY be used when the cardholder and card are present at the time of the transaction. For all keyed transactions originated from a POS terminal where the cardholder and card are not present, commerceIndicator should be submitted as “moto"

Returns:

  • (String)


126
127
128
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 126

def commerce_indicator
  @commerce_indicator
end

#commerce_indicator_labelString

Type of transaction. Some payment card companies use this information when determining discount rates.

Used by

Authorization Required payer authentication transactions; otherwise, optional. Credit Required for standalone credits on Chase Paymentech solutions; otherwise, optional. The list of valid values in this field depends on your processor.

Ingenico ePayments

When you omit this field for Ingenico ePayments, the processor uses the default transaction type they have on file for you instead of the default value

Card Present

You must set this field to retail. This field is required for a card-present transaction. Note that this should ONLY be used when the cardholder and card are present at the time of the transaction. For all keyed transactions originated from a POS terminal where the cardholder and card are not present, commerceIndicator should be submitted as moto

Returns:

  • (String)


150
151
152
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 150

def commerce_indicator_label
  @commerce_indicator_label
end

#electronic_benefits_transferElectronicBenefitsTransfer

Indicates that the transaction includes industry-specific data. Possible Values:

  • airline
  • restaurant
  • lodging
  • auto_rental
  • transit
  • healthcare_medical
  • healthcare_transit
  • transit

Card Present, Airlines and Auto Rental

You must set this field to airline in order for airline data to be sent to the processor. For example, if this field is not set to airline or is not included in the request, no airline data is sent to the processor. You must set this field to restaurant in order for restaurant data to be sent to the processor. When this field is not set to restaurant or is not included in the request, no restaurant data is sent to the processor. You must set this field to auto_rental in order for auto rental data to be sent to the processor. For example, if this field is not set to auto_rental or is not included in the request, no auto rental data is sent to the processor. Restaurant data is supported only on Visa Acceptance through VisaNet.



407
408
409
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 407

def electronic_benefits_transfer
  @electronic_benefits_transfer
end

#enable_escrow_optionTrueClass | FalseClass

Indicates whether to use the customer’s escrow agreement. Possible values:

  • true: yes, use the customer’s escrow agreement.
  • false: no, do not use the customer’s escrow agreement.

Returns:

  • (TrueClass | FalseClass)


42
43
44
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 42

def enable_escrow_option
  @enable_escrow_option
end

#enabler_idString

Enablers are payment processing entities that are not acquiring members and are often the primary relationship owner with merchants and originators. Enablers own technical solutions through which the merchant or originator will access acceptance. The Enabler ID is a five-character hexadecimal identifier that will be used by Visa to identify enablers. Enabler ID assignment will be determined by Visa. Visa will communicate Enablers assignments to enablers.

Returns:

  • (String)


638
639
640
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 638

def enabler_id
  @enabler_id
end

#extended_credit_total_countString

A private national-use field submitted by acquirers and issuers in South Africa for South Africa-domestic (intra-country) authorizations and financial requests. Values for this field are 00 through 99.

Returns:

  • (String)


558
559
560
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 558

def extended_credit_total_count
  @extended_credit_total_count
end

#industry_data_typeString

Indicates that the transaction includes industry-specific data. Possible Values:

  • airline
  • restaurant
  • lodging
  • auto_rental
  • transit
  • healthcare_medical
  • healthcare_transit
  • transit

Card Present, Airlines and Auto Rental

You must set this field to airline in order for airline data to be sent to the processor. For example, if this field is not set to airline or is not included in the request, no airline data is sent to the processor. You must set this field to restaurant in order for restaurant data to be sent to the processor. When this field is not set to restaurant or is not included in the request, no restaurant data is sent to the processor. You must set this field to auto_rental in order for auto rental data to be sent to the processor. For example, if this field is not set to auto_rental or is not included in the request, no auto rental data is sent to the processor. Restaurant data is supported only on Visa Acceptance through VisaNet.

Returns:

  • (String)


245
246
247
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 245

def industry_data_type
  @industry_data_type
end

#intents_idString

Set to the value of the requestID field returned in the order service response.

Returns:

  • (String)


207
208
209
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 207

def intents_id
  @intents_id
end

#is_return_auth_record_enabledTrueClass | FalseClass

Flag that indicates the functionality we are having for merchants for which auth is done through Visa Acceptance but settlement is done by themselves. true: functionality is supported. Processor should send raw processor auth response to Merchant. false: functionality is not supported. Default: false

Returns:

  • (TrueClass | FalseClass)


617
618
619
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 617

def is_return_auth_record_enabled
  @is_return_auth_record_enabled
end

#japan_payment_optionsJapanPaymentOptions

Supplementary domestic transaction information provided by the acquirer for National Net Settlement Service (NNSS) transactions. NNSS is a settlement service that Visa provides. For transactions on Visa Acceptance through VisaNet in countries that subscribe to NNSS: VisaNet clears transactions; VisaNet transfers funds to the acquirer after deducting processing fees and interchange fees. VisaNet settles transactions in the local pricing currency through a local financial institution. This field is supported only on Visa Acceptance through VisaNet for domestic data in Colombia

Returns:



522
523
524
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 522

def japan_payment_options
  @japan_payment_options
end

#language_codeString

Contains the ISO 639-2 defined language Code

Returns:

  • (String)


691
692
693
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 691

def language_code
  @language_code
end

Value that links the current authorization request to the original authorization request. Set this value to the ID that was returned in the reply message from the original authorization request. This value is used for:

  • Partial authorizations
  • Split shipments

Returns:

  • (String)


190
191
192
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 190

def link_id
  @link_id
end

#loan_optionsLoanOptions

Indicates that the transaction includes industry-specific data. Possible Values:

  • airline
  • restaurant
  • lodging
  • auto_rental
  • transit
  • healthcare_medical
  • healthcare_transit
  • transit

Card Present, Airlines and Auto Rental

You must set this field to airline in order for airline data to be sent to the processor. For example, if this field is not set to airline or is not included in the request, no airline data is sent to the processor. You must set this field to restaurant in order for restaurant data to be sent to the processor. When this field is not set to restaurant or is not included in the request, no restaurant data is sent to the processor. You must set this field to auto_rental in order for auto rental data to be sent to the processor. For example, if this field is not set to auto_rental or is not included in the request, no auto rental data is sent to the processor. Restaurant data is supported only on Visa Acceptance through VisaNet.

Returns:



434
435
436
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 434

def loan_options
  @loan_options
end

#mobile_remote_payment_typeString

Type of payment initiated from a cardholder's mobile device. Possible values:

  • 1 : Consumer-initiated remote purchase, face-to-face
  • 2 : Consumer-initiated remote purchase, e-commerce
  • 3 : Consumer-initiated remote purchase, mail order / telephone order
  • 4 : Consumer-initiated bill pay
  • 5 : Consumer-initiated top up
  • 6 : Consumer-initiated cash out
  • 7 : ATM triggered or agent-initiated cash out
  • 8 : Merchant-initiated remote purchase, face-to-face
  • 9 : Merchant-initiated remote purchase, e-commerce This field is supported only for Mastercard transactions on Visa Acceptance through VisaNet. Optional field. Note On Visa Acceptance through VisaNet, the value for this field corresponds to the following data in the TC 33 capture file:
  • Record: CP01 TCR6
  • Position: 94
  • Field: Mastercard Mobile Remote Payment Program Indicator The TC 33 Capture file contains information about the purchases and refunds that a merchant submits to Visa Acceptance. Visa Acceptance through VisaNet creates the TC 33 Capture file at the end of the day and sends it to the merchant’s acquirer, who uses this information to facilitate end-of-day clearing processing with payment networks.

Returns:

  • (String)


551
552
553
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 551

def mobile_remote_payment_type
  @mobile_remote_payment_type
end

#national_net_domestic_dataString

Supplementary domestic transaction information provided by the acquirer for National Net Settlement Service (NNSS) transactions. NNSS is a settlement service that Visa provides. For transactions on Visa Acceptance through VisaNet in countries that subscribe to NNSS: VisaNet clears transactions; VisaNet transfers funds to the acquirer after deducting processing fees and interchange fees. VisaNet settles transactions in the local pricing currency through a local financial institution. This field is supported only on Visa Acceptance through VisaNet for domestic data in Colombia

Returns:

  • (String)


508
509
510
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 508

def national_net_domestic_data
  @national_net_domestic_data
end

#network_partner_idString

Merchant payment gateway ID that is assigned by Mastercard and is provided by the acquirer when a registered merchant payment gateway service provider is involved in the transaction. This field is supported for Visa Platform Connect.

Returns:

  • (String)


624
625
626
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 624

def network_partner_id
  @network_partner_id
end

#network_routing_orderString

On PIN Debit Gateways: This U.S.-only field is optionally used by participants (merchants and acquirers) to specify the network access priority. VisaNet checks to determine if there are issuer routing preferences for any of the networks specified by the sharing group code. If an issuer preference exists for one of the specified debit networks, VisaNet makes a routing selection based on the issuer’s preference. If an issuer preference exists for more than one of the specified debit networks, or if no issuer preference exists, VisaNet makes a selection based on the acquirer’s routing priorities.

PIN debit

Priority order of the networks through which he transaction will be routed. Set this value to a series of one-character network codes in your preferred order. This is a list of the network codes:

Network Code
Accel E
AFFN U
Alaska Option 3
CU24 C
Interlink G
Maestro 8
NETS P
NYCE F
Pulse H
Shazam 7
Star M
Visa V

For example, if the Star network is your first preference and Pulse is your second preference, set this field to a value of MH. When you do not include this value in your PIN debit request, the list of network codes from your account is used. Note This field is supported only for businesses located in the U.S. Optional field for PIN debit credit or PIN debit purchase.

Returns:

  • (String)


595
596
597
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 595

def network_routing_order
  @network_routing_order
end

#original_payment_idString

This value is used for linking Authorization extension transaction to the original Authorization transaction and for linking MIT (Merchant initiated transaction) with the respective CIT (Customer initiated transaction).

Returns:

  • (String)


698
699
700
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 698

def original_payment_id
  @original_payment_id
end

#pay_by_points_indicatorTrueClass | FalseClass

Flag that indicates if the transaction is pay by points transaction true: Transaction uses loyalty points false: Transaction does not use loyalty points Default: false

Returns:

  • (TrueClass | FalseClass)


602
603
604
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 602

def pay_by_points_indicator
  @pay_by_points_indicator
end

#payment_solutionString

Type of digital payment solution for the transaction. Possible Values:

  • visacheckout: Visa Checkout. This value is required for Visa Checkout transactions. For details, see payment_solution field description in [Visa Checkout Using the REST API.](
  • 001: Apple Pay.
  • 004: Visa Acceptance In-App Solution.
  • 005: Masterpass. This value is required for Masterpass transactions on OmniPay Direct.
  • 006: Android Pay.
  • 007: Chase Pay.
  • 008: Samsung Pay.
  • 012: Google Pay.
  • 013: Visa Acceptance P2PE Decryption
  • 014: Mastercard credential on file (COF) payment network token. Returned in authorizations that use a payment network token associated with a TMS token.
  • 015: Visa credential on file (COF) payment network token. Returned in authorizations that use a payment network token associated with a TMS token.
  • 027: Click to Pay.

Returns:

  • (String)


173
174
175
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 173

def payment_solution
  @payment_solution
end

#payment_typeString

Identifier for the payment type.

Returns:

  • (String)


628
629
630
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 628

def payment_type
  @payment_type
end

#processing_instructionString

The instruction to process an order.

  • default value: 'NO_INSTRUCTION'
  • 'ORDER_SAVED_EXPLICITLY'

Returns:

  • (String)


644
645
646
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 644

def processing_instruction
  @processing_instruction
end

#processor_idString

Value that identifies the processor/acquirer to use for the transaction. This value is supported only for Visa Acceptance through VisaNet. Contact Visa Acceptance Customer Support to get the value for this field.

Returns:

  • (String)


79
80
81
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 79

def processor_id
  @processor_id
end

#purchase_levelString

Set this field to 3 to indicate that the request includes Level III data.

Returns:

  • (String)


194
195
196
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 194

def purchase_level
  @purchase_level
end

#purchase_optionsPurchaseOptions

Indicates that the transaction includes industry-specific data. Possible Values:

  • airline
  • restaurant
  • lodging
  • auto_rental
  • transit
  • healthcare_medical
  • healthcare_transit
  • transit

Card Present, Airlines and Auto Rental

You must set this field to airline in order for airline data to be sent to the processor. For example, if this field is not set to airline or is not included in the request, no airline data is sent to the processor. You must set this field to restaurant in order for restaurant data to be sent to the processor. When this field is not set to restaurant or is not included in the request, no restaurant data is sent to the processor. You must set this field to auto_rental in order for auto rental data to be sent to the processor. For example, if this field is not set to auto_rental or is not included in the request, no auto rental data is sent to the processor. Restaurant data is supported only on Visa Acceptance through VisaNet.

Returns:



380
381
382
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 380

def purchase_options
  @purchase_options
end

#purpose_of_paymentString

This field is applicable for AFT and OCT transactions. For list of supported values, please refer to Developer Guide.

Returns:

  • (String)


687
688
689
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 687

def purpose_of_payment
  @purpose_of_payment
end

#reconciliation_idString

Please check with Visa Acceptance customer support to see if your merchant account is configured correctly so you can include this field in your request.

  • For Payouts: max length for FDCCompass is String (22).

Returns:

  • (String)


180
181
182
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 180

def reconciliation_id
  @reconciliation_id
end

#recurring_optionsRecurringOptions

Indicates that the transaction includes industry-specific data. Possible Values:

  • airline
  • restaurant
  • lodging
  • auto_rental
  • transit
  • healthcare_medical
  • healthcare_transit
  • transit

Card Present, Airlines and Auto Rental

You must set this field to airline in order for airline data to be sent to the processor. For example, if this field is not set to airline or is not included in the request, no airline data is sent to the processor. You must set this field to restaurant in order for restaurant data to be sent to the processor. When this field is not set to restaurant or is not included in the request, no restaurant data is sent to the processor. You must set this field to auto_rental in order for auto rental data to be sent to the processor. For example, if this field is not set to auto_rental or is not included in the request, no auto rental data is sent to the processor. Restaurant data is supported only on Visa Acceptance through VisaNet.

Returns:



326
327
328
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 326

def recurring_options
  @recurring_options
end

#report_groupString

Attribute that lets you define custom grouping for your processor reports. This field is supported only for Worldpay VAP.

Returns:

  • (String)


212
213
214
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 212

def report_group
  @report_group
end

#timeoutInteger

Minutes until a pending MyBank transaction will be timed out. Value must be between 5 and 30. Default is 5.

Returns:

  • (Integer)


607
608
609
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 607

def timeout
  @timeout
end

#transaction_timeoutInteger

The time-out limit in seconds for the transaction. The time-out limit starts when the customer is directed to the merchant URL that is included in the sale service response. The maximum value is 99999 (about 27 hours). When the transaction times out, the payment system changes the status to abandoned.

Returns:

  • (Integer)


202
203
204
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 202

def transaction_timeout
  @transaction_timeout
end

#transaction_type_indicatorString

This field is used identify the type of payment transaction taking place. This field is applicable for MasterCard transactions only. Possible values:

  • 201- Mastercard Rebate
  • 202- rePower Load Value
  • 203- Gaming Re-pay
  • 204- General Person-to-Person
  • 205- General Transfer to Own Account
  • 206- Agent Cash Out
  • 207- Payment of Own Credit Card Bill
  • 208- Business Disbursement
  • 209- Government/Non-Profit Disbursement
  • 210- Rapid Merchant Settlement
  • 211- Cash in at ATM (Usage limited to specific countries)
  • 212- Cash in at Point of Sale (Usage limited to specific countries)
  • 213- General Business to Business Transfer
  • 214- Mastercard Merchant Presented QR
  • 215- Mastercard Merchant Presented QR Refund Payment
  • 216- Utility Payments (for Brazil domestic use only)
  • 217- Government Services (for Brazil domestic use only)
  • 218- Mobile phone top-ups (for Brazil domestic use only)
  • 219- Coupon booklet payments (for Brazil domestic use only)
  • 220- General Person-to-Person Transfer
  • 221- Person-to-Person Transfer to Card Account
  • 222- General Transfer to Own Account
  • 223- Agent Cash Out
  • 224- Payment of Own Credit Card Bill
  • 225- Business Disbursement
  • 226- Transfer to Own Staged Digital Wallet Account
  • 227- Transfer to Own Debit or Prepaid Account
  • 228- General Business-to-Business Transfer
  • 229- Installment-based repayment
  • 230- Mastercard ATM Cash Pick-Up Transaction
  • 231- Cryptocurrency
  • 232- High-risk Securities

Returns:

  • (String)


682
683
684
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 682

def transaction_type_indicator
  @transaction_type_indicator
end

#visa_checkout_idString

Identifier for the Visa Checkout order. Visa Checkout provides a unique order ID for every transaction in the Visa Checkout callID field.

Returns:

  • (String)


218
219
220
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 218

def visa_checkout_id
  @visa_checkout_id
end

#wallet_typeString

This field carries the wallet type in authorization requests and credit requests. Possible value are:

  • 101: Masterpass remote payment. The customer created the wallet by manually interacting with a customer-controlled device such as a computer, tablet, or phone. This value is supported only for Masterpass transactions on Chase Paymentech Solutions and Visa Acceptance through VisaNet.
  • 102: Masterpass remote near field communication (NFC) payment. The customer created the wallet by tapping a PayPass card or customer-controlled device at a contactless card reader. This value is supported only for card-present Masterpass transactions on Visa Acceptance through VisaNet.
  • 103: Masterpass Apple Pay payment. The payment was made with a combination of Masterpass and Apple Pay. This value is supported only for Masterpass Apple Pay transactions on Visa Acceptance through VisaNet.
  • 216: Masterpass Google Pay payment. The payment was made with a combination of Masterpass and Google Pay. This value is supported only for Masterpass Google Pay transactions on Visa Acceptance through VisaNet.
  • 217: Masterpass Samsung Pay payment. The payment was made with a combination of Masterpass and Samsung Pay. This value is supported only for Masterpass Samsung Pay transactions on Visa Acceptance through VisaNet.
  • SDW: Staged digital wallet. An issuer or operator created the wallet. This value is supported only for Masterpass transactions on Chase Paymentech Solutions.
  • VCIND: Visa Checkout payment. This value is supported only on Visa Acceptance through VisaNet, FDC Compass, FDC Nashville Global, FDI Australia, and TSYS Acquiring Solutions. See Getting Started with Visa Checkout. For Visa Checkout transactions, the way Visa Acceptance processes the value for this field depends on the processor. See the Visa Checkout section below. For all other values, this field is a passthrough; therefore, Visa Acceptance does not verify the value or modify it in any way before sending it to the processor. Masterpass (101, 102, 103, 216, and 217): The Masterpass platform generates the wallet type value and passes it to you along with the customer’s checkout information. Visa Checkout: This field is optional for Visa Checkout authorizations on FDI Australia. For all other processors, this field is required for Visa Checkout authorizations. For Visa Checkout transactions on the following processors, Visa Acceptance sends the value that the processor expects for this field:FDC Compass,FDC Nashville Global,FDI Australia,TSYS Acquiring Solutions For all other processors, this field is a passthrough; therefore, Visa Acceptance does not verify the value or modify it in any way before sending it to the processor. For incremental authorizations, this field is supported only for Mastercard and the supported values are 101 and 102. Payment card companies can introduce new values without notice. Your order management system should be able to process new values without problems. Visa Acceptance through VisaNet When the value for this field is 101, 102, 103, 216, or 217, it corresponds to the following data in the TC 33 capture file5: Record: CP01 TCR6, Position: 88-90, Field: Mastercard Wallet Identifier. When the value for this field is VCIND, it corresponds to the following data in the TC 33 capture file5: Record: CP01 TCR8, Position: 72-76, Field: Agent Unique ID.

Returns:

  • (String)


494
495
496
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 494

def wallet_type
  @wallet_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 891

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  action_list = hash.key?('actionList') ? hash['actionList'] : SKIP
  enable_escrow_option =
    hash.key?('enableEscrowOption') ? hash['enableEscrowOption'] : SKIP
  action_token_types =
    hash.key?('actionTokenTypes') ? hash['actionTokenTypes'] : SKIP
  bin_source = hash.key?('binSource') ? hash['binSource'] : SKIP
  capture = hash['capture'] ||= false
  processor_id = hash.key?('processorId') ? hash['processorId'] : SKIP
  business_application_id =
    hash.key?('businessApplicationId') ? hash['businessApplicationId'] : SKIP
  commerce_indicator =
    hash.key?('commerceIndicator') ? hash['commerceIndicator'] : SKIP
  commerce_indicator_label =
    hash.key?('commerceIndicatorLabel') ? hash['commerceIndicatorLabel'] : SKIP
  payment_solution =
    hash.key?('paymentSolution') ? hash['paymentSolution'] : SKIP
  reconciliation_id =
    hash.key?('reconciliationId') ? hash['reconciliationId'] : SKIP
  link_id = hash.key?('linkId') ? hash['linkId'] : SKIP
  purchase_level = hash.key?('purchaseLevel') ? hash['purchaseLevel'] : SKIP
  transaction_timeout =
    hash.key?('transactionTimeout') ? hash['transactionTimeout'] : SKIP
  intents_id = hash.key?('intentsId') ? hash['intentsId'] : SKIP
  report_group = hash.key?('reportGroup') ? hash['reportGroup'] : SKIP
  visa_checkout_id =
    hash.key?('visaCheckoutId') ? hash['visaCheckoutId'] : SKIP
  industry_data_type =
    hash.key?('industryDataType') ? hash['industryDataType'] : SKIP
  authorization_options = AuthorizationOptions.from_hash(hash['authorizationOptions']) if
    hash['authorizationOptions']
  capture_options = CaptureOptions.from_hash(hash['captureOptions']) if hash['captureOptions']
  recurring_options = RecurringOptions.from_hash(hash['recurringOptions']) if
    hash['recurringOptions']
  bank_transfer_options = BankTransferOptions.from_hash(hash['bankTransferOptions']) if
    hash['bankTransferOptions']
  purchase_options = PurchaseOptions.from_hash(hash['purchaseOptions']) if
    hash['purchaseOptions']
  if hash['electronicBenefitsTransfer']
    electronic_benefits_transfer = ElectronicBenefitsTransfer.from_hash(hash['electronicBenefitsTransfer'])
  end
  loan_options = LoanOptions.from_hash(hash['loanOptions']) if hash['loanOptions']
  wallet_type = hash.key?('walletType') ? hash['walletType'] : SKIP
  national_net_domestic_data =
    hash.key?('nationalNetDomesticData') ? hash['nationalNetDomesticData'] : SKIP
  japan_payment_options = JapanPaymentOptions.from_hash(hash['japanPaymentOptions']) if
    hash['japanPaymentOptions']
  mobile_remote_payment_type =
    hash.key?('mobileRemotePaymentType') ? hash['mobileRemotePaymentType'] : SKIP
  extended_credit_total_count =
    hash.key?('extendedCreditTotalCount') ? hash['extendedCreditTotalCount'] : SKIP
  network_routing_order =
    hash.key?('networkRoutingOrder') ? hash['networkRoutingOrder'] : SKIP
  pay_by_points_indicator =
    hash.key?('payByPointsIndicator') ? hash['payByPointsIndicator'] : SKIP
  timeout = hash.key?('timeout') ? hash['timeout'] : SKIP
  is_return_auth_record_enabled =
    hash.key?('isReturnAuthRecordEnabled') ? hash['isReturnAuthRecordEnabled'] : SKIP
  network_partner_id =
    hash.key?('networkPartnerId') ? hash['networkPartnerId'] : SKIP
  payment_type = hash.key?('paymentType') ? hash['paymentType'] : SKIP
  enabler_id = hash.key?('enablerId') ? hash['enablerId'] : SKIP
  processing_instruction =
    hash.key?('processingInstruction') ? hash['processingInstruction'] : SKIP
  transaction_type_indicator =
    hash.key?('transactionTypeIndicator') ? hash['transactionTypeIndicator'] : SKIP
  purpose_of_payment =
    hash.key?('purposeOfPayment') ? hash['purposeOfPayment'] : SKIP
  language_code = hash.key?('languageCode') ? hash['languageCode'] : SKIP
  original_payment_id =
    hash.key?('originalPaymentId') ? hash['originalPaymentId'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProcessingInformation.new(action_list: action_list,
                            enable_escrow_option: enable_escrow_option,
                            action_token_types: action_token_types,
                            bin_source: bin_source,
                            capture: capture,
                            processor_id: processor_id,
                            business_application_id: business_application_id,
                            commerce_indicator: commerce_indicator,
                            commerce_indicator_label: commerce_indicator_label,
                            payment_solution: payment_solution,
                            reconciliation_id: reconciliation_id,
                            link_id: link_id,
                            purchase_level: purchase_level,
                            transaction_timeout: transaction_timeout,
                            intents_id: intents_id,
                            report_group: report_group,
                            visa_checkout_id: visa_checkout_id,
                            industry_data_type: industry_data_type,
                            authorization_options: authorization_options,
                            capture_options: capture_options,
                            recurring_options: recurring_options,
                            bank_transfer_options: bank_transfer_options,
                            purchase_options: purchase_options,
                            electronic_benefits_transfer: electronic_benefits_transfer,
                            loan_options: loan_options,
                            wallet_type: wallet_type,
                            national_net_domestic_data: national_net_domestic_data,
                            japan_payment_options: japan_payment_options,
                            mobile_remote_payment_type: mobile_remote_payment_type,
                            extended_credit_total_count: extended_credit_total_count,
                            network_routing_order: network_routing_order,
                            pay_by_points_indicator: pay_by_points_indicator,
                            timeout: timeout,
                            is_return_auth_record_enabled: is_return_auth_record_enabled,
                            network_partner_id: network_partner_id,
                            payment_type: payment_type,
                            enabler_id: enabler_id,
                            processing_instruction: processing_instruction,
                            transaction_type_indicator: transaction_type_indicator,
                            purpose_of_payment: purpose_of_payment,
                            language_code: language_code,
                            original_payment_id: original_payment_id,
                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 701

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['action_list'] = 'actionList'
  @_hash['enable_escrow_option'] = 'enableEscrowOption'
  @_hash['action_token_types'] = 'actionTokenTypes'
  @_hash['bin_source'] = 'binSource'
  @_hash['capture'] = 'capture'
  @_hash['processor_id'] = 'processorId'
  @_hash['business_application_id'] = 'businessApplicationId'
  @_hash['commerce_indicator'] = 'commerceIndicator'
  @_hash['commerce_indicator_label'] = 'commerceIndicatorLabel'
  @_hash['payment_solution'] = 'paymentSolution'
  @_hash['reconciliation_id'] = 'reconciliationId'
  @_hash['link_id'] = 'linkId'
  @_hash['purchase_level'] = 'purchaseLevel'
  @_hash['transaction_timeout'] = 'transactionTimeout'
  @_hash['intents_id'] = 'intentsId'
  @_hash['report_group'] = 'reportGroup'
  @_hash['visa_checkout_id'] = 'visaCheckoutId'
  @_hash['industry_data_type'] = 'industryDataType'
  @_hash['authorization_options'] = 'authorizationOptions'
  @_hash['capture_options'] = 'captureOptions'
  @_hash['recurring_options'] = 'recurringOptions'
  @_hash['bank_transfer_options'] = 'bankTransferOptions'
  @_hash['purchase_options'] = 'purchaseOptions'
  @_hash['electronic_benefits_transfer'] = 'electronicBenefitsTransfer'
  @_hash['loan_options'] = 'loanOptions'
  @_hash['wallet_type'] = 'walletType'
  @_hash['national_net_domestic_data'] = 'nationalNetDomesticData'
  @_hash['japan_payment_options'] = 'japanPaymentOptions'
  @_hash['mobile_remote_payment_type'] = 'mobileRemotePaymentType'
  @_hash['extended_credit_total_count'] = 'extendedCreditTotalCount'
  @_hash['network_routing_order'] = 'networkRoutingOrder'
  @_hash['pay_by_points_indicator'] = 'payByPointsIndicator'
  @_hash['timeout'] = 'timeout'
  @_hash['is_return_auth_record_enabled'] = 'isReturnAuthRecordEnabled'
  @_hash['network_partner_id'] = 'networkPartnerId'
  @_hash['payment_type'] = 'paymentType'
  @_hash['enabler_id'] = 'enablerId'
  @_hash['processing_instruction'] = 'processingInstruction'
  @_hash['transaction_type_indicator'] = 'transactionTypeIndicator'
  @_hash['purpose_of_payment'] = 'purposeOfPayment'
  @_hash['language_code'] = 'languageCode'
  @_hash['original_payment_id'] = 'originalPaymentId'
  @_hash
end

.nullablesObject

An array for nullable fields



797
798
799
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 797

def self.nullables
  []
end

.optionalsObject

An array for optional fields



749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 749

def self.optionals
  %w[
    action_list
    enable_escrow_option
    action_token_types
    bin_source
    capture
    processor_id
    business_application_id
    commerce_indicator
    commerce_indicator_label
    payment_solution
    reconciliation_id
    link_id
    purchase_level
    transaction_timeout
    intents_id
    report_group
    visa_checkout_id
    industry_data_type
    authorization_options
    capture_options
    recurring_options
    bank_transfer_options
    purchase_options
    electronic_benefits_transfer
    loan_options
    wallet_type
    national_net_domestic_data
    japan_payment_options
    mobile_remote_payment_type
    extended_credit_total_count
    network_routing_order
    pay_by_points_indicator
    timeout
    is_return_auth_record_enabled
    network_partner_id
    payment_type
    enabler_id
    processing_instruction
    transaction_type_indicator
    purpose_of_payment
    language_code
    original_payment_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 1049

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} action_list: #{@action_list.inspect}, enable_escrow_option:"\
  " #{@enable_escrow_option.inspect}, action_token_types: #{@action_token_types.inspect},"\
  " bin_source: #{@bin_source.inspect}, capture: #{@capture.inspect}, processor_id:"\
  " #{@processor_id.inspect}, business_application_id: #{@business_application_id.inspect},"\
  " commerce_indicator: #{@commerce_indicator.inspect}, commerce_indicator_label:"\
  " #{@commerce_indicator_label.inspect}, payment_solution: #{@payment_solution.inspect},"\
  " reconciliation_id: #{@reconciliation_id.inspect}, link_id: #{@link_id.inspect},"\
  " purchase_level: #{@purchase_level.inspect}, transaction_timeout:"\
  " #{@transaction_timeout.inspect}, intents_id: #{@intents_id.inspect}, report_group:"\
  " #{@report_group.inspect}, visa_checkout_id: #{@visa_checkout_id.inspect},"\
  " industry_data_type: #{@industry_data_type.inspect}, authorization_options:"\
  " #{@authorization_options.inspect}, capture_options: #{@capture_options.inspect},"\
  " recurring_options: #{@recurring_options.inspect}, bank_transfer_options:"\
  " #{@bank_transfer_options.inspect}, purchase_options: #{@purchase_options.inspect},"\
  " electronic_benefits_transfer: #{@electronic_benefits_transfer.inspect}, loan_options:"\
  " #{@loan_options.inspect}, wallet_type: #{@wallet_type.inspect},"\
  " national_net_domestic_data: #{@national_net_domestic_data.inspect}, japan_payment_options:"\
  " #{@japan_payment_options.inspect}, mobile_remote_payment_type:"\
  " #{@mobile_remote_payment_type.inspect}, extended_credit_total_count:"\
  " #{@extended_credit_total_count.inspect}, network_routing_order:"\
  " #{@network_routing_order.inspect}, pay_by_points_indicator:"\
  " #{@pay_by_points_indicator.inspect}, timeout: #{@timeout.inspect},"\
  " is_return_auth_record_enabled: #{@is_return_auth_record_enabled.inspect},"\
  " network_partner_id: #{@network_partner_id.inspect}, payment_type:"\
  " #{@payment_type.inspect}, enabler_id: #{@enabler_id.inspect}, processing_instruction:"\
  " #{@processing_instruction.inspect}, transaction_type_indicator:"\
  " #{@transaction_type_indicator.inspect}, purpose_of_payment:"\
  " #{@purpose_of_payment.inspect}, language_code: #{@language_code.inspect},"\
  " original_payment_id: #{@original_payment_id.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
# File 'lib/visa_acceptance_merged_spec/models/processing_information.rb', line 1020

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} action_list: #{@action_list}, enable_escrow_option:"\
  " #{@enable_escrow_option}, action_token_types: #{@action_token_types}, bin_source:"\
  " #{@bin_source}, capture: #{@capture}, processor_id: #{@processor_id},"\
  " business_application_id: #{@business_application_id}, commerce_indicator:"\
  " #{@commerce_indicator}, commerce_indicator_label: #{@commerce_indicator_label},"\
  " payment_solution: #{@payment_solution}, reconciliation_id: #{@reconciliation_id}, link_id:"\
  " #{@link_id}, purchase_level: #{@purchase_level}, transaction_timeout:"\
  " #{@transaction_timeout}, intents_id: #{@intents_id}, report_group: #{@report_group},"\
  " visa_checkout_id: #{@visa_checkout_id}, industry_data_type: #{@industry_data_type},"\
  " authorization_options: #{@authorization_options}, capture_options: #{@capture_options},"\
  " recurring_options: #{@recurring_options}, bank_transfer_options:"\
  " #{@bank_transfer_options}, purchase_options: #{@purchase_options},"\
  " electronic_benefits_transfer: #{@electronic_benefits_transfer}, loan_options:"\
  " #{@loan_options}, wallet_type: #{@wallet_type}, national_net_domestic_data:"\
  " #{@national_net_domestic_data}, japan_payment_options: #{@japan_payment_options},"\
  " mobile_remote_payment_type: #{@mobile_remote_payment_type}, extended_credit_total_count:"\
  " #{@extended_credit_total_count}, network_routing_order: #{@network_routing_order},"\
  " pay_by_points_indicator: #{@pay_by_points_indicator}, timeout: #{@timeout},"\
  " is_return_auth_record_enabled: #{@is_return_auth_record_enabled}, network_partner_id:"\
  " #{@network_partner_id}, payment_type: #{@payment_type}, enabler_id: #{@enabler_id},"\
  " processing_instruction: #{@processing_instruction}, transaction_type_indicator:"\
  " #{@transaction_type_indicator}, purpose_of_payment: #{@purpose_of_payment}, language_code:"\
  " #{@language_code}, original_payment_id: #{@original_payment_id}, additional_properties:"\
  " #{@additional_properties}>"
end