Class: VisaAcceptanceMergedSpec::ProcessingInformation11

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/processing_information11.rb

Overview

ProcessingInformation11 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(commerce_indicator: SKIP, processor_id: SKIP, payment_solution: SKIP, reconciliation_id: SKIP, link_id: SKIP, report_group: SKIP, visa_checkout_id: SKIP, purchase_level: SKIP, industry_data_type: SKIP, wallet_type: SKIP, national_net_domestic_data: SKIP, network_routing_order: SKIP, recurring_options: SKIP, bank_transfer_options: SKIP, purchase_options: SKIP, electronic_benefits_transfer: SKIP, loan_options: SKIP, japan_payment_options: SKIP, refund_options: SKIP, additional_properties: nil) ⇒ ProcessingInformation11

Returns a new instance of ProcessingInformation11.



550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
# File 'lib/visa_acceptance_merged_spec/models/processing_information11.rb', line 550

def initialize(commerce_indicator: SKIP, processor_id: SKIP,
               payment_solution: SKIP, reconciliation_id: SKIP,
               link_id: SKIP, report_group: SKIP, visa_checkout_id: SKIP,
               purchase_level: SKIP, industry_data_type: SKIP,
               wallet_type: SKIP, national_net_domestic_data: SKIP,
               network_routing_order: SKIP, recurring_options: SKIP,
               bank_transfer_options: SKIP, purchase_options: SKIP,
               electronic_benefits_transfer: SKIP, loan_options: SKIP,
               japan_payment_options: SKIP, refund_options: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @commerce_indicator = commerce_indicator unless commerce_indicator == SKIP
  @processor_id = processor_id unless processor_id == SKIP
  @payment_solution = payment_solution unless payment_solution == SKIP
  @reconciliation_id = reconciliation_id unless reconciliation_id == SKIP
  @link_id = link_id unless link_id == SKIP
  @report_group = report_group unless report_group == SKIP
  @visa_checkout_id = visa_checkout_id unless visa_checkout_id == SKIP
  @purchase_level = purchase_level unless purchase_level == SKIP
  @industry_data_type = industry_data_type unless industry_data_type == SKIP
  @wallet_type = wallet_type unless wallet_type == SKIP
  unless national_net_domestic_data == SKIP
    @national_net_domestic_data =
      national_net_domestic_data
  end
  @network_routing_order = network_routing_order unless network_routing_order == SKIP
  @recurring_options = recurring_options unless recurring_options == SKIP
  @bank_transfer_options = bank_transfer_options unless bank_transfer_options == SKIP
  @purchase_options = purchase_options unless purchase_options == SKIP
  unless electronic_benefits_transfer == SKIP
    @electronic_benefits_transfer =
      electronic_benefits_transfer
  end
  @loan_options = loan_options unless loan_options == SKIP
  @japan_payment_options = japan_payment_options unless japan_payment_options == SKIP
  @refund_options = refund_options unless refund_options == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#bank_transfer_optionsBankTransferOptions2

On PIN Debit Gateways: This U.S.-only field is optionally used by participants (merchants and acquirers) to specify the network access priority. VisaNet checks to determine if there are issuer routing preferences for any of the networks specified by the sharing group code. If an issuer preference exists for one of the specified debit networks, VisaNet makes a routing selection based on the issuer’s preference. If an issuer preference exists for more than one of the specified debit networks, or if no issuer preference exists, VisaNet makes a selection based on the acquirer’s routing priorities.

PIN debit

Priority order of the networks through which he transaction will be routed. Set this value to a series of one-character network codes in your preferred order. This is a list of the network codes:

Network Code
Accel E
AFFN U
Alaska Option 3
CU24 C
Interlink G
Maestro 8
NETS P
NYCE F
Pulse H
Shazam 7
Star M
Visa V

For example, if the Star network is your first preference and Pulse is your second preference, set this field to a value of MH. When you do not include this value in your PIN debit request, the list of network codes from your account is used. Note This field is supported only for businesses located in the U.S. Optional field for PIN debit credit or PIN debit purchase.



308
309
310
# File 'lib/visa_acceptance_merged_spec/models/processing_information11.rb', line 308

def bank_transfer_options
  @bank_transfer_options
end

#commerce_indicatorString

Type of transaction. Some payment card companies use this information when determining discount rates.

Used by

Authorization Required payer authentication transactions; otherwise, optional. Credit Required for standalone credits on Chase Paymentech solutions; otherwise, optional. The list of valid values in this field depends on your processor.

Ingenico ePayments

When you omit this field for Ingenico ePayments, the processor uses the default transaction type they have on file for you instead of the default value

Card Present

You must set this field to retail. This field is required for a card-present transaction. Note that this should ONLY be used when the cardholder and card are present at the time of the transaction. For all keyed transactions originated from a POS terminal where the cardholder and card are not present, commerceIndicator should be submitted as “moto"

Returns:

  • (String)


34
35
36
# File 'lib/visa_acceptance_merged_spec/models/processing_information11.rb', line 34

def commerce_indicator
  @commerce_indicator
end

#electronic_benefits_transferElectronicBenefitsTransfer1

On PIN Debit Gateways: This U.S.-only field is optionally used by participants (merchants and acquirers) to specify the network access priority. VisaNet checks to determine if there are issuer routing preferences for any of the networks specified by the sharing group code. If an issuer preference exists for one of the specified debit networks, VisaNet makes a routing selection based on the issuer’s preference. If an issuer preference exists for more than one of the specified debit networks, or if no issuer preference exists, VisaNet makes a selection based on the acquirer’s routing priorities.

PIN debit

Priority order of the networks through which he transaction will be routed. Set this value to a series of one-character network codes in your preferred order. This is a list of the network codes:

Network Code
Accel E
AFFN U
Alaska Option 3
CU24 C
Interlink G
Maestro 8
NETS P
NYCE F
Pulse H
Shazam 7
Star M
Visa V

For example, if the Star network is your first preference and Pulse is your second preference, set this field to a value of MH. When you do not include this value in your PIN debit request, the list of network codes from your account is used. Note This field is supported only for businesses located in the U.S. Optional field for PIN debit credit or PIN debit purchase.



382
383
384
# File 'lib/visa_acceptance_merged_spec/models/processing_information11.rb', line 382

def electronic_benefits_transfer
  @electronic_benefits_transfer
end

#industry_data_typeString

Indicates that the transaction includes industry-specific data. Possible Values:

  • airline
  • restaurant
  • lodging
  • auto_rental
  • transit
  • healthcare_medical
  • healthcare_transit
  • transit

Card Present, Airlines and Auto Rental

You must set this field to airline in order for airline data to be sent to the processor. For example, if this field is not set to airline or is not included in the request, no airline data is sent to the processor. You must set this field to restaurant in order for restaurant data to be sent to the processor. When this field is not set to restaurant or is not included in the request, no restaurant data is sent to the processor. You must set this field to auto_rental in order for auto rental data to be sent to the processor. For example, if this field is not set to auto_rental or is not included in the request, no auto rental data is sent to the processor. Restaurant data is supported only on Visa Acceptance through VisaNet.

Returns:

  • (String)


123
124
125
# File 'lib/visa_acceptance_merged_spec/models/processing_information11.rb', line 123

def industry_data_type
  @industry_data_type
end

#japan_payment_optionsJapanPaymentOptions1

On PIN Debit Gateways: This U.S.-only field is optionally used by participants (merchants and acquirers) to specify the network access priority. VisaNet checks to determine if there are issuer routing preferences for any of the networks specified by the sharing group code. If an issuer preference exists for one of the specified debit networks, VisaNet makes a routing selection based on the issuer’s preference. If an issuer preference exists for more than one of the specified debit networks, or if no issuer preference exists, VisaNet makes a selection based on the acquirer’s routing priorities.

PIN debit

Priority order of the networks through which he transaction will be routed. Set this value to a series of one-character network codes in your preferred order. This is a list of the network codes:

Network Code
Accel E
AFFN U
Alaska Option 3
CU24 C
Interlink G
Maestro 8
NETS P
NYCE F
Pulse H
Shazam 7
Star M
Visa V

For example, if the Star network is your first preference and Pulse is your second preference, set this field to a value of MH. When you do not include this value in your PIN debit request, the list of network codes from your account is used. Note This field is supported only for businesses located in the U.S. Optional field for PIN debit credit or PIN debit purchase.



456
457
458
# File 'lib/visa_acceptance_merged_spec/models/processing_information11.rb', line 456

def japan_payment_options
  @japan_payment_options
end

Value that links the current authorization request to the original authorization request. Set this value to the ID that was returned in the reply message from the original authorization request. This value is used for:

  • Partial authorizations
  • Split shipments

Returns:

  • (String)


81
82
83
# File 'lib/visa_acceptance_merged_spec/models/processing_information11.rb', line 81

def link_id
  @link_id
end

#loan_optionsLoanOptions

On PIN Debit Gateways: This U.S.-only field is optionally used by participants (merchants and acquirers) to specify the network access priority. VisaNet checks to determine if there are issuer routing preferences for any of the networks specified by the sharing group code. If an issuer preference exists for one of the specified debit networks, VisaNet makes a routing selection based on the issuer’s preference. If an issuer preference exists for more than one of the specified debit networks, or if no issuer preference exists, VisaNet makes a selection based on the acquirer’s routing priorities.

PIN debit

Priority order of the networks through which he transaction will be routed. Set this value to a series of one-character network codes in your preferred order. This is a list of the network codes:

Network Code
Accel E
AFFN U
Alaska Option 3
CU24 C
Interlink G
Maestro 8
NETS P
NYCE F
Pulse H
Shazam 7
Star M
Visa V

For example, if the Star network is your first preference and Pulse is your second preference, set this field to a value of MH. When you do not include this value in your PIN debit request, the list of network codes from your account is used. Note This field is supported only for businesses located in the U.S. Optional field for PIN debit credit or PIN debit purchase.

Returns:



419
420
421
# File 'lib/visa_acceptance_merged_spec/models/processing_information11.rb', line 419

def loan_options
  @loan_options
end

#national_net_domestic_dataString

Supplementary domestic transaction information provided by the acquirer for National Net Settlement Service (NNSS) transactions. NNSS is a settlement service that Visa provides. For transactions on Visa Acceptance through VisaNet in countries that subscribe to NNSS: VisaNet clears transactions; VisaNet transfers funds to the acquirer after deducting processing fees and interchange fees. VisaNet settles transactions in the local pricing currency through a local financial institution. This field is supported only on Visa Acceptance through VisaNet for domestic data in Colombia

Returns:

  • (String)


197
198
199
# File 'lib/visa_acceptance_merged_spec/models/processing_information11.rb', line 197

def national_net_domestic_data
  @national_net_domestic_data
end

#network_routing_orderString

On PIN Debit Gateways: This U.S.-only field is optionally used by participants (merchants and acquirers) to specify the network access priority. VisaNet checks to determine if there are issuer routing preferences for any of the networks specified by the sharing group code. If an issuer preference exists for one of the specified debit networks, VisaNet makes a routing selection based on the issuer’s preference. If an issuer preference exists for more than one of the specified debit networks, or if no issuer preference exists, VisaNet makes a selection based on the acquirer’s routing priorities.

PIN debit

Priority order of the networks through which he transaction will be routed. Set this value to a series of one-character network codes in your preferred order. This is a list of the network codes:

Network Code
Accel E
AFFN U
Alaska Option 3
CU24 C
Interlink G
Maestro 8
NETS P
NYCE F
Pulse H
Shazam 7
Star M
Visa V

For example, if the Star network is your first preference and Pulse is your second preference, set this field to a value of MH. When you do not include this value in your PIN debit request, the list of network codes from your account is used. Note This field is supported only for businesses located in the U.S. Optional field for PIN debit credit or PIN debit purchase.

Returns:

  • (String)


234
235
236
# File 'lib/visa_acceptance_merged_spec/models/processing_information11.rb', line 234

def network_routing_order
  @network_routing_order
end

#payment_solutionString

Type of digital payment solution for the transaction. Possible Values:

  • visacheckout: Visa Checkout. This value is required for Visa Checkout transactions. For details, see payment_solution field description in [Visa Checkout Using the REST API.](
  • 001: Apple Pay.
  • 004: Visa Acceptance In-App Solution.
  • 005: Masterpass. This value is required for Masterpass transactions on OmniPay Direct.
  • 006: Android Pay.
  • 007: Chase Pay.
  • 008: Samsung Pay.
  • 012: Google Pay.
  • 013: Visa Acceptance P2PE Decryption
  • 014: Mastercard credential on file (COF) payment network token. Returned in authorizations that use a payment network token associated with a TMS token.
  • 015: Visa credential on file (COF) payment network token. Returned in authorizations that use a payment network token associated with a TMS token.
  • 027: Click to Pay.

Returns:

  • (String)


64
65
66
# File 'lib/visa_acceptance_merged_spec/models/processing_information11.rb', line 64

def payment_solution
  @payment_solution
end

#processor_idString

Value that identifies the processor/acquirer to use for the transaction. This value is supported only for Visa Acceptance through VisaNet. Contact Visa Acceptance Customer Support to get the value for this field.

Returns:

  • (String)


41
42
43
# File 'lib/visa_acceptance_merged_spec/models/processing_information11.rb', line 41

def processor_id
  @processor_id
end

#purchase_levelString

Set this field to 3 to indicate that the request includes Level III data.

Returns:

  • (String)


96
97
98
# File 'lib/visa_acceptance_merged_spec/models/processing_information11.rb', line 96

def purchase_level
  @purchase_level
end

#purchase_optionsPurchaseOptions2

On PIN Debit Gateways: This U.S.-only field is optionally used by participants (merchants and acquirers) to specify the network access priority. VisaNet checks to determine if there are issuer routing preferences for any of the networks specified by the sharing group code. If an issuer preference exists for one of the specified debit networks, VisaNet makes a routing selection based on the issuer’s preference. If an issuer preference exists for more than one of the specified debit networks, or if no issuer preference exists, VisaNet makes a selection based on the acquirer’s routing priorities.

PIN debit

Priority order of the networks through which he transaction will be routed. Set this value to a series of one-character network codes in your preferred order. This is a list of the network codes:

Network Code
Accel E
AFFN U
Alaska Option 3
CU24 C
Interlink G
Maestro 8
NETS P
NYCE F
Pulse H
Shazam 7
Star M
Visa V

For example, if the Star network is your first preference and Pulse is your second preference, set this field to a value of MH. When you do not include this value in your PIN debit request, the list of network codes from your account is used. Note This field is supported only for businesses located in the U.S. Optional field for PIN debit credit or PIN debit purchase.

Returns:



345
346
347
# File 'lib/visa_acceptance_merged_spec/models/processing_information11.rb', line 345

def purchase_options
  @purchase_options
end

#reconciliation_idString

Please check with Visa Acceptance customer support to see if your merchant account is configured correctly so you can include this field in your request.

  • For Payouts: max length for FDCCompass is String (22).

Returns:

  • (String)


71
72
73
# File 'lib/visa_acceptance_merged_spec/models/processing_information11.rb', line 71

def reconciliation_id
  @reconciliation_id
end

#recurring_optionsRecurringOptions1

On PIN Debit Gateways: This U.S.-only field is optionally used by participants (merchants and acquirers) to specify the network access priority. VisaNet checks to determine if there are issuer routing preferences for any of the networks specified by the sharing group code. If an issuer preference exists for one of the specified debit networks, VisaNet makes a routing selection based on the issuer’s preference. If an issuer preference exists for more than one of the specified debit networks, or if no issuer preference exists, VisaNet makes a selection based on the acquirer’s routing priorities.

PIN debit

Priority order of the networks through which he transaction will be routed. Set this value to a series of one-character network codes in your preferred order. This is a list of the network codes:

Network Code
Accel E
AFFN U
Alaska Option 3
CU24 C
Interlink G
Maestro 8
NETS P
NYCE F
Pulse H
Shazam 7
Star M
Visa V

For example, if the Star network is your first preference and Pulse is your second preference, set this field to a value of MH. When you do not include this value in your PIN debit request, the list of network codes from your account is used. Note This field is supported only for businesses located in the U.S. Optional field for PIN debit credit or PIN debit purchase.

Returns:



271
272
273
# File 'lib/visa_acceptance_merged_spec/models/processing_information11.rb', line 271

def recurring_options
  @recurring_options
end

#refund_optionsRefundOptions2

On PIN Debit Gateways: This U.S.-only field is optionally used by participants (merchants and acquirers) to specify the network access priority. VisaNet checks to determine if there are issuer routing preferences for any of the networks specified by the sharing group code. If an issuer preference exists for one of the specified debit networks, VisaNet makes a routing selection based on the issuer’s preference. If an issuer preference exists for more than one of the specified debit networks, or if no issuer preference exists, VisaNet makes a selection based on the acquirer’s routing priorities.

PIN debit

Priority order of the networks through which he transaction will be routed. Set this value to a series of one-character network codes in your preferred order. This is a list of the network codes:

Network Code
Accel E
AFFN U
Alaska Option 3
CU24 C
Interlink G
Maestro 8
NETS P
NYCE F
Pulse H
Shazam 7
Star M
Visa V

For example, if the Star network is your first preference and Pulse is your second preference, set this field to a value of MH. When you do not include this value in your PIN debit request, the list of network codes from your account is used. Note This field is supported only for businesses located in the U.S. Optional field for PIN debit credit or PIN debit purchase.

Returns:



493
494
495
# File 'lib/visa_acceptance_merged_spec/models/processing_information11.rb', line 493

def refund_options
  @refund_options
end

#report_groupString

Attribute that lets you define custom grouping for your processor reports. This field is supported only for Worldpay VAP.

Returns:

  • (String)


86
87
88
# File 'lib/visa_acceptance_merged_spec/models/processing_information11.rb', line 86

def report_group
  @report_group
end

#visa_checkout_idString

Identifier for the Visa Checkout order. Visa Checkout provides a unique order ID for every transaction in the Visa Checkout callID field.

Returns:

  • (String)


92
93
94
# File 'lib/visa_acceptance_merged_spec/models/processing_information11.rb', line 92

def visa_checkout_id
  @visa_checkout_id
end

#wallet_typeString

This field carries the wallet type in authorization requests and credit requests. Possible value are:

  • 101: Masterpass remote payment. The customer created the wallet by manually interacting with a customer-controlled device such as a computer, tablet, or phone. This value is supported only for Masterpass transactions on Chase Paymentech Solutions and Visa Acceptance through VisaNet.
  • 102: Masterpass remote near field communication (NFC) payment. The customer created the wallet by tapping a PayPass card or customer-controlled device at a contactless card reader. This value is supported only for card-present Masterpass transactions on Visa Acceptance through VisaNet.
  • 103: Masterpass Apple Pay payment. The payment was made with a combination of Masterpass and Apple Pay. This value is supported only for Masterpass Apple Pay transactions on Visa Acceptance through VisaNet.
  • 216: Masterpass Google Pay payment. The payment was made with a combination of Masterpass and Google Pay. This value is supported only for Masterpass Google Pay transactions on Visa Acceptance through VisaNet.
  • 217: Masterpass Samsung Pay payment. The payment was made with a combination of Masterpass and Samsung Pay. This value is supported only for Masterpass Samsung Pay transactions on Visa Acceptance through VisaNet.
  • SDW: Staged digital wallet. An issuer or operator created the wallet. This value is supported only for Masterpass transactions on Chase Paymentech Solutions.
  • VCIND: Visa Checkout payment. This value is supported only on Visa Acceptance through VisaNet, FDC Compass, FDC Nashville Global, FDI Australia, and TSYS Acquiring Solutions. See Getting Started with Visa Checkout. For Visa Checkout transactions, the way Visa Acceptance processes the value for this field depends on the processor. See the Visa Checkout section below. For all other values, this field is a passthrough; therefore, Visa Acceptance does not verify the value or modify it in any way before sending it to the processor. Masterpass (101, 102, 103, 216, and 217): The Masterpass platform generates the wallet type value and passes it to you along with the customer’s checkout information. Visa Checkout: This field is optional for Visa Checkout authorizations on FDI Australia. For all other processors, this field is required for Visa Checkout authorizations. For Visa Checkout transactions on the following processors, Visa Acceptance sends the value that the processor expects for this field:FDC Compass,FDC Nashville Global,FDI Australia,TSYS Acquiring Solutions For all other processors, this field is a passthrough; therefore, Visa Acceptance does not verify the value or modify it in any way before sending it to the processor. For incremental authorizations, this field is supported only for Mastercard and the supported values are 101 and 102. Payment card companies can introduce new values without notice. Your order management system should be able to process new values without problems. Visa Acceptance through VisaNet When the value for this field is 101, 102, 103, 216, or 217, it corresponds to the following data in the TC 33 capture file5: Record: CP01 TCR6, Position: 88-90, Field: Mastercard Wallet Identifier. When the value for this field is VCIND, it corresponds to the following data in the TC 33 capture file5: Record: CP01 TCR8, Position: 72-76, Field: Agent Unique ID.

Returns:

  • (String)


183
184
185
# File 'lib/visa_acceptance_merged_spec/models/processing_information11.rb', line 183

def wallet_type
  @wallet_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
# File 'lib/visa_acceptance_merged_spec/models/processing_information11.rb', line 592

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  commerce_indicator =
    hash.key?('commerceIndicator') ? hash['commerceIndicator'] : SKIP
  processor_id = hash.key?('processorId') ? hash['processorId'] : SKIP
  payment_solution =
    hash.key?('paymentSolution') ? hash['paymentSolution'] : SKIP
  reconciliation_id =
    hash.key?('reconciliationId') ? hash['reconciliationId'] : SKIP
  link_id = hash.key?('linkId') ? hash['linkId'] : SKIP
  report_group = hash.key?('reportGroup') ? hash['reportGroup'] : SKIP
  visa_checkout_id =
    hash.key?('visaCheckoutId') ? hash['visaCheckoutId'] : SKIP
  purchase_level = hash.key?('purchaseLevel') ? hash['purchaseLevel'] : SKIP
  industry_data_type =
    hash.key?('industryDataType') ? hash['industryDataType'] : SKIP
  wallet_type = hash.key?('walletType') ? hash['walletType'] : SKIP
  national_net_domestic_data =
    hash.key?('nationalNetDomesticData') ? hash['nationalNetDomesticData'] : SKIP
  network_routing_order =
    hash.key?('networkRoutingOrder') ? hash['networkRoutingOrder'] : SKIP
  recurring_options = RecurringOptions1.from_hash(hash['recurringOptions']) if
    hash['recurringOptions']
  bank_transfer_options = BankTransferOptions2.from_hash(hash['bankTransferOptions']) if
    hash['bankTransferOptions']
  purchase_options = PurchaseOptions2.from_hash(hash['purchaseOptions']) if
    hash['purchaseOptions']
  if hash['electronicBenefitsTransfer']
    electronic_benefits_transfer = ElectronicBenefitsTransfer1.from_hash(hash['electronicBenefitsTransfer'])
  end
  loan_options = LoanOptions.from_hash(hash['loanOptions']) if hash['loanOptions']
  japan_payment_options = JapanPaymentOptions1.from_hash(hash['japanPaymentOptions']) if
    hash['japanPaymentOptions']
  refund_options = RefundOptions2.from_hash(hash['refundOptions']) if hash['refundOptions']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProcessingInformation11.new(commerce_indicator: commerce_indicator,
                              processor_id: processor_id,
                              payment_solution: payment_solution,
                              reconciliation_id: reconciliation_id,
                              link_id: link_id,
                              report_group: report_group,
                              visa_checkout_id: visa_checkout_id,
                              purchase_level: purchase_level,
                              industry_data_type: industry_data_type,
                              wallet_type: wallet_type,
                              national_net_domestic_data: national_net_domestic_data,
                              network_routing_order: network_routing_order,
                              recurring_options: recurring_options,
                              bank_transfer_options: bank_transfer_options,
                              purchase_options: purchase_options,
                              electronic_benefits_transfer: electronic_benefits_transfer,
                              loan_options: loan_options,
                              japan_payment_options: japan_payment_options,
                              refund_options: refund_options,
                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
# File 'lib/visa_acceptance_merged_spec/models/processing_information11.rb', line 496

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['commerce_indicator'] = 'commerceIndicator'
  @_hash['processor_id'] = 'processorId'
  @_hash['payment_solution'] = 'paymentSolution'
  @_hash['reconciliation_id'] = 'reconciliationId'
  @_hash['link_id'] = 'linkId'
  @_hash['report_group'] = 'reportGroup'
  @_hash['visa_checkout_id'] = 'visaCheckoutId'
  @_hash['purchase_level'] = 'purchaseLevel'
  @_hash['industry_data_type'] = 'industryDataType'
  @_hash['wallet_type'] = 'walletType'
  @_hash['national_net_domestic_data'] = 'nationalNetDomesticData'
  @_hash['network_routing_order'] = 'networkRoutingOrder'
  @_hash['recurring_options'] = 'recurringOptions'
  @_hash['bank_transfer_options'] = 'bankTransferOptions'
  @_hash['purchase_options'] = 'purchaseOptions'
  @_hash['electronic_benefits_transfer'] = 'electronicBenefitsTransfer'
  @_hash['loan_options'] = 'loanOptions'
  @_hash['japan_payment_options'] = 'japanPaymentOptions'
  @_hash['refund_options'] = 'refundOptions'
  @_hash
end

.nullablesObject

An array for nullable fields



546
547
548
# File 'lib/visa_acceptance_merged_spec/models/processing_information11.rb', line 546

def self.nullables
  []
end

.optionalsObject

An array for optional fields



521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
# File 'lib/visa_acceptance_merged_spec/models/processing_information11.rb', line 521

def self.optionals
  %w[
    commerce_indicator
    processor_id
    payment_solution
    reconciliation_id
    link_id
    report_group
    visa_checkout_id
    purchase_level
    industry_data_type
    wallet_type
    national_net_domestic_data
    network_routing_order
    recurring_options
    bank_transfer_options
    purchase_options
    electronic_benefits_transfer
    loan_options
    japan_payment_options
    refund_options
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
# File 'lib/visa_acceptance_merged_spec/models/processing_information11.rb', line 675

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} commerce_indicator: #{@commerce_indicator.inspect}, processor_id:"\
  " #{@processor_id.inspect}, payment_solution: #{@payment_solution.inspect},"\
  " reconciliation_id: #{@reconciliation_id.inspect}, link_id: #{@link_id.inspect},"\
  " report_group: #{@report_group.inspect}, visa_checkout_id: #{@visa_checkout_id.inspect},"\
  " purchase_level: #{@purchase_level.inspect}, industry_data_type:"\
  " #{@industry_data_type.inspect}, wallet_type: #{@wallet_type.inspect},"\
  " national_net_domestic_data: #{@national_net_domestic_data.inspect}, network_routing_order:"\
  " #{@network_routing_order.inspect}, recurring_options: #{@recurring_options.inspect},"\
  " bank_transfer_options: #{@bank_transfer_options.inspect}, purchase_options:"\
  " #{@purchase_options.inspect}, electronic_benefits_transfer:"\
  " #{@electronic_benefits_transfer.inspect}, loan_options: #{@loan_options.inspect},"\
  " japan_payment_options: #{@japan_payment_options.inspect}, refund_options:"\
  " #{@refund_options.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



660
661
662
663
664
665
666
667
668
669
670
671
672
# File 'lib/visa_acceptance_merged_spec/models/processing_information11.rb', line 660

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} commerce_indicator: #{@commerce_indicator}, processor_id: #{@processor_id},"\
  " payment_solution: #{@payment_solution}, reconciliation_id: #{@reconciliation_id}, link_id:"\
  " #{@link_id}, report_group: #{@report_group}, visa_checkout_id: #{@visa_checkout_id},"\
  " purchase_level: #{@purchase_level}, industry_data_type: #{@industry_data_type},"\
  " wallet_type: #{@wallet_type}, national_net_domestic_data: #{@national_net_domestic_data},"\
  " network_routing_order: #{@network_routing_order}, recurring_options:"\
  " #{@recurring_options}, bank_transfer_options: #{@bank_transfer_options}, purchase_options:"\
  " #{@purchase_options}, electronic_benefits_transfer: #{@electronic_benefits_transfer},"\
  " loan_options: #{@loan_options}, japan_payment_options: #{@japan_payment_options},"\
  " refund_options: #{@refund_options}, additional_properties: #{@additional_properties}>"
end