Class: VisaAcceptanceMergedSpec::ProcessingInformation20
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::ProcessingInformation20
- Defined in:
- lib/visa_acceptance_merged_spec/models/processing_information20.rb
Overview
ProcessingInformation20 Model.
Instance Attribute Summary collapse
-
#action_list ⇒ Array[String]
- Use
CONSUMER_AUTHENTICATIONto use Payer Authentication along with Decision Manager.
- Use
-
#commerce_indicator ⇒ String
Type of transaction.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(commerce_indicator: SKIP, action_list: SKIP, additional_properties: nil) ⇒ ProcessingInformation20
constructor
A new instance of ProcessingInformation20.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(commerce_indicator: SKIP, action_list: SKIP, additional_properties: nil) ⇒ ProcessingInformation20
Returns a new instance of ProcessingInformation20.
89 90 91 92 93 94 95 96 97 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information20.rb', line 89 def initialize(commerce_indicator: SKIP, action_list: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @commerce_indicator = commerce_indicator unless commerce_indicator == SKIP @action_list = action_list unless action_list == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#action_list ⇒ Array[String]
- Use
CONSUMER_AUTHENTICATIONto use Payer Authentication along with Decision Manager. For any other value, only Decision Manager will run. - Use
WATCHLIST_SCREENINGwhen you want to call Watchlist Screening service. - Use
BILLING_AGREEMENT_CREATEwhen Paypal billing agreements service is requested. - Use
UPDATE_AGREEMENT - Use
CANCEL_AGREEMENT - Use
AP_UPDATE_AGREEMENTwhen Alternative Payment update mandate service is requested. - Use
AP_CANCEL_AGREEMENTwhen Alternative Payment revoke mandate service is requested. - Use
AP_REFRESH_AGREEMENT_STATUSwhen Alternative Payment mandate status service is requested.
66 67 68 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information20.rb', line 66 def action_list @action_list end |
#commerce_indicator ⇒ String
Type of transaction. Used to determine fees based on channel. Possible values:
- aesk: American Express SafeKey authentication was successful.
- aesk_attempted: American Express SafeKey authentication was attempted
but did not succeed. • install: Installment payment.
- install_internet: Non-U.S. e-commerce (Internet) installment payment. This value is supported only on Visa Platform Connect.
- internet (default for authorizations): E-commerce order placed using a web site.
- js: JCB J/Secure authentication was successful.
- js_attempted: JCB J/Secure authentication was attempted but did not succeed.
- moto: Mail order or telephone order.
- moto_cc: Mail order or telephone order from a call center. This value is supported only on the Asia, Middle East, and Africa Gateway.
- pb: ProtectBuy authentication was successful.
- pb_attempted: ProtectBuy authentication was attempted but did not succeed.
- recurring: Recurring payment that is a U.S. transaction or non-U.S. mail order / telephone order (MOTO) transaction.
- recurring_internet: Recurring payment that is a non-U.S. e-commerce (Internet) transaction.
- retail: Card-present transaction.
- spa: For Mastercard Identity Check: Authentication was successful or was attempted but did not succeed. The e-commerce indicator for all Mastercard Identity Check transactions, including authentication attempts, must be set to spa.
- spa_attempted: Authentication for a co-badged Mastercard and Cartes Bancaires card was attempted but did not succeed.
- spa_failure: – For Mastercard Identity Check: Authentication failed. This value is supported only on Elavon, HSBC, and Streamline.
- vbv: – For Visa Secure: Authentication was successful.
- vbv_attempted: – For Visa Secure: Authentication was attempted but did not succeed.
- vbv_failure: – For Visa Secure: Authentication failed. This value is supported only on HSBC and Streamline.
49 50 51 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information20.rb', line 49 def commerce_indicator @commerce_indicator end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information20.rb', line 100 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. commerce_indicator = hash.key?('commerceIndicator') ? hash['commerceIndicator'] : SKIP action_list = hash.key?('actionList') ? hash['actionList'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProcessingInformation20.new(commerce_indicator: commerce_indicator, action_list: action_list, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
69 70 71 72 73 74 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information20.rb', line 69 def self.names @_hash = {} if @_hash.nil? @_hash['commerce_indicator'] = 'commerceIndicator' @_hash['action_list'] = 'actionList' @_hash end |
.nullables ⇒ Object
An array for nullable fields
85 86 87 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information20.rb', line 85 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
77 78 79 80 81 82 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information20.rb', line 77 def self.optionals %w[ commerce_indicator action_list ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
129 130 131 132 133 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information20.rb', line 129 def inspect class_name = self.class.name.split('::').last "<#{class_name} commerce_indicator: #{@commerce_indicator.inspect}, action_list:"\ " #{@action_list.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
122 123 124 125 126 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information20.rb', line 122 def to_s class_name = self.class.name.split('::').last "<#{class_name} commerce_indicator: #{@commerce_indicator}, action_list: #{@action_list},"\ " additional_properties: #{@additional_properties}>" end |