Class: VisaAcceptanceMergedSpec::ProcessingInformation25
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::ProcessingInformation25
- Defined in:
- lib/visa_acceptance_merged_spec/models/processing_information25.rb
Overview
ProcessingInformation25 Model.
Instance Attribute Summary collapse
-
#action_list ⇒ Array[String]
Array of actions (one or more) to be included in the order to invoke bundled services along with order.
-
#authorization_options ⇒ AuthorizationOptions5
The instruction to process an order.
-
#face_id_verification ⇒ String
Indicates if face ID verification is required.
-
#high_risk_transaction_flag ⇒ String
Indicates if the transaction is flagged as high risk.
-
#ip_address ⇒ String
The IP address of the user.
-
#last_one_day_transaction_count ⇒ String
The number of transactions in the last one day.
-
#last_one_hr_transaction_count ⇒ String
The number of transactions in the last one hour.
-
#last_three_months_txn_count ⇒ String
The number of transactions in the last three months.
-
#pin_verification ⇒ String
Indicates if PIN verification is required.
-
#processing_instruction ⇒ String
The instruction to process an order.
-
#tangible ⇒ String
Indicates if the transaction involves tangible goods.
-
#total_transaction_count ⇒ String
The total number of transactions.
-
#transaction_date ⇒ String
The date of the transaction.
-
#transaction_retry ⇒ String
Indicates if the transaction is a retry.
-
#user_passed_verification ⇒ String
Indicates if the user passed verification.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(processing_instruction: SKIP, authorization_options: SKIP, action_list: SKIP, high_risk_transaction_flag: SKIP, transaction_retry: SKIP, last_one_hr_transaction_count: SKIP, last_one_day_transaction_count: SKIP, last_three_months_txn_count: SKIP, total_transaction_count: SKIP, pin_verification: SKIP, face_id_verification: SKIP, user_passed_verification: SKIP, ip_address: SKIP, transaction_date: SKIP, tangible: SKIP, additional_properties: nil) ⇒ ProcessingInformation25
constructor
A new instance of ProcessingInformation25.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(processing_instruction: SKIP, authorization_options: SKIP, action_list: SKIP, high_risk_transaction_flag: SKIP, transaction_retry: SKIP, last_one_hr_transaction_count: SKIP, last_one_day_transaction_count: SKIP, last_three_months_txn_count: SKIP, total_transaction_count: SKIP, pin_verification: SKIP, face_id_verification: SKIP, user_passed_verification: SKIP, ip_address: SKIP, transaction_date: SKIP, tangible: SKIP, additional_properties: nil) ⇒ ProcessingInformation25
Returns a new instance of ProcessingInformation25.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information25.rb', line 127 def initialize(processing_instruction: SKIP, authorization_options: SKIP, action_list: SKIP, high_risk_transaction_flag: SKIP, transaction_retry: SKIP, last_one_hr_transaction_count: SKIP, last_one_day_transaction_count: SKIP, last_three_months_txn_count: SKIP, total_transaction_count: SKIP, pin_verification: SKIP, face_id_verification: SKIP, user_passed_verification: SKIP, ip_address: SKIP, transaction_date: SKIP, tangible: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @processing_instruction = processing_instruction unless processing_instruction == SKIP @authorization_options = unless == SKIP @action_list = action_list unless action_list == SKIP unless high_risk_transaction_flag == SKIP @high_risk_transaction_flag = high_risk_transaction_flag end @transaction_retry = transaction_retry unless transaction_retry == SKIP unless last_one_hr_transaction_count == SKIP @last_one_hr_transaction_count = last_one_hr_transaction_count end unless last_one_day_transaction_count == SKIP @last_one_day_transaction_count = last_one_day_transaction_count end unless last_three_months_txn_count == SKIP @last_three_months_txn_count = last_three_months_txn_count end @total_transaction_count = total_transaction_count unless total_transaction_count == SKIP @pin_verification = pin_verification unless pin_verification == SKIP @face_id_verification = face_id_verification unless face_id_verification == SKIP @user_passed_verification = user_passed_verification unless user_passed_verification == SKIP @ip_address = ip_address unless ip_address == SKIP @transaction_date = transaction_date unless transaction_date == SKIP @tangible = tangible unless tangible == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#action_list ⇒ Array[String]
Array of actions (one or more) to be included in the order to invoke bundled services along with order. Possible values:
AP_ORDER: Use this when Alternative Payment Order service is requested.
30 31 32 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information25.rb', line 30 def action_list @action_list end |
#authorization_options ⇒ AuthorizationOptions5
The instruction to process an order.
- default value: 'NO_INSTRUCTION'
- 'ORDER_SAVED_EXPLICITLY'
22 23 24 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information25.rb', line 22 def @authorization_options end |
#face_id_verification ⇒ String
Indicates if face ID verification is required.
62 63 64 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information25.rb', line 62 def face_id_verification @face_id_verification end |
#high_risk_transaction_flag ⇒ String
Indicates if the transaction is flagged as high risk.
34 35 36 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information25.rb', line 34 def high_risk_transaction_flag @high_risk_transaction_flag end |
#ip_address ⇒ String
The IP address of the user.
70 71 72 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information25.rb', line 70 def ip_address @ip_address end |
#last_one_day_transaction_count ⇒ String
The number of transactions in the last one day.
46 47 48 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information25.rb', line 46 def last_one_day_transaction_count @last_one_day_transaction_count end |
#last_one_hr_transaction_count ⇒ String
The number of transactions in the last one hour.
42 43 44 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information25.rb', line 42 def last_one_hr_transaction_count @last_one_hr_transaction_count end |
#last_three_months_txn_count ⇒ String
The number of transactions in the last three months.
50 51 52 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information25.rb', line 50 def last_three_months_txn_count @last_three_months_txn_count end |
#pin_verification ⇒ String
Indicates if PIN verification is required.
58 59 60 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information25.rb', line 58 def pin_verification @pin_verification end |
#processing_instruction ⇒ String
The instruction to process an order.
- default value: 'NO_INSTRUCTION'
- 'ORDER_SAVED_EXPLICITLY'
16 17 18 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information25.rb', line 16 def processing_instruction @processing_instruction end |
#tangible ⇒ String
Indicates if the transaction involves tangible goods.
78 79 80 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information25.rb', line 78 def tangible @tangible end |
#total_transaction_count ⇒ String
The total number of transactions.
54 55 56 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information25.rb', line 54 def total_transaction_count @total_transaction_count end |
#transaction_date ⇒ String
The date of the transaction.
74 75 76 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information25.rb', line 74 def transaction_date @transaction_date end |
#transaction_retry ⇒ String
Indicates if the transaction is a retry.
38 39 40 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information25.rb', line 38 def transaction_retry @transaction_retry end |
#user_passed_verification ⇒ String
Indicates if the user passed verification.
66 67 68 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information25.rb', line 66 def user_passed_verification @user_passed_verification end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information25.rb', line 170 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. processing_instruction = hash.key?('processingInstruction') ? hash['processingInstruction'] : SKIP = AuthorizationOptions5.from_hash(hash['authorizationOptions']) if hash['authorizationOptions'] action_list = hash.key?('actionList') ? hash['actionList'] : SKIP high_risk_transaction_flag = hash.key?('highRiskTransactionFlag') ? hash['highRiskTransactionFlag'] : SKIP transaction_retry = hash.key?('transactionRetry') ? hash['transactionRetry'] : SKIP last_one_hr_transaction_count = hash.key?('lastOneHrTransactionCount') ? hash['lastOneHrTransactionCount'] : SKIP last_one_day_transaction_count = hash.key?('lastOneDayTransactionCount') ? hash['lastOneDayTransactionCount'] : SKIP last_three_months_txn_count = hash.key?('lastThreeMonthsTxnCount') ? hash['lastThreeMonthsTxnCount'] : SKIP total_transaction_count = hash.key?('totalTransactionCount') ? hash['totalTransactionCount'] : SKIP pin_verification = hash.key?('pinVerification') ? hash['pinVerification'] : SKIP face_id_verification = hash.key?('faceIdVerification') ? hash['faceIdVerification'] : SKIP user_passed_verification = hash.key?('userPassedVerification') ? hash['userPassedVerification'] : SKIP ip_address = hash.key?('ipAddress') ? hash['ipAddress'] : SKIP transaction_date = hash.key?('transactionDate') ? hash['transactionDate'] : SKIP tangible = hash.key?('tangible') ? hash['tangible'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProcessingInformation25.new(processing_instruction: processing_instruction, authorization_options: , action_list: action_list, high_risk_transaction_flag: high_risk_transaction_flag, transaction_retry: transaction_retry, last_one_hr_transaction_count: last_one_hr_transaction_count, last_one_day_transaction_count: last_one_day_transaction_count, last_three_months_txn_count: last_three_months_txn_count, total_transaction_count: total_transaction_count, pin_verification: pin_verification, face_id_verification: face_id_verification, user_passed_verification: user_passed_verification, ip_address: ip_address, transaction_date: transaction_date, tangible: tangible, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information25.rb', line 81 def self.names @_hash = {} if @_hash.nil? @_hash['processing_instruction'] = 'processingInstruction' @_hash['authorization_options'] = 'authorizationOptions' @_hash['action_list'] = 'actionList' @_hash['high_risk_transaction_flag'] = 'highRiskTransactionFlag' @_hash['transaction_retry'] = 'transactionRetry' @_hash['last_one_hr_transaction_count'] = 'lastOneHrTransactionCount' @_hash['last_one_day_transaction_count'] = 'lastOneDayTransactionCount' @_hash['last_three_months_txn_count'] = 'lastThreeMonthsTxnCount' @_hash['total_transaction_count'] = 'totalTransactionCount' @_hash['pin_verification'] = 'pinVerification' @_hash['face_id_verification'] = 'faceIdVerification' @_hash['user_passed_verification'] = 'userPassedVerification' @_hash['ip_address'] = 'ipAddress' @_hash['transaction_date'] = 'transactionDate' @_hash['tangible'] = 'tangible' @_hash end |
.nullables ⇒ Object
An array for nullable fields
123 124 125 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information25.rb', line 123 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information25.rb', line 102 def self.optionals %w[ processing_instruction authorization_options action_list high_risk_transaction_flag transaction_retry last_one_hr_transaction_count last_one_day_transaction_count last_three_months_txn_count total_transaction_count pin_verification face_id_verification user_passed_verification ip_address transaction_date tangible ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information25.rb', line 244 def inspect class_name = self.class.name.split('::').last "<#{class_name} processing_instruction: #{@processing_instruction.inspect},"\ " authorization_options: #{@authorization_options.inspect}, action_list:"\ " #{@action_list.inspect}, high_risk_transaction_flag:"\ " #{@high_risk_transaction_flag.inspect}, transaction_retry: #{@transaction_retry.inspect},"\ " last_one_hr_transaction_count: #{@last_one_hr_transaction_count.inspect},"\ " last_one_day_transaction_count: #{@last_one_day_transaction_count.inspect},"\ " last_three_months_txn_count: #{@last_three_months_txn_count.inspect},"\ " total_transaction_count: #{@total_transaction_count.inspect}, pin_verification:"\ " #{@pin_verification.inspect}, face_id_verification: #{@face_id_verification.inspect},"\ " user_passed_verification: #{@user_passed_verification.inspect}, ip_address:"\ " #{@ip_address.inspect}, transaction_date: #{@transaction_date.inspect}, tangible:"\ " #{@tangible.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information25.rb', line 229 def to_s class_name = self.class.name.split('::').last "<#{class_name} processing_instruction: #{@processing_instruction}, authorization_options:"\ " #{@authorization_options}, action_list: #{@action_list}, high_risk_transaction_flag:"\ " #{@high_risk_transaction_flag}, transaction_retry: #{@transaction_retry},"\ " last_one_hr_transaction_count: #{@last_one_hr_transaction_count},"\ " last_one_day_transaction_count: #{@last_one_day_transaction_count},"\ " last_three_months_txn_count: #{@last_three_months_txn_count}, total_transaction_count:"\ " #{@total_transaction_count}, pin_verification: #{@pin_verification}, face_id_verification:"\ " #{@face_id_verification}, user_passed_verification: #{@user_passed_verification},"\ " ip_address: #{@ip_address}, transaction_date: #{@transaction_date}, tangible:"\ " #{@tangible}, additional_properties: #{@additional_properties}>" end |