Class: VisaAcceptanceMergedSpec::ProcessingInformation26
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::ProcessingInformation26
- Defined in:
- lib/visa_acceptance_merged_spec/models/processing_information26.rb
Overview
ProcessingInformation26 Model.
Instance Attribute Summary collapse
-
#action_list ⇒ Array[String]
Array of actions (one or more) to be included in the void to invoke bundled services along with void.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(action_list: SKIP, additional_properties: nil) ⇒ ProcessingInformation26
constructor
A new instance of ProcessingInformation26.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(action_list: SKIP, additional_properties: nil) ⇒ ProcessingInformation26
Returns a new instance of ProcessingInformation26.
41 42 43 44 45 46 47 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information26.rb', line 41 def initialize(action_list: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @action_list = action_list unless action_list == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#action_list ⇒ Array[String]
Array of actions (one or more) to be included in the void to invoke bundled services along with void. Possible values:
AP_UPDATE_ORDER: Use this when Alternative Payment Update order service is requested.AP_EXTEND_ORDER: Use this when Alternative Payment extend order service is requested.
20 21 22 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information26.rb', line 20 def action_list @action_list end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information26.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. action_list = hash.key?('actionList') ? hash['actionList'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProcessingInformation26.new(action_list: action_list, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information26.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['action_list'] = 'actionList' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information26.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information26.rb', line 30 def self.optionals %w[ action_list ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 80 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information26.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} action_list: #{@action_list.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 73 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information26.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} action_list: #{@action_list}, additional_properties:"\ " #{@additional_properties}>" end |