Class: VisaAcceptanceMergedSpec::ProcessingInformation3

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/processing_information3.rb

Overview

ProcessingInformation3 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(payment_solution: SKIP, reconciliation_id: SKIP, link_id: SKIP, report_group: SKIP, visa_checkout_id: SKIP, issuer: SKIP, action_list: SKIP, transaction_type_indicator: SKIP, additional_properties: nil) ⇒ ProcessingInformation3

Returns a new instance of ProcessingInformation3.



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/visa_acceptance_merged_spec/models/processing_information3.rb', line 147

def initialize(payment_solution: SKIP, reconciliation_id: SKIP,
               link_id: SKIP, report_group: SKIP, visa_checkout_id: SKIP,
               issuer: SKIP, action_list: SKIP,
               transaction_type_indicator: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @payment_solution = payment_solution unless payment_solution == SKIP
  @reconciliation_id = reconciliation_id unless reconciliation_id == SKIP
  @link_id = link_id unless link_id == SKIP
  @report_group = report_group unless report_group == SKIP
  @visa_checkout_id = visa_checkout_id unless visa_checkout_id == SKIP
  @issuer = issuer unless issuer == SKIP
  @action_list = action_list unless action_list == SKIP
  unless transaction_type_indicator == SKIP
    @transaction_type_indicator =
      transaction_type_indicator
  end
  @additional_properties = additional_properties
end

Instance Attribute Details

#action_listArray[String]

Array of actions (one or more) to be included in the reversal Possible value:

  • AP_AUTH_REVERSAL: Use this when you want to reverse an Alternative Payment Authorization.

Returns:

  • (Array[String])


74
75
76
# File 'lib/visa_acceptance_merged_spec/models/processing_information3.rb', line 74

def action_list
  @action_list
end

#issuerIssuer

Identifier for the Visa Checkout order. Visa Checkout provides a unique order ID for every transaction in the Visa Checkout callID field.

Returns:



67
68
69
# File 'lib/visa_acceptance_merged_spec/models/processing_information3.rb', line 67

def issuer
  @issuer
end

Value that links the current authorization request to the original authorization request. Set this value to the ID that was returned in the reply message from the original authorization request. This value is used for:

  • Partial authorizations
  • Split shipments

Returns:

  • (String)


50
51
52
# File 'lib/visa_acceptance_merged_spec/models/processing_information3.rb', line 50

def link_id
  @link_id
end

#payment_solutionString

Type of digital payment solution for the transaction. Possible Values:

  • visacheckout: Visa Checkout. This value is required for Visa Checkout transactions. For details, see payment_solution field description in [Visa Checkout Using the REST API.](
  • 001: Apple Pay.
  • 004: Visa Acceptance In-App Solution.
  • 005: Masterpass. This value is required for Masterpass transactions on OmniPay Direct.
  • 006: Android Pay.
  • 007: Chase Pay.
  • 008: Samsung Pay.
  • 012: Google Pay.
  • 013: Visa Acceptance P2PE Decryption
  • 014: Mastercard credential on file (COF) payment network token. Returned in authorizations that use a payment network token associated with a TMS token.
  • 015: Visa credential on file (COF) payment network token. Returned in authorizations that use a payment network token associated with a TMS token.
  • 027: Click to Pay.

Returns:

  • (String)


33
34
35
# File 'lib/visa_acceptance_merged_spec/models/processing_information3.rb', line 33

def payment_solution
  @payment_solution
end

#reconciliation_idString

Please check with Visa Acceptance customer support to see if your merchant account is configured correctly so you can include this field in your request.

  • For Payouts: max length for FDCCompass is String (22).

Returns:

  • (String)


40
41
42
# File 'lib/visa_acceptance_merged_spec/models/processing_information3.rb', line 40

def reconciliation_id
  @reconciliation_id
end

#report_groupString

Attribute that lets you define custom grouping for your processor reports. This field is supported only for Worldpay VAP.

Returns:

  • (String)


55
56
57
# File 'lib/visa_acceptance_merged_spec/models/processing_information3.rb', line 55

def report_group
  @report_group
end

#transaction_type_indicatorString

This field is used identify the type of payment transaction taking place. This field is applicable for MasterCard transactions only. Possible values:

  • 201- Mastercard Rebate
  • 202- rePower Load Value
  • 203- Gaming Re-pay
  • 204- General Person-to-Person
  • 205- General Transfer to Own Account
  • 206- Agent Cash Out
  • 207- Payment of Own Credit Card Bill
  • 208- Business Disbursement
  • 209- Government/Non-Profit Disbursement
  • 210- Rapid Merchant Settlement
  • 211- Cash in at ATM (Usage limited to specific countries)
  • 212- Cash in at Point of Sale (Usage limited to specific countries)
  • 213- General Business to Business Transfer
  • 214- Mastercard Merchant Presented QR
  • 215- Mastercard Merchant Presented QR Refund Payment
  • 216- Utility Payments (for Brazil domestic use only)
  • 217- Government Services (for Brazil domestic use only)
  • 218- Mobile phone top-ups (for Brazil domestic use only)
  • 219- Coupon booklet payments (for Brazil domestic use only)
  • 220- General Person-to-Person Transfer
  • 221- Person-to-Person Transfer to Card Account
  • 222- General Transfer to Own Account
  • 223- Agent Cash Out
  • 224- Payment of Own Credit Card Bill
  • 225- Business Disbursement
  • 226- Transfer to Own Staged Digital Wallet Account
  • 227- Transfer to Own Debit or Prepaid Account
  • 228- General Business-to-Business Transfer
  • 229- Installment-based repayment
  • 230- Mastercard ATM Cash Pick-Up Transaction
  • 231- Cryptocurrency
  • 232- High-risk Securities

Returns:

  • (String)


112
113
114
# File 'lib/visa_acceptance_merged_spec/models/processing_information3.rb', line 112

def transaction_type_indicator
  @transaction_type_indicator
end

#visa_checkout_idString

Identifier for the Visa Checkout order. Visa Checkout provides a unique order ID for every transaction in the Visa Checkout callID field.

Returns:

  • (String)


61
62
63
# File 'lib/visa_acceptance_merged_spec/models/processing_information3.rb', line 61

def visa_checkout_id
  @visa_checkout_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/visa_acceptance_merged_spec/models/processing_information3.rb', line 169

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  payment_solution =
    hash.key?('paymentSolution') ? hash['paymentSolution'] : SKIP
  reconciliation_id =
    hash.key?('reconciliationId') ? hash['reconciliationId'] : SKIP
  link_id = hash.key?('linkId') ? hash['linkId'] : SKIP
  report_group = hash.key?('reportGroup') ? hash['reportGroup'] : SKIP
  visa_checkout_id =
    hash.key?('visaCheckoutId') ? hash['visaCheckoutId'] : SKIP
  issuer = Issuer.from_hash(hash['issuer']) if hash['issuer']
  action_list = hash.key?('actionList') ? hash['actionList'] : SKIP
  transaction_type_indicator =
    hash.key?('transactionTypeIndicator') ? hash['transactionTypeIndicator'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProcessingInformation3.new(payment_solution: payment_solution,
                             reconciliation_id: reconciliation_id,
                             link_id: link_id,
                             report_group: report_group,
                             visa_checkout_id: visa_checkout_id,
                             issuer: issuer,
                             action_list: action_list,
                             transaction_type_indicator: transaction_type_indicator,
                             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/visa_acceptance_merged_spec/models/processing_information3.rb', line 115

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['payment_solution'] = 'paymentSolution'
  @_hash['reconciliation_id'] = 'reconciliationId'
  @_hash['link_id'] = 'linkId'
  @_hash['report_group'] = 'reportGroup'
  @_hash['visa_checkout_id'] = 'visaCheckoutId'
  @_hash['issuer'] = 'issuer'
  @_hash['action_list'] = 'actionList'
  @_hash['transaction_type_indicator'] = 'transactionTypeIndicator'
  @_hash
end

.nullablesObject

An array for nullable fields



143
144
145
# File 'lib/visa_acceptance_merged_spec/models/processing_information3.rb', line 143

def self.nullables
  []
end

.optionalsObject

An array for optional fields



129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/visa_acceptance_merged_spec/models/processing_information3.rb', line 129

def self.optionals
  %w[
    payment_solution
    reconciliation_id
    link_id
    report_group
    visa_checkout_id
    issuer
    action_list
    transaction_type_indicator
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



216
217
218
219
220
221
222
223
# File 'lib/visa_acceptance_merged_spec/models/processing_information3.rb', line 216

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} payment_solution: #{@payment_solution.inspect}, reconciliation_id:"\
  " #{@reconciliation_id.inspect}, link_id: #{@link_id.inspect}, report_group:"\
  " #{@report_group.inspect}, visa_checkout_id: #{@visa_checkout_id.inspect}, issuer:"\
  " #{@issuer.inspect}, action_list: #{@action_list.inspect}, transaction_type_indicator:"\
  " #{@transaction_type_indicator.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



206
207
208
209
210
211
212
213
# File 'lib/visa_acceptance_merged_spec/models/processing_information3.rb', line 206

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} payment_solution: #{@payment_solution}, reconciliation_id:"\
  " #{@reconciliation_id}, link_id: #{@link_id}, report_group: #{@report_group},"\
  " visa_checkout_id: #{@visa_checkout_id}, issuer: #{@issuer}, action_list: #{@action_list},"\
  " transaction_type_indicator: #{@transaction_type_indicator}, additional_properties:"\
  " #{@additional_properties}>"
end