Class: VisaAcceptanceMergedSpec::ProcessingInformation5

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/processing_information5.rb

Overview

ProcessingInformation5 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(payment_solution: SKIP, reconciliation_id: SKIP, link_id: SKIP, report_group: SKIP, visa_checkout_id: SKIP, purchase_level: SKIP, industry_data_type: SKIP, issuer: SKIP, authorization_options: SKIP, capture_options: SKIP, loan_options: SKIP, pay_by_points_indicator: SKIP, action_list: SKIP, additional_properties: nil) ⇒ ProcessingInformation5

Returns a new instance of ProcessingInformation5.



260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/visa_acceptance_merged_spec/models/processing_information5.rb', line 260

def initialize(payment_solution: SKIP, reconciliation_id: SKIP,
               link_id: SKIP, report_group: SKIP, visa_checkout_id: SKIP,
               purchase_level: SKIP, industry_data_type: SKIP, issuer: SKIP,
               authorization_options: SKIP, capture_options: SKIP,
               loan_options: SKIP, pay_by_points_indicator: SKIP,
               action_list: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @payment_solution = payment_solution unless payment_solution == SKIP
  @reconciliation_id = reconciliation_id unless reconciliation_id == SKIP
  @link_id = link_id unless link_id == SKIP
  @report_group = report_group unless report_group == SKIP
  @visa_checkout_id = visa_checkout_id unless visa_checkout_id == SKIP
  @purchase_level = purchase_level unless purchase_level == SKIP
  @industry_data_type = industry_data_type unless industry_data_type == SKIP
  @issuer = issuer unless issuer == SKIP
  @authorization_options = authorization_options unless authorization_options == SKIP
  @capture_options = capture_options unless capture_options == SKIP
  @loan_options = loan_options unless loan_options == SKIP
  @pay_by_points_indicator = pay_by_points_indicator unless pay_by_points_indicator == SKIP
  @action_list = action_list unless action_list == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#action_listArray[String]

Array of actions (one or more) to be included in the capture to invoke bundled services along with capture. Possible values :

  • AP_CAPTURE: Use this when Alternative Payment Capture service is requested.

Returns:

  • (Array[String])


215
216
217
# File 'lib/visa_acceptance_merged_spec/models/processing_information5.rb', line 215

def action_list
  @action_list
end

#authorization_optionsAuthorizationOptions4

Indicates that the transaction includes industry-specific data. Possible Values:

  • airline
  • restaurant
  • lodging
  • auto_rental
  • transit
  • healthcare_medical
  • healthcare_transit
  • transit

Card Present, Airlines and Auto Rental

You must set this field to airline in order for airline data to be sent to the processor. For example, if this field is not set to airline or is not included in the request, no airline data is sent to the processor. You must set this field to restaurant in order for restaurant data to be sent to the processor. When this field is not set to restaurant or is not included in the request, no restaurant data is sent to the processor. You must set this field to auto_rental in order for auto rental data to be sent to the processor. For example, if this field is not set to auto_rental or is not included in the request, no auto rental data is sent to the processor. Restaurant data is supported only on Visa Acceptance through VisaNet.



146
147
148
# File 'lib/visa_acceptance_merged_spec/models/processing_information5.rb', line 146

def authorization_options
  @authorization_options
end

#capture_optionsCaptureOptions2

Indicates that the transaction includes industry-specific data. Possible Values:

  • airline
  • restaurant
  • lodging
  • auto_rental
  • transit
  • healthcare_medical
  • healthcare_transit
  • transit

Card Present, Airlines and Auto Rental

You must set this field to airline in order for airline data to be sent to the processor. For example, if this field is not set to airline or is not included in the request, no airline data is sent to the processor. You must set this field to restaurant in order for restaurant data to be sent to the processor. When this field is not set to restaurant or is not included in the request, no restaurant data is sent to the processor. You must set this field to auto_rental in order for auto rental data to be sent to the processor. For example, if this field is not set to auto_rental or is not included in the request, no auto rental data is sent to the processor. Restaurant data is supported only on Visa Acceptance through VisaNet.

Returns:



173
174
175
# File 'lib/visa_acceptance_merged_spec/models/processing_information5.rb', line 173

def capture_options
  @capture_options
end

#industry_data_typeString

Indicates that the transaction includes industry-specific data. Possible Values:

  • airline
  • restaurant
  • lodging
  • auto_rental
  • transit
  • healthcare_medical
  • healthcare_transit
  • transit

Card Present, Airlines and Auto Rental

You must set this field to airline in order for airline data to be sent to the processor. For example, if this field is not set to airline or is not included in the request, no airline data is sent to the processor. You must set this field to restaurant in order for restaurant data to be sent to the processor. When this field is not set to restaurant or is not included in the request, no restaurant data is sent to the processor. You must set this field to auto_rental in order for auto rental data to be sent to the processor. For example, if this field is not set to auto_rental or is not included in the request, no auto rental data is sent to the processor. Restaurant data is supported only on Visa Acceptance through VisaNet.

Returns:

  • (String)


92
93
94
# File 'lib/visa_acceptance_merged_spec/models/processing_information5.rb', line 92

def industry_data_type
  @industry_data_type
end

#issuerIssuer

Indicates that the transaction includes industry-specific data. Possible Values:

  • airline
  • restaurant
  • lodging
  • auto_rental
  • transit
  • healthcare_medical
  • healthcare_transit
  • transit

Card Present, Airlines and Auto Rental

You must set this field to airline in order for airline data to be sent to the processor. For example, if this field is not set to airline or is not included in the request, no airline data is sent to the processor. You must set this field to restaurant in order for restaurant data to be sent to the processor. When this field is not set to restaurant or is not included in the request, no restaurant data is sent to the processor. You must set this field to auto_rental in order for auto rental data to be sent to the processor. For example, if this field is not set to auto_rental or is not included in the request, no auto rental data is sent to the processor. Restaurant data is supported only on Visa Acceptance through VisaNet.

Returns:



119
120
121
# File 'lib/visa_acceptance_merged_spec/models/processing_information5.rb', line 119

def issuer
  @issuer
end

Value that links the current authorization request to the original authorization request. Set this value to the ID that was returned in the reply message from the original authorization request. This value is used for:

  • Partial authorizations
  • Split shipments

Returns:

  • (String)


50
51
52
# File 'lib/visa_acceptance_merged_spec/models/processing_information5.rb', line 50

def link_id
  @link_id
end

#loan_optionsLoanOptions

Indicates that the transaction includes industry-specific data. Possible Values:

  • airline
  • restaurant
  • lodging
  • auto_rental
  • transit
  • healthcare_medical
  • healthcare_transit
  • transit

Card Present, Airlines and Auto Rental

You must set this field to airline in order for airline data to be sent to the processor. For example, if this field is not set to airline or is not included in the request, no airline data is sent to the processor. You must set this field to restaurant in order for restaurant data to be sent to the processor. When this field is not set to restaurant or is not included in the request, no restaurant data is sent to the processor. You must set this field to auto_rental in order for auto rental data to be sent to the processor. For example, if this field is not set to auto_rental or is not included in the request, no auto rental data is sent to the processor. Restaurant data is supported only on Visa Acceptance through VisaNet.

Returns:



200
201
202
# File 'lib/visa_acceptance_merged_spec/models/processing_information5.rb', line 200

def loan_options
  @loan_options
end

#pay_by_points_indicatorTrueClass | FalseClass

Flag that indicates if the transaction is pay by points transaction true: Transaction uses loyalty points false: Transaction does not use loyalty points Default: false

Returns:

  • (TrueClass | FalseClass)


207
208
209
# File 'lib/visa_acceptance_merged_spec/models/processing_information5.rb', line 207

def pay_by_points_indicator
  @pay_by_points_indicator
end

#payment_solutionString

Type of digital payment solution for the transaction. Possible Values:

  • visacheckout: Visa Checkout. This value is required for Visa Checkout transactions. For details, see payment_solution field description in [Visa Checkout Using the REST API.](
  • 001: Apple Pay.
  • 004: Visa Acceptance In-App Solution.
  • 005: Masterpass. This value is required for Masterpass transactions on OmniPay Direct.
  • 006: Android Pay.
  • 007: Chase Pay.
  • 008: Samsung Pay.
  • 012: Google Pay.
  • 013: Visa Acceptance P2PE Decryption
  • 014: Mastercard credential on file (COF) payment network token. Returned in authorizations that use a payment network token associated with a TMS token.
  • 015: Visa credential on file (COF) payment network token. Returned in authorizations that use a payment network token associated with a TMS token.
  • 027: Click to Pay.

Returns:

  • (String)


33
34
35
# File 'lib/visa_acceptance_merged_spec/models/processing_information5.rb', line 33

def payment_solution
  @payment_solution
end

#purchase_levelString

Set this field to 3 to indicate that the request includes Level III data.

Returns:

  • (String)


65
66
67
# File 'lib/visa_acceptance_merged_spec/models/processing_information5.rb', line 65

def purchase_level
  @purchase_level
end

#reconciliation_idString

Please check with Visa Acceptance customer support to see if your merchant account is configured correctly so you can include this field in your request.

  • For Payouts: max length for FDCCompass is String (22).

Returns:

  • (String)


40
41
42
# File 'lib/visa_acceptance_merged_spec/models/processing_information5.rb', line 40

def reconciliation_id
  @reconciliation_id
end

#report_groupString

Attribute that lets you define custom grouping for your processor reports. This field is supported only for Worldpay VAP.

Returns:

  • (String)


55
56
57
# File 'lib/visa_acceptance_merged_spec/models/processing_information5.rb', line 55

def report_group
  @report_group
end

#visa_checkout_idString

Identifier for the Visa Checkout order. Visa Checkout provides a unique order ID for every transaction in the Visa Checkout callID field.

Returns:

  • (String)


61
62
63
# File 'lib/visa_acceptance_merged_spec/models/processing_information5.rb', line 61

def visa_checkout_id
  @visa_checkout_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/visa_acceptance_merged_spec/models/processing_information5.rb', line 286

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  payment_solution =
    hash.key?('paymentSolution') ? hash['paymentSolution'] : SKIP
  reconciliation_id =
    hash.key?('reconciliationId') ? hash['reconciliationId'] : SKIP
  link_id = hash.key?('linkId') ? hash['linkId'] : SKIP
  report_group = hash.key?('reportGroup') ? hash['reportGroup'] : SKIP
  visa_checkout_id =
    hash.key?('visaCheckoutId') ? hash['visaCheckoutId'] : SKIP
  purchase_level = hash.key?('purchaseLevel') ? hash['purchaseLevel'] : SKIP
  industry_data_type =
    hash.key?('industryDataType') ? hash['industryDataType'] : SKIP
  issuer = Issuer.from_hash(hash['issuer']) if hash['issuer']
  authorization_options = AuthorizationOptions4.from_hash(hash['authorizationOptions']) if
    hash['authorizationOptions']
  capture_options = CaptureOptions2.from_hash(hash['captureOptions']) if
    hash['captureOptions']
  loan_options = LoanOptions.from_hash(hash['loanOptions']) if hash['loanOptions']
  pay_by_points_indicator =
    hash.key?('payByPointsIndicator') ? hash['payByPointsIndicator'] : SKIP
  action_list = hash.key?('actionList') ? hash['actionList'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProcessingInformation5.new(payment_solution: payment_solution,
                             reconciliation_id: reconciliation_id,
                             link_id: link_id,
                             report_group: report_group,
                             visa_checkout_id: visa_checkout_id,
                             purchase_level: purchase_level,
                             industry_data_type: industry_data_type,
                             issuer: issuer,
                             authorization_options: authorization_options,
                             capture_options: capture_options,
                             loan_options: loan_options,
                             pay_by_points_indicator: pay_by_points_indicator,
                             action_list: action_list,
                             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/visa_acceptance_merged_spec/models/processing_information5.rb', line 218

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['payment_solution'] = 'paymentSolution'
  @_hash['reconciliation_id'] = 'reconciliationId'
  @_hash['link_id'] = 'linkId'
  @_hash['report_group'] = 'reportGroup'
  @_hash['visa_checkout_id'] = 'visaCheckoutId'
  @_hash['purchase_level'] = 'purchaseLevel'
  @_hash['industry_data_type'] = 'industryDataType'
  @_hash['issuer'] = 'issuer'
  @_hash['authorization_options'] = 'authorizationOptions'
  @_hash['capture_options'] = 'captureOptions'
  @_hash['loan_options'] = 'loanOptions'
  @_hash['pay_by_points_indicator'] = 'payByPointsIndicator'
  @_hash['action_list'] = 'actionList'
  @_hash
end

.nullablesObject

An array for nullable fields



256
257
258
# File 'lib/visa_acceptance_merged_spec/models/processing_information5.rb', line 256

def self.nullables
  []
end

.optionalsObject

An array for optional fields



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/visa_acceptance_merged_spec/models/processing_information5.rb', line 237

def self.optionals
  %w[
    payment_solution
    reconciliation_id
    link_id
    report_group
    visa_checkout_id
    purchase_level
    industry_data_type
    issuer
    authorization_options
    capture_options
    loan_options
    pay_by_points_indicator
    action_list
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



348
349
350
351
352
353
354
355
356
357
358
# File 'lib/visa_acceptance_merged_spec/models/processing_information5.rb', line 348

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} payment_solution: #{@payment_solution.inspect}, reconciliation_id:"\
  " #{@reconciliation_id.inspect}, link_id: #{@link_id.inspect}, report_group:"\
  " #{@report_group.inspect}, visa_checkout_id: #{@visa_checkout_id.inspect}, purchase_level:"\
  " #{@purchase_level.inspect}, industry_data_type: #{@industry_data_type.inspect}, issuer:"\
  " #{@issuer.inspect}, authorization_options: #{@authorization_options.inspect},"\
  " capture_options: #{@capture_options.inspect}, loan_options: #{@loan_options.inspect},"\
  " pay_by_points_indicator: #{@pay_by_points_indicator.inspect}, action_list:"\
  " #{@action_list.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



336
337
338
339
340
341
342
343
344
345
# File 'lib/visa_acceptance_merged_spec/models/processing_information5.rb', line 336

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} payment_solution: #{@payment_solution}, reconciliation_id:"\
  " #{@reconciliation_id}, link_id: #{@link_id}, report_group: #{@report_group},"\
  " visa_checkout_id: #{@visa_checkout_id}, purchase_level: #{@purchase_level},"\
  " industry_data_type: #{@industry_data_type}, issuer: #{@issuer}, authorization_options:"\
  " #{@authorization_options}, capture_options: #{@capture_options}, loan_options:"\
  " #{@loan_options}, pay_by_points_indicator: #{@pay_by_points_indicator}, action_list:"\
  " #{@action_list}, additional_properties: #{@additional_properties}>"
end