Class: VisaAcceptanceMergedSpec::ProcessingInformation6

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/processing_information6.rb

Overview

ProcessingInformation6 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(enhanced_data_enabled: SKIP, additional_properties: nil) ⇒ ProcessingInformation6

Returns a new instance of ProcessingInformation6.



39
40
41
42
43
44
45
# File 'lib/visa_acceptance_merged_spec/models/processing_information6.rb', line 39

def initialize(enhanced_data_enabled: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @enhanced_data_enabled = enhanced_data_enabled unless enhanced_data_enabled == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#enhanced_data_enabledTrueClass | FalseClass

The possible values for the reply field are:

  • true : the airline data was included in the request to the processor.
  • false : the airline data was not included in the request to the processor. Returned by authorization, capture, or credit services.

Returns:

  • (TrueClass | FalseClass)


18
19
20
# File 'lib/visa_acceptance_merged_spec/models/processing_information6.rb', line 18

def enhanced_data_enabled
  @enhanced_data_enabled
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/visa_acceptance_merged_spec/models/processing_information6.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  enhanced_data_enabled =
    hash.key?('enhancedDataEnabled') ? hash['enhancedDataEnabled'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProcessingInformation6.new(enhanced_data_enabled: enhanced_data_enabled,
                             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
# File 'lib/visa_acceptance_merged_spec/models/processing_information6.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['enhanced_data_enabled'] = 'enhancedDataEnabled'
  @_hash
end

.nullablesObject

An array for nullable fields



35
36
37
# File 'lib/visa_acceptance_merged_spec/models/processing_information6.rb', line 35

def self.nullables
  []
end

.optionalsObject

An array for optional fields



28
29
30
31
32
# File 'lib/visa_acceptance_merged_spec/models/processing_information6.rb', line 28

def self.optionals
  %w[
    enhanced_data_enabled
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



75
76
77
78
79
# File 'lib/visa_acceptance_merged_spec/models/processing_information6.rb', line 75

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} enhanced_data_enabled: #{@enhanced_data_enabled.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



68
69
70
71
72
# File 'lib/visa_acceptance_merged_spec/models/processing_information6.rb', line 68

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} enhanced_data_enabled: #{@enhanced_data_enabled}, additional_properties:"\
  " #{@additional_properties}>"
end