Class: VisaAcceptanceMergedSpec::ProcessorInformation1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/processor_information1.rb

Overview

ProcessorInformation1 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(auth_indicator: SKIP, approval_code: SKIP, card_reference_data: SKIP, transaction_id: SKIP, network_transaction_id: SKIP, response_code: SKIP, response_code_source: SKIP, response_details: SKIP, response_category_code: SKIP, forwarded_acquirer_code: SKIP, settlement_date: SKIP, sequence_number: SKIP, avs: SKIP, card_verification: SKIP, merchant_advice: SKIP, electronic_verification_results: SKIP, ach_verification: SKIP, customer: SKIP, consumer_authentication_response: SKIP, system_trace_audit_number: SKIP, payment_account_reference_number: SKIP, transaction_integrity_code: SKIP, amex_verbal_auth_reference_number: SKIP, master_card_service_code: SKIP, master_card_service_reply_code: SKIP, master_card_authentication_type: SKIP, name: SKIP, routing: SKIP, merchant_number: SKIP, retrieval_reference_number: SKIP, payment_url: SKIP, complete_url: SKIP, signature: SKIP, public_key: SKIP, seller_protection: SKIP, transaction_expiry_date: SKIP, custom_url: SKIP, scheme_assigned_id: SKIP, device_url: SKIP, disbursement_mode: SKIP, update_time_utc: SKIP, expiration_time_utc: SKIP, order_id: SKIP, order_status: SKIP, merchant_risk_prediction: SKIP, additional_properties: nil) ⇒ ProcessorInformation1

Returns a new instance of ProcessorInformation1.



582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 582

def initialize(auth_indicator: SKIP, approval_code: SKIP,
               card_reference_data: SKIP, transaction_id: SKIP,
               network_transaction_id: SKIP, response_code: SKIP,
               response_code_source: SKIP, response_details: SKIP,
               response_category_code: SKIP, forwarded_acquirer_code: SKIP,
               settlement_date: SKIP, sequence_number: SKIP, avs: SKIP,
               card_verification: SKIP, merchant_advice: SKIP,
               electronic_verification_results: SKIP,
               ach_verification: SKIP, customer: SKIP,
               consumer_authentication_response: SKIP,
               system_trace_audit_number: SKIP,
               payment_account_reference_number: SKIP,
               transaction_integrity_code: SKIP,
               amex_verbal_auth_reference_number: SKIP,
               master_card_service_code: SKIP,
               master_card_service_reply_code: SKIP,
               master_card_authentication_type: SKIP, name: SKIP,
               routing: SKIP, merchant_number: SKIP,
               retrieval_reference_number: SKIP, payment_url: SKIP,
               complete_url: SKIP, signature: SKIP, public_key: SKIP,
               seller_protection: SKIP, transaction_expiry_date: SKIP,
               custom_url: SKIP, scheme_assigned_id: SKIP, device_url: SKIP,
               disbursement_mode: SKIP, update_time_utc: SKIP,
               expiration_time_utc: SKIP, order_id: SKIP,
               order_status: SKIP, merchant_risk_prediction: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @auth_indicator = auth_indicator unless auth_indicator == SKIP
  @approval_code = approval_code unless approval_code == SKIP
  @card_reference_data = card_reference_data unless card_reference_data == SKIP
  @transaction_id = transaction_id unless transaction_id == SKIP
  @network_transaction_id = network_transaction_id unless network_transaction_id == SKIP
  @response_code = response_code unless response_code == SKIP
  @response_code_source = response_code_source unless response_code_source == SKIP
  @response_details = response_details unless response_details == SKIP
  @response_category_code = response_category_code unless response_category_code == SKIP
  @forwarded_acquirer_code = forwarded_acquirer_code unless forwarded_acquirer_code == SKIP
  @settlement_date = settlement_date unless settlement_date == SKIP
  @sequence_number = sequence_number unless sequence_number == SKIP
  @avs = avs unless avs == SKIP
  @card_verification = card_verification unless card_verification == SKIP
  @merchant_advice = merchant_advice unless merchant_advice == SKIP
  unless electronic_verification_results == SKIP
    @electronic_verification_results =
      electronic_verification_results
  end
  @ach_verification = ach_verification unless ach_verification == SKIP
  @customer = customer unless customer == SKIP
  unless consumer_authentication_response == SKIP
    @consumer_authentication_response =
      consumer_authentication_response
  end
  unless system_trace_audit_number == SKIP
    @system_trace_audit_number =
      system_trace_audit_number
  end
  unless  == SKIP
    @payment_account_reference_number =
      
  end
  unless transaction_integrity_code == SKIP
    @transaction_integrity_code =
      transaction_integrity_code
  end
  unless amex_verbal_auth_reference_number == SKIP
    @amex_verbal_auth_reference_number =
      amex_verbal_auth_reference_number
  end
  @master_card_service_code = master_card_service_code unless master_card_service_code == SKIP
  unless master_card_service_reply_code == SKIP
    @master_card_service_reply_code =
      master_card_service_reply_code
  end
  unless master_card_authentication_type == SKIP
    @master_card_authentication_type =
      master_card_authentication_type
  end
  @name = name unless name == SKIP
  @routing = routing unless routing == SKIP
  @merchant_number = merchant_number unless merchant_number == SKIP
  unless retrieval_reference_number == SKIP
    @retrieval_reference_number =
      retrieval_reference_number
  end
  @payment_url = payment_url unless payment_url == SKIP
  @complete_url = complete_url unless complete_url == SKIP
  @signature = signature unless signature == SKIP
  @public_key = public_key unless public_key == SKIP
  @seller_protection = seller_protection unless seller_protection == SKIP
  @transaction_expiry_date = transaction_expiry_date unless transaction_expiry_date == SKIP
  @custom_url = custom_url unless custom_url == SKIP
  @scheme_assigned_id = scheme_assigned_id unless scheme_assigned_id == SKIP
  @device_url = device_url unless device_url == SKIP
  @disbursement_mode = disbursement_mode unless disbursement_mode == SKIP
  @update_time_utc = update_time_utc unless update_time_utc == SKIP
  @expiration_time_utc = expiration_time_utc unless expiration_time_utc == SKIP
  @order_id = order_id unless order_id == SKIP
  @order_status = order_status unless order_status == SKIP
  @merchant_risk_prediction = merchant_risk_prediction unless merchant_risk_prediction == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#ach_verificationAchVerification

This field serves as a unique identifier for initial and subsequent recurring transactions, specific to the payment brand, and is crucial for transaction tracking and recurrence management. Not all processors provide this value. Returned by the authorization service.

Returns:



199
200
201
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 199

def ach_verification
  @ach_verification
end

#amex_verbal_auth_reference_numberString

Referral response number for a verbal authorization with FDMS Nashville when using an American Express card. Give this number to American Express when you call them for the verbal authorization.

Returns:

  • (String)


292
293
294
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 292

def amex_verbal_auth_reference_number
  @amex_verbal_auth_reference_number
end

#approval_codeString

Authorization code. Returned only when the processor returns this value. The length of this value depends on your processor. Returned by authorization service.

PIN debit

Authorization code that is returned by the processor. Returned by PIN debit credit.

Elavon Encrypted Account Number Program

The returned value is OFFLINE.

TSYS Acquiring Solutions

The returned value for a successful zero amount authorization is 000000.

Returns:

  • (String)


30
31
32
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 30

def approval_code
  @approval_code
end

#auth_indicatorString

Flag that specifies the purpose of the authorization. Possible values:

  • 0: Preauthorization
  • 1: Final authorization

Returns:

  • (String)


17
18
19
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 17

def auth_indicator
  @auth_indicator
end

#avsAvs

This field serves as a unique identifier for initial and subsequent recurring transactions, specific to the payment brand, and is crucial for transaction tracking and recurrence management. Not all processors provide this value. Returned by the authorization service.

Returns:



167
168
169
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 167

def avs
  @avs
end

#card_reference_dataString

The Scheme reference data is a variable length data element up to a maximum of 56 characters. It may be sent by the acquirer in the authorisation response message, and by the terminal (unchanged) in subsequent authorisation request messages associated with the same transaction. This field is used by Streamline and HSBC UK only, at present.

Returns:

  • (String)


39
40
41
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 39

def card_reference_data
  @card_reference_data
end

#card_verificationCardVerification

This field serves as a unique identifier for initial and subsequent recurring transactions, specific to the payment brand, and is crucial for transaction tracking and recurrence management. Not all processors provide this value. Returned by the authorization service.

Returns:



175
176
177
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 175

def card_verification
  @card_verification
end

#complete_urlString

The redirect URL for forwarding the consumer to complete page. This redirect needed by PSP to track browser information of consumer. PSP then redirect consumer to merchant success URL.

Returns:

  • (String)


390
391
392
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 390

def complete_url
  @complete_url
end

#consumer_authentication_responseConsumerAuthenticationResponse

This field serves as a unique identifier for initial and subsequent recurring transactions, specific to the payment brand, and is crucial for transaction tracking and recurrence management. Not all processors provide this value. Returned by the authorization service.



215
216
217
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 215

def consumer_authentication_response
  @consumer_authentication_response
end

#custom_urlString

For merchants to declare customs Customs declaration service URL.

Returns:

  • (String)


417
418
419
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 417

def custom_url
  @custom_url
end

#customerCustomer2

This field serves as a unique identifier for initial and subsequent recurring transactions, specific to the payment brand, and is crucial for transaction tracking and recurrence management. Not all processors provide this value. Returned by the authorization service.

Returns:



207
208
209
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 207

def customer
  @customer
end

#device_urlString

The QR code value. Convert this value into an image and send it to the POS terminal to be displayed. The terminal can also perform the conversion. The value is a URL like in the example below:

Returns:

  • (String)


428
429
430
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 428

def device_url
  @device_url
end

#disbursement_modeString

The funds are released to the merchant immediately. INSTANT The funds are released to the merchant immediately. DELAYED The funds are held for a finite number of days. The actual duration depends on the region and type of integration. You can release the funds through a referenced payout. Otherwise, the funds disbursed automatically after the specified duration.

Returns:

  • (String)


437
438
439
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 437

def disbursement_mode
  @disbursement_mode
end

#electronic_verification_resultsElectronicVerificationResults

This field serves as a unique identifier for initial and subsequent recurring transactions, specific to the payment brand, and is crucial for transaction tracking and recurrence management. Not all processors provide this value. Returned by the authorization service.



191
192
193
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 191

def electronic_verification_results
  @electronic_verification_results
end

#expiration_time_utcString

The date and time when the authorized payment expires, in Internet date and time format.

Returns:

  • (String)


447
448
449
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 447

def expiration_time_utc
  @expiration_time_utc
end

#forwarded_acquirer_codeString

Name of the Japanese acquirer that processed the transaction. Returned only for JCN Gateway. Please contact the Visa Acceptance Japan Support Group for more information.

Returns:

  • (String)


146
147
148
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 146

def forwarded_acquirer_code
  @forwarded_acquirer_code
end

#master_card_authentication_typeString

Type of authentication for which the transaction qualifies as determined by the Mastercard authentication service, which confirms the identity of the cardholder. Mastercard provides this value to Visa Acceptance. Possible values:

  • 1: Transaction qualifies for Mastercard authentication type 1.
  • 2: Transaction qualifies for Mastercard authentication type 2.

Visa Acceptance through VisaNet

The value for this field corresponds to the following data in the TC 33 capture file:

  • Record: CP01 TCR6
  • Position: 132
  • Field: Mastercard Member Defined service. Note This field is returned only for Visa Acceptance through VisaNet.

Returns:

  • (String)


347
348
349
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 347

def master_card_authentication_type
  @master_card_authentication_type
end

#master_card_service_codeString

Mastercard service that was used for the transaction. Mastercard provides this value to Visa Acceptance. Possible value:

  • 53: Mastercard card-on-file token service

Visa Acceptance through VisaNet

The value for this field corresponds to the following data in the TC 33 capture file:

  • Record: CP01 TCR6
  • Position: 133-134
  • Field: Mastercard Merchant on-behalf service. Note This field is returned only for Visa Acceptance through VisaNet.

Returns:

  • (String)


306
307
308
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 306

def master_card_service_code
  @master_card_service_code
end

#master_card_service_reply_codeString

Result of the Mastercard card-on-file token service. Mastercard provides this value to Visa Acceptance. Possible values:

  • C: Service completed successfully.
  • F: One of the following:
    • Incorrect Mastercard POS entry mode. The Mastercard POS entry mode should be 81 for an authorization or authorization reversal.
    • Incorrect Mastercard POS entry mode. The Mastercard POS entry mode should be 01 for a tokenized request.
    • Token requestor ID is missing or formatted incorrectly.
  • I: One of the following:
    • Invalid token requestor ID.
    • Suspended or deactivated token.
    • Invalid token (not in mapping table).
  • T: Invalid combination of token requestor ID and token.
  • U: Expired token.
  • W: Primary account number (PAN) listed in electronic warning bulletin. Note This field is returned only for Visa Acceptance through VisaNet.

Returns:

  • (String)


330
331
332
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 330

def master_card_service_reply_code
  @master_card_service_reply_code
end

#merchant_adviceMerchantAdvice

This field serves as a unique identifier for initial and subsequent recurring transactions, specific to the payment brand, and is crucial for transaction tracking and recurrence management. Not all processors provide this value. Returned by the authorization service.

Returns:



183
184
185
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 183

def merchant_advice
  @merchant_advice
end

#merchant_numberString

Identifier that was assigned to you by your acquirer. This value must be printed on the receipt.

Returned by

Authorizations and Credits. This reply field is only supported by merchants who have installed client software on their POS terminals and use these processors:

  • American Express Direct
  • Credit Mutuel-CIC
  • FDC Nashville Global
  • OmniPay Direct
  • SIX

Returns:

  • (String)


370
371
372
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 370

def merchant_number
  @merchant_number
end

#merchant_risk_predictionString

Mastercard is introducing the Merchant Risk Predict Service in the middle East/Africa Region. A newly launched service comprised of seven independent artificial intelligence (AI)-powered scores intended to augment existing merchant risk management practices.

Returns:

  • (String)


468
469
470
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 468

def merchant_risk_prediction
  @merchant_risk_prediction
end

#nameString

Name of the Processor.

Returns:

  • (String)


351
352
353
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 351

def name
  @name
end

#network_transaction_idString

Same value as processorInformation.transactionId

Returns:

  • (String)


81
82
83
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 81

def network_transaction_id
  @network_transaction_id
end

#order_idString

The id of the order

Returns:

  • (String)


451
452
453
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 451

def order_id
  @order_id
end

#order_statusString

The order status. Possible values:

  • CREATED
  • VOIDED
  • COMPLETED
  • PAYER_ACTION_REQUIRED

Returns:

  • (String)


460
461
462
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 460

def order_status
  @order_status
end

#payment_account_reference_numberString

Payment Account Reference (PAR) is a non-financial reference assigned to each unique payment account and used to link a payment account to associated network tokens, i.e. the same PAR is returned for PAN-based and tokenized transactions, such as from digital wallets. PAR can be returned in authorisation responses for requests initiated with both real PANs and tokenized PANs. PAR can be used by merchants for fraud detection and regulatory compliance across different channels and digital wallets. PAR allows all participants in the payments chain to have a single, non-sensitive value assigned to a consumer. This value can be used in place of sensitive card holder identification fields, and transmitted across the payments ecosystem to facilitate card holder identification. Note On Visa Acceptance through VisaNet, the value for this field corresponds to the following data in the TC 33 capture file:

  • Record: CP01 TCR8
  • Position: 79-110
  • Field: Payment Account Reference The TC 33 Capture file contains information about the purchases and refunds that a merchant submits to Visa Acceptance. Visa Acceptance through VisaNet creates the TC 33 Capture file at the end of the day and sends it to the merchant’s acquirer, who uses this information to facilitate end-of-day clearing processing with payment networks.

Returns:

  • (String)


252
253
254
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 252

def 
  @payment_account_reference_number
end

#payment_urlString

Direct the customer to this URL to complete the payment.

Returns:

  • (String)


384
385
386
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 384

def payment_url
  @payment_url
end

#public_keyString

The redirect URL for forwarding the consumer to complete page. This redirect needed by PSP to track browser information of consumer. PSP then redirect consumer to merchant success URL.

Returns:

  • (String)


402
403
404
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 402

def public_key
  @public_key
end

#response_category_codeString

Processor-defined response category code. The associated detail error code is in the processorInformation.responseCode or issuerInformation.responseCode field of the service you requested. This field is supported only for:

  • Japanese issuers
  • Domestic transactions in Japan
  • Comercio Latino—processor transaction ID required for troubleshooting

Maximum length for processors

  • Comercio Latino: 36
  • All other processors: 3

Returns:

  • (String)


139
140
141
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 139

def response_category_code
  @response_category_code
end

#response_codeString

For most processors, this is the error message sent directly from the bank. Returned only when the processor returns this value. Important Do not use this field to evaluate the result of the authorization.

PIN debit

Response value that is returned by the processor or bank. Important Do not use this field to evaluate the results of the transaction request. Returned by PIN debit credit, PIN debit purchase, and PIN debit reversal.

AIBMS

If this value is 08, you can accept the transaction if the customer provides you with identification.

Atos

This value is the response code sent from Atos and it might also include the response code from the bank. Format: aa,bb with the two values separated by a comma and where:

  • aa is the two-digit error message from Atos.
  • bb is the optional two-digit error message from the bank.

Comercio Latino

This value is the status code and the error or response code received from the processor separated by a colon. Format: [status code]:E[error code] or [status code]:R[response code] Example 2:R06

JCN Gateway

Processor-defined detail error code. The associated response category code is in the processorInformation.responseCategoryCode field. String (3)

paypalgateway

Processor generated ID for the itemized detail.

Returns:

  • (String)


114
115
116
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 114

def response_code
  @response_code
end

#response_code_sourceString

Used by Visa only and contains the response source/reason code that identifies the source of the response decision.

Returns:

  • (String)


119
120
121
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 119

def response_code_source
  @response_code_source
end

#response_detailsString

This field might contain information about a decline. This field is supported only for Visa Acceptance through VisaNet.

Returns:

  • (String)


125
126
127
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 125

def response_details
  @response_details
end

#retrieval_reference_numberString

Ingenico ePayments

Unique number that Visa Acceptance generates to identify the transaction. You can use this value to identify transactions in the Ingenico ePayments Collections Report, which provides settlement information. Contact customer support for information about the report.

Visa Acceptance through VisaNet

Retrieval request number.

Returns:

  • (String)


380
381
382
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 380

def retrieval_reference_number
  @retrieval_reference_number
end

#routingRouting

Name of the Processor.

Returns:



355
356
357
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 355

def routing
  @routing
end

#scheme_assigned_idString

Unique id assigned to a merchant by the APM and not PSP The merchant ID, as boarded with Alipay

Returns:

  • (String)


422
423
424
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 422

def scheme_assigned_id
  @scheme_assigned_id
end

#seller_protectionSellerProtection

The redirect URL for forwarding the consumer to complete page. This redirect needed by PSP to track browser information of consumer. PSP then redirect consumer to merchant success URL.

Returns:



408
409
410
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 408

def seller_protection
  @seller_protection
end

#sequence_numberString

This field serves as a unique identifier for initial and subsequent recurring transactions, specific to the payment brand, and is crucial for transaction tracking and recurrence management. Not all processors provide this value. Returned by the authorization service.

Returns:

  • (String)


159
160
161
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 159

def sequence_number
  @sequence_number
end

#settlement_dateString

Field contains a settlement date. The date is in mmdd format, where: mm = month and dd = day.

Returns:

  • (String)


151
152
153
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 151

def settlement_date
  @settlement_date
end

#signatureString

The redirect URL for forwarding the consumer to complete page. This redirect needed by PSP to track browser information of consumer. PSP then redirect consumer to merchant success URL.

Returns:

  • (String)


396
397
398
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 396

def signature
  @signature
end

#system_trace_audit_numberString

This field is returned only for American Express Direct and Visa Acceptance through VisaNet. Returned by authorization and incremental authorization services.

American Express Direct

System trace audit number (STAN). This value identifies the transaction and is useful when investigating a chargeback dispute.

Visa Acceptance through VisaNet

System trace number that must be printed on the customer’s receipt.

Returns:

  • (String)


227
228
229
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 227

def system_trace_audit_number
  @system_trace_audit_number
end

#transaction_expiry_dateString

The date on which the transaction expires and payment cannot be made.

Returns:

  • (String)


412
413
414
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 412

def transaction_expiry_date
  @transaction_expiry_date
end

#transaction_idString

Network transaction identifier (TID). You can use this value to identify a specific transaction when you are discussing the transaction with your processor. Not all processors provide this value. Returned by the authorization service.

PIN debit

Transaction identifier generated by the processor. Returned by PIN debit credit.

GPX

Processor transaction ID.

Cielo

For Cielo, this value is the non-sequential unit (NSU) and is supported for all transactions. The value is generated by Cielo or the issuing bank.

Comercio Latino

For Comercio Latino, this value is the proof of sale or non-sequential unit (NSU) number generated by the acquirers Cielo and Rede, or the issuing bank.

Visa Acceptance through VisaNet and GPN

For details about this value for Visa Acceptance through VisaNet and GPN, see "processorInformation.networkTransactionId" in [REST API Fields](

Moneris

This value identifies the transaction on a host system. It contains the following information:

  • Terminal used to process the transaction
  • Shift during which the transaction took place
  • Batch number
  • Transaction number within the batch You must store this value. If you give the customer a receipt, display this value on the receipt. Example For the value 66012345001069003:
  • Terminal ID = 66012345
  • Shift number = 001
  • Batch number = 069
  • Transaction number = 003

Returns:

  • (String)


77
78
79
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 77

def transaction_id
  @transaction_id
end

#transaction_integrity_codeString

Transaction integrity classification provided by Mastercard. This value specifies Mastercard’s evaluation of the transaction’s safety and security. This field is returned only for Visa Acceptance through VisaNet. For card-present transactions, possible values:

  • A1: EMV or token in a secure, trusted environment
  • B1: EMV or chip equivalent
  • C1: Magnetic stripe
  • E1: Key entered
  • U0: Unclassified For card-not-present transactions, possible values:
  • A2: Digital transactions
  • B2: Authenticated checkout
  • C2: Transaction validation
  • D2: Enhanced data
  • E2: Generic messaging
  • U0: Unclassified For information about these values, contact Mastercard or your acquirer.

Visa Acceptance through VisaNet

The value for this field corresponds to the following data in the TC 33 capture file,1:

  • Record: CP01 TCR6
  • Position: 136-137
  • Field: Mastercard Transaction Integrity Classification 1 The TC 33 Capture file contains information about the purchases and refunds that a merchant submits to Visa Acceptance. Visa Acceptance through VisaNet creates the TC 33 Capture file at the end of the day and sends it to the merchant’s acquirer, who uses this information to facilitate end-of-day clearing processing with payment networks.

Returns:

  • (String)


285
286
287
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 285

def transaction_integrity_code
  @transaction_integrity_code
end

#update_time_utcString

The date and time when the transaction was last updated, in Internet date and time format.

Returns:

  • (String)


442
443
444
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 442

def update_time_utc
  @update_time_utc
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 687

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  auth_indicator = hash.key?('authIndicator') ? hash['authIndicator'] : SKIP
  approval_code = hash.key?('approvalCode') ? hash['approvalCode'] : SKIP
  card_reference_data =
    hash.key?('cardReferenceData') ? hash['cardReferenceData'] : SKIP
  transaction_id = hash.key?('transactionId') ? hash['transactionId'] : SKIP
  network_transaction_id =
    hash.key?('networkTransactionId') ? hash['networkTransactionId'] : SKIP
  response_code = hash.key?('responseCode') ? hash['responseCode'] : SKIP
  response_code_source =
    hash.key?('responseCodeSource') ? hash['responseCodeSource'] : SKIP
  response_details =
    hash.key?('responseDetails') ? hash['responseDetails'] : SKIP
  response_category_code =
    hash.key?('responseCategoryCode') ? hash['responseCategoryCode'] : SKIP
  forwarded_acquirer_code =
    hash.key?('forwardedAcquirerCode') ? hash['forwardedAcquirerCode'] : SKIP
  settlement_date =
    hash.key?('settlementDate') ? hash['settlementDate'] : SKIP
  sequence_number =
    hash.key?('sequenceNumber') ? hash['sequenceNumber'] : SKIP
  avs = Avs.from_hash(hash['avs']) if hash['avs']
  card_verification = CardVerification.from_hash(hash['cardVerification']) if
    hash['cardVerification']
  merchant_advice = MerchantAdvice.from_hash(hash['merchantAdvice']) if hash['merchantAdvice']
  if hash['electronicVerificationResults']
    electronic_verification_results = ElectronicVerificationResults.from_hash(hash['electronicVerificationResults'])
  end
  ach_verification = AchVerification.from_hash(hash['achVerification']) if
    hash['achVerification']
  customer = Customer2.from_hash(hash['customer']) if hash['customer']
  if hash['consumerAuthenticationResponse']
    consumer_authentication_response = ConsumerAuthenticationResponse.from_hash(hash['consumerAuthenticationResponse'])
  end
  system_trace_audit_number =
    hash.key?('systemTraceAuditNumber') ? hash['systemTraceAuditNumber'] : SKIP
   =
    hash.key?('paymentAccountReferenceNumber') ? hash['paymentAccountReferenceNumber'] : SKIP
  transaction_integrity_code =
    hash.key?('transactionIntegrityCode') ? hash['transactionIntegrityCode'] : SKIP
  amex_verbal_auth_reference_number =
    hash.key?('amexVerbalAuthReferenceNumber') ? hash['amexVerbalAuthReferenceNumber'] : SKIP
  master_card_service_code =
    hash.key?('masterCardServiceCode') ? hash['masterCardServiceCode'] : SKIP
  master_card_service_reply_code =
    hash.key?('masterCardServiceReplyCode') ? hash['masterCardServiceReplyCode'] : SKIP
  master_card_authentication_type =
    hash.key?('masterCardAuthenticationType') ? hash['masterCardAuthenticationType'] : SKIP
  name = hash.key?('name') ? hash['name'] : SKIP
  routing = Routing.from_hash(hash['routing']) if hash['routing']
  merchant_number =
    hash.key?('merchantNumber') ? hash['merchantNumber'] : SKIP
  retrieval_reference_number =
    hash.key?('retrievalReferenceNumber') ? hash['retrievalReferenceNumber'] : SKIP
  payment_url = hash.key?('paymentUrl') ? hash['paymentUrl'] : SKIP
  complete_url = hash.key?('completeUrl') ? hash['completeUrl'] : SKIP
  signature = hash.key?('signature') ? hash['signature'] : SKIP
  public_key = hash.key?('publicKey') ? hash['publicKey'] : SKIP
  seller_protection = SellerProtection.from_hash(hash['sellerProtection']) if
    hash['sellerProtection']
  transaction_expiry_date =
    hash.key?('transactionExpiryDate') ? hash['transactionExpiryDate'] : SKIP
  custom_url = hash.key?('customUrl') ? hash['customUrl'] : SKIP
  scheme_assigned_id =
    hash.key?('schemeAssignedId') ? hash['schemeAssignedId'] : SKIP
  device_url = hash.key?('deviceUrl') ? hash['deviceUrl'] : SKIP
  disbursement_mode =
    hash.key?('disbursementMode') ? hash['disbursementMode'] : SKIP
  update_time_utc =
    hash.key?('updateTimeUtc') ? hash['updateTimeUtc'] : SKIP
  expiration_time_utc =
    hash.key?('expirationTimeUtc') ? hash['expirationTimeUtc'] : SKIP
  order_id = hash.key?('orderId') ? hash['orderId'] : SKIP
  order_status = hash.key?('orderStatus') ? hash['orderStatus'] : SKIP
  merchant_risk_prediction =
    hash.key?('merchantRiskPrediction') ? hash['merchantRiskPrediction'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProcessorInformation1.new(auth_indicator: auth_indicator,
                            approval_code: approval_code,
                            card_reference_data: card_reference_data,
                            transaction_id: transaction_id,
                            network_transaction_id: network_transaction_id,
                            response_code: response_code,
                            response_code_source: response_code_source,
                            response_details: response_details,
                            response_category_code: response_category_code,
                            forwarded_acquirer_code: forwarded_acquirer_code,
                            settlement_date: settlement_date,
                            sequence_number: sequence_number,
                            avs: avs,
                            card_verification: card_verification,
                            merchant_advice: merchant_advice,
                            electronic_verification_results: electronic_verification_results,
                            ach_verification: ach_verification,
                            customer: customer,
                            consumer_authentication_response: consumer_authentication_response,
                            system_trace_audit_number: system_trace_audit_number,
                            payment_account_reference_number: ,
                            transaction_integrity_code: transaction_integrity_code,
                            amex_verbal_auth_reference_number: amex_verbal_auth_reference_number,
                            master_card_service_code: master_card_service_code,
                            master_card_service_reply_code: master_card_service_reply_code,
                            master_card_authentication_type: master_card_authentication_type,
                            name: name,
                            routing: routing,
                            merchant_number: merchant_number,
                            retrieval_reference_number: retrieval_reference_number,
                            payment_url: payment_url,
                            complete_url: complete_url,
                            signature: signature,
                            public_key: public_key,
                            seller_protection: seller_protection,
                            transaction_expiry_date: transaction_expiry_date,
                            custom_url: custom_url,
                            scheme_assigned_id: scheme_assigned_id,
                            device_url: device_url,
                            disbursement_mode: disbursement_mode,
                            update_time_utc: update_time_utc,
                            expiration_time_utc: expiration_time_utc,
                            order_id: order_id,
                            order_status: order_status,
                            merchant_risk_prediction: merchant_risk_prediction,
                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 471

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['auth_indicator'] = 'authIndicator'
  @_hash['approval_code'] = 'approvalCode'
  @_hash['card_reference_data'] = 'cardReferenceData'
  @_hash['transaction_id'] = 'transactionId'
  @_hash['network_transaction_id'] = 'networkTransactionId'
  @_hash['response_code'] = 'responseCode'
  @_hash['response_code_source'] = 'responseCodeSource'
  @_hash['response_details'] = 'responseDetails'
  @_hash['response_category_code'] = 'responseCategoryCode'
  @_hash['forwarded_acquirer_code'] = 'forwardedAcquirerCode'
  @_hash['settlement_date'] = 'settlementDate'
  @_hash['sequence_number'] = 'sequenceNumber'
  @_hash['avs'] = 'avs'
  @_hash['card_verification'] = 'cardVerification'
  @_hash['merchant_advice'] = 'merchantAdvice'
  @_hash['electronic_verification_results'] =
    'electronicVerificationResults'
  @_hash['ach_verification'] = 'achVerification'
  @_hash['customer'] = 'customer'
  @_hash['consumer_authentication_response'] =
    'consumerAuthenticationResponse'
  @_hash['system_trace_audit_number'] = 'systemTraceAuditNumber'
  @_hash['payment_account_reference_number'] =
    'paymentAccountReferenceNumber'
  @_hash['transaction_integrity_code'] = 'transactionIntegrityCode'
  @_hash['amex_verbal_auth_reference_number'] =
    'amexVerbalAuthReferenceNumber'
  @_hash['master_card_service_code'] = 'masterCardServiceCode'
  @_hash['master_card_service_reply_code'] = 'masterCardServiceReplyCode'
  @_hash['master_card_authentication_type'] =
    'masterCardAuthenticationType'
  @_hash['name'] = 'name'
  @_hash['routing'] = 'routing'
  @_hash['merchant_number'] = 'merchantNumber'
  @_hash['retrieval_reference_number'] = 'retrievalReferenceNumber'
  @_hash['payment_url'] = 'paymentUrl'
  @_hash['complete_url'] = 'completeUrl'
  @_hash['signature'] = 'signature'
  @_hash['public_key'] = 'publicKey'
  @_hash['seller_protection'] = 'sellerProtection'
  @_hash['transaction_expiry_date'] = 'transactionExpiryDate'
  @_hash['custom_url'] = 'customUrl'
  @_hash['scheme_assigned_id'] = 'schemeAssignedId'
  @_hash['device_url'] = 'deviceUrl'
  @_hash['disbursement_mode'] = 'disbursementMode'
  @_hash['update_time_utc'] = 'updateTimeUtc'
  @_hash['expiration_time_utc'] = 'expirationTimeUtc'
  @_hash['order_id'] = 'orderId'
  @_hash['order_status'] = 'orderStatus'
  @_hash['merchant_risk_prediction'] = 'merchantRiskPrediction'
  @_hash
end

.nullablesObject

An array for nullable fields



578
579
580
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 578

def self.nullables
  []
end

.optionalsObject

An array for optional fields



527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 527

def self.optionals
  %w[
    auth_indicator
    approval_code
    card_reference_data
    transaction_id
    network_transaction_id
    response_code
    response_code_source
    response_details
    response_category_code
    forwarded_acquirer_code
    settlement_date
    sequence_number
    avs
    card_verification
    merchant_advice
    electronic_verification_results
    ach_verification
    customer
    consumer_authentication_response
    system_trace_audit_number
    payment_account_reference_number
    transaction_integrity_code
    amex_verbal_auth_reference_number
    master_card_service_code
    master_card_service_reply_code
    master_card_authentication_type
    name
    routing
    merchant_number
    retrieval_reference_number
    payment_url
    complete_url
    signature
    public_key
    seller_protection
    transaction_expiry_date
    custom_url
    scheme_assigned_id
    device_url
    disbursement_mode
    update_time_utc
    expiration_time_utc
    order_id
    order_status
    merchant_risk_prediction
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 855

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} auth_indicator: #{@auth_indicator.inspect}, approval_code:"\
  " #{@approval_code.inspect}, card_reference_data: #{@card_reference_data.inspect},"\
  " transaction_id: #{@transaction_id.inspect}, network_transaction_id:"\
  " #{@network_transaction_id.inspect}, response_code: #{@response_code.inspect},"\
  " response_code_source: #{@response_code_source.inspect}, response_details:"\
  " #{@response_details.inspect}, response_category_code: #{@response_category_code.inspect},"\
  " forwarded_acquirer_code: #{@forwarded_acquirer_code.inspect}, settlement_date:"\
  " #{@settlement_date.inspect}, sequence_number: #{@sequence_number.inspect}, avs:"\
  " #{@avs.inspect}, card_verification: #{@card_verification.inspect}, merchant_advice:"\
  " #{@merchant_advice.inspect}, electronic_verification_results:"\
  " #{@electronic_verification_results.inspect}, ach_verification:"\
  " #{@ach_verification.inspect}, customer: #{@customer.inspect},"\
  " consumer_authentication_response: #{@consumer_authentication_response.inspect},"\
  " system_trace_audit_number: #{@system_trace_audit_number.inspect},"\
  " payment_account_reference_number: #{@payment_account_reference_number.inspect},"\
  " transaction_integrity_code: #{@transaction_integrity_code.inspect},"\
  " amex_verbal_auth_reference_number: #{@amex_verbal_auth_reference_number.inspect},"\
  " master_card_service_code: #{@master_card_service_code.inspect},"\
  " master_card_service_reply_code: #{@master_card_service_reply_code.inspect},"\
  " master_card_authentication_type: #{@master_card_authentication_type.inspect}, name:"\
  " #{@name.inspect}, routing: #{@routing.inspect}, merchant_number:"\
  " #{@merchant_number.inspect}, retrieval_reference_number:"\
  " #{@retrieval_reference_number.inspect}, payment_url: #{@payment_url.inspect},"\
  " complete_url: #{@complete_url.inspect}, signature: #{@signature.inspect}, public_key:"\
  " #{@public_key.inspect}, seller_protection: #{@seller_protection.inspect},"\
  " transaction_expiry_date: #{@transaction_expiry_date.inspect}, custom_url:"\
  " #{@custom_url.inspect}, scheme_assigned_id: #{@scheme_assigned_id.inspect}, device_url:"\
  " #{@device_url.inspect}, disbursement_mode: #{@disbursement_mode.inspect}, update_time_utc:"\
  " #{@update_time_utc.inspect}, expiration_time_utc: #{@expiration_time_utc.inspect},"\
  " order_id: #{@order_id.inspect}, order_status: #{@order_status.inspect},"\
  " merchant_risk_prediction: #{@merchant_risk_prediction.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
# File 'lib/visa_acceptance_merged_spec/models/processor_information1.rb', line 824

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} auth_indicator: #{@auth_indicator}, approval_code: #{@approval_code},"\
  " card_reference_data: #{@card_reference_data}, transaction_id: #{@transaction_id},"\
  " network_transaction_id: #{@network_transaction_id}, response_code: #{@response_code},"\
  " response_code_source: #{@response_code_source}, response_details: #{@response_details},"\
  " response_category_code: #{@response_category_code}, forwarded_acquirer_code:"\
  " #{@forwarded_acquirer_code}, settlement_date: #{@settlement_date}, sequence_number:"\
  " #{@sequence_number}, avs: #{@avs}, card_verification: #{@card_verification},"\
  " merchant_advice: #{@merchant_advice}, electronic_verification_results:"\
  " #{@electronic_verification_results}, ach_verification: #{@ach_verification}, customer:"\
  " #{@customer}, consumer_authentication_response: #{@consumer_authentication_response},"\
  " system_trace_audit_number: #{@system_trace_audit_number},"\
  " payment_account_reference_number: #{@payment_account_reference_number},"\
  " transaction_integrity_code: #{@transaction_integrity_code},"\
  " amex_verbal_auth_reference_number: #{@amex_verbal_auth_reference_number},"\
  " master_card_service_code: #{@master_card_service_code}, master_card_service_reply_code:"\
  " #{@master_card_service_reply_code}, master_card_authentication_type:"\
  " #{@master_card_authentication_type}, name: #{@name}, routing: #{@routing},"\
  " merchant_number: #{@merchant_number}, retrieval_reference_number:"\
  " #{@retrieval_reference_number}, payment_url: #{@payment_url}, complete_url:"\
  " #{@complete_url}, signature: #{@signature}, public_key: #{@public_key}, seller_protection:"\
  " #{@seller_protection}, transaction_expiry_date: #{@transaction_expiry_date}, custom_url:"\
  " #{@custom_url}, scheme_assigned_id: #{@scheme_assigned_id}, device_url: #{@device_url},"\
  " disbursement_mode: #{@disbursement_mode}, update_time_utc: #{@update_time_utc},"\
  " expiration_time_utc: #{@expiration_time_utc}, order_id: #{@order_id}, order_status:"\
  " #{@order_status}, merchant_risk_prediction: #{@merchant_risk_prediction},"\
  " additional_properties: #{@additional_properties}>"
end