Class: VisaAcceptanceMergedSpec::ProcessorInformation22

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/processor_information22.rb

Overview

ProcessorInformation22 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(transaction_id: SKIP, network_transaction_id: SKIP, payment_url: SKIP, additional_properties: nil) ⇒ ProcessorInformation22

Returns a new instance of ProcessorInformation22.



81
82
83
84
85
86
87
88
89
90
# File 'lib/visa_acceptance_merged_spec/models/processor_information22.rb', line 81

def initialize(transaction_id: SKIP, network_transaction_id: SKIP,
               payment_url: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @transaction_id = transaction_id unless transaction_id == SKIP
  @network_transaction_id = network_transaction_id unless network_transaction_id == SKIP
  @payment_url = payment_url unless payment_url == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#network_transaction_idString

Same value as processorInformation.transactionId

Returns:

  • (String)


52
53
54
# File 'lib/visa_acceptance_merged_spec/models/processor_information22.rb', line 52

def network_transaction_id
  @network_transaction_id
end

#payment_urlString

Direct the customer to this URL to complete the payment.

Returns:

  • (String)


56
57
58
# File 'lib/visa_acceptance_merged_spec/models/processor_information22.rb', line 56

def payment_url
  @payment_url
end

#transaction_idString

Network transaction identifier (TID). You can use this value to identify a specific transaction when you are discussing the transaction with your processor. Not all processors provide this value. Returned by the authorization service.

PIN debit

Transaction identifier generated by the processor. Returned by PIN debit credit.

GPX

Processor transaction ID.

Cielo

For Cielo, this value is the non-sequential unit (NSU) and is supported for all transactions. The value is generated by Cielo or the issuing bank.

Comercio Latino

For Comercio Latino, this value is the proof of sale or non-sequential unit (NSU) number generated by the acquirers Cielo and Rede, or the issuing bank.

Visa Acceptance through VisaNet and GPN

For details about this value for Visa Acceptance through VisaNet and GPN, see "processorInformation.networkTransactionId" in [REST API Fields](

Moneris

This value identifies the transaction on a host system. It contains the following information:

  • Terminal used to process the transaction
  • Shift during which the transaction took place
  • Batch number
  • Transaction number within the batch You must store this value. If you give the customer a receipt, display this value on the receipt. Example For the value 66012345001069003:
  • Terminal ID = 66012345
  • Shift number = 001
  • Batch number = 069
  • Transaction number = 003

Returns:

  • (String)


48
49
50
# File 'lib/visa_acceptance_merged_spec/models/processor_information22.rb', line 48

def transaction_id
  @transaction_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/visa_acceptance_merged_spec/models/processor_information22.rb', line 93

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  transaction_id = hash.key?('transactionId') ? hash['transactionId'] : SKIP
  network_transaction_id =
    hash.key?('networkTransactionId') ? hash['networkTransactionId'] : SKIP
  payment_url = hash.key?('paymentUrl') ? hash['paymentUrl'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProcessorInformation22.new(transaction_id: transaction_id,
                             network_transaction_id: network_transaction_id,
                             payment_url: payment_url,
                             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



59
60
61
62
63
64
65
# File 'lib/visa_acceptance_merged_spec/models/processor_information22.rb', line 59

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['transaction_id'] = 'transactionId'
  @_hash['network_transaction_id'] = 'networkTransactionId'
  @_hash['payment_url'] = 'paymentUrl'
  @_hash
end

.nullablesObject

An array for nullable fields



77
78
79
# File 'lib/visa_acceptance_merged_spec/models/processor_information22.rb', line 77

def self.nullables
  []
end

.optionalsObject

An array for optional fields



68
69
70
71
72
73
74
# File 'lib/visa_acceptance_merged_spec/models/processor_information22.rb', line 68

def self.optionals
  %w[
    transaction_id
    network_transaction_id
    payment_url
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



125
126
127
128
129
130
# File 'lib/visa_acceptance_merged_spec/models/processor_information22.rb', line 125

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} transaction_id: #{@transaction_id.inspect}, network_transaction_id:"\
  " #{@network_transaction_id.inspect}, payment_url: #{@payment_url.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



117
118
119
120
121
122
# File 'lib/visa_acceptance_merged_spec/models/processor_information22.rb', line 117

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} transaction_id: #{@transaction_id}, network_transaction_id:"\
  " #{@network_transaction_id}, payment_url: #{@payment_url}, additional_properties:"\
  " #{@additional_properties}>"
end