Class: VisaAcceptanceMergedSpec::Profile3

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/profile3.rb

Overview

Profile3 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(name: SKIP, additional_properties: nil) ⇒ Profile3

Returns a new instance of Profile3.



41
42
43
44
45
46
47
# File 'lib/visa_acceptance_merged_spec/models/profile3.rb', line 41

def initialize(name: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @name = name unless name == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#nameString

Name of the active profile chosen by the profile selector. If no profile selector exists, the default active profile is chosen. Note By default, your default profile is the active profile, or the Profile Selector chooses the active profile. Use this field only if you want to specify the name of a different profile. The passed-in profile will then become the active profile.

Returns:

  • (String)


20
21
22
# File 'lib/visa_acceptance_merged_spec/models/profile3.rb', line 20

def name
  @name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/visa_acceptance_merged_spec/models/profile3.rb', line 50

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  name = hash.key?('name') ? hash['name'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Profile3.new(name: name,
               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
# File 'lib/visa_acceptance_merged_spec/models/profile3.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['name'] = 'name'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/visa_acceptance_merged_spec/models/profile3.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
# File 'lib/visa_acceptance_merged_spec/models/profile3.rb', line 30

def self.optionals
  %w[
    name
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



75
76
77
78
# File 'lib/visa_acceptance_merged_spec/models/profile3.rb', line 75

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



69
70
71
72
# File 'lib/visa_acceptance_merged_spec/models/profile3.rb', line 69

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name}, additional_properties: #{@additional_properties}>"
end