Class: VisaAcceptanceMergedSpec::PromotionInformation
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::PromotionInformation
- Defined in:
- lib/visa_acceptance_merged_spec/models/promotion_information.rb
Overview
PromotionInformation Model.
Instance Attribute Summary collapse
-
#additional_code ⇒ String
Additional rental agency marketed coupons for consumers to discount the rate of the vehicle rental agreement.
-
#code ⇒ String
Code for a promotion or discount.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(additional_code: SKIP, code: SKIP, additional_properties: nil) ⇒ PromotionInformation
constructor
A new instance of PromotionInformation.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(additional_code: SKIP, code: SKIP, additional_properties: nil) ⇒ PromotionInformation
Returns a new instance of PromotionInformation.
42 43 44 45 46 47 48 49 50 |
# File 'lib/visa_acceptance_merged_spec/models/promotion_information.rb', line 42 def initialize(additional_code: SKIP, code: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @additional_code = additional_code unless additional_code == SKIP @code = code unless code == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#additional_code ⇒ String
Additional rental agency marketed coupons for consumers to discount the rate of the vehicle rental agreement.
15 16 17 |
# File 'lib/visa_acceptance_merged_spec/models/promotion_information.rb', line 15 def additional_code @additional_code end |
#code ⇒ String
Code for a promotion or discount.
19 20 21 |
# File 'lib/visa_acceptance_merged_spec/models/promotion_information.rb', line 19 def code @code end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/visa_acceptance_merged_spec/models/promotion_information.rb', line 53 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. additional_code = hash.key?('additionalCode') ? hash['additionalCode'] : SKIP code = hash.key?('code') ? hash['code'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PromotionInformation.new(additional_code: additional_code, code: code, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/visa_acceptance_merged_spec/models/promotion_information.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['additional_code'] = 'additionalCode' @_hash['code'] = 'code' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 |
# File 'lib/visa_acceptance_merged_spec/models/promotion_information.rb', line 38 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 35 |
# File 'lib/visa_acceptance_merged_spec/models/promotion_information.rb', line 30 def self.optionals %w[ additional_code code ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
82 83 84 85 86 |
# File 'lib/visa_acceptance_merged_spec/models/promotion_information.rb', line 82 def inspect class_name = self.class.name.split('::').last "<#{class_name} additional_code: #{@additional_code.inspect}, code: #{@code.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
75 76 77 78 79 |
# File 'lib/visa_acceptance_merged_spec/models/promotion_information.rb', line 75 def to_s class_name = self.class.name.split('::').last "<#{class_name} additional_code: #{@additional_code}, code: #{@code},"\ " additional_properties: #{@additional_properties}>" end |