Class: VisaAcceptanceMergedSpec::PtsV1TransactionBatchesGet404Response1Exception
- Inherits:
-
APIException
- Object
- CoreLibrary::ApiException
- APIException
- VisaAcceptanceMergedSpec::PtsV1TransactionBatchesGet404Response1Exception
- Defined in:
- lib/visa_acceptance_merged_spec/exceptions/pts_v1_transaction_batches_get404_response1_exception.rb
Overview
ptsV1TransactionBatchesGet404Response1 class.
Instance Attribute Summary collapse
-
#error_information ⇒ ErrorInformation2
TODO: Write general description for this method.
-
#submit_time_utc ⇒ String
Time of request in UTC.
Instance Method Summary collapse
-
#initialize(reason, response) ⇒ PtsV1TransactionBatchesGet404Response1Exception
constructor
The constructor.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
-
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash.
Constructor Details
#initialize(reason, response) ⇒ PtsV1TransactionBatchesGet404Response1Exception
The constructor.
27 28 29 30 31 |
# File 'lib/visa_acceptance_merged_spec/exceptions/pts_v1_transaction_batches_get404_response1_exception.rb', line 27 def initialize(reason, response) super(reason, response) hash = APIHelper.json_deserialize(@response.raw_body) unbox(hash) end |
Instance Attribute Details
#error_information ⇒ ErrorInformation2
TODO: Write general description for this method
14 15 16 |
# File 'lib/visa_acceptance_merged_spec/exceptions/pts_v1_transaction_batches_get404_response1_exception.rb', line 14 def error_information @error_information end |
#submit_time_utc ⇒ String
Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ
Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57
(10:47:57 p.m.).
The T separates the date and the time. The Z indicates UTC.
Returned by Visa Acceptance for all services.
22 23 24 |
# File 'lib/visa_acceptance_merged_spec/exceptions/pts_v1_transaction_batches_get404_response1_exception.rb', line 22 def submit_time_utc @submit_time_utc end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
53 54 55 56 57 |
# File 'lib/visa_acceptance_merged_spec/exceptions/pts_v1_transaction_batches_get404_response1_exception.rb', line 53 def inspect class_name = self.class.name.split('::').last "<#{class_name} error_information: #{@error_information.inspect}, submit_time_utc:"\ " #{@submit_time_utc.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
46 47 48 49 50 |
# File 'lib/visa_acceptance_merged_spec/exceptions/pts_v1_transaction_batches_get404_response1_exception.rb', line 46 def to_s class_name = self.class.name.split('::').last "<#{class_name} error_information: #{@error_information}, submit_time_utc:"\ " #{@submit_time_utc}>" end |
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash. response body.
36 37 38 39 40 41 42 43 |
# File 'lib/visa_acceptance_merged_spec/exceptions/pts_v1_transaction_batches_get404_response1_exception.rb', line 36 def unbox(hash) return nil unless hash @error_information = ErrorInformation2.from_hash(hash['errorInformation']) if hash['errorInformation'] @submit_time_utc = hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP end |