Class: VisaAcceptanceMergedSpec::PtsV1TransactionBatchesGet502Response1Exception

Inherits:
APIException
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/exceptions/pts_v1_transaction_batches_get502_response1_exception.rb

Overview

ptsV1TransactionBatchesGet502Response1 class.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(reason, response) ⇒ PtsV1TransactionBatchesGet502Response1Exception

The constructor.

Parameters:

  • reason (String)

    The reason for raising an exception.

  • response (HttpResponse)

    The HttpReponse of the API call.



27
28
29
30
31
# File 'lib/visa_acceptance_merged_spec/exceptions/pts_v1_transaction_batches_get502_response1_exception.rb', line 27

def initialize(reason, response)
  super(reason, response)
  hash = APIHelper.json_deserialize(@response.raw_body)
  unbox(hash)
end

Instance Attribute Details

#error_informationErrorInformation6

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/visa_acceptance_merged_spec/exceptions/pts_v1_transaction_batches_get502_response1_exception.rb', line 14

def error_information
  @error_information
end

#submit_time_utcString

Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The T separates the date and the time. The Z indicates UTC. Returned by Visa Acceptance for all services.

Returns:

  • (String)


22
23
24
# File 'lib/visa_acceptance_merged_spec/exceptions/pts_v1_transaction_batches_get502_response1_exception.rb', line 22

def submit_time_utc
  @submit_time_utc
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



53
54
55
56
57
# File 'lib/visa_acceptance_merged_spec/exceptions/pts_v1_transaction_batches_get502_response1_exception.rb', line 53

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} error_information: #{@error_information.inspect}, submit_time_utc:"\
  " #{@submit_time_utc.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



46
47
48
49
50
# File 'lib/visa_acceptance_merged_spec/exceptions/pts_v1_transaction_batches_get502_response1_exception.rb', line 46

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} error_information: #{@error_information}, submit_time_utc:"\
  " #{@submit_time_utc}>"
end

#unbox(hash) ⇒ Object

Populates this object by extracting properties from a hash. response body.

Parameters:

  • hash (Hash)

    The deserialized response sent by the server in the



36
37
38
39
40
41
42
43
# File 'lib/visa_acceptance_merged_spec/exceptions/pts_v1_transaction_batches_get502_response1_exception.rb', line 36

def unbox(hash)
  return nil unless hash

  @error_information = ErrorInformation6.from_hash(hash['errorInformation']) if
    hash['errorInformation']
  @submit_time_utc =
    hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP
end