Class: VisaAcceptanceMergedSpec::PtsV2CreateOrderPost201Response

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/pts_v2_create_order_post201_response.rb

Overview

PtsV2CreateOrderPost201Response Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(submit_time_utc: SKIP, update_time_utc: SKIP, status: SKIP, reconciliation_id: SKIP, client_reference_information: SKIP, processor_information: SKIP, payment_information: SKIP, buyer_information: SKIP, additional_properties: nil) ⇒ PtsV2CreateOrderPost201Response

Returns a new instance of PtsV2CreateOrderPost201Response.



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_create_order_post201_response.rb', line 115

def initialize(submit_time_utc: SKIP, update_time_utc: SKIP, status: SKIP,
               reconciliation_id: SKIP, client_reference_information: SKIP,
               processor_information: SKIP, payment_information: SKIP,
               buyer_information: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @submit_time_utc = submit_time_utc unless submit_time_utc == SKIP
  @update_time_utc = update_time_utc unless update_time_utc == SKIP
  @status = status unless status == SKIP
  @reconciliation_id = reconciliation_id unless reconciliation_id == SKIP
  unless client_reference_information == SKIP
    @client_reference_information =
      client_reference_information
  end
  @processor_information = processor_information unless processor_information == SKIP
  @payment_information = payment_information unless payment_information == SKIP
  @buyer_information = buyer_information unless buyer_information == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#buyer_informationBuyerInformation11

Reference number for the transaction. Depending on how your Visa Acceptance account is configured, this value could either be provided in the API request or generated by Visa Acceptance. The actual value used in the request to the processor is provided back to you by Visa Acceptance in the response.

Returns:



80
81
82
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_create_order_post201_response.rb', line 80

def buyer_information
  @buyer_information
end

#client_reference_informationClientReferenceInformation3

Reference number for the transaction. Depending on how your Visa Acceptance account is configured, this value could either be provided in the API request or generated by Visa Acceptance. The actual value used in the request to the processor is provided back to you by Visa Acceptance in the response.



53
54
55
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_create_order_post201_response.rb', line 53

def client_reference_information
  @client_reference_information
end

#payment_informationPaymentInformation21

Reference number for the transaction. Depending on how your Visa Acceptance account is configured, this value could either be provided in the API request or generated by Visa Acceptance. The actual value used in the request to the processor is provided back to you by Visa Acceptance in the response.



71
72
73
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_create_order_post201_response.rb', line 71

def payment_information
  @payment_information
end

#processor_informationProcessorInformation22

Reference number for the transaction. Depending on how your Visa Acceptance account is configured, this value could either be provided in the API request or generated by Visa Acceptance. The actual value used in the request to the processor is provided back to you by Visa Acceptance in the response.



62
63
64
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_create_order_post201_response.rb', line 62

def processor_information
  @processor_information
end

#reconciliation_idString

Reference number for the transaction. Depending on how your Visa Acceptance account is configured, this value could either be provided in the API request or generated by Visa Acceptance. The actual value used in the request to the processor is provided back to you by Visa Acceptance in the response.

Returns:

  • (String)


44
45
46
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_create_order_post201_response.rb', line 44

def reconciliation_id
  @reconciliation_id
end

#statusString

The status of the submitted transaction. Possible values:

- CREATED
- SAVED
- APPROVED
- VOIDED
- COMPLETED
- PAYER_ACTION_REQUIRED

Returns:

  • (String)


35
36
37
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_create_order_post201_response.rb', line 35

def status
  @status
end

#submit_time_utcString

Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The T separates the date and the time. The Z indicates UTC. Returned by Visa Acceptance for all services.

Returns:

  • (String)


18
19
20
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_create_order_post201_response.rb', line 18

def submit_time_utc
  @submit_time_utc
end

#update_time_utcString

The date and time when the request was last updated. Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57 p.m.).

Returns:

  • (String)


24
25
26
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_create_order_post201_response.rb', line 24

def update_time_utc
  @update_time_utc
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_create_order_post201_response.rb', line 137

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  submit_time_utc =
    hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP
  update_time_utc =
    hash.key?('updateTimeUtc') ? hash['updateTimeUtc'] : SKIP
  status = hash.key?('status') ? hash['status'] : SKIP
  reconciliation_id =
    hash.key?('reconciliationId') ? hash['reconciliationId'] : SKIP
  if hash['clientReferenceInformation']
    client_reference_information = ClientReferenceInformation3.from_hash(hash['clientReferenceInformation'])
  end
  processor_information = ProcessorInformation22.from_hash(hash['processorInformation']) if
    hash['processorInformation']
  payment_information = PaymentInformation21.from_hash(hash['paymentInformation']) if
    hash['paymentInformation']
  buyer_information = BuyerInformation11.from_hash(hash['buyerInformation']) if
    hash['buyerInformation']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PtsV2CreateOrderPost201Response.new(submit_time_utc: submit_time_utc,
                                      update_time_utc: update_time_utc,
                                      status: status,
                                      reconciliation_id: reconciliation_id,
                                      client_reference_information: client_reference_information,
                                      processor_information: processor_information,
                                      payment_information: payment_information,
                                      buyer_information: buyer_information,
                                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_create_order_post201_response.rb', line 83

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['submit_time_utc'] = 'submitTimeUtc'
  @_hash['update_time_utc'] = 'updateTimeUtc'
  @_hash['status'] = 'status'
  @_hash['reconciliation_id'] = 'reconciliationId'
  @_hash['client_reference_information'] = 'clientReferenceInformation'
  @_hash['processor_information'] = 'processorInformation'
  @_hash['payment_information'] = 'paymentInformation'
  @_hash['buyer_information'] = 'buyerInformation'
  @_hash
end

.nullablesObject

An array for nullable fields



111
112
113
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_create_order_post201_response.rb', line 111

def self.nullables
  []
end

.optionalsObject

An array for optional fields



97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_create_order_post201_response.rb', line 97

def self.optionals
  %w[
    submit_time_utc
    update_time_utc
    status
    reconciliation_id
    client_reference_information
    processor_information
    payment_information
    buyer_information
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



189
190
191
192
193
194
195
196
197
198
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_create_order_post201_response.rb', line 189

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} submit_time_utc: #{@submit_time_utc.inspect}, update_time_utc:"\
  " #{@update_time_utc.inspect}, status: #{@status.inspect}, reconciliation_id:"\
  " #{@reconciliation_id.inspect}, client_reference_information:"\
  " #{@client_reference_information.inspect}, processor_information:"\
  " #{@processor_information.inspect}, payment_information: #{@payment_information.inspect},"\
  " buyer_information: #{@buyer_information.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



178
179
180
181
182
183
184
185
186
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_create_order_post201_response.rb', line 178

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} submit_time_utc: #{@submit_time_utc}, update_time_utc: #{@update_time_utc},"\
  " status: #{@status}, reconciliation_id: #{@reconciliation_id},"\
  " client_reference_information: #{@client_reference_information}, processor_information:"\
  " #{@processor_information}, payment_information: #{@payment_information},"\
  " buyer_information: #{@buyer_information}, additional_properties:"\
  " #{@additional_properties}>"
end