Class: VisaAcceptanceMergedSpec::PtsV2IncrementalAuthorizationPatch201Response

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/pts_v2_incremental_authorization_patch201_response.rb

Overview

PtsV2IncrementalAuthorizationPatch201Response Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, status: SKIP, reconciliation_id: SKIP, error_information: SKIP, client_reference_information: SKIP, processor_information: SKIP, payment_information: SKIP, order_information: SKIP, additional_properties: nil) ⇒ PtsV2IncrementalAuthorizationPatch201Response

Returns a new instance of PtsV2IncrementalAuthorizationPatch201Response.



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_incremental_authorization_patch201_response.rb', line 131

def initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, status: SKIP,
               reconciliation_id: SKIP, error_information: SKIP,
               client_reference_information: SKIP,
               processor_information: SKIP, payment_information: SKIP,
               order_information: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @links = links unless links == SKIP
  @id = id unless id == SKIP
  @submit_time_utc = submit_time_utc unless submit_time_utc == SKIP
  @status = status unless status == SKIP
  @reconciliation_id = reconciliation_id unless reconciliation_id == SKIP
  @error_information = error_information unless error_information == SKIP
  unless client_reference_information == SKIP
    @client_reference_information =
      client_reference_information
  end
  @processor_information = processor_information unless processor_information == SKIP
  @payment_information = payment_information unless payment_information == SKIP
  @order_information = order_information unless order_information == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_reference_informationClientReferenceInformation3

Reference number for the transaction. Depending on how your Visa Acceptance account is configured, this value could either be provided in the API request or generated by Visa Acceptance. The actual value used in the request to the processor is provided back to you by Visa Acceptance in the response.



65
66
67
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_incremental_authorization_patch201_response.rb', line 65

def client_reference_information
  @client_reference_information
end

#error_informationErrorInformation1

Reference number for the transaction. Depending on how your Visa Acceptance account is configured, this value could either be provided in the API request or generated by Visa Acceptance. The actual value used in the request to the processor is provided back to you by Visa Acceptance in the response.

Returns:



56
57
58
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_incremental_authorization_patch201_response.rb', line 56

def error_information
  @error_information
end

#idString

An unique identification number generated by Visa Acceptance to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.

Returns:

  • (String)


22
23
24
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_incremental_authorization_patch201_response.rb', line 22

def id
  @id
end

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_incremental_authorization_patch201_response.rb', line 14

def links
  @links
end

#order_informationOrderInformation3

Reference number for the transaction. Depending on how your Visa Acceptance account is configured, this value could either be provided in the API request or generated by Visa Acceptance. The actual value used in the request to the processor is provided back to you by Visa Acceptance in the response.

Returns:



92
93
94
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_incremental_authorization_patch201_response.rb', line 92

def order_information
  @order_information
end

#payment_informationPaymentInformation2

Reference number for the transaction. Depending on how your Visa Acceptance account is configured, this value could either be provided in the API request or generated by Visa Acceptance. The actual value used in the request to the processor is provided back to you by Visa Acceptance in the response.

Returns:



83
84
85
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_incremental_authorization_patch201_response.rb', line 83

def payment_information
  @payment_information
end

#processor_informationProcessorInformation2

Reference number for the transaction. Depending on how your Visa Acceptance account is configured, this value could either be provided in the API request or generated by Visa Acceptance. The actual value used in the request to the processor is provided back to you by Visa Acceptance in the response.



74
75
76
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_incremental_authorization_patch201_response.rb', line 74

def processor_information
  @processor_information
end

#reconciliation_idString

Reference number for the transaction. Depending on how your Visa Acceptance account is configured, this value could either be provided in the API request or generated by Visa Acceptance. The actual value used in the request to the processor is provided back to you by Visa Acceptance in the response.

Returns:

  • (String)


47
48
49
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_incremental_authorization_patch201_response.rb', line 47

def reconciliation_id
  @reconciliation_id
end

#statusString

The status of the submitted transaction. Possible values:

  • AUTHORIZED
  • AUTHORIZED_PENDING_REVIEW
  • DECLINED

Returns:

  • (String)


38
39
40
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_incremental_authorization_patch201_response.rb', line 38

def status
  @status
end

#submit_time_utcString

Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The T separates the date and the time. The Z indicates UTC. Returned by Visa Acceptance for all services.

Returns:

  • (String)


30
31
32
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_incremental_authorization_patch201_response.rb', line 30

def submit_time_utc
  @submit_time_utc
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_incremental_authorization_patch201_response.rb', line 156

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  links = Links1.from_hash(hash['_links']) if hash['_links']
  id = hash.key?('id') ? hash['id'] : SKIP
  submit_time_utc =
    hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP
  status = hash.key?('status') ? hash['status'] : SKIP
  reconciliation_id =
    hash.key?('reconciliationId') ? hash['reconciliationId'] : SKIP
  error_information = ErrorInformation1.from_hash(hash['errorInformation']) if
    hash['errorInformation']
  if hash['clientReferenceInformation']
    client_reference_information = ClientReferenceInformation3.from_hash(hash['clientReferenceInformation'])
  end
  processor_information = ProcessorInformation2.from_hash(hash['processorInformation']) if
    hash['processorInformation']
  payment_information = PaymentInformation2.from_hash(hash['paymentInformation']) if
    hash['paymentInformation']
  order_information = OrderInformation3.from_hash(hash['orderInformation']) if
    hash['orderInformation']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PtsV2IncrementalAuthorizationPatch201Response.new(links: links,
                                                    id: id,
                                                    submit_time_utc: submit_time_utc,
                                                    status: status,
                                                    reconciliation_id: reconciliation_id,
                                                    error_information: error_information,
                                                    client_reference_information: client_reference_information,
                                                    processor_information: processor_information,
                                                    payment_information: payment_information,
                                                    order_information: order_information,
                                                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_incremental_authorization_patch201_response.rb', line 95

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['links'] = '_links'
  @_hash['id'] = 'id'
  @_hash['submit_time_utc'] = 'submitTimeUtc'
  @_hash['status'] = 'status'
  @_hash['reconciliation_id'] = 'reconciliationId'
  @_hash['error_information'] = 'errorInformation'
  @_hash['client_reference_information'] = 'clientReferenceInformation'
  @_hash['processor_information'] = 'processorInformation'
  @_hash['payment_information'] = 'paymentInformation'
  @_hash['order_information'] = 'orderInformation'
  @_hash
end

.nullablesObject

An array for nullable fields



127
128
129
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_incremental_authorization_patch201_response.rb', line 127

def self.nullables
  []
end

.optionalsObject

An array for optional fields



111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_incremental_authorization_patch201_response.rb', line 111

def self.optionals
  %w[
    links
    id
    submit_time_utc
    status
    reconciliation_id
    error_information
    client_reference_information
    processor_information
    payment_information
    order_information
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



212
213
214
215
216
217
218
219
220
221
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_incremental_authorization_patch201_response.rb', line 212

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} links: #{@links.inspect}, id: #{@id.inspect}, submit_time_utc:"\
  " #{@submit_time_utc.inspect}, status: #{@status.inspect}, reconciliation_id:"\
  " #{@reconciliation_id.inspect}, error_information: #{@error_information.inspect},"\
  " client_reference_information: #{@client_reference_information.inspect},"\
  " processor_information: #{@processor_information.inspect}, payment_information:"\
  " #{@payment_information.inspect}, order_information: #{@order_information.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



201
202
203
204
205
206
207
208
209
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_incremental_authorization_patch201_response.rb', line 201

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} links: #{@links}, id: #{@id}, submit_time_utc: #{@submit_time_utc}, status:"\
  " #{@status}, reconciliation_id: #{@reconciliation_id}, error_information:"\
  " #{@error_information}, client_reference_information: #{@client_reference_information},"\
  " processor_information: #{@processor_information}, payment_information:"\
  " #{@payment_information}, order_information: #{@order_information}, additional_properties:"\
  " #{@additional_properties}>"
end