Class: VisaAcceptanceMergedSpec::PtsV2PaymentsRefundPost201Response

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/pts_v2_payments_refund_post201_response.rb

Overview

PtsV2PaymentsRefundPost201Response Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, status: SKIP, reconciliation_id: SKIP, client_reference_information: SKIP, refund_amount_details: SKIP, processing_information: SKIP, processor_information: SKIP, order_information: SKIP, point_of_sale_information: SKIP, additional_properties: nil) ⇒ PtsV2PaymentsRefundPost201Response

Returns a new instance of PtsV2PaymentsRefundPost201Response.



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_refund_post201_response.rb', line 140

def initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, status: SKIP,
               reconciliation_id: SKIP, client_reference_information: SKIP,
               refund_amount_details: SKIP, processing_information: SKIP,
               processor_information: SKIP, order_information: SKIP,
               point_of_sale_information: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @links = links unless links == SKIP
  @id = id unless id == SKIP
  @submit_time_utc = submit_time_utc unless submit_time_utc == SKIP
  @status = status unless status == SKIP
  @reconciliation_id = reconciliation_id unless reconciliation_id == SKIP
  unless client_reference_information == SKIP
    @client_reference_information =
      client_reference_information
  end
  @refund_amount_details = refund_amount_details unless refund_amount_details == SKIP
  @processing_information = processing_information unless processing_information == SKIP
  @processor_information = processor_information unless processor_information == SKIP
  @order_information = order_information unless order_information == SKIP
  unless point_of_sale_information == SKIP
    @point_of_sale_information =
      point_of_sale_information
  end
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_reference_information ⇒ ClientReferenceInformation11

Reference number for the transaction. Depending on how your Visa Acceptance account is configured, this value could either be provided in the API request or generated by Visa Acceptance. The actual value used in the request to the processor is provided back to you by Visa Acceptance in the response.



54
55
56
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_refund_post201_response.rb', line 54

def client_reference_information
  @client_reference_information
end

#id ⇒ String

An unique identification number generated by Visa Acceptance to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.

Returns:

  • (String)


22
23
24
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_refund_post201_response.rb', line 22

def id
  @id
end

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_refund_post201_response.rb', line 14

def links
  @links
end

#order_information ⇒ OrderInformation9

Reference number for the transaction. Depending on how your Visa Acceptance account is configured, this value could either be provided in the API request or generated by Visa Acceptance. The actual value used in the request to the processor is provided back to you by Visa Acceptance in the response.

Returns:



90
91
92
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_refund_post201_response.rb', line 90

def order_information
  @order_information
end

#point_of_sale_information ⇒ PointOfSaleInformation7

Reference number for the transaction. Depending on how your Visa Acceptance account is configured, this value could either be provided in the API request or generated by Visa Acceptance. The actual value used in the request to the processor is provided back to you by Visa Acceptance in the response.



99
100
101
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_refund_post201_response.rb', line 99

def point_of_sale_information
  @point_of_sale_information
end

#processing_information ⇒ ProcessingInformation6

Reference number for the transaction. Depending on how your Visa Acceptance account is configured, this value could either be provided in the API request or generated by Visa Acceptance. The actual value used in the request to the processor is provided back to you by Visa Acceptance in the response.



72
73
74
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_refund_post201_response.rb', line 72

def processing_information
  @processing_information
end

#processor_information ⇒ ProcessorInformation7

Reference number for the transaction. Depending on how your Visa Acceptance account is configured, this value could either be provided in the API request or generated by Visa Acceptance. The actual value used in the request to the processor is provided back to you by Visa Acceptance in the response.



81
82
83
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_refund_post201_response.rb', line 81

def processor_information
  @processor_information
end

#reconciliation_id ⇒ String

Reference number for the transaction. Depending on how your Visa Acceptance account is configured, this value could either be provided in the API request or generated by Visa Acceptance. The actual value used in the request to the processor is provided back to you by Visa Acceptance in the response.

Returns:

  • (String)


45
46
47
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_refund_post201_response.rb', line 45

def reconciliation_id
  @reconciliation_id
end

#refund_amount_details ⇒ RefundAmountDetails

Reference number for the transaction. Depending on how your Visa Acceptance account is configured, this value could either be provided in the API request or generated by Visa Acceptance. The actual value used in the request to the processor is provided back to you by Visa Acceptance in the response.

Returns:



63
64
65
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_refund_post201_response.rb', line 63

def refund_amount_details
  @refund_amount_details
end

#status ⇒ String

The status of the submitted transaction. Possible values:

  • PENDING

Returns:

  • (String)


36
37
38
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_refund_post201_response.rb', line 36

def status
  @status
end

#submit_time_utc ⇒ String

Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The T separates the date and the time. The Z indicates UTC. Returned by Visa Acceptance for all services.

Returns:

  • (String)


30
31
32
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_refund_post201_response.rb', line 30

def submit_time_utc
  @submit_time_utc
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_refund_post201_response.rb', line 169

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  links = Links5.from_hash(hash['_links']) if hash['_links']
  id = hash.key?('id') ? hash['id'] : SKIP
  submit_time_utc =
    hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP
  status = hash.key?('status') ? hash['status'] : SKIP
  reconciliation_id =
    hash.key?('reconciliationId') ? hash['reconciliationId'] : SKIP
  if hash['clientReferenceInformation']
    client_reference_information = ClientReferenceInformation11.from_hash(hash['clientReferenceInformation'])
  end
  refund_amount_details = RefundAmountDetails.from_hash(hash['refundAmountDetails']) if
    hash['refundAmountDetails']
  processing_information = ProcessingInformation6.from_hash(hash['processingInformation']) if
    hash['processingInformation']
  processor_information = ProcessorInformation7.from_hash(hash['processorInformation']) if
    hash['processorInformation']
  order_information = OrderInformation9.from_hash(hash['orderInformation']) if
    hash['orderInformation']
  if hash['pointOfSaleInformation']
    point_of_sale_information = PointOfSaleInformation7.from_hash(hash['pointOfSaleInformation'])
  end

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PtsV2PaymentsRefundPost201Response.new(links: links,
                                         id: id,
                                         submit_time_utc: submit_time_utc,
                                         status: status,
                                         reconciliation_id: reconciliation_id,
                                         client_reference_information: client_reference_information,
                                         refund_amount_details: refund_amount_details,
                                         processing_information: processing_information,
                                         processor_information: processor_information,
                                         order_information: order_information,
                                         point_of_sale_information: point_of_sale_information,
                                         additional_properties: additional_properties)
end

.names ⇒ Object

A mapping from model property names to API property names.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_refund_post201_response.rb', line 102

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['links'] = '_links'
  @_hash['id'] = 'id'
  @_hash['submit_time_utc'] = 'submitTimeUtc'
  @_hash['status'] = 'status'
  @_hash['reconciliation_id'] = 'reconciliationId'
  @_hash['client_reference_information'] = 'clientReferenceInformation'
  @_hash['refund_amount_details'] = 'refundAmountDetails'
  @_hash['processing_information'] = 'processingInformation'
  @_hash['processor_information'] = 'processorInformation'
  @_hash['order_information'] = 'orderInformation'
  @_hash['point_of_sale_information'] = 'pointOfSaleInformation'
  @_hash
end

.nullables ⇒ Object

An array for nullable fields



136
137
138
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_refund_post201_response.rb', line 136

def self.nullables
  []
end

.optionals ⇒ Object

An array for optional fields



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_refund_post201_response.rb', line 119

def self.optionals
  %w[
    links
    id
    submit_time_utc
    status
    reconciliation_id
    client_reference_information
    refund_amount_details
    processing_information
    processor_information
    order_information
    point_of_sale_information
  ]
end

Instance Method Details

#inspect ⇒ Object

Provides a debugging-friendly string with detailed object information.



230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_refund_post201_response.rb', line 230

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} links: #{@links.inspect}, id: #{@id.inspect}, submit_time_utc:"\
  " #{@submit_time_utc.inspect}, status: #{@status.inspect}, reconciliation_id:"\
  " #{@reconciliation_id.inspect}, client_reference_information:"\
  " #{@client_reference_information.inspect}, refund_amount_details:"\
  " #{@refund_amount_details.inspect}, processing_information:"\
  " #{@processing_information.inspect}, processor_information:"\
  " #{@processor_information.inspect}, order_information: #{@order_information.inspect},"\
  " point_of_sale_information: #{@point_of_sale_information.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_s ⇒ Object

Provides a human-readable string representation of the object.



218
219
220
221
222
223
224
225
226
227
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_refund_post201_response.rb', line 218

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} links: #{@links}, id: #{@id}, submit_time_utc: #{@submit_time_utc}, status:"\
  " #{@status}, reconciliation_id: #{@reconciliation_id}, client_reference_information:"\
  " #{@client_reference_information}, refund_amount_details: #{@refund_amount_details},"\
  " processing_information: #{@processing_information}, processor_information:"\
  " #{@processor_information}, order_information: #{@order_information},"\
  " point_of_sale_information: #{@point_of_sale_information}, additional_properties:"\
  " #{@additional_properties}>"
end