Class: VisaAcceptanceMergedSpec::PtsV2UpdateOrderPatch400Response1Exception

Inherits:
APIException
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/exceptions/pts_v2_update_order_patch400_response1_exception.rb

Overview

ptsV2UpdateOrderPatch400Response1 class.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(reason, response) ⇒ PtsV2UpdateOrderPatch400Response1Exception

The constructor.

Parameters:

  • reason (String)

    The reason for raising an exception.

  • response (HttpResponse)

    The HttpReponse of the API call.



37
38
39
40
41
# File 'lib/visa_acceptance_merged_spec/exceptions/pts_v2_update_order_patch400_response1_exception.rb', line 37

def initialize(reason, response)
  super(reason, response)
  hash = APIHelper.json_deserialize(@response.raw_body)
  unbox(hash)
end

Instance Attribute Details

#detailsArray[Detail]

The detail message related to the status and reason listed above.

Returns:



32
33
34
# File 'lib/visa_acceptance_merged_spec/exceptions/pts_v2_update_order_patch400_response1_exception.rb', line 32

def details
  @details
end

#messageString

The detail message related to the status and reason listed above.

Returns:

  • (String)


28
29
30
# File 'lib/visa_acceptance_merged_spec/exceptions/pts_v2_update_order_patch400_response1_exception.rb', line 28

def message
  @message
end

#statusString

The status of the submitted transaction. Possible values:

  • INVALID_REQUEST

Returns:

  • (String)


24
25
26
# File 'lib/visa_acceptance_merged_spec/exceptions/pts_v2_update_order_patch400_response1_exception.rb', line 24

def status
  @status
end

#submit_time_utcString

Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The T separates the date and the time. The Z indicates UTC. Returned by Visa Acceptance for all services.

Returns:

  • (String)


18
19
20
# File 'lib/visa_acceptance_merged_spec/exceptions/pts_v2_update_order_patch400_response1_exception.rb', line 18

def submit_time_utc
  @submit_time_utc
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



73
74
75
76
77
# File 'lib/visa_acceptance_merged_spec/exceptions/pts_v2_update_order_patch400_response1_exception.rb', line 73

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} submit_time_utc: #{@submit_time_utc.inspect}, status: #{@status.inspect},"\
  " message: #{@message.inspect}, details: #{@details.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



66
67
68
69
70
# File 'lib/visa_acceptance_merged_spec/exceptions/pts_v2_update_order_patch400_response1_exception.rb', line 66

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} submit_time_utc: #{@submit_time_utc}, status: #{@status}, message:"\
  " #{@message}, details: #{@details}>"
end

#unbox(hash) ⇒ Object

Populates this object by extracting properties from a hash. response body.

Parameters:

  • hash (Hash)

    The deserialized response sent by the server in the



46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/visa_acceptance_merged_spec/exceptions/pts_v2_update_order_patch400_response1_exception.rb', line 46

def unbox(hash)
  return nil unless hash

  @submit_time_utc =
    hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP
  @status = hash.key?('status') ? hash['status'] : SKIP
  @message = hash.key?('message') ? hash['message'] : SKIP
  # Parameter is an array, so we need to iterate through it
  @details = nil
  unless hash['details'].nil?
    @details = []
    hash['details'].each do |structure|
      @details << (Detail.from_hash(structure) if structure)
    end
  end

  @details = SKIP unless hash.key?('details')
end