Class: VisaAcceptanceMergedSpec::PurchaseOptions2

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/purchase_options2.rb

Overview

PurchaseOptions2 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(is_electronic_benefits_transfer: SKIP, additional_properties: nil) ⇒ PurchaseOptions2

Returns a new instance of PurchaseOptions2.



42
43
44
45
46
47
48
49
50
51
52
# File 'lib/visa_acceptance_merged_spec/models/purchase_options2.rb', line 42

def initialize(is_electronic_benefits_transfer: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  unless is_electronic_benefits_transfer == SKIP
    @is_electronic_benefits_transfer =
      is_electronic_benefits_transfer
  end
  @additional_properties = additional_properties
end

Instance Attribute Details

#is_electronic_benefits_transferTrueClass | FalseClass

Flag that indicates whether this transaction is an EBT transaction. Possible values:

  • true
  • false

PIN debit

Required field for EBT and EBT voucher transactions that use PIN debit credit or PIN debit purchase; otherwise, not used.

Returns:

  • (TrueClass | FalseClass)


20
21
22
# File 'lib/visa_acceptance_merged_spec/models/purchase_options2.rb', line 20

def is_electronic_benefits_transfer
  @is_electronic_benefits_transfer
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/visa_acceptance_merged_spec/models/purchase_options2.rb', line 55

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  is_electronic_benefits_transfer =
    hash.key?('isElectronicBenefitsTransfer') ? hash['isElectronicBenefitsTransfer'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PurchaseOptions2.new(is_electronic_benefits_transfer: is_electronic_benefits_transfer,
                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/visa_acceptance_merged_spec/models/purchase_options2.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['is_electronic_benefits_transfer'] =
    'isElectronicBenefitsTransfer'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/visa_acceptance_merged_spec/models/purchase_options2.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
34
35
# File 'lib/visa_acceptance_merged_spec/models/purchase_options2.rb', line 31

def self.optionals
  %w[
    is_electronic_benefits_transfer
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



82
83
84
85
86
87
# File 'lib/visa_acceptance_merged_spec/models/purchase_options2.rb', line 82

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} is_electronic_benefits_transfer:"\
  " #{@is_electronic_benefits_transfer.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



75
76
77
78
79
# File 'lib/visa_acceptance_merged_spec/models/purchase_options2.rb', line 75

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} is_electronic_benefits_transfer: #{@is_electronic_benefits_transfer},"\
  " additional_properties: #{@additional_properties}>"
end