Class: VisaAcceptanceMergedSpec::RecipientInformation1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/recipient_information1.rb

Overview

RecipientInformation1 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(first_name: SKIP, last_name: SKIP, additional_properties: nil) ⇒ RecipientInformation1

Returns a new instance of RecipientInformation1.



51
52
53
54
55
56
57
58
59
# File 'lib/visa_acceptance_merged_spec/models/recipient_information1.rb', line 51

def initialize(first_name: SKIP, last_name: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @first_name = first_name unless first_name == SKIP
  @last_name = last_name unless last_name == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#first_nameString

First name of recipient of the funds.

  • Required for Mastercard Payment of Winnings (POW) transactions.
  • Must not be all numeric.
  • Must contain only ASCII characters in range 32-122.
  • Must not be greater than 35 characters including spaces.
  • Required for POW on Barclays

Returns:

  • (String)


19
20
21
# File 'lib/visa_acceptance_merged_spec/models/recipient_information1.rb', line 19

def first_name
  @first_name
end

#last_nameString

Last name of recipient of the funds.

  • Required for Mastercard Payment of Winnings (POW) transactions.
  • Must not be all numeric.
  • Must contain only ASCII characters in range 32-122.
  • Must not be greater than 35 characters including spaces.
  • Required for POW on Barclays

Returns:

  • (String)


28
29
30
# File 'lib/visa_acceptance_merged_spec/models/recipient_information1.rb', line 28

def last_name
  @last_name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/visa_acceptance_merged_spec/models/recipient_information1.rb', line 62

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  first_name = hash.key?('firstName') ? hash['firstName'] : SKIP
  last_name = hash.key?('lastName') ? hash['lastName'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  RecipientInformation1.new(first_name: first_name,
                            last_name: last_name,
                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



31
32
33
34
35
36
# File 'lib/visa_acceptance_merged_spec/models/recipient_information1.rb', line 31

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['first_name'] = 'firstName'
  @_hash['last_name'] = 'lastName'
  @_hash
end

.nullablesObject

An array for nullable fields



47
48
49
# File 'lib/visa_acceptance_merged_spec/models/recipient_information1.rb', line 47

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
44
# File 'lib/visa_acceptance_merged_spec/models/recipient_information1.rb', line 39

def self.optionals
  %w[
    first_name
    last_name
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



90
91
92
93
94
# File 'lib/visa_acceptance_merged_spec/models/recipient_information1.rb', line 90

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} first_name: #{@first_name.inspect}, last_name: #{@last_name.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



83
84
85
86
87
# File 'lib/visa_acceptance_merged_spec/models/recipient_information1.rb', line 83

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} first_name: #{@first_name}, last_name: #{@last_name},"\
  " additional_properties: #{@additional_properties}>"
end