Class: VisaAcceptanceMergedSpec::RefreshPaymentStatusRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::RefreshPaymentStatusRequest
- Defined in:
- lib/visa_acceptance_merged_spec/models/refresh_payment_status_request.rb
Overview
RefreshPaymentStatusRequest Model.
Instance Attribute Summary collapse
-
#agreement_information ⇒ AgreementInformation5
TODO: Write general description for this method.
-
#client_reference_information ⇒ ClientReferenceInformation26
TODO: Write general description for this method.
-
#payment_information ⇒ PaymentInformation14
TODO: Write general description for this method.
-
#processing_information ⇒ ProcessingInformation18
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(payment_information: SKIP, client_reference_information: SKIP, agreement_information: SKIP, processing_information: SKIP, additional_properties: nil) ⇒ RefreshPaymentStatusRequest
constructor
A new instance of RefreshPaymentStatusRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(payment_information: SKIP, client_reference_information: SKIP, agreement_information: SKIP, processing_information: SKIP, additional_properties: nil) ⇒ RefreshPaymentStatusRequest
Returns a new instance of RefreshPaymentStatusRequest.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/visa_acceptance_merged_spec/models/refresh_payment_status_request.rb', line 53 def initialize(payment_information: SKIP, client_reference_information: SKIP, agreement_information: SKIP, processing_information: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @payment_information = payment_information unless payment_information == SKIP unless client_reference_information == SKIP @client_reference_information = client_reference_information end @agreement_information = agreement_information unless agreement_information == SKIP @processing_information = processing_information unless processing_information == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#agreement_information ⇒ AgreementInformation5
TODO: Write general description for this method
22 23 24 |
# File 'lib/visa_acceptance_merged_spec/models/refresh_payment_status_request.rb', line 22 def agreement_information @agreement_information end |
#client_reference_information ⇒ ClientReferenceInformation26
TODO: Write general description for this method
18 19 20 |
# File 'lib/visa_acceptance_merged_spec/models/refresh_payment_status_request.rb', line 18 def client_reference_information @client_reference_information end |
#payment_information ⇒ PaymentInformation14
TODO: Write general description for this method
14 15 16 |
# File 'lib/visa_acceptance_merged_spec/models/refresh_payment_status_request.rb', line 14 def payment_information @payment_information end |
#processing_information ⇒ ProcessingInformation18
TODO: Write general description for this method
26 27 28 |
# File 'lib/visa_acceptance_merged_spec/models/refresh_payment_status_request.rb', line 26 def processing_information @processing_information end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/visa_acceptance_merged_spec/models/refresh_payment_status_request.rb', line 71 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. payment_information = PaymentInformation14.from_hash(hash['paymentInformation']) if hash['paymentInformation'] if hash['clientReferenceInformation'] client_reference_information = ClientReferenceInformation26.from_hash(hash['clientReferenceInformation']) end agreement_information = AgreementInformation5.from_hash(hash['agreementInformation']) if hash['agreementInformation'] processing_information = ProcessingInformation18.from_hash(hash['processingInformation']) if hash['processingInformation'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. RefreshPaymentStatusRequest.new(payment_information: payment_information, client_reference_information: client_reference_information, agreement_information: agreement_information, processing_information: processing_information, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/visa_acceptance_merged_spec/models/refresh_payment_status_request.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['payment_information'] = 'paymentInformation' @_hash['client_reference_information'] = 'clientReferenceInformation' @_hash['agreement_information'] = 'agreementInformation' @_hash['processing_information'] = 'processingInformation' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/visa_acceptance_merged_spec/models/refresh_payment_status_request.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/visa_acceptance_merged_spec/models/refresh_payment_status_request.rb', line 39 def self.optionals %w[ payment_information client_reference_information agreement_information processing_information ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
110 111 112 113 114 115 116 |
# File 'lib/visa_acceptance_merged_spec/models/refresh_payment_status_request.rb', line 110 def inspect class_name = self.class.name.split('::').last "<#{class_name} payment_information: #{@payment_information.inspect},"\ " client_reference_information: #{@client_reference_information.inspect},"\ " agreement_information: #{@agreement_information.inspect}, processing_information:"\ " #{@processing_information.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
101 102 103 104 105 106 107 |
# File 'lib/visa_acceptance_merged_spec/models/refresh_payment_status_request.rb', line 101 def to_s class_name = self.class.name.split('::').last "<#{class_name} payment_information: #{@payment_information}, client_reference_information:"\ " #{@client_reference_information}, agreement_information: #{@agreement_information},"\ " processing_information: #{@processing_information}, additional_properties:"\ " #{@additional_properties}>" end |