Class: VisaAcceptanceMergedSpec::Rule

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/rule.rb

Overview

Rule Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(name: SKIP, decision: SKIP, additional_properties: nil) ⇒ Rule

Returns a new instance of Rule.



47
48
49
50
51
52
53
54
# File 'lib/visa_acceptance_merged_spec/models/rule.rb', line 47

def initialize(name: SKIP, decision: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @name = name unless name == SKIP
  @decision = decision unless decision == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#decisionString

Summarizes the result for the rule according to the setting that you chose in the Profile Editor. This field can contain one of the following values:

  • IGNORE
  • REVIEW
  • REJECT
  • ACCEPT

Returns:

  • (String)


24
25
26
# File 'lib/visa_acceptance_merged_spec/models/rule.rb', line 24

def decision
  @decision
end

#nameString

Description of the rule as it appears in the Profile Editor.

Returns:

  • (String)


14
15
16
# File 'lib/visa_acceptance_merged_spec/models/rule.rb', line 14

def name
  @name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/visa_acceptance_merged_spec/models/rule.rb', line 57

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  name = hash.key?('name') ? hash['name'] : SKIP
  decision = hash.key?('decision') ? hash['decision'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Rule.new(name: name,
           decision: decision,
           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



27
28
29
30
31
32
# File 'lib/visa_acceptance_merged_spec/models/rule.rb', line 27

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['name'] = 'name'
  @_hash['decision'] = 'decision'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/visa_acceptance_merged_spec/models/rule.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
38
39
40
# File 'lib/visa_acceptance_merged_spec/models/rule.rb', line 35

def self.optionals
  %w[
    name
    decision
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



85
86
87
88
89
# File 'lib/visa_acceptance_merged_spec/models/rule.rb', line 85

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name.inspect}, decision: #{@decision.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



78
79
80
81
82
# File 'lib/visa_acceptance_merged_spec/models/rule.rb', line 78

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name}, decision: #{@decision}, additional_properties:"\
  " #{@additional_properties}>"
end