Class: VisaAcceptanceMergedSpec::Rule1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/rule1.rb

Overview

Names of one or more rules that were processed, and the decisions made by the rules.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(name: SKIP, decision: SKIP, additional_properties: nil) ⇒ Rule1

Returns a new instance of Rule1.



48
49
50
51
52
53
54
55
# File 'lib/visa_acceptance_merged_spec/models/rule1.rb', line 48

def initialize(name: SKIP, decision: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @name = name unless name == SKIP
  @decision = decision unless decision == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#decisionString

Summarizes the result for the rule according to the setting that you chose in the Profile Editor. This field can contain one of the following values:

  • IGNORE
  • REVIEW
  • REJECT
  • ACCEPT

Returns:

  • (String)


25
26
27
# File 'lib/visa_acceptance_merged_spec/models/rule1.rb', line 25

def decision
  @decision
end

#nameString

Description of the rule as it appears in the Profile Editor.

Returns:

  • (String)


15
16
17
# File 'lib/visa_acceptance_merged_spec/models/rule1.rb', line 15

def name
  @name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/visa_acceptance_merged_spec/models/rule1.rb', line 58

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  name = hash.key?('name') ? hash['name'] : SKIP
  decision = hash.key?('decision') ? hash['decision'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Rule1.new(name: name,
            decision: decision,
            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



28
29
30
31
32
33
# File 'lib/visa_acceptance_merged_spec/models/rule1.rb', line 28

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['name'] = 'name'
  @_hash['decision'] = 'decision'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/visa_acceptance_merged_spec/models/rule1.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



36
37
38
39
40
41
# File 'lib/visa_acceptance_merged_spec/models/rule1.rb', line 36

def self.optionals
  %w[
    name
    decision
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



86
87
88
89
90
# File 'lib/visa_acceptance_merged_spec/models/rule1.rb', line 86

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name.inspect}, decision: #{@decision.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



79
80
81
82
83
# File 'lib/visa_acceptance_merged_spec/models/rule1.rb', line 79

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name}, decision: #{@decision}, additional_properties:"\
  " #{@additional_properties}>"
end