Class: VisaAcceptanceMergedSpec::Score1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::Score1
- Defined in:
- lib/visa_acceptance_merged_spec/models/score1.rb
Overview
Score1 Model.
Instance Attribute Summary collapse
-
#factor_codes ⇒ Array[String]
Array of factor codes.
-
#result ⇒ Integer
The description for this field is not available.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(factor_codes: SKIP, result: SKIP, additional_properties: nil) ⇒ Score1
constructor
A new instance of Score1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(factor_codes: SKIP, result: SKIP, additional_properties: nil) ⇒ Score1
Returns a new instance of Score1.
41 42 43 44 45 46 47 48 |
# File 'lib/visa_acceptance_merged_spec/models/score1.rb', line 41 def initialize(factor_codes: SKIP, result: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @factor_codes = factor_codes unless factor_codes == SKIP @result = result unless result == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#factor_codes ⇒ Array[String]
Array of factor codes.
14 15 16 |
# File 'lib/visa_acceptance_merged_spec/models/score1.rb', line 14 def factor_codes @factor_codes end |
#result ⇒ Integer
The description for this field is not available.
18 19 20 |
# File 'lib/visa_acceptance_merged_spec/models/score1.rb', line 18 def result @result end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/visa_acceptance_merged_spec/models/score1.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. factor_codes = hash.key?('factorCodes') ? hash['factorCodes'] : SKIP result = hash.key?('result') ? hash['result'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Score1.new(factor_codes: factor_codes, result: result, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/visa_acceptance_merged_spec/models/score1.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['factor_codes'] = 'factorCodes' @_hash['result'] = 'result' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/visa_acceptance_merged_spec/models/score1.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/visa_acceptance_merged_spec/models/score1.rb', line 29 def self.optionals %w[ factor_codes result ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
79 80 81 82 83 |
# File 'lib/visa_acceptance_merged_spec/models/score1.rb', line 79 def inspect class_name = self.class.name.split('::').last "<#{class_name} factor_codes: #{@factor_codes.inspect}, result: #{@result.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
72 73 74 75 76 |
# File 'lib/visa_acceptance_merged_spec/models/score1.rb', line 72 def to_s class_name = self.class.name.split('::').last "<#{class_name} factor_codes: #{@factor_codes}, result: #{@result}, additional_properties:"\ " #{@additional_properties}>" end |