Class: VisaAcceptanceMergedSpec::Self

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/mself.rb

Overview

Self Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(href: SKIP, method: SKIP, additional_properties: nil) ⇒ Self

Returns a new instance of Self.



43
44
45
46
47
48
49
50
# File 'lib/visa_acceptance_merged_spec/models/mself.rb', line 43

def initialize(href: SKIP, method: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @href = href unless href == SKIP
  @method = method unless method == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#hrefString

This is the endpoint of the resource that was created by the successful request.

Returns:

  • (String)


15
16
17
# File 'lib/visa_acceptance_merged_spec/models/mself.rb', line 15

def href
  @href
end

#methodString

method refers to the HTTP method that you can send to the self endpoint to retrieve details of the resource.

Returns:

  • (String)


20
21
22
# File 'lib/visa_acceptance_merged_spec/models/mself.rb', line 20

def method
  @method
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/visa_acceptance_merged_spec/models/mself.rb', line 53

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  href = hash.key?('href') ? hash['href'] : SKIP
  method = hash.key?('method') ? hash['method'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Self.new(href: href,
           method: method,
           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/visa_acceptance_merged_spec/models/mself.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['href'] = 'href'
  @_hash['method'] = 'method'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/visa_acceptance_merged_spec/models/mself.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
34
35
36
# File 'lib/visa_acceptance_merged_spec/models/mself.rb', line 31

def self.optionals
  %w[
    href
    method
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



81
82
83
84
85
# File 'lib/visa_acceptance_merged_spec/models/mself.rb', line 81

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} href: #{@href.inspect}, method: #{@method.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



74
75
76
77
78
# File 'lib/visa_acceptance_merged_spec/models/mself.rb', line 74

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} href: #{@href}, method: #{@method}, additional_properties:"\
  " #{@additional_properties}>"
end