Class: VisaAcceptanceMergedSpec::ShipTo14

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/ship_to14.rb

Overview

ShipTo14 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(first_name: SKIP, last_name: SKIP, company: SKIP, address1: SKIP, address2: SKIP, locality: SKIP, administrative_area: SKIP, postal_code: SKIP, country: SKIP, email: SKIP, phone_number: SKIP, additional_properties: nil) ⇒ ShipTo14

Returns a new instance of ShipTo14.



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/visa_acceptance_merged_spec/models/ship_to14.rb', line 111

def initialize(first_name: SKIP, last_name: SKIP, company: SKIP,
               address1: SKIP, address2: SKIP, locality: SKIP,
               administrative_area: SKIP, postal_code: SKIP, country: SKIP,
               email: SKIP, phone_number: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @first_name = first_name unless first_name == SKIP
  @last_name = last_name unless last_name == SKIP
  @company = company unless company == SKIP
  @address1 = address1 unless address1 == SKIP
  @address2 = address2 unless address2 == SKIP
  @locality = locality unless locality == SKIP
  @administrative_area = administrative_area unless administrative_area == SKIP
  @postal_code = postal_code unless postal_code == SKIP
  @country = country unless country == SKIP
  @email = email unless email == SKIP
  @phone_number = phone_number unless phone_number == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#address1String

First line of the shipping address.

Returns:

  • (String)


26
27
28
# File 'lib/visa_acceptance_merged_spec/models/ship_to14.rb', line 26

def address1
  @address1
end

#address2String

Second line of the shipping address.

Returns:

  • (String)


30
31
32
# File 'lib/visa_acceptance_merged_spec/models/ship_to14.rb', line 30

def address2
  @address2
end

#administrative_areaString

State or province of the shipping address. Use 2 character the State, Province, and Territory Codes for the United States and Canada.

Returns:

  • (String)


39
40
41
# File 'lib/visa_acceptance_merged_spec/models/ship_to14.rb', line 39

def administrative_area
  @administrative_area
end

#companyString

Company associated with the shipping address.

Returns:

  • (String)


22
23
24
# File 'lib/visa_acceptance_merged_spec/models/ship_to14.rb', line 22

def company
  @company
end

#countryString

Country of the shipping address. Use the two-character ISO Standard Country Codes.

Returns:

  • (String)


62
63
64
# File 'lib/visa_acceptance_merged_spec/models/ship_to14.rb', line 62

def country
  @country
end

#emailString

Email associated with the shipping address.

Returns:

  • (String)


66
67
68
# File 'lib/visa_acceptance_merged_spec/models/ship_to14.rb', line 66

def email
  @email
end

#first_nameString

First name of the recipient.

Returns:

  • (String)


14
15
16
# File 'lib/visa_acceptance_merged_spec/models/ship_to14.rb', line 14

def first_name
  @first_name
end

#last_nameString

Last name of the recipient.

Returns:

  • (String)


18
19
20
# File 'lib/visa_acceptance_merged_spec/models/ship_to14.rb', line 18

def last_name
  @last_name
end

#localityString

City of the shipping address.

Returns:

  • (String)


34
35
36
# File 'lib/visa_acceptance_merged_spec/models/ship_to14.rb', line 34

def locality
  @locality
end

#phone_numberString

Phone number associated with the shipping address.

Returns:

  • (String)


70
71
72
# File 'lib/visa_acceptance_merged_spec/models/ship_to14.rb', line 70

def phone_number
  @phone_number
end

#postal_codeString

Postal code for the shipping address. The postal code must consist of 5 to 9 digits. When the billing country is the U.S., the 9-digit postal code must follow this format: [5 digits][dash][4 digits] Example 12345-6789 When the billing country is Canada, the 6-digit postal code must follow this format: [alpha][numeric][alpha][space][numeric][alpha][numeric] Example A1B 2C3 American Express Direct
Before sending the postal code to the processor, all nonalphanumeric characters are removed and, if the remaining value is longer than nine characters, truncates the value starting from the right side.

Returns:

  • (String)


57
58
59
# File 'lib/visa_acceptance_merged_spec/models/ship_to14.rb', line 57

def postal_code
  @postal_code
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/visa_acceptance_merged_spec/models/ship_to14.rb', line 133

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  first_name = hash.key?('firstName') ? hash['firstName'] : SKIP
  last_name = hash.key?('lastName') ? hash['lastName'] : SKIP
  company = hash.key?('company') ? hash['company'] : SKIP
  address1 = hash.key?('address1') ? hash['address1'] : SKIP
  address2 = hash.key?('address2') ? hash['address2'] : SKIP
  locality = hash.key?('locality') ? hash['locality'] : SKIP
  administrative_area =
    hash.key?('administrativeArea') ? hash['administrativeArea'] : SKIP
  postal_code = hash.key?('postalCode') ? hash['postalCode'] : SKIP
  country = hash.key?('country') ? hash['country'] : SKIP
  email = hash.key?('email') ? hash['email'] : SKIP
  phone_number = hash.key?('phoneNumber') ? hash['phoneNumber'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ShipTo14.new(first_name: first_name,
               last_name: last_name,
               company: company,
               address1: address1,
               address2: address2,
               locality: locality,
               administrative_area: administrative_area,
               postal_code: postal_code,
               country: country,
               email: email,
               phone_number: phone_number,
               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/visa_acceptance_merged_spec/models/ship_to14.rb', line 73

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['first_name'] = 'firstName'
  @_hash['last_name'] = 'lastName'
  @_hash['company'] = 'company'
  @_hash['address1'] = 'address1'
  @_hash['address2'] = 'address2'
  @_hash['locality'] = 'locality'
  @_hash['administrative_area'] = 'administrativeArea'
  @_hash['postal_code'] = 'postalCode'
  @_hash['country'] = 'country'
  @_hash['email'] = 'email'
  @_hash['phone_number'] = 'phoneNumber'
  @_hash
end

.nullablesObject

An array for nullable fields



107
108
109
# File 'lib/visa_acceptance_merged_spec/models/ship_to14.rb', line 107

def self.nullables
  []
end

.optionalsObject

An array for optional fields



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/visa_acceptance_merged_spec/models/ship_to14.rb', line 90

def self.optionals
  %w[
    first_name
    last_name
    company
    address1
    address2
    locality
    administrative_area
    postal_code
    country
    email
    phone_number
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



183
184
185
186
187
188
189
190
191
# File 'lib/visa_acceptance_merged_spec/models/ship_to14.rb', line 183

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} first_name: #{@first_name.inspect}, last_name: #{@last_name.inspect},"\
  " company: #{@company.inspect}, address1: #{@address1.inspect}, address2:"\
  " #{@address2.inspect}, locality: #{@locality.inspect}, administrative_area:"\
  " #{@administrative_area.inspect}, postal_code: #{@postal_code.inspect}, country:"\
  " #{@country.inspect}, email: #{@email.inspect}, phone_number: #{@phone_number.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



173
174
175
176
177
178
179
180
# File 'lib/visa_acceptance_merged_spec/models/ship_to14.rb', line 173

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} first_name: #{@first_name}, last_name: #{@last_name}, company: #{@company},"\
  " address1: #{@address1}, address2: #{@address2}, locality: #{@locality},"\
  " administrative_area: #{@administrative_area}, postal_code: #{@postal_code}, country:"\
  " #{@country}, email: #{@email}, phone_number: #{@phone_number}, additional_properties:"\
  " #{@additional_properties}>"
end