Class: VisaAcceptanceMergedSpec::TmsBinLookup
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::TmsBinLookup
- Defined in:
- lib/visa_acceptance_merged_spec/models/tms_bin_lookup.rb
Overview
Bin Information of the PAN provided by BinLookUp Service. This is only retrieved when retrieveBinDetails=true is passed as a query parameter.
Instance Attribute Summary collapse
-
#issuer_information ⇒ IssuerInformation6
TODO: Write general description for this method.
-
#payment_account_information ⇒ PaymentAccountInformation1
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(payment_account_information: SKIP, issuer_information: SKIP, additional_properties: nil) ⇒ TmsBinLookup
constructor
A new instance of TmsBinLookup.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(payment_account_information: SKIP, issuer_information: SKIP, additional_properties: nil) ⇒ TmsBinLookup
Returns a new instance of TmsBinLookup.
42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/visa_acceptance_merged_spec/models/tms_bin_lookup.rb', line 42 def initialize(payment_account_information: SKIP, issuer_information: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? unless payment_account_information == SKIP @payment_account_information = payment_account_information end @issuer_information = issuer_information unless issuer_information == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#issuer_information ⇒ IssuerInformation6
TODO: Write general description for this method
19 20 21 |
# File 'lib/visa_acceptance_merged_spec/models/tms_bin_lookup.rb', line 19 def issuer_information @issuer_information end |
#payment_account_information ⇒ PaymentAccountInformation1
TODO: Write general description for this method
15 16 17 |
# File 'lib/visa_acceptance_merged_spec/models/tms_bin_lookup.rb', line 15 def payment_account_information @payment_account_information end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/visa_acceptance_merged_spec/models/tms_bin_lookup.rb', line 56 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. if hash['paymentAccountInformation'] payment_account_information = PaymentAccountInformation1.from_hash(hash['paymentAccountInformation']) end issuer_information = IssuerInformation6.from_hash(hash['issuerInformation']) if hash['issuerInformation'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TmsBinLookup.new(payment_account_information: payment_account_information, issuer_information: issuer_information, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/visa_acceptance_merged_spec/models/tms_bin_lookup.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['payment_account_information'] = 'paymentAccountInformation' @_hash['issuer_information'] = 'issuerInformation' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 |
# File 'lib/visa_acceptance_merged_spec/models/tms_bin_lookup.rb', line 38 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 35 |
# File 'lib/visa_acceptance_merged_spec/models/tms_bin_lookup.rb', line 30 def self.optionals %w[ payment_account_information issuer_information ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
88 89 90 91 92 93 |
# File 'lib/visa_acceptance_merged_spec/models/tms_bin_lookup.rb', line 88 def inspect class_name = self.class.name.split('::').last "<#{class_name} payment_account_information: #{@payment_account_information.inspect},"\ " issuer_information: #{@issuer_information.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
80 81 82 83 84 85 |
# File 'lib/visa_acceptance_merged_spec/models/tms_bin_lookup.rb', line 80 def to_s class_name = self.class.name.split('::').last "<#{class_name} payment_account_information: #{@payment_account_information},"\ " issuer_information: #{@issuer_information}, additional_properties:"\ " #{@additional_properties}>" end |