Class: VisaAcceptanceMergedSpec::Tokencreate

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/tokencreate.rb

Overview

Tokencreate Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(status: SKIP, reason: SKIP, message: SKIP, additional_properties: nil) ⇒ Tokencreate

Returns a new instance of Tokencreate.



55
56
57
58
59
60
61
62
63
64
# File 'lib/visa_acceptance_merged_spec/models/tokencreate.rb', line 55

def initialize(status: SKIP, reason: SKIP, message: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @status = status unless status == SKIP
  @reason = reason unless reason == SKIP
  @message = message unless message == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#messageString

The detail message related to the status and reason listed above.

Returns:

  • (String)


30
31
32
# File 'lib/visa_acceptance_merged_spec/models/tokencreate.rb', line 30

def message
  @message
end

#reasonString

The reason of the status. Possible values:

  • INVALID_DATA
  • SYSTEM_ERROR
  • MISSING_FIELD

Returns:

  • (String)


26
27
28
# File 'lib/visa_acceptance_merged_spec/models/tokencreate.rb', line 26

def reason
  @reason
end

#statusString

The status of the token create. Possible value is:

- SUCCESS
- SERVER_ERROR
- INVALID_REQUEST

Returns:

  • (String)


18
19
20
# File 'lib/visa_acceptance_merged_spec/models/tokencreate.rb', line 18

def status
  @status
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/visa_acceptance_merged_spec/models/tokencreate.rb', line 67

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  status = hash.key?('status') ? hash['status'] : SKIP
  reason = hash.key?('reason') ? hash['reason'] : SKIP
  message = hash.key?('message') ? hash['message'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Tokencreate.new(status: status,
                  reason: reason,
                  message: message,
                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
38
39
# File 'lib/visa_acceptance_merged_spec/models/tokencreate.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['status'] = 'status'
  @_hash['reason'] = 'reason'
  @_hash['message'] = 'message'
  @_hash
end

.nullablesObject

An array for nullable fields



51
52
53
# File 'lib/visa_acceptance_merged_spec/models/tokencreate.rb', line 51

def self.nullables
  []
end

.optionalsObject

An array for optional fields



42
43
44
45
46
47
48
# File 'lib/visa_acceptance_merged_spec/models/tokencreate.rb', line 42

def self.optionals
  %w[
    status
    reason
    message
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



97
98
99
100
101
# File 'lib/visa_acceptance_merged_spec/models/tokencreate.rb', line 97

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} status: #{@status.inspect}, reason: #{@reason.inspect}, message:"\
  " #{@message.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



90
91
92
93
94
# File 'lib/visa_acceptance_merged_spec/models/tokencreate.rb', line 90

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} status: #{@status}, reason: #{@reason}, message: #{@message},"\
  " additional_properties: #{@additional_properties}>"
end