Class: VisaAcceptanceMergedSpec::TokenizedCard5

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/tokenized_card5.rb

Overview

TokenizedCard5 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(cryptogram: SKIP, expiration_month: SKIP, expiration_year: SKIP, number: SKIP, transaction_type: SKIP, type: SKIP, additional_properties: nil) ⇒ TokenizedCard5

Returns a new instance of TokenizedCard5.



265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/visa_acceptance_merged_spec/models/tokenized_card5.rb', line 265

def initialize(cryptogram: SKIP, expiration_month: SKIP,
               expiration_year: SKIP, number: SKIP, transaction_type: SKIP,
               type: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @cryptogram = cryptogram unless cryptogram == SKIP
  @expiration_month = expiration_month unless expiration_month == SKIP
  @expiration_year = expiration_year unless expiration_year == SKIP
  @number = number unless number == SKIP
  @transaction_type = transaction_type unless transaction_type == SKIP
  @type = type unless type == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#cryptogramString

This field contains token information.

Returns:

  • (String)


14
15
16
# File 'lib/visa_acceptance_merged_spec/models/tokenized_card5.rb', line 14

def cryptogram
  @cryptogram
end

#expiration_monthString

One of two possible meanings:

  • The two-digit month in which a token expires.
  • The two-digit month in which a card expires. Format: MM Possible values: 01 through 12 NOTE The meaning of this field is dependent on the payment processor that is returning the value in an authorization reply. Please see the processor-specific details below.

Barclays and Streamline

For Maestro (UK Domestic) and Maestro (International) cards on Barclays and Streamline, this must be a valid value (01 through 12) but is not required to be a valid expiration date. In other words, an expiration date that is in the past does not cause Visa Acceptance to reject your request. However, an invalid expiration date might cause the issuer to reject your request.

Encoded Account Numbers

For encoded account numbers (card_type=039), if there is no expiration date on the card, use 12.
Important It is your responsibility to determine whether a field is required for the transaction you are requesting.

Samsung Pay and Apple Pay

Month in which the token expires. Visa Acceptance includes this field in the reply message when it decrypts the payment blob for the tokenized transaction.

Returns:

  • (String)


41
42
43
# File 'lib/visa_acceptance_merged_spec/models/tokenized_card5.rb', line 41

def expiration_month
  @expiration_month
end

#expiration_yearString

One of two possible meanings:

  • The four-digit year in which a token expires.
  • The four-digit year in which a card expires. Format: YYYY Possible values: 1900 through 3000 Data type: Non-negative integer NOTE The meaning of this field is dependent on the payment processor that is returning the value in an authorization reply. Please see the processor-specific details below.

Barclays and Streamline

For Maestro (UK Domestic) and Maestro (International) cards on Barclays and Streamline, this must be a valid value (1900 through 3000) but is not required to be a valid expiration date. In other words, an expiration date that is in the past does not cause Visa Acceptance to reject your request. However, an invalid expiration date might cause the issuer to reject your request.

Encoded Account Numbers

For encoded account numbers (card_ type=039), if there is no expiration date on the card, use 2021.

FDC Nashville Global and FDMS South

You can send in 2 digits or 4 digits. When you send in 2 digits, they must be the last 2 digits of the year.

Samsung Pay and Apple Pay

Year in which the token expires. Visa Acceptance includes this field in the reply message when it decrypts the payment blob for the tokenized transaction. Important It is your responsibility to determine whether a field is required for the transaction you are requesting.

Returns:

  • (String)


74
75
76
# File 'lib/visa_acceptance_merged_spec/models/tokenized_card5.rb', line 74

def expiration_year
  @expiration_year
end

#numberString

Customer’s payment network token value.

Returns:

  • (String)


78
79
80
# File 'lib/visa_acceptance_merged_spec/models/tokenized_card5.rb', line 78

def number
  @number
end

#transaction_typeString

Type of transaction that provided the token data. This value does not specify the token service provider; it specifies the entity that provided you with information about the token. Possible value:

  • 2: Near-field communication (NFC) transaction. The customer’s mobile device provided the token data for a contactless EMV transaction. For recurring transactions, use this value if the original transaction was a contactless EMV transaction.

Visa Platform Connect

  • 1: For Rupay and In App tokenization. Example: InApp apple pay.
  • 3: Card/Credential On File Tokenization. NOTE No Visa Acceptance through VisaNet acquirers support EMV at this time. Required field for PIN debit credit or PIN debit purchase transactions that use payment network tokens; otherwise, not used.

Rupay

  • 3: Card/Credential On File Tokenization.
  • 4: Tokenizined Transaction. Should be used for Guest Checkout transactions with token.

Returns:

  • (String)


101
102
103
# File 'lib/visa_acceptance_merged_spec/models/tokenized_card5.rb', line 101

def transaction_type
  @transaction_type
end

#typeString

Three-digit value that indicates the card type. IMPORTANT It is strongly recommended that you include the card type field in request messages even if it is optional for your processor and card type. Omitting the card type can cause the transaction to be processed with the wrong card type. Possible values:

  • 001: Visa. Use card type value 001 for Visa Electron.
  • 002: Mastercard, Eurocard, which is a European regional brand of Mastercard.
  • 003: American Express
  • 004: Discover
  • 005: Diners Club
  • 006: Carte Blanche
  • 007: JCB
  • 008: Optima
  • 009: GE Private Label
  • 010: Beneficial Private Label
  • 011: Twinpay Credit Card
  • 012: Twinpay Debit Card
  • 013: WalMart
  • 014: Enroute
  • 015: Lowe's Consumer
  • 016: Home Depot Consumer
  • 017: MBNA
  • 018: Dick's Sportswear
  • 019: Casual Corner
  • 020: Sears
  • 021: JAL
  • 023: Disney Card
  • 024: Maestro (UK Domestic)[^1]
  • 025: Sam's Club Consumer
  • 026: Sam's Club Business
  • 027: Nico's
  • 028: Paymentech Bill Me Later
  • 029: Bebe
  • 030: Restoration Hardware
  • 031: Delta Online
  • 032: Solo
  • 033: Visa Electron. Do not use this value. Use 001 for all Visa card types.
  • 034: Dankort
  • 035: Laser
  • 036: Cartes Bancaires
  • 037: Carta Si
  • 038: Pinless Debit
  • 039: Encoded account number
  • 040: UATP
  • 041: HOUSEHOLD
  • 042: Maestro (International)[^1]
  • 043: GE MONEY
  • 044: Korean Cards
  • 045: Style Cards
  • 046: JCrew
  • 047: Payeasecn eWallet
  • 048: Payeasecn Bank Transfer
  • 049: Meijer
  • 050: Hipercard
  • 051: Aura
  • 052: Redecard
  • 053: Orico card
  • 054: Elo
  • 055: Capitol One Private Label
  • 056: Carnet
  • 057: Costco Private Label
  • 058: Carnet
  • 059: ValueLink
  • 060: MADA
  • 061: RuPay
  • 062: China UnionPay
  • 063: Falabella Private Label
  • 064: Prompt Card
  • 065: Korean Domestic
  • 066: Banricompras
  • 067: MEEZA
  • 068: PayPak
  • 070: EFTPOS
  • 071: Codensa
  • 072: Olimpica
  • 073: Colsubsidio
  • 074: Tuya
  • 075: Sodexo
  • 076: Naranja
  • 077: Cabal
  • 078: DINELCO
  • 079: PANAL
  • 080: EPM
  • 081: Jaywan [^1]: For this card type, you must include the paymentInformation.card.type or paymentInformation.tokenizedCard.type field in your request for an authorization or a stand-alone credit. [^2]: For this card type on Cielo 3.0, you must include the paymentInformation.card.type or paymentInformation.tokenizedCard.type field in a request for an authorization or a stand-alone credit. This card type is not supported on Cielo 1.5. [^3]: For this card type on Getnet and Rede, you must include the paymentInformation.card.type or paymentInformation.tokenizedCard.type field in a request for an authorization or a stand-alone credit. [^4]: For this card type, you must include the paymentInformation.card.type in your request for any payer authentication services.

Used by

Authorization Required for Carte Blanche and JCB. Optional for all other card types.

Card Present reply

This field is included in the reply message when the client software that is installed on the POS terminal uses the token management service (TMS) to retrieve tokenized payment details. You must contact customer support to have your account enabled to receive these fields in the credit reply message. Returned by the Credit service. This reply field is only supported by the following processors:

  • American Express Direct
  • Credit Mutuel-CIC
  • FDC Nashville Global
  • OmniPay Direct
  • SIX

Google Pay transactions

For PAN-based Google Pay transactions, this field is returned in the API response.

GPX

This field only supports transactions from the following card types:

  • Visa
  • Mastercard
  • AMEX
  • Discover
  • Diners
  • JCB
  • Union Pay International

Returns:

  • (String)


234
235
236
# File 'lib/visa_acceptance_merged_spec/models/tokenized_card5.rb', line 234

def type
  @type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/visa_acceptance_merged_spec/models/tokenized_card5.rb', line 281

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  cryptogram = hash.key?('cryptogram') ? hash['cryptogram'] : SKIP
  expiration_month =
    hash.key?('expirationMonth') ? hash['expirationMonth'] : SKIP
  expiration_year =
    hash.key?('expirationYear') ? hash['expirationYear'] : SKIP
  number = hash.key?('number') ? hash['number'] : SKIP
  transaction_type =
    hash.key?('transactionType') ? hash['transactionType'] : SKIP
  type = hash.key?('type') ? hash['type'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TokenizedCard5.new(cryptogram: cryptogram,
                     expiration_month: expiration_month,
                     expiration_year: expiration_year,
                     number: number,
                     transaction_type: transaction_type,
                     type: type,
                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



237
238
239
240
241
242
243
244
245
246
# File 'lib/visa_acceptance_merged_spec/models/tokenized_card5.rb', line 237

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['cryptogram'] = 'cryptogram'
  @_hash['expiration_month'] = 'expirationMonth'
  @_hash['expiration_year'] = 'expirationYear'
  @_hash['number'] = 'number'
  @_hash['transaction_type'] = 'transactionType'
  @_hash['type'] = 'type'
  @_hash
end

.nullablesObject

An array for nullable fields



261
262
263
# File 'lib/visa_acceptance_merged_spec/models/tokenized_card5.rb', line 261

def self.nullables
  []
end

.optionalsObject

An array for optional fields



249
250
251
252
253
254
255
256
257
258
# File 'lib/visa_acceptance_merged_spec/models/tokenized_card5.rb', line 249

def self.optionals
  %w[
    cryptogram
    expiration_month
    expiration_year
    number
    transaction_type
    type
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



321
322
323
324
325
326
327
# File 'lib/visa_acceptance_merged_spec/models/tokenized_card5.rb', line 321

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} cryptogram: #{@cryptogram.inspect}, expiration_month:"\
  " #{@expiration_month.inspect}, expiration_year: #{@expiration_year.inspect}, number:"\
  " #{@number.inspect}, transaction_type: #{@transaction_type.inspect}, type:"\
  " #{@type.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



313
314
315
316
317
318
# File 'lib/visa_acceptance_merged_spec/models/tokenized_card5.rb', line 313

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} cryptogram: #{@cryptogram}, expiration_month: #{@expiration_month},"\
  " expiration_year: #{@expiration_year}, number: #{@number}, transaction_type:"\
  " #{@transaction_type}, type: #{@type}, additional_properties: #{@additional_properties}>"
end