Class: VisaAcceptanceMergedSpec::TokenizedPaymentMethod4

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/tokenized_payment_method4.rb

Overview

TokenizedPaymentMethod4 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id: SKIP, usage_type: SKIP, additional_properties: nil) ⇒ TokenizedPaymentMethod4

Returns a new instance of TokenizedPaymentMethod4.



43
44
45
46
47
48
49
50
# File 'lib/visa_acceptance_merged_spec/models/tokenized_payment_method4.rb', line 43

def initialize(id: SKIP, usage_type: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @id = id unless id == SKIP
  @usage_type = usage_type unless usage_type == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#idString

The PayPal-generated ID for the token.

Returns:

  • (String)


14
15
16
# File 'lib/visa_acceptance_merged_spec/models/tokenized_payment_method4.rb', line 14

def id
  @id
end

#usage_typeString

Indicates the type of vaulting relationship. Valid values:

  • “MERCHANT”: Single merchant relationship.
  • “PLATFORM”: Platform hosting multiple merchants.

Returns:

  • (String)


20
21
22
# File 'lib/visa_acceptance_merged_spec/models/tokenized_payment_method4.rb', line 20

def usage_type
  @usage_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/visa_acceptance_merged_spec/models/tokenized_payment_method4.rb', line 53

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : SKIP
  usage_type = hash.key?('usageType') ? hash['usageType'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TokenizedPaymentMethod4.new(id: id,
                              usage_type: usage_type,
                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/visa_acceptance_merged_spec/models/tokenized_payment_method4.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['usage_type'] = 'usageType'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/visa_acceptance_merged_spec/models/tokenized_payment_method4.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
34
35
36
# File 'lib/visa_acceptance_merged_spec/models/tokenized_payment_method4.rb', line 31

def self.optionals
  %w[
    id
    usage_type
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



81
82
83
84
85
# File 'lib/visa_acceptance_merged_spec/models/tokenized_payment_method4.rb', line 81

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, usage_type: #{@usage_type.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



74
75
76
77
78
# File 'lib/visa_acceptance_merged_spec/models/tokenized_payment_method4.rb', line 74

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, usage_type: #{@usage_type}, additional_properties:"\
  " #{@additional_properties}>"
end