Class: VisaAcceptanceMergedSpec::UnscheduledPaymentInformation
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::UnscheduledPaymentInformation
- Defined in:
- lib/visa_acceptance_merged_spec/models/unscheduled_payment_information.rb
Overview
UnscheduledPaymentInformation Model.
Instance Attribute Summary collapse
-
#type ⇒ String
Indicates the type of unscheduled payment.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(type: SKIP, additional_properties: nil) ⇒ UnscheduledPaymentInformation
constructor
A new instance of UnscheduledPaymentInformation.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(type: SKIP, additional_properties: nil) ⇒ UnscheduledPaymentInformation
Returns a new instance of UnscheduledPaymentInformation.
38 39 40 41 42 43 44 |
# File 'lib/visa_acceptance_merged_spec/models/unscheduled_payment_information.rb', line 38 def initialize(type: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @type = type unless type == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#type ⇒ String
Indicates the type of unscheduled payment. This field is required for unscheduled payments CIT/MIT Possible values: 1: First unscheduled transaction. 2: Subsequent unscheduled transaction.
17 18 19 |
# File 'lib/visa_acceptance_merged_spec/models/unscheduled_payment_information.rb', line 17 def type @type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/visa_acceptance_merged_spec/models/unscheduled_payment_information.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. type = hash.key?('type') ? hash['type'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UnscheduledPaymentInformation.new(type: type, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
20 21 22 23 24 |
# File 'lib/visa_acceptance_merged_spec/models/unscheduled_payment_information.rb', line 20 def self.names @_hash = {} if @_hash.nil? @_hash['type'] = 'type' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/visa_acceptance_merged_spec/models/unscheduled_payment_information.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
27 28 29 30 31 |
# File 'lib/visa_acceptance_merged_spec/models/unscheduled_payment_information.rb', line 27 def self.optionals %w[ type ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
72 73 74 75 |
# File 'lib/visa_acceptance_merged_spec/models/unscheduled_payment_information.rb', line 72 def inspect class_name = self.class.name.split('::').last "<#{class_name} type: #{@type.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
66 67 68 69 |
# File 'lib/visa_acceptance_merged_spec/models/unscheduled_payment_information.rb', line 66 def to_s class_name = self.class.name.split('::').last "<#{class_name} type: #{@type}, additional_properties: #{@additional_properties}>" end |