Class: VisaAcceptanceMergedSpec::UserAgent

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/user_agent.rb

Overview

The images to be used as background on Klarna’s payment page (the image best matching the resolution will be used). This is a pass-through field. Check Klarna’s documentation for more information about the correct format. This value can also be set in the merchant configuration.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(url: SKIP, width: SKIP, additional_properties: nil) ⇒ UserAgent

Returns a new instance of UserAgent.



44
45
46
47
48
49
50
51
# File 'lib/visa_acceptance_merged_spec/models/user_agent.rb', line 44

def initialize(url: SKIP, width: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @url = url unless url == SKIP
  @width = width unless width == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#urlString

Url for the image

Returns:

  • (String)


17
18
19
# File 'lib/visa_acceptance_merged_spec/models/user_agent.rb', line 17

def url
  @url
end

#widthInteger

Width of the image

Returns:

  • (Integer)


21
22
23
# File 'lib/visa_acceptance_merged_spec/models/user_agent.rb', line 21

def width
  @width
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/visa_acceptance_merged_spec/models/user_agent.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  url = hash.key?('url') ? hash['url'] : SKIP
  width = hash.key?('width') ? hash['width'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  UserAgent.new(url: url,
                width: width,
                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



24
25
26
27
28
29
# File 'lib/visa_acceptance_merged_spec/models/user_agent.rb', line 24

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['url'] = 'url'
  @_hash['width'] = 'width'
  @_hash
end

.nullablesObject

An array for nullable fields



40
41
42
# File 'lib/visa_acceptance_merged_spec/models/user_agent.rb', line 40

def self.nullables
  []
end

.optionalsObject

An array for optional fields



32
33
34
35
36
37
# File 'lib/visa_acceptance_merged_spec/models/user_agent.rb', line 32

def self.optionals
  %w[
    url
    width
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



82
83
84
85
86
# File 'lib/visa_acceptance_merged_spec/models/user_agent.rb', line 82

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} url: #{@url.inspect}, width: #{@width.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



75
76
77
78
79
# File 'lib/visa_acceptance_merged_spec/models/user_agent.rb', line 75

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} url: #{@url}, width: #{@width}, additional_properties:"\
  " #{@additional_properties}>"
end