Class: VisaAcceptanceMergedSpec::Validateconsumerauthentication

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/validateconsumerauthentication.rb

Overview

Validateconsumerauthentication Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(status: SKIP, reason: SKIP, message: SKIP, additional_properties: nil) ⇒ Validateconsumerauthentication

Returns a new instance of Validateconsumerauthentication.



57
58
59
60
61
62
63
64
65
66
# File 'lib/visa_acceptance_merged_spec/models/validateconsumerauthentication.rb', line 57

def initialize(status: SKIP, reason: SKIP, message: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @status = status unless status == SKIP
  @reason = reason unless reason == SKIP
  @message = message unless message == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#messageString

The message describing the reason of the status. Value is:

  • Encountered a Payer Authentication problem. Payer could not be authenticated.

Returns:

  • (String)


32
33
34
# File 'lib/visa_acceptance_merged_spec/models/validateconsumerauthentication.rb', line 32

def message
  @message
end

#reasonString

The reason of the status. Possible values are:

  • INVALID_MERCHANT_CONFIGURATION
  • CONSUMER_AUTHENTICATION_REQUIRED
  • CONSUMER_AUTHENTICATION_FAILED
  • AUTHENTICATION_FAILED

Returns:

  • (String)


26
27
28
# File 'lib/visa_acceptance_merged_spec/models/validateconsumerauthentication.rb', line 26

def reason
  @reason
end

#statusString

The status for payerAuthentication 201 enroll and validate calls. Possible values are:

  • AUTHENTICATION_SUCCESSFUL
  • PENDING_AUTHENTICATION
  • AUTHENTICATION_FAILED

Returns:

  • (String)


18
19
20
# File 'lib/visa_acceptance_merged_spec/models/validateconsumerauthentication.rb', line 18

def status
  @status
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/visa_acceptance_merged_spec/models/validateconsumerauthentication.rb', line 69

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  status = hash.key?('status') ? hash['status'] : SKIP
  reason = hash.key?('reason') ? hash['reason'] : SKIP
  message = hash.key?('message') ? hash['message'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Validateconsumerauthentication.new(status: status,
                                     reason: reason,
                                     message: message,
                                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



35
36
37
38
39
40
41
# File 'lib/visa_acceptance_merged_spec/models/validateconsumerauthentication.rb', line 35

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['status'] = 'status'
  @_hash['reason'] = 'reason'
  @_hash['message'] = 'message'
  @_hash
end

.nullablesObject

An array for nullable fields



53
54
55
# File 'lib/visa_acceptance_merged_spec/models/validateconsumerauthentication.rb', line 53

def self.nullables
  []
end

.optionalsObject

An array for optional fields



44
45
46
47
48
49
50
# File 'lib/visa_acceptance_merged_spec/models/validateconsumerauthentication.rb', line 44

def self.optionals
  %w[
    status
    reason
    message
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



99
100
101
102
103
# File 'lib/visa_acceptance_merged_spec/models/validateconsumerauthentication.rb', line 99

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} status: #{@status.inspect}, reason: #{@reason.inspect}, message:"\
  " #{@message.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



92
93
94
95
96
# File 'lib/visa_acceptance_merged_spec/models/validateconsumerauthentication.rb', line 92

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} status: #{@status}, reason: #{@reason}, message: #{@message},"\
  " additional_properties: #{@additional_properties}>"
end