Class: VisaAcceptanceMergedSpec::Velocity

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/visa_acceptance_merged_spec/models/velocity.rb

Overview

Velocity Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(morphing: SKIP, address: SKIP, additional_properties: nil) ⇒ Velocity

Returns a new instance of Velocity.



47
48
49
50
51
52
53
54
# File 'lib/visa_acceptance_merged_spec/models/velocity.rb', line 47

def initialize(morphing: SKIP, address: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @morphing = morphing unless morphing == SKIP
  @address = address unless address == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#addressArray[String]

List of information codes triggered by the order. These information codes were generated when you created the order and product velocity rules and are returned so that you can associate them with the rules. Returned by scoring service.

Returns:

  • (Array[String])


24
25
26
# File 'lib/visa_acceptance_merged_spec/models/velocity.rb', line 24

def address
  @address
end

#morphingArray[Morphing]

List of information codes triggered by the order. These information codes were generated when you created the order and product velocity rules and are returned so that you can associate them with the rules. Returned by scoring service.

Returns:



17
18
19
# File 'lib/visa_acceptance_merged_spec/models/velocity.rb', line 17

def morphing
  @morphing
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/visa_acceptance_merged_spec/models/velocity.rb', line 57

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  morphing = nil
  unless hash['morphing'].nil?
    morphing = []
    hash['morphing'].each do |structure|
      morphing << (Morphing.from_hash(structure) if structure)
    end
  end

  morphing = SKIP unless hash.key?('morphing')
  address = hash.key?('address') ? hash['address'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Velocity.new(morphing: morphing,
               address: address,
               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



27
28
29
30
31
32
# File 'lib/visa_acceptance_merged_spec/models/velocity.rb', line 27

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['morphing'] = 'morphing'
  @_hash['address'] = 'address'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/visa_acceptance_merged_spec/models/velocity.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
38
39
40
# File 'lib/visa_acceptance_merged_spec/models/velocity.rb', line 35

def self.optionals
  %w[
    morphing
    address
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



94
95
96
97
98
# File 'lib/visa_acceptance_merged_spec/models/velocity.rb', line 94

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} morphing: #{@morphing.inspect}, address: #{@address.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



87
88
89
90
91
# File 'lib/visa_acceptance_merged_spec/models/velocity.rb', line 87

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} morphing: #{@morphing}, address: #{@address}, additional_properties:"\
  " #{@additional_properties}>"
end