Class: VisaAcceptanceMergedSpec::VoidCreditRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::VoidCreditRequest
- Defined in:
- lib/visa_acceptance_merged_spec/models/void_credit_request.rb
Overview
VoidCreditRequest Model.
Instance Attribute Summary collapse
-
#agreement_information ⇒ AgreementInformation1
TODO: Write general description for this method.
-
#client_reference_information ⇒ ClientReferenceInformation4
TODO: Write general description for this method.
-
#merchant_information ⇒ MerchantInformation7
TODO: Write general description for this method.
-
#order_information ⇒ OrderInformation14
TODO: Write general description for this method.
-
#payment_information ⇒ PaymentInformation9
TODO: Write general description for this method.
-
#processing_information ⇒ ProcessingInformation13
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client_reference_information: SKIP, payment_information: SKIP, order_information: SKIP, agreement_information: SKIP, merchant_information: SKIP, processing_information: SKIP, additional_properties: nil) ⇒ VoidCreditRequest
constructor
A new instance of VoidCreditRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client_reference_information: SKIP, payment_information: SKIP, order_information: SKIP, agreement_information: SKIP, merchant_information: SKIP, processing_information: SKIP, additional_properties: nil) ⇒ VoidCreditRequest
Returns a new instance of VoidCreditRequest.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/visa_acceptance_merged_spec/models/void_credit_request.rb', line 65 def initialize(client_reference_information: SKIP, payment_information: SKIP, order_information: SKIP, agreement_information: SKIP, merchant_information: SKIP, processing_information: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? unless client_reference_information == SKIP @client_reference_information = client_reference_information end @payment_information = payment_information unless payment_information == SKIP @order_information = order_information unless order_information == SKIP @agreement_information = agreement_information unless agreement_information == SKIP @merchant_information = merchant_information unless merchant_information == SKIP @processing_information = processing_information unless processing_information == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#agreement_information ⇒ AgreementInformation1
TODO: Write general description for this method
26 27 28 |
# File 'lib/visa_acceptance_merged_spec/models/void_credit_request.rb', line 26 def agreement_information @agreement_information end |
#client_reference_information ⇒ ClientReferenceInformation4
TODO: Write general description for this method
14 15 16 |
# File 'lib/visa_acceptance_merged_spec/models/void_credit_request.rb', line 14 def client_reference_information @client_reference_information end |
#merchant_information ⇒ MerchantInformation7
TODO: Write general description for this method
30 31 32 |
# File 'lib/visa_acceptance_merged_spec/models/void_credit_request.rb', line 30 def merchant_information @merchant_information end |
#order_information ⇒ OrderInformation14
TODO: Write general description for this method
22 23 24 |
# File 'lib/visa_acceptance_merged_spec/models/void_credit_request.rb', line 22 def order_information @order_information end |
#payment_information ⇒ PaymentInformation9
TODO: Write general description for this method
18 19 20 |
# File 'lib/visa_acceptance_merged_spec/models/void_credit_request.rb', line 18 def payment_information @payment_information end |
#processing_information ⇒ ProcessingInformation13
TODO: Write general description for this method
34 35 36 |
# File 'lib/visa_acceptance_merged_spec/models/void_credit_request.rb', line 34 def processing_information @processing_information end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/visa_acceptance_merged_spec/models/void_credit_request.rb', line 85 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. if hash['clientReferenceInformation'] client_reference_information = ClientReferenceInformation4.from_hash(hash['clientReferenceInformation']) end payment_information = PaymentInformation9.from_hash(hash['paymentInformation']) if hash['paymentInformation'] order_information = OrderInformation14.from_hash(hash['orderInformation']) if hash['orderInformation'] agreement_information = AgreementInformation1.from_hash(hash['agreementInformation']) if hash['agreementInformation'] merchant_information = MerchantInformation7.from_hash(hash['merchantInformation']) if hash['merchantInformation'] processing_information = ProcessingInformation13.from_hash(hash['processingInformation']) if hash['processingInformation'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. VoidCreditRequest.new(client_reference_information: client_reference_information, payment_information: payment_information, order_information: order_information, agreement_information: agreement_information, merchant_information: merchant_information, processing_information: processing_information, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/visa_acceptance_merged_spec/models/void_credit_request.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['client_reference_information'] = 'clientReferenceInformation' @_hash['payment_information'] = 'paymentInformation' @_hash['order_information'] = 'orderInformation' @_hash['agreement_information'] = 'agreementInformation' @_hash['merchant_information'] = 'merchantInformation' @_hash['processing_information'] = 'processingInformation' @_hash end |
.nullables ⇒ Object
An array for nullable fields
61 62 63 |
# File 'lib/visa_acceptance_merged_spec/models/void_credit_request.rb', line 61 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 52 53 54 55 56 57 58 |
# File 'lib/visa_acceptance_merged_spec/models/void_credit_request.rb', line 49 def self.optionals %w[ client_reference_information payment_information order_information agreement_information merchant_information processing_information ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
131 132 133 134 135 136 137 138 |
# File 'lib/visa_acceptance_merged_spec/models/void_credit_request.rb', line 131 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_reference_information: #{@client_reference_information.inspect},"\ " payment_information: #{@payment_information.inspect}, order_information:"\ " #{@order_information.inspect}, agreement_information: #{@agreement_information.inspect},"\ " merchant_information: #{@merchant_information.inspect}, processing_information:"\ " #{@processing_information.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
121 122 123 124 125 126 127 128 |
# File 'lib/visa_acceptance_merged_spec/models/void_credit_request.rb', line 121 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_reference_information: #{@client_reference_information},"\ " payment_information: #{@payment_information}, order_information: #{@order_information},"\ " agreement_information: #{@agreement_information}, merchant_information:"\ " #{@merchant_information}, processing_information: #{@processing_information},"\ " additional_properties: #{@additional_properties}>" end |