Class: VisaAcceptanceMergedSpec::AuthorizationOptions6
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::AuthorizationOptions6
- Defined in:
- lib/visa_acceptance_merged_spec/models/authorization_options6.rb
Overview
AuthorizationOptions6 Model.
Instance Attribute Summary collapse
-
#auth_indicator ⇒ String
Flag that specifies the purpose of the authorization.
-
#auth_type ⇒ String
Authorization type.
-
#card_verification_indicator ⇒ TrueClass | FalseClass
This API field will indicate whether a card verification check is being performed during the transaction Possible values: -
true-false(default value). -
#extend_auth_indicator ⇒ String
Indicates Authorization extension transaction.
-
#initiator ⇒ Initiator26
This API field will indicate whether a card verification check is being performed during the transaction Possible values: -
true-false(default value).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(auth_type: SKIP, auth_indicator: SKIP, extend_auth_indicator: SKIP, card_verification_indicator: SKIP, initiator: SKIP, additional_properties: nil) ⇒ AuthorizationOptions6
constructor
A new instance of AuthorizationOptions6.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(auth_type: SKIP, auth_indicator: SKIP, extend_auth_indicator: SKIP, card_verification_indicator: SKIP, initiator: SKIP, additional_properties: nil) ⇒ AuthorizationOptions6
Returns a new instance of AuthorizationOptions6.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/visa_acceptance_merged_spec/models/authorization_options6.rb', line 109 def initialize(auth_type: SKIP, auth_indicator: SKIP, extend_auth_indicator: SKIP, card_verification_indicator: SKIP, initiator: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @auth_type = auth_type unless auth_type == SKIP @auth_indicator = auth_indicator unless auth_indicator == SKIP @extend_auth_indicator = extend_auth_indicator unless extend_auth_indicator == SKIP unless card_verification_indicator == SKIP @card_verification_indicator = card_verification_indicator end @initiator = initiator unless initiator == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#auth_indicator ⇒ String
Flag that specifies the purpose of the authorization. Possible values:
- 0: Preauthorization
- 1: Final authorization To set the default for this field, contact Visa Acceptance Customer Support.
Barclays and Elavon
The default for Barclays and Elavon is 1 (final authorization). To change the default for this field, contact Visa Acceptance Customer Support.
Visa Acceptance through VisaNet
When the value for this field is 0, it corresponds to the following data in the TC 33 capture file:
- Record: CP01 TCR0
- Position: 164
- Field: Additional Authorization Indicators When the value for this field is 1, it does not correspond to any data in the TC 33 capture file.
55 56 57 |
# File 'lib/visa_acceptance_merged_spec/models/authorization_options6.rb', line 55 def auth_indicator @auth_indicator end |
#auth_type ⇒ String
Authorization type. Possible values:
AUTOCAPTURE: automatic capture.STANDARDCAPTURE: standard capture.VERBAL: forced capture. Include it in the payment request for a forced capture. Include it in the capture request for a verbal payment.
Asia, Middle East, and Africa Gateway; Cielo; Comercio Latino; and
Visa Acceptance Latin American Processing
Set this field to AUTOCAPTURE and include it in a bundled request to
indicate that you are requesting an automatic capture. If your account is
configured to enable automatic captures, set this field to
STANDARDCAPTURE and include it in a standard authorization or bundled
request to indicate that you are overriding an automatic capture.
Forced Capture
Set this field to VERBAL and include it in the authorization request to
indicate that you are performing a forced capture; therefore, you receive
the authorization code outside the Visa Acceptance system.
Verbal Authorization
Set this field to VERBAL and include it in the capture request to
indicate that the request is for a verbal authorization.
for PayPal ptsV2CreateOrderPost400Response
Set this field to 'AUTHORIZE' or 'CAPTURE' depending on whether you want to invoke delayed capture or sale respectively.
35 36 37 |
# File 'lib/visa_acceptance_merged_spec/models/authorization_options6.rb', line 35 def auth_type @auth_type end |
#card_verification_indicator ⇒ TrueClass | FalseClass
This API field will indicate whether a card verification check is being performed during the transaction Possible values:
- `true`
- `false` (default value)
72 73 74 |
# File 'lib/visa_acceptance_merged_spec/models/authorization_options6.rb', line 72 def card_verification_indicator @card_verification_indicator end |
#extend_auth_indicator ⇒ String
Indicates Authorization extension transaction. Extension transaction is used to prolong the settlement period by one additional settlement cycle period. Possible values:
- true: Transaction is an Authorization Extension transaction.
- false: Transaction is not an Authorization Extension transaction.
64 65 66 |
# File 'lib/visa_acceptance_merged_spec/models/authorization_options6.rb', line 64 def extend_auth_indicator @extend_auth_indicator end |
#initiator ⇒ Initiator26
This API field will indicate whether a card verification check is being performed during the transaction Possible values:
- `true`
- `false` (default value)
80 81 82 |
# File 'lib/visa_acceptance_merged_spec/models/authorization_options6.rb', line 80 def initiator @initiator end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/visa_acceptance_merged_spec/models/authorization_options6.rb', line 128 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. auth_type = hash.key?('authType') ? hash['authType'] : SKIP auth_indicator = hash.key?('authIndicator') ? hash['authIndicator'] : SKIP extend_auth_indicator = hash.key?('extendAuthIndicator') ? hash['extendAuthIndicator'] : SKIP card_verification_indicator = hash.key?('cardVerificationIndicator') ? hash['cardVerificationIndicator'] : SKIP initiator = Initiator26.from_hash(hash['initiator']) if hash['initiator'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. AuthorizationOptions6.new(auth_type: auth_type, auth_indicator: auth_indicator, extend_auth_indicator: extend_auth_indicator, card_verification_indicator: card_verification_indicator, initiator: initiator, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
83 84 85 86 87 88 89 90 91 |
# File 'lib/visa_acceptance_merged_spec/models/authorization_options6.rb', line 83 def self.names @_hash = {} if @_hash.nil? @_hash['auth_type'] = 'authType' @_hash['auth_indicator'] = 'authIndicator' @_hash['extend_auth_indicator'] = 'extendAuthIndicator' @_hash['card_verification_indicator'] = 'cardVerificationIndicator' @_hash['initiator'] = 'initiator' @_hash end |
.nullables ⇒ Object
An array for nullable fields
105 106 107 |
# File 'lib/visa_acceptance_merged_spec/models/authorization_options6.rb', line 105 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
94 95 96 97 98 99 100 101 102 |
# File 'lib/visa_acceptance_merged_spec/models/authorization_options6.rb', line 94 def self.optionals %w[ auth_type auth_indicator extend_auth_indicator card_verification_indicator initiator ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
166 167 168 169 170 171 172 |
# File 'lib/visa_acceptance_merged_spec/models/authorization_options6.rb', line 166 def inspect class_name = self.class.name.split('::').last "<#{class_name} auth_type: #{@auth_type.inspect}, auth_indicator:"\ " #{@auth_indicator.inspect}, extend_auth_indicator: #{@extend_auth_indicator.inspect},"\ " card_verification_indicator: #{@card_verification_indicator.inspect}, initiator:"\ " #{@initiator.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
157 158 159 160 161 162 163 |
# File 'lib/visa_acceptance_merged_spec/models/authorization_options6.rb', line 157 def to_s class_name = self.class.name.split('::').last "<#{class_name} auth_type: #{@auth_type}, auth_indicator: #{@auth_indicator},"\ " extend_auth_indicator: #{@extend_auth_indicator}, card_verification_indicator:"\ " #{@card_verification_indicator}, initiator: #{@initiator}, additional_properties:"\ " #{@additional_properties}>" end |