Class: VisaAcceptanceMergedSpec::BankTransferOptions1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::BankTransferOptions1
- Defined in:
- lib/visa_acceptance_merged_spec/models/bank_transfer_options1.rb
Overview
BankTransferOptions1 Model.
Instance Attribute Summary collapse
-
#fraud_screening_level ⇒ String
Level of fraud screening.
-
#settlement_method ⇒ String
Method used for settlement.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(settlement_method: SKIP, fraud_screening_level: SKIP, additional_properties: nil) ⇒ BankTransferOptions1
constructor
A new instance of BankTransferOptions1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(settlement_method: SKIP, fraud_screening_level: SKIP, additional_properties: nil) ⇒ BankTransferOptions1
Returns a new instance of BankTransferOptions1.
52 53 54 55 56 57 58 59 60 |
# File 'lib/visa_acceptance_merged_spec/models/bank_transfer_options1.rb', line 52 def initialize(settlement_method: SKIP, fraud_screening_level: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @settlement_method = settlement_method unless settlement_method == SKIP @fraud_screening_level = fraud_screening_level unless fraud_screening_level == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#fraud_screening_level ⇒ String
Level of fraud screening. Possible values:
1: Validation — default if the field has not already been configured for your merchant ID2: Verification
29 30 31 |
# File 'lib/visa_acceptance_merged_spec/models/bank_transfer_options1.rb', line 29 def fraud_screening_level @fraud_screening_level end |
#settlement_method ⇒ String
Method used for settlement. Possible values:
A: Automated Clearing House (default for credits and for transactions using Canadian dollars)F: Facsimile draft (U.S. dollars only)B: Best possible (U.S. dollars only) (default if the field has not already been configured for your merchant ID)
21 22 23 |
# File 'lib/visa_acceptance_merged_spec/models/bank_transfer_options1.rb', line 21 def settlement_method @settlement_method end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/visa_acceptance_merged_spec/models/bank_transfer_options1.rb', line 63 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. settlement_method = hash.key?('settlementMethod') ? hash['settlementMethod'] : SKIP fraud_screening_level = hash.key?('fraudScreeningLevel') ? hash['fraudScreeningLevel'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BankTransferOptions1.new(settlement_method: settlement_method, fraud_screening_level: fraud_screening_level, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
32 33 34 35 36 37 |
# File 'lib/visa_acceptance_merged_spec/models/bank_transfer_options1.rb', line 32 def self.names @_hash = {} if @_hash.nil? @_hash['settlement_method'] = 'settlementMethod' @_hash['fraud_screening_level'] = 'fraudScreeningLevel' @_hash end |
.nullables ⇒ Object
An array for nullable fields
48 49 50 |
# File 'lib/visa_acceptance_merged_spec/models/bank_transfer_options1.rb', line 48 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
40 41 42 43 44 45 |
# File 'lib/visa_acceptance_merged_spec/models/bank_transfer_options1.rb', line 40 def self.optionals %w[ settlement_method fraud_screening_level ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
93 94 95 96 97 |
# File 'lib/visa_acceptance_merged_spec/models/bank_transfer_options1.rb', line 93 def inspect class_name = self.class.name.split('::').last "<#{class_name} settlement_method: #{@settlement_method.inspect}, fraud_screening_level:"\ " #{@fraud_screening_level.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
86 87 88 89 90 |
# File 'lib/visa_acceptance_merged_spec/models/bank_transfer_options1.rb', line 86 def to_s class_name = self.class.name.split('::').last "<#{class_name} settlement_method: #{@settlement_method}, fraud_screening_level:"\ " #{@fraud_screening_level}, additional_properties: #{@additional_properties}>" end |