Class: VisaAcceptanceMergedSpec::BillTo2
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::BillTo2
- Defined in:
- lib/visa_acceptance_merged_spec/models/bill_to2.rb
Overview
BillTo2 Model.
Instance Attribute Summary collapse
-
#address1 ⇒ String
Payment card billing street address as it appears on the credit card issuer’s records.
-
#address2 ⇒ String
Used for additional address information.
-
#administrative_area ⇒ String
State or province of the billing address.
-
#company ⇒ Company
Customer’s last name.
-
#country ⇒ String
Payment card billing country.
-
#county ⇒ String
U.S.
-
#district ⇒ String
Customer’s neighborhood, community, or region (a barrio in Brazil) within the city or municipality.
-
#email ⇒ String
Customer's email address, including the full domain name.
-
#first_name ⇒ String
Customer’s first name.
-
#last_name ⇒ String
Customer’s last name.
-
#locality ⇒ String
Payment card billing city.
-
#middle_name ⇒ String
Customer’s middle name.
-
#phone_number ⇒ String
Customer’s phone number.
-
#postal_code ⇒ String
Postal code for the billing address.
-
#title ⇒ String
Title.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(title: SKIP, first_name: SKIP, middle_name: SKIP, last_name: SKIP, company: SKIP, address1: SKIP, address2: SKIP, locality: SKIP, district: SKIP, administrative_area: SKIP, postal_code: SKIP, county: SKIP, country: SKIP, email: SKIP, phone_number: SKIP, additional_properties: nil) ⇒ BillTo2
constructor
A new instance of BillTo2.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(title: SKIP, first_name: SKIP, middle_name: SKIP, last_name: SKIP, company: SKIP, address1: SKIP, address2: SKIP, locality: SKIP, district: SKIP, administrative_area: SKIP, postal_code: SKIP, county: SKIP, country: SKIP, email: SKIP, phone_number: SKIP, additional_properties: nil) ⇒ BillTo2
Returns a new instance of BillTo2.
521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to2.rb', line 521 def initialize(title: SKIP, first_name: SKIP, middle_name: SKIP, last_name: SKIP, company: SKIP, address1: SKIP, address2: SKIP, locality: SKIP, district: SKIP, administrative_area: SKIP, postal_code: SKIP, county: SKIP, country: SKIP, email: SKIP, phone_number: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @title = title unless title == SKIP @first_name = first_name unless first_name == SKIP @middle_name = middle_name unless middle_name == SKIP @last_name = last_name unless last_name == SKIP @company = company unless company == SKIP @address1 = address1 unless address1 == SKIP @address2 = address2 unless address2 == SKIP @locality = locality unless locality == SKIP @district = district unless district == SKIP @administrative_area = administrative_area unless administrative_area == SKIP @postal_code = postal_code unless postal_code == SKIP @county = county unless county == SKIP @country = country unless country == SKIP @email = email unless email == SKIP @phone_number = phone_number unless phone_number == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#address1 ⇒ String
Payment card billing street address as it appears on the credit card issuer’s records.
SEPA
Required for Create Mandate and Import Mandate
Atos
This field must not contain colons (:).
Visa Acceptance through VisaNet
Important When you populate orderInformation.billTo.address1 and orderInformation.billTo.address2, Visa Acceptance through VisaNet concatenates the two values. If the concatenated value exceeds 40 characters, Visa Acceptance through VisaNet truncates the value at 40 characters before sending it to Visa and the issuing bank. Truncating this value affects AVS results and therefore might also affect risk decisions and chargebacks. Credit card networks cannot process transactions that contain non-ASCII characters. Visa Acceptance through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent Visa Acceptance through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, Visa Acceptance through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.
FDMS Nashville
When the street name is numeric, it must be sent in numeric format. For example, if the address is One First Street, it must be sent as 1 1st Street. Required if keyed; not used if swiped. String (20)
TSYS Acquiring Solutions
Required when processingInformation.billPaymentOptions.billPayment=true
and pointOfSaleInformation.entryMode=keyed.
All other processors:
Optional. String (60)
For Payouts
This field may be sent only for FDC Compass. Important It is your responsibility to determine whether a field is required for the transaction you are requesting.
212 213 214 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to2.rb', line 212 def address1 @address1 end |
#address2 ⇒ String
Used for additional address information. For example: Attention: Accounts Payable Optional field. For Payouts: This field may be sent only for FDC Compass.
Atos
This field must not contain colons (:).
Visa Acceptance through VisaNet
Important When you populate orderInformation.billTo.address1 and
orderInformation.billTo.address2,
Visa Acceptance through VisaNet concatenates the two values. If the
concatenated value exceeds 40 characters,
Visa Acceptance through VisaNet truncates the value at 40 characters
before sending it to Visa and the issuing bank.
Truncating this value affects AVS results and therefore might also affect
risk decisions and chargebacks.
Credit card networks cannot process transactions that contain non-ASCII
characters. Visa Acceptance through VisaNet
accepts and stores non-ASCII characters correctly and displays them
correctly in reports. However, the limitations
of the credit card networks prevent Visa Acceptance through VisaNet from
transmitting non-ASCII characters to the
credit card networks. Therefore, Visa Acceptance through VisaNet replaces
non-ASCII characters with meaningless
ASCII characters for transmission to the credit card networks.
Chase Paymentech Solutions, FDC Compass, and TSYS Acquiring Solutions
This value is used for AVS.
FDMS Nashville
orderInformation.billTo.address1 and orderInformation.billTo.address2
together cannot exceed 20 characters.
String (20)
All Other Processors
String (60)
247 248 249 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to2.rb', line 247 def address2 @address2 end |
#administrative_area ⇒ String
State or province of the billing address. Use the [State, Province, and Territory Codes for the United States and Canada]( For Payouts: This field may be sent only for FDC Compass.
Visa Acceptance through VisaNet
Credit card networks cannot process transactions that contain non-ASCII characters. Visa Acceptance through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent Visa Acceptance through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, Visa Acceptance through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks. Important It is your responsibility to determine whether a field is required for the transaction you are requesting.
Chase Paymentech Solutions
Optional field.
Credit Mutuel-CIC
Optional field.
OmniPay Direct
Optional field.
SIX
Optional field.
TSYS Acquiring Solutions
Required when processingInformation.billPaymentOptions.billPayment=true
and pointOfSaleInformation.entryMode=keyed.
Worldpay VAP
Optional field.
All other processors
Not used.
320 321 322 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to2.rb', line 320 def administrative_area @administrative_area end |
#company ⇒ Company
Customer’s last name. This name must be the same as the name on the card. Important It is your responsibility to determine whether a field is required for the transaction you are requesting.
SEPA
Required for Create Mandate and Import Mandate
BACS
Required for Import Mandate
Chase Paymentech Solutions
Optional field.
Credit Mutuel-CIC
Optional field.
Visa Acceptance Latin American Processing
Important For an authorization request, Visa Acceptance Latin American
Processing concatenates orderInformation.billTo.firstName and
orderInformation.billTo.lastName. If the concatenated value exceeds 30
characters, Visa Acceptance Latin American Processing declines the
authorization request.
Note Visa Acceptance Latin American Processing is the name of a
specific processing connection that Visa Acceptance supports. In the Visa
Acceptance API documentation, Visa Acceptance Latin American Processing
does not refer to the general topic of processing in Latin America. The
information in this field description is for the specific processing
connection called Visa Acceptance Latin American Processing. It is not for
any other Latin American processors that Visa Acceptance supports.
Visa Acceptance through VisaNet
Credit card networks cannot process transactions that contain non-ASCII characters. Visa Acceptance through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent Visa Acceptance through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, Visa Acceptance through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.
For Payouts:
This field may be sent only for FDC Compass.
OmniPay Direct
Optional field.
RBS WorldPay Atlanta
Optional field.
SIX
Optional field.
TSYS Acquiring Solutions
Required when processingInformation.billPaymentOptions.billPayment=true
and pointOfSaleInformation.entryMode=keyed.
Worldpay VAP
Optional field.
All other processors
Not used.
169 170 171 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to2.rb', line 169 def company @company end |
#country ⇒ String
Payment card billing country. Use the two-character [ISO Standard Country Codes](
SEPA/BACS
Required for Create Mandate and Import Mandate
Visa Acceptance through VisaNet
Credit card networks cannot process transactions that contain non-ASCII characters. Visa Acceptance through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent Visa Acceptance through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, Visa Acceptance through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks. Important It is your responsibility to determine whether a field is required for the transaction you are requesting.
Chase Paymentech Solutions
Optional field.
Credit Mutuel-CIC
Optional field.
OmniPay Direct
Optional field.
SIX
Optional field.
TSYS Acquiring Solutions
Required when processingInformation.billPaymentOptions.billPayment=true
and pointOfSaleInformation.entryMode=keyed.
Worldpay VAP
Optional field.
All other processors
Not used.
407 408 409 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to2.rb', line 407 def country @country end |
#county ⇒ String
U.S. county if available.
373 374 375 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to2.rb', line 373 def county @county end |
#district ⇒ String
Customer’s neighborhood, community, or region (a barrio in Brazil) within the city or municipality. This field is available only on Cielo.
287 288 289 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to2.rb', line 287 def district @district end |
#email ⇒ String
Customer's email address, including the full domain name.
Visa Acceptance through VisaNet
Credit card networks cannot process transactions that contain non-ASCII characters. Visa Acceptance through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent Visa Acceptance through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, Visa Acceptance through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks. Important It is your responsibility to determine whether a field is required for the transaction you are requesting.
Invoicing
Email address for the customer for sending the invoice. If the invoice is in SENT status and email is updated, the old email customer payment link won't work and you must resend the invoice with the new payment link.
Chase Paymentech Solutions
Optional field.
Credit Mutuel-CIC
Optional field.
OmniPay Direct
Optional field.
SIX
Optional field.
TSYS Acquiring Solutions
Required when processingInformation.billPaymentOptions.billPayment=true
and pointOfSaleInformation.entryMode=keyed.
Worldpay VAP
Optional field.
All other processors
Not used.
441 442 443 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to2.rb', line 441 def email @email end |
#first_name ⇒ String
Customer’s first name. This name must be the same as the name on the card. Important It is your responsibility to determine whether a field is required for the transaction you are requesting.
SEPA
Required for Create Mandate and Import Mandate
BACS
Required for Import Mandate
Visa Acceptance Latin American Processing
Important For an authorization request, Visa Acceptance Latin American
Processing concatenates orderInformation.billTo.firstName and
orderInformation.billTo.lastName. If the concatenated value exceeds 30
characters, Visa Acceptance Latin American Processing declines the
authorization request.
Note Visa Acceptance Latin American Processing is the name of a
specific processing connection that Visa Acceptance supports. In the Visa
Acceptance API documentation, Visa Acceptance Latin American Processing
does not refer to the general topic of processing in Latin America. The
information in this field description is for the specific processing
connection called Visa Acceptance Latin American Processing. It is not
for any other Latin American processors that Visa Acceptance supports.
Visa Acceptance through VisaNet
Credit card networks cannot process transactions that contain non-ASCII characters. Visa Acceptance through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent Visa Acceptance through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, Visa Acceptance through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.
For Payouts:
This field may be sent only for FDC Compass.
Chase Paymentech Solutions
Optional field.
Credit Mutuel-CIC
Optional field.
OmniPay Direct
Optional field.
SIX
Optional field.
TSYS Acquiring Solutions
Required when processingInformation.billPaymentOptions.billPayment=true
and pointOfSaleInformation.entryMode=keyed.
Worldpay VAP
Optional field.
All other processors
Not used.
63 64 65 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to2.rb', line 63 def first_name @first_name end |
#last_name ⇒ String
Customer’s last name. This name must be the same as the name on the card. Important It is your responsibility to determine whether a field is required for the transaction you are requesting.
SEPA
Required for Create Mandate and Import Mandate
BACS
Required for Import Mandate
Chase Paymentech Solutions
Optional field.
Credit Mutuel-CIC
Optional field.
Visa Acceptance Latin American Processing
Important For an authorization request, Visa Acceptance Latin American
Processing concatenates orderInformation.billTo.firstName and
orderInformation.billTo.lastName. If the concatenated value exceeds 30
characters, Visa Acceptance Latin American Processing declines the
authorization request.
Note Visa Acceptance Latin American Processing is the name of a
specific processing connection that Visa Acceptance supports. In the Visa
Acceptance API documentation, Visa Acceptance Latin American Processing
does not refer to the general topic of processing in Latin America. The
information in this field description is for the specific processing
connection called Visa Acceptance Latin American Processing. It is not for
any other Latin American processors that Visa Acceptance supports.
Visa Acceptance through VisaNet
Credit card networks cannot process transactions that contain non-ASCII characters. Visa Acceptance through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent Visa Acceptance through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, Visa Acceptance through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.
For Payouts:
This field may be sent only for FDC Compass.
OmniPay Direct
Optional field.
RBS WorldPay Atlanta
Optional field.
SIX
Optional field.
TSYS Acquiring Solutions
Required when processingInformation.billPaymentOptions.billPayment=true
and pointOfSaleInformation.entryMode=keyed.
Worldpay VAP
Optional field.
All other processors
Not used.
118 119 120 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to2.rb', line 118 def last_name @last_name end |
#locality ⇒ String
Payment card billing city.
SEPA
Required for Create Mandate and Import Mandate
Atos
This field must not contain colons (:).
Visa Acceptance through VisaNet
Credit card networks cannot process transactions that contain non-ASCII characters. Visa Acceptance through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent Visa Acceptance through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, Visa Acceptance through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.
For Payouts:
This field may be sent only for FDC Compass.
Chase Paymentech Solutions
Optional field.
Credit Mutuel-CIC
Optional field.
OmniPay Direct
Optional field.
SIX
Optional field.
TSYS Acquiring Solutions
Required when processingInformation.billPaymentOptions.billPayment=true
and pointOfSaleInformation.entryMode=keyed.
Worldpay VAP
Optional field.
All other processors
Not used.
281 282 283 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to2.rb', line 281 def locality @locality end |
#middle_name ⇒ String
Customer’s middle name.
67 68 69 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to2.rb', line 67 def middle_name @middle_name end |
#phone_number ⇒ String
Customer’s phone number. It is recommended that you include the country code when the order is from outside the U.S.
Chase Paymentech Solutions
Optional field.
Credit Mutuel-CIC
Optional field.
Visa Acceptance through VisaNet
Credit card networks cannot process transactions that contain non-ASCII characters. Visa Acceptance through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent Visa Acceptance through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, Visa Acceptance through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.
For Payouts:
This field may be sent only for FDC Compass.
OmniPay Direct
Optional field.
SIX
Optional field.
TSYS Acquiring Solutions
Optional field.
Worldpay VAP
Optional field.
All other processors
Not used.
472 473 474 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to2.rb', line 472 def phone_number @phone_number end |
#postal_code ⇒ String
Postal code for the billing address. The postal code must consist of 5 to
9 digits.
When the billing country is the U.S., the 9-digit postal code must follow
this format:
[5 digits][dash][4 digits]
Example 12345-6789
When the billing country is Canada, the 6-digit postal code must follow
this format:
[alpha][numeric][alpha][space][numeric][alpha][numeric]
Example A1B 2C3
Important It is your responsibility to determine whether a field is
required for the transaction you are requesting.
SEPA
Required for Create Mandate and Import Mandate
For Payouts:
This field may be sent only for FDC Compass.
American Express Direct
Before sending the postal code to the processor, Visa Acceptance removes all nonalphanumeric characters and, if the remaining value is longer than nine characters, truncates the value starting from the right side.
Atos
This field must not contain colons (:).
Visa Acceptance through VisaNet
Credit card networks cannot process transactions that contain non-ASCII characters. Visa Acceptance through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent Visa Acceptance through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, Visa Acceptance through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.
FDMS Nashville
Required if pointOfSaleInformation.entryMode=keyed and the address is in
the U.S. or Canada.
Optional if pointOfSaleInformation.entryMode=keyed and the address is
not in the U.S. or Canada.
Not used if swiped.
RBS WorldPay Atlanta:
For best card-present keyed rates, send the postal code if
pointOfSaleInformation.entryMode=keyed.
TSYS Acquiring Solutions
Required when processingInformation.billPaymentOptions.billPayment=true
and pointOfSaleInformation.entryMode=keyed.
All other processors:
Optional field.
369 370 371 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to2.rb', line 369 def postal_code @postal_code end |
#title ⇒ String
Title.
14 15 16 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to2.rb', line 14 def title @title end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to2.rb', line 549 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. title = hash.key?('title') ? hash['title'] : SKIP first_name = hash.key?('firstName') ? hash['firstName'] : SKIP middle_name = hash.key?('middleName') ? hash['middleName'] : SKIP last_name = hash.key?('lastName') ? hash['lastName'] : SKIP company = Company.from_hash(hash['company']) if hash['company'] address1 = hash.key?('address1') ? hash['address1'] : SKIP address2 = hash.key?('address2') ? hash['address2'] : SKIP locality = hash.key?('locality') ? hash['locality'] : SKIP district = hash.key?('district') ? hash['district'] : SKIP administrative_area = hash.key?('administrativeArea') ? hash['administrativeArea'] : SKIP postal_code = hash.key?('postalCode') ? hash['postalCode'] : SKIP county = hash.key?('county') ? hash['county'] : SKIP country = hash.key?('country') ? hash['country'] : SKIP email = hash.key?('email') ? hash['email'] : SKIP phone_number = hash.key?('phoneNumber') ? hash['phoneNumber'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BillTo2.new(title: title, first_name: first_name, middle_name: middle_name, last_name: last_name, company: company, address1: address1, address2: address2, locality: locality, district: district, administrative_area: administrative_area, postal_code: postal_code, county: county, country: country, email: email, phone_number: phone_number, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to2.rb', line 475 def self.names @_hash = {} if @_hash.nil? @_hash['title'] = 'title' @_hash['first_name'] = 'firstName' @_hash['middle_name'] = 'middleName' @_hash['last_name'] = 'lastName' @_hash['company'] = 'company' @_hash['address1'] = 'address1' @_hash['address2'] = 'address2' @_hash['locality'] = 'locality' @_hash['district'] = 'district' @_hash['administrative_area'] = 'administrativeArea' @_hash['postal_code'] = 'postalCode' @_hash['county'] = 'county' @_hash['country'] = 'country' @_hash['email'] = 'email' @_hash['phone_number'] = 'phoneNumber' @_hash end |
.nullables ⇒ Object
An array for nullable fields
517 518 519 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to2.rb', line 517 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to2.rb', line 496 def self.optionals %w[ title first_name middle_name last_name company address1 address2 locality district administrative_area postal_code county country email phone_number ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
608 609 610 611 612 613 614 615 616 617 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to2.rb', line 608 def inspect class_name = self.class.name.split('::').last "<#{class_name} title: #{@title.inspect}, first_name: #{@first_name.inspect}, middle_name:"\ " #{@middle_name.inspect}, last_name: #{@last_name.inspect}, company: #{@company.inspect},"\ " address1: #{@address1.inspect}, address2: #{@address2.inspect}, locality:"\ " #{@locality.inspect}, district: #{@district.inspect}, administrative_area:"\ " #{@administrative_area.inspect}, postal_code: #{@postal_code.inspect}, county:"\ " #{@county.inspect}, country: #{@country.inspect}, email: #{@email.inspect}, phone_number:"\ " #{@phone_number.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
597 598 599 600 601 602 603 604 605 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to2.rb', line 597 def to_s class_name = self.class.name.split('::').last "<#{class_name} title: #{@title}, first_name: #{@first_name}, middle_name: #{@middle_name},"\ " last_name: #{@last_name}, company: #{@company}, address1: #{@address1}, address2:"\ " #{@address2}, locality: #{@locality}, district: #{@district}, administrative_area:"\ " #{@administrative_area}, postal_code: #{@postal_code}, county: #{@county}, country:"\ " #{@country}, email: #{@email}, phone_number: #{@phone_number}, additional_properties:"\ " #{@additional_properties}>" end |