Class: VisaAcceptanceMergedSpec::BillTo9
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::BillTo9
- Defined in:
- lib/visa_acceptance_merged_spec/models/bill_to9.rb
Overview
BillTo9 Model.
Instance Attribute Summary collapse
-
#address1 ⇒ String
First line of the billing street address.
-
#address2 ⇒ String
Additional address information.
-
#administrative_area ⇒ String
State of the billing address in the U.S.
-
#country ⇒ String
Billing country.
-
#email ⇒ String
Customer’s email address, including the full domain name.
-
#first_name ⇒ String
Customer’s first name.
-
#last_name ⇒ String
Customer’s last name.
-
#locality ⇒ String
City of the billing address.
-
#postal_code ⇒ String
Postal code for the billing address.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(first_name: SKIP, last_name: SKIP, address1: SKIP, address2: SKIP, locality: SKIP, administrative_area: SKIP, postal_code: SKIP, country: SKIP, email: SKIP, additional_properties: nil) ⇒ BillTo9
constructor
A new instance of BillTo9.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(first_name: SKIP, last_name: SKIP, address1: SKIP, address2: SKIP, locality: SKIP, administrative_area: SKIP, postal_code: SKIP, country: SKIP, email: SKIP, additional_properties: nil) ⇒ BillTo9
Returns a new instance of BillTo9.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to9.rb', line 88 def initialize(first_name: SKIP, last_name: SKIP, address1: SKIP, address2: SKIP, locality: SKIP, administrative_area: SKIP, postal_code: SKIP, country: SKIP, email: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @first_name = first_name unless first_name == SKIP @last_name = last_name unless last_name == SKIP @address1 = address1 unless address1 == SKIP @address2 = address2 unless address2 == SKIP @locality = locality unless locality == SKIP @administrative_area = administrative_area unless administrative_area == SKIP @postal_code = postal_code unless postal_code == SKIP @country = country unless country == SKIP @email = email unless email == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#address1 ⇒ String
First line of the billing street address.
22 23 24 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to9.rb', line 22 def address1 @address1 end |
#address2 ⇒ String
Additional address information. Example: Attention - Accounts Payable
27 28 29 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to9.rb', line 27 def address2 @address2 end |
#administrative_area ⇒ String
State of the billing address in the U.S.
35 36 37 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to9.rb', line 35 def administrative_area @administrative_area end |
#country ⇒ String
Billing country. Use the two character ISO Standard Country Codes.
46 47 48 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to9.rb', line 46 def country @country end |
#email ⇒ String
Customer’s email address, including the full domain name.
51 52 53 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to9.rb', line 51 def email @email end |
#first_name ⇒ String
Customer’s first name.
14 15 16 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to9.rb', line 14 def first_name @first_name end |
#last_name ⇒ String
Customer’s last name.
18 19 20 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to9.rb', line 18 def last_name @last_name end |
#locality ⇒ String
City of the billing address.
31 32 33 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to9.rb', line 31 def locality @locality end |
#postal_code ⇒ String
Postal code for the billing address. The postal code must consist of 5 to 9 digits. A 9-digit postal code must follow this format: [5 digits][dash][4 digits] Example: 12345-6789"
42 43 44 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to9.rb', line 42 def postal_code @postal_code end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to9.rb', line 108 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. first_name = hash.key?('firstName') ? hash['firstName'] : SKIP last_name = hash.key?('lastName') ? hash['lastName'] : SKIP address1 = hash.key?('address1') ? hash['address1'] : SKIP address2 = hash.key?('address2') ? hash['address2'] : SKIP locality = hash.key?('locality') ? hash['locality'] : SKIP administrative_area = hash.key?('administrativeArea') ? hash['administrativeArea'] : SKIP postal_code = hash.key?('postalCode') ? hash['postalCode'] : SKIP country = hash.key?('country') ? hash['country'] : SKIP email = hash.key?('email') ? hash['email'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BillTo9.new(first_name: first_name, last_name: last_name, address1: address1, address2: address2, locality: locality, administrative_area: administrative_area, postal_code: postal_code, country: country, email: email, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to9.rb', line 54 def self.names @_hash = {} if @_hash.nil? @_hash['first_name'] = 'firstName' @_hash['last_name'] = 'lastName' @_hash['address1'] = 'address1' @_hash['address2'] = 'address2' @_hash['locality'] = 'locality' @_hash['administrative_area'] = 'administrativeArea' @_hash['postal_code'] = 'postalCode' @_hash['country'] = 'country' @_hash['email'] = 'email' @_hash end |
.nullables ⇒ Object
An array for nullable fields
84 85 86 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to9.rb', line 84 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to9.rb', line 69 def self.optionals %w[ first_name last_name address1 address2 locality administrative_area postal_code country email ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
153 154 155 156 157 158 159 160 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to9.rb', line 153 def inspect class_name = self.class.name.split('::').last "<#{class_name} first_name: #{@first_name.inspect}, last_name: #{@last_name.inspect},"\ " address1: #{@address1.inspect}, address2: #{@address2.inspect}, locality:"\ " #{@locality.inspect}, administrative_area: #{@administrative_area.inspect}, postal_code:"\ " #{@postal_code.inspect}, country: #{@country.inspect}, email: #{@email.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
144 145 146 147 148 149 150 |
# File 'lib/visa_acceptance_merged_spec/models/bill_to9.rb', line 144 def to_s class_name = self.class.name.split('::').last "<#{class_name} first_name: #{@first_name}, last_name: #{@last_name}, address1:"\ " #{@address1}, address2: #{@address2}, locality: #{@locality}, administrative_area:"\ " #{@administrative_area}, postal_code: #{@postal_code}, country: #{@country}, email:"\ " #{@email}, additional_properties: #{@additional_properties}>" end |