Class: VisaAcceptanceMergedSpec::BuyerInformation8
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::BuyerInformation8
- Defined in:
- lib/visa_acceptance_merged_spec/models/buyer_information8.rb
Overview
BuyerInformation8 Model.
Instance Attribute Summary collapse
-
#personal_identification ⇒ Array[PersonalIdentification6]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(personal_identification: SKIP, additional_properties: nil) ⇒ BuyerInformation8
constructor
A new instance of BuyerInformation8.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(personal_identification: SKIP, additional_properties: nil) ⇒ BuyerInformation8
Returns a new instance of BuyerInformation8.
35 36 37 38 39 40 41 |
# File 'lib/visa_acceptance_merged_spec/models/buyer_information8.rb', line 35 def initialize(personal_identification: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @personal_identification = personal_identification unless personal_identification == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#personal_identification ⇒ Array[PersonalIdentification6]
TODO: Write general description for this method
14 15 16 |
# File 'lib/visa_acceptance_merged_spec/models/buyer_information8.rb', line 14 def personal_identification @personal_identification end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/visa_acceptance_merged_spec/models/buyer_information8.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it personal_identification = nil unless hash['personalIdentification'].nil? personal_identification = [] hash['personalIdentification'].each do |structure| personal_identification << (PersonalIdentification6.from_hash(structure) if structure) end end personal_identification = SKIP unless hash.key?('personalIdentification') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BuyerInformation8.new(personal_identification: personal_identification, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/visa_acceptance_merged_spec/models/buyer_information8.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['personal_identification'] = 'personalIdentification' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/visa_acceptance_merged_spec/models/buyer_information8.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/visa_acceptance_merged_spec/models/buyer_information8.rb', line 24 def self.optionals %w[ personal_identification ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
79 80 81 82 83 |
# File 'lib/visa_acceptance_merged_spec/models/buyer_information8.rb', line 79 def inspect class_name = self.class.name.split('::').last "<#{class_name} personal_identification: #{@personal_identification.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
72 73 74 75 76 |
# File 'lib/visa_acceptance_merged_spec/models/buyer_information8.rb', line 72 def to_s class_name = self.class.name.split('::').last "<#{class_name} personal_identification: #{@personal_identification},"\ " additional_properties: #{@additional_properties}>" end |