Class: VisaAcceptanceMergedSpec::Card1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::Card1
- Defined in:
- lib/visa_acceptance_merged_spec/models/card1.rb
Overview
Card1 Model.
Instance Attribute Summary collapse
-
#expiration_month ⇒ String
Two-digit month in which the payment card expires.
-
#expiration_year ⇒ String
Four-digit year in which the payment card expires.
-
#hashed_number ⇒ String
Visa Platform Connect This API field will contain the SHA 256 hashed value of PAN.
-
#prefix ⇒ String
Bank Identification Number (BIN).
-
#suffix ⇒ String
Last four digits of the cardholder’s account number.
-
#type ⇒ String
Three-digit value that indicates the card type.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(suffix: SKIP, expiration_month: SKIP, expiration_year: SKIP, type: SKIP, prefix: SKIP, hashed_number: SKIP, additional_properties: nil) ⇒ Card1
constructor
A new instance of Card1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(suffix: SKIP, expiration_month: SKIP, expiration_year: SKIP, type: SKIP, prefix: SKIP, hashed_number: SKIP, additional_properties: nil) ⇒ Card1
Returns a new instance of Card1.
266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/visa_acceptance_merged_spec/models/card1.rb', line 266 def initialize(suffix: SKIP, expiration_month: SKIP, expiration_year: SKIP, type: SKIP, prefix: SKIP, hashed_number: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @suffix = suffix unless suffix == SKIP @expiration_month = expiration_month unless expiration_month == SKIP @expiration_year = expiration_year unless expiration_year == SKIP @type = type unless type == SKIP @prefix = prefix unless prefix == SKIP @hashed_number = hashed_number unless hashed_number == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#expiration_month ⇒ String
Two-digit month in which the payment card expires.
Format: MM.
Valid values: 01 through 12. Leading 0 is required.
Barclays and Streamline
For Maestro (UK Domestic) and Maestro (International) cards on Barclays
and Streamline, this must be a valid value
(01 through 12) but is not required to be a valid expiration date. In
other words, an expiration date that is
in the past does not cause Visa Acceptance to reject your request.
However, an invalid expiration date might cause
the issuer to reject your request.
Encoded Account Numbers
For encoded account numbers (type=039), if there is no expiration date
on the card, use 12.
FDMS Nashville
Required field.
All other processors
Required if pointOfSaleInformation.entryMode=keyed. However, this field
is optional if your account is configured
for relaxed requirements for address data and expiration date.
Important It is your responsibility to determine
whether a field is required for the transaction you are requesting.
Google Pay transactions
For PAN-based Google Pay transactions, this field is returned in the API response.
60 61 62 |
# File 'lib/visa_acceptance_merged_spec/models/card1.rb', line 60 def expiration_month @expiration_month end |
#expiration_year ⇒ String
Four-digit year in which the payment card expires.
Format: YYYY.
Barclays and Streamline
For Maestro (UK Domestic) and Maestro (International) cards on Barclays
and Streamline, this must be a valid value (1900 through 3000) but is
not required to be a valid expiration date. In other words, an expiration
date that is in the past does not cause Visa Acceptance to reject your
request. However, an invalid expiration date might cause the issuer to
reject your request.
Encoded Account Numbers
For encoded account numbers (**type**=039), if there is no expiration
date on the card, use 2021.
FDMS Nashville
Required field.
FDC Nashville Global and FDMS South
You can send in 2 digits or 4 digits. If you send in 2 digits, they must be the last 2 digits of the year.
All other processors
Required if pointOfSaleInformation.entryMode=keyed. However, this field
is optional if your account is configured
for relaxed requirements for address data and expiration date.
Important It is your responsibility to determine
whether a field is required for the transaction you are requesting.
Google Pay transactions
For PAN-based Google Pay transactions, this field is returned in the API response.
89 90 91 |
# File 'lib/visa_acceptance_merged_spec/models/card1.rb', line 89 def expiration_year @expiration_year end |
#hashed_number ⇒ String
Visa Platform Connect
This API field will contain the SHA 256 hashed value of PAN.
235 236 237 |
# File 'lib/visa_acceptance_merged_spec/models/card1.rb', line 235 def hashed_number @hashed_number end |
#prefix ⇒ String
Bank Identification Number (BIN). This is the initial four to six numbers on a credit card account number.
Google Pay transactions
For PAN-based Google Pay transactions, this field is returned in the API response.
230 231 232 |
# File 'lib/visa_acceptance_merged_spec/models/card1.rb', line 230 def prefix @prefix end |
#suffix ⇒ String
Last four digits of the cardholder’s account number. This field is included in the reply message when the client software that is installed on the POS terminal uses the token management service (TMS) to retrieve tokenized payment details. You must contact customer support to have your account enabled to receive these fields in the credit reply message.
Google Pay transactions
For PAN-based Google Pay transactions, this field is returned in the API response.
PIN debit
This field is returned only for tokenized transactions. You can use this value on the receipt that you give to the cardholder. Returned by PIN debit credit and PIN debit purchase. This field is supported only by the following processors:
- American Express Direct
- Credit Mutuel-CIC
- FDC Nashville Global
- OmniPay Direct
- SIX
32 33 34 |
# File 'lib/visa_acceptance_merged_spec/models/card1.rb', line 32 def suffix @suffix end |
#type ⇒ String
Three-digit value that indicates the card type. IMPORTANT It is strongly recommended that you include the card type field in request messages even if it is optional for your processor and card type. Omitting the card type can cause the transaction to be processed with the wrong card type. Possible values:
001: Visa. Use card type value001for Visa Electron.002: Mastercard, Eurocard, which is a European regional brand of Mastercard.003: American Express004: Discover005: Diners Club006: Carte Blanche007: JCB008: Optima009: GE Private Label010: Beneficial Private Label011: Twinpay Credit Card012: Twinpay Debit Card013: WalMart014: Enroute015: Lowe's Consumer016: Home Depot Consumer017: MBNA018: Dick's Sportswear019: Casual Corner020: Sears021: JAL023: Disney Card024: Maestro (UK Domestic)[^1]025: Sam's Club Consumer026: Sam's Club Business027: Nico's028: Paymentech Bill Me Later029: Bebe030: Restoration Hardware031: Delta Online032: Solo033: Visa Electron. Do not use this value. Use001for all Visa card types.034: Dankort035: Laser036: Cartes Bancaires037: Carta Si038: Pinless Debit039: Encoded account number040: UATP041: HOUSEHOLD042: Maestro (International)[^1]043: GE MONEY044: Korean Cards045: Style Cards046: JCrew047: Payeasecn eWallet048: Payeasecn Bank Transfer049: Meijer050: Hipercard051: Aura052: Redecard053: Orico card054: Elo055: Capitol One Private Label056: Carnet057: Costco Private Label058: Carnet059: ValueLink060: MADA061: RuPay062: China UnionPay063: Falabella Private Label064: Prompt Card065: Korean Domestic066: Banricompras067: MEEZA068: PayPak070: EFTPOS071: Codensa072: Olimpica073: Colsubsidio074: Tuya075: Sodexo076: Naranja077: Cabal078: DINELCO079: PANAL080: EPM081: Jaywan [^1]: For this card type, you must include thepaymentInformation.card.typeorpaymentInformation.tokenizedCard.typefield in your request for an authorization or a stand-alone credit. [^2]: For this card type on Cielo 3.0, you must include thepaymentInformation.card.typeorpaymentInformation.tokenizedCard.typefield in a request for an authorization or a stand-alone credit. This card type is not supported on Cielo 1.5. [^3]: For this card type on Getnet and Rede, you must include thepaymentInformation.card.typeorpaymentInformation.tokenizedCard.typefield in a request for an authorization or a stand-alone credit. [^4]: For this card type, you must include thepaymentInformation.card.typein your request for any payer authentication services.
Used by
Authorization Required for Carte Blanche and JCB. Optional for all other card types.
Card Present reply
This field is included in the reply message when the client software that is installed on the POS terminal uses the token management service (TMS) to retrieve tokenized payment details. You must contact customer support to have your account enabled to receive these fields in the credit reply message. Returned by the Credit service. This reply field is only supported by the following processors:
- American Express Direct
- Credit Mutuel-CIC
- FDC Nashville Global
- OmniPay Direct
- SIX
Google Pay transactions
For PAN-based Google Pay transactions, this field is returned in the API response.
GPX
This field only supports transactions from the following card types:
- Visa
- Mastercard
- AMEX
- Discover
- Diners
- JCB
- Union Pay International
222 223 224 |
# File 'lib/visa_acceptance_merged_spec/models/card1.rb', line 222 def type @type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/visa_acceptance_merged_spec/models/card1.rb', line 282 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. suffix = hash.key?('suffix') ? hash['suffix'] : SKIP expiration_month = hash.key?('expirationMonth') ? hash['expirationMonth'] : SKIP expiration_year = hash.key?('expirationYear') ? hash['expirationYear'] : SKIP type = hash.key?('type') ? hash['type'] : SKIP prefix = hash.key?('prefix') ? hash['prefix'] : SKIP hashed_number = hash.key?('hashedNumber') ? hash['hashedNumber'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Card1.new(suffix: suffix, expiration_month: expiration_month, expiration_year: expiration_year, type: type, prefix: prefix, hashed_number: hashed_number, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
238 239 240 241 242 243 244 245 246 247 |
# File 'lib/visa_acceptance_merged_spec/models/card1.rb', line 238 def self.names @_hash = {} if @_hash.nil? @_hash['suffix'] = 'suffix' @_hash['expiration_month'] = 'expirationMonth' @_hash['expiration_year'] = 'expirationYear' @_hash['type'] = 'type' @_hash['prefix'] = 'prefix' @_hash['hashed_number'] = 'hashedNumber' @_hash end |
.nullables ⇒ Object
An array for nullable fields
262 263 264 |
# File 'lib/visa_acceptance_merged_spec/models/card1.rb', line 262 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
250 251 252 253 254 255 256 257 258 259 |
# File 'lib/visa_acceptance_merged_spec/models/card1.rb', line 250 def self.optionals %w[ suffix expiration_month expiration_year type prefix hashed_number ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
321 322 323 324 325 326 327 |
# File 'lib/visa_acceptance_merged_spec/models/card1.rb', line 321 def inspect class_name = self.class.name.split('::').last "<#{class_name} suffix: #{@suffix.inspect}, expiration_month: #{@expiration_month.inspect},"\ " expiration_year: #{@expiration_year.inspect}, type: #{@type.inspect}, prefix:"\ " #{@prefix.inspect}, hashed_number: #{@hashed_number.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
313 314 315 316 317 318 |
# File 'lib/visa_acceptance_merged_spec/models/card1.rb', line 313 def to_s class_name = self.class.name.split('::').last "<#{class_name} suffix: #{@suffix}, expiration_month: #{@expiration_month},"\ " expiration_year: #{@expiration_year}, type: #{@type}, prefix: #{@prefix}, hashed_number:"\ " #{@hashed_number}, additional_properties: #{@additional_properties}>" end |