Class: VisaAcceptanceMergedSpec::Card10
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::Card10
- Defined in:
- lib/visa_acceptance_merged_spec/models/card10.rb
Overview
Card10 Model.
Instance Attribute Summary collapse
-
#expiration_month ⇒ String
Two-digit month in which the payment card expires.
-
#expiration_year ⇒ String
Four-digit year in which the payment card expires.
-
#number ⇒ String
The customer’s payment card number, also known as the Primary Account Number (PAN).
-
#security_code ⇒ String
Card Verification Number.
-
#type ⇒ String
Three-digit value that indicates the card type.
-
#use_as ⇒ String
Flag that specifies the type of account associated with the card.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(number: SKIP, expiration_month: SKIP, expiration_year: SKIP, type: SKIP, security_code: SKIP, use_as: SKIP, additional_properties: nil) ⇒ Card10
constructor
A new instance of Card10.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(number: SKIP, expiration_month: SKIP, expiration_year: SKIP, type: SKIP, security_code: SKIP, use_as: SKIP, additional_properties: nil) ⇒ Card10
Returns a new instance of Card10.
304 305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/visa_acceptance_merged_spec/models/card10.rb', line 304 def initialize(number: SKIP, expiration_month: SKIP, expiration_year: SKIP, type: SKIP, security_code: SKIP, use_as: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @number = number unless number == SKIP @expiration_month = expiration_month unless expiration_month == SKIP @expiration_year = expiration_year unless expiration_year == SKIP @type = type unless type == SKIP @security_code = security_code unless security_code == SKIP @use_as = use_as unless use_as == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#expiration_month ⇒ String
Two-digit month in which the payment card expires.
Format: MM.
Valid values: 01 through 12. Leading 0 is required.
Barclays and Streamline
For Maestro (UK Domestic) and Maestro (International) cards on Barclays
and Streamline, this must be a valid value
(01 through 12) but is not required to be a valid expiration date. In
other words, an expiration date that is
in the past does not cause Visa Acceptance to reject your request.
However, an invalid expiration date might cause
the issuer to reject your request.
Encoded Account Numbers
For encoded account numbers (type=039), if there is no expiration date
on the card, use 12.
FDMS Nashville
Required field.
All other processors
Required if pointOfSaleInformation.entryMode=keyed. However, this field
is optional if your account is configured
for relaxed requirements for address data and expiration date.
Important It is your responsibility to determine
whether a field is required for the transaction you are requesting.
Google Pay transactions
For PAN-based Google Pay transactions, this field is returned in the API response.
58 59 60 |
# File 'lib/visa_acceptance_merged_spec/models/card10.rb', line 58 def expiration_month @expiration_month end |
#expiration_year ⇒ String
Four-digit year in which the payment card expires.
Format: YYYY.
Barclays and Streamline
For Maestro (UK Domestic) and Maestro (International) cards on Barclays
and Streamline, this must be a valid value (1900 through 3000) but is
not required to be a valid expiration date. In other words, an expiration
date that is in the past does not cause Visa Acceptance to reject your
request. However, an invalid expiration date might cause the issuer to
reject your request.
Encoded Account Numbers
For encoded account numbers (**type**=039), if there is no expiration
date on the card, use 2021.
FDMS Nashville
Required field.
FDC Nashville Global and FDMS South
You can send in 2 digits or 4 digits. If you send in 2 digits, they must be the last 2 digits of the year.
All other processors
Required if pointOfSaleInformation.entryMode=keyed. However, this field
is optional if your account is configured
for relaxed requirements for address data and expiration date.
Important It is your responsibility to determine
whether a field is required for the transaction you are requesting.
Google Pay transactions
For PAN-based Google Pay transactions, this field is returned in the API response.
87 88 89 |
# File 'lib/visa_acceptance_merged_spec/models/card10.rb', line 87 def expiration_year @expiration_year end |
#number ⇒ String
The customer’s payment card number, also known as the Primary Account Number (PAN). You can also use this field for encoded account numbers.
FDMS Nashville
Required. String (19)
GPX
Required if pointOfSaleInformation.entryMode=keyed. However, this field
is optional if your account is configured
for relaxed requirements for address data and expiration date.
Important It is your responsibility to determine
whether a field is required for the transaction you are requesting.
All other processors
Required if pointOfSaleInformation.entryMode=keyed. However, this field
is optional if your account is configured
for relaxed requirements for address data and expiration date.
Important It is your responsibility to determine
whether a field is required for the transaction you are requesting.
30 31 32 |
# File 'lib/visa_acceptance_merged_spec/models/card10.rb', line 30 def number @number end |
#security_code ⇒ String
Card Verification Number.
FDMS Nashville
Required for American Express or if swiped; otherwise, optional.
Ingenico ePayments
Do not include this field when commerceIndicator=recurring.
Note Ingenico ePayments was previously called Global Collect.
TSYS Acquiring Solutions
Optional if pointOfSaleInformation.entryMode=keyed; otherwise, not used.
GPX
Optional.
All other processors:
Optional.
235 236 237 |
# File 'lib/visa_acceptance_merged_spec/models/card10.rb', line 235 def security_code @security_code end |
#type ⇒ String
Three-digit value that indicates the card type. IMPORTANT It is strongly recommended that you include the card type field in request messages even if it is optional for your processor and card type. Omitting the card type can cause the transaction to be processed with the wrong card type. Possible values:
001: Visa. Use card type value001for Visa Electron.002: Mastercard, Eurocard, which is a European regional brand of Mastercard.003: American Express004: Discover005: Diners Club006: Carte Blanche007: JCB008: Optima009: GE Private Label010: Beneficial Private Label011: Twinpay Credit Card012: Twinpay Debit Card013: WalMart014: Enroute015: Lowe's Consumer016: Home Depot Consumer017: MBNA018: Dick's Sportswear019: Casual Corner020: Sears021: JAL023: Disney Card024: Maestro (UK Domestic)[^1]025: Sam's Club Consumer026: Sam's Club Business027: Nico's028: Paymentech Bill Me Later029: Bebe030: Restoration Hardware031: Delta Online032: Solo033: Visa Electron. Do not use this value. Use001for all Visa card types.034: Dankort035: Laser036: Cartes Bancaires037: Carta Si038: Pinless Debit039: Encoded account number040: UATP041: HOUSEHOLD042: Maestro (International)[^1]043: GE MONEY044: Korean Cards045: Style Cards046: JCrew047: Payeasecn eWallet048: Payeasecn Bank Transfer049: Meijer050: Hipercard051: Aura052: Redecard053: Orico card054: Elo055: Capitol One Private Label056: Carnet057: Costco Private Label058: Carnet059: ValueLink060: MADA061: RuPay062: China UnionPay063: Falabella Private Label064: Prompt Card065: Korean Domestic066: Banricompras067: MEEZA068: PayPak070: EFTPOS071: Codensa072: Olimpica073: Colsubsidio074: Tuya075: Sodexo076: Naranja077: Cabal078: DINELCO079: PANAL080: EPM081: Jaywan [^1]: For this card type, you must include thepaymentInformation.card.typeorpaymentInformation.tokenizedCard.typefield in your request for an authorization or a stand-alone credit. [^2]: For this card type on Cielo 3.0, you must include thepaymentInformation.card.typeorpaymentInformation.tokenizedCard.typefield in a request for an authorization or a stand-alone credit. This card type is not supported on Cielo 1.5. [^3]: For this card type on Getnet and Rede, you must include thepaymentInformation.card.typeorpaymentInformation.tokenizedCard.typefield in a request for an authorization or a stand-alone credit. [^4]: For this card type, you must include thepaymentInformation.card.typein your request for any payer authentication services.
Used by
Authorization Required for Carte Blanche and JCB. Optional for all other card types.
Card Present reply
This field is included in the reply message when the client software that is installed on the POS terminal uses the token management service (TMS) to retrieve tokenized payment details. You must contact customer support to have your account enabled to receive these fields in the credit reply message. Returned by the Credit service. This reply field is only supported by the following processors:
- American Express Direct
- Credit Mutuel-CIC
- FDC Nashville Global
- OmniPay Direct
- SIX
Google Pay transactions
For PAN-based Google Pay transactions, this field is returned in the API response.
GPX
This field only supports transactions from the following card types:
- Visa
- Mastercard
- AMEX
- Discover
- Diners
- JCB
- Union Pay International
220 221 222 |
# File 'lib/visa_acceptance_merged_spec/models/card10.rb', line 220 def type @type end |
#use_as ⇒ String
Flag that specifies the type of account associated with the card. This field is available only for China UnionPay, Cielo, Comercio Latino and Visa Platform Connect. The cardholder provides this information during the payment process. This field is required for:
- Debit transactions on Cielo and Comercio Latino.
- Transactions with Brazilian-issued cards on Visa Acceptance through VisaNet. China UnionPayCard Transactions on China UnionPay: Possible values:
- C: Domestic credit card
- D: Domestic debit card
- F: International credit card
- I: International debit card When the value is D, the e-commerce indicator and CAVV fields must be included in the authorization request. When the value is C, F or I the card verification number, expiration month and expiration year fields must in included in the authorization request. Cielo and Comercio Latino Credit Card Transactions: On these processors, this field is supported only for authorizations. Possible values:
- CR: Credit card
- DB: Debit card
Visa Platform Connect Credit Card Transactions: This field is supported for all card types on Visa Platform Connect. For combo card present transactions with Mastercard on Brazilian-issued cards, possible values: - CR: Credit card
- DB: Debit Card For combo card not present transactions with Mastercard on Brazilian-issued cards, possible values:
- C: Credit card
- D: Debit card A value of CR or DB in the useAs field takes precedence over any value in the Source Account Type field.
273 274 275 |
# File 'lib/visa_acceptance_merged_spec/models/card10.rb', line 273 def use_as @use_as end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'lib/visa_acceptance_merged_spec/models/card10.rb', line 320 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. number = hash.key?('number') ? hash['number'] : SKIP expiration_month = hash.key?('expirationMonth') ? hash['expirationMonth'] : SKIP expiration_year = hash.key?('expirationYear') ? hash['expirationYear'] : SKIP type = hash.key?('type') ? hash['type'] : SKIP security_code = hash.key?('securityCode') ? hash['securityCode'] : SKIP use_as = hash.key?('useAs') ? hash['useAs'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Card10.new(number: number, expiration_month: expiration_month, expiration_year: expiration_year, type: type, security_code: security_code, use_as: use_as, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
276 277 278 279 280 281 282 283 284 285 |
# File 'lib/visa_acceptance_merged_spec/models/card10.rb', line 276 def self.names @_hash = {} if @_hash.nil? @_hash['number'] = 'number' @_hash['expiration_month'] = 'expirationMonth' @_hash['expiration_year'] = 'expirationYear' @_hash['type'] = 'type' @_hash['security_code'] = 'securityCode' @_hash['use_as'] = 'useAs' @_hash end |
.nullables ⇒ Object
An array for nullable fields
300 301 302 |
# File 'lib/visa_acceptance_merged_spec/models/card10.rb', line 300 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
288 289 290 291 292 293 294 295 296 297 |
# File 'lib/visa_acceptance_merged_spec/models/card10.rb', line 288 def self.optionals %w[ number expiration_month expiration_year type security_code use_as ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
359 360 361 362 363 364 365 |
# File 'lib/visa_acceptance_merged_spec/models/card10.rb', line 359 def inspect class_name = self.class.name.split('::').last "<#{class_name} number: #{@number.inspect}, expiration_month: #{@expiration_month.inspect},"\ " expiration_year: #{@expiration_year.inspect}, type: #{@type.inspect}, security_code:"\ " #{@security_code.inspect}, use_as: #{@use_as.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
351 352 353 354 355 356 |
# File 'lib/visa_acceptance_merged_spec/models/card10.rb', line 351 def to_s class_name = self.class.name.split('::').last "<#{class_name} number: #{@number}, expiration_month: #{@expiration_month},"\ " expiration_year: #{@expiration_year}, type: #{@type}, security_code: #{@security_code},"\ " use_as: #{@use_as}, additional_properties: #{@additional_properties}>" end |