Class: VisaAcceptanceMergedSpec::Card4
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::Card4
- Defined in:
- lib/visa_acceptance_merged_spec/models/card4.rb
Overview
Card4 Model.
Instance Attribute Summary collapse
-
#account_encoder_id ⇒ String
Identifier for the issuing bank that provided the customer’s encoded account number.
-
#expiration_month ⇒ String
Two-digit month in which the payment card expires.
-
#expiration_year ⇒ String
Four-digit year in which the payment card expires.
-
#issue_number ⇒ String
Number of times a Maestro (UK Domestic) card has been issued to the account holder.
-
#number ⇒ String
The customer’s payment card number, also known as the Primary Account Number (PAN).
-
#security_code ⇒ String
Card Verification Number.
-
#source_account_type ⇒ String
Flag that specifies the type of account associated with the card.
-
#source_account_type_details ⇒ String
Type of account that is being used when the value for the override_payment_method field is line of credit (LI) or prepaid card (PP).
-
#start_month ⇒ String
Month of the start of the Maestro (UK Domestic) card validity period.
-
#start_year ⇒ String
Year of the start of the Maestro (UK Domestic) card validity period.
-
#type ⇒ String
Three-digit value that indicates the card type.
-
#use_as ⇒ String
Flag that specifies the type of account associated with the card.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(number: SKIP, expiration_month: SKIP, expiration_year: SKIP, type: SKIP, account_encoder_id: SKIP, issue_number: SKIP, start_month: SKIP, start_year: SKIP, source_account_type: SKIP, source_account_type_details: SKIP, security_code: SKIP, use_as: SKIP, additional_properties: nil) ⇒ Card4
constructor
A new instance of Card4.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(number: SKIP, expiration_month: SKIP, expiration_year: SKIP, type: SKIP, account_encoder_id: SKIP, issue_number: SKIP, start_month: SKIP, start_year: SKIP, source_account_type: SKIP, source_account_type_details: SKIP, security_code: SKIP, use_as: SKIP, additional_properties: nil) ⇒ Card4
Returns a new instance of Card4.
393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 |
# File 'lib/visa_acceptance_merged_spec/models/card4.rb', line 393 def initialize(number: SKIP, expiration_month: SKIP, expiration_year: SKIP, type: SKIP, account_encoder_id: SKIP, issue_number: SKIP, start_month: SKIP, start_year: SKIP, source_account_type: SKIP, source_account_type_details: SKIP, security_code: SKIP, use_as: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @number = number unless number == SKIP @expiration_month = expiration_month unless expiration_month == SKIP @expiration_year = expiration_year unless expiration_year == SKIP @type = type unless type == SKIP @account_encoder_id = account_encoder_id unless account_encoder_id == SKIP @issue_number = issue_number unless issue_number == SKIP @start_month = start_month unless start_month == SKIP @start_year = start_year unless start_year == SKIP @source_account_type = source_account_type unless source_account_type == SKIP unless source_account_type_details == SKIP @source_account_type_details = source_account_type_details end @security_code = security_code unless security_code == SKIP @use_as = use_as unless use_as == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_encoder_id ⇒ String
Identifier for the issuing bank that provided the customer’s encoded account number. Contact your processor for the bank’s ID.
225 226 227 |
# File 'lib/visa_acceptance_merged_spec/models/card4.rb', line 225 def account_encoder_id @account_encoder_id end |
#expiration_month ⇒ String
Two-digit month in which the payment card expires.
Format: MM.
Valid values: 01 through 12. Leading 0 is required.
Barclays and Streamline
For Maestro (UK Domestic) and Maestro (International) cards on Barclays
and Streamline, this must be a valid value
(01 through 12) but is not required to be a valid expiration date. In
other words, an expiration date that is
in the past does not cause Visa Acceptance to reject your request.
However, an invalid expiration date might cause
the issuer to reject your request.
Encoded Account Numbers
For encoded account numbers (type=039), if there is no expiration date
on the card, use 12.
FDMS Nashville
Required field.
All other processors
Required if pointOfSaleInformation.entryMode=keyed. However, this field
is optional if your account is configured
for relaxed requirements for address data and expiration date.
Important It is your responsibility to determine
whether a field is required for the transaction you are requesting.
Google Pay transactions
For PAN-based Google Pay transactions, this field is returned in the API response.
58 59 60 |
# File 'lib/visa_acceptance_merged_spec/models/card4.rb', line 58 def expiration_month @expiration_month end |
#expiration_year ⇒ String
Four-digit year in which the payment card expires.
Format: YYYY.
Barclays and Streamline
For Maestro (UK Domestic) and Maestro (International) cards on Barclays
and Streamline, this must be a valid value (1900 through 3000) but is
not required to be a valid expiration date. In other words, an expiration
date that is in the past does not cause Visa Acceptance to reject your
request. However, an invalid expiration date might cause the issuer to
reject your request.
Encoded Account Numbers
For encoded account numbers (**type**=039), if there is no expiration
date on the card, use 2021.
FDMS Nashville
Required field.
FDC Nashville Global and FDMS South
You can send in 2 digits or 4 digits. If you send in 2 digits, they must be the last 2 digits of the year.
All other processors
Required if pointOfSaleInformation.entryMode=keyed. However, this field
is optional if your account is configured
for relaxed requirements for address data and expiration date.
Important It is your responsibility to determine
whether a field is required for the transaction you are requesting.
Google Pay transactions
For PAN-based Google Pay transactions, this field is returned in the API response.
87 88 89 |
# File 'lib/visa_acceptance_merged_spec/models/card4.rb', line 87 def expiration_year @expiration_year end |
#issue_number ⇒ String
Number of times a Maestro (UK Domestic) card has been issued to the account holder. The card might or might not have an issue number. The number can consist of one or two digits, and the first digit might be a zero. When you include this value in your request, include exactly what is printed on the card. A value of 2 is different than a value of 02. Do not include the field, even with a blank value, if the card is not a Maestro (UK Domestic) card. Note The issue number is not required for Maestro (UK Domestic) transactions.
237 238 239 |
# File 'lib/visa_acceptance_merged_spec/models/card4.rb', line 237 def issue_number @issue_number end |
#number ⇒ String
The customer’s payment card number, also known as the Primary Account Number (PAN). You can also use this field for encoded account numbers.
FDMS Nashville
Required. String (19)
GPX
Required if pointOfSaleInformation.entryMode=keyed. However, this field
is optional if your account is configured
for relaxed requirements for address data and expiration date.
Important It is your responsibility to determine
whether a field is required for the transaction you are requesting.
All other processors
Required if pointOfSaleInformation.entryMode=keyed. However, this field
is optional if your account is configured
for relaxed requirements for address data and expiration date.
Important It is your responsibility to determine
whether a field is required for the transaction you are requesting.
30 31 32 |
# File 'lib/visa_acceptance_merged_spec/models/card4.rb', line 30 def number @number end |
#security_code ⇒ String
Card Verification Number.
FDMS Nashville
Required for American Express or if swiped; otherwise, optional.
Ingenico ePayments
Do not include this field when commerceIndicator=recurring.
Note Ingenico ePayments was previously called Global Collect.
TSYS Acquiring Solutions
Optional if pointOfSaleInformation.entryMode=keyed; otherwise, not used.
GPX
Optional.
All other processors:
Optional.
312 313 314 |
# File 'lib/visa_acceptance_merged_spec/models/card4.rb', line 312 def security_code @security_code end |
#source_account_type ⇒ String
Flag that specifies the type of account associated with the card. The cardholder provides this information during the payment process. This field is required in the following cases:
- Debit transactions on Cielo and Comercio Latino.
- Transactions with Brazilian-issued cards on Visa Acceptance through
VisaNet.
- Applicable only for Visa Acceptance through VisaNet (CtV). Note Combo cards in Brazil contain credit and debit functionality in a single card. Visa systems use a credit bank identification number (BIN) for this type of card. Using the BIN to determine whether a card is debit or credit can cause transactions with these cards to be processed incorrectly. Visa Acceptance strongly recommends that you include this field for combo card transactions. Possible values include the following.
CH: Checking accountCR: Credit card accountSA: Saving accountLI: Line of credit or credit portion of combo cardPP: Prepaid card account or prepaid portion of combo cardUA: Universal account If useAs is set to credit/debit and there is a value in SourceAccountType, the value in the SourceAccountType field will take precedence. If useAs is set to CR/DB and there is a value in SourceAccountType, the value in the useAs field will take precedence.
281 282 283 |
# File 'lib/visa_acceptance_merged_spec/models/card4.rb', line 281 def source_account_type @source_account_type end |
#source_account_type_details ⇒ String
Type of account that is being used when the value for the override_payment_method field is line of credit (LI) or prepaid card (PP). Possible values for line of credit:
AGRC: Visa Agro CusteioAGRE: Visa Agro ElectronAGRI: Visa Agro InvestimentoAGRO: Visa Agro Possible values for prepaid card:VVA: Visa Vale AlimentacaoVVF: Visa Vale FlexVVR: Visa Vale Refeicao This field is supported only for combo card transactions in Brazil on Visa Acceptance through VisaNet.
297 298 299 |
# File 'lib/visa_acceptance_merged_spec/models/card4.rb', line 297 def source_account_type_details @source_account_type_details end |
#start_month ⇒ String
Month of the start of the Maestro (UK Domestic) card validity period. Do
not include the field, even with a blank value, if the card is not a
Maestro (UK Domestic) card. Format: MM. Possible values: 01 through 12.
Note The start date is not required for Maestro (UK Domestic)
transactions.
245 246 247 |
# File 'lib/visa_acceptance_merged_spec/models/card4.rb', line 245 def start_month @start_month end |
#start_year ⇒ String
Year of the start of the Maestro (UK Domestic) card validity period. Do
not include the field, even with a blank value, if the card is not a
Maestro (UK Domestic) card. Format: YYYY.
Note The start date is not required for Maestro (UK Domestic)
transactions.
253 254 255 |
# File 'lib/visa_acceptance_merged_spec/models/card4.rb', line 253 def start_year @start_year end |
#type ⇒ String
Three-digit value that indicates the card type. IMPORTANT It is strongly recommended that you include the card type field in request messages even if it is optional for your processor and card type. Omitting the card type can cause the transaction to be processed with the wrong card type. Possible values:
001: Visa. Use card type value001for Visa Electron.002: Mastercard, Eurocard, which is a European regional brand of Mastercard.003: American Express004: Discover005: Diners Club006: Carte Blanche007: JCB008: Optima009: GE Private Label010: Beneficial Private Label011: Twinpay Credit Card012: Twinpay Debit Card013: WalMart014: Enroute015: Lowe's Consumer016: Home Depot Consumer017: MBNA018: Dick's Sportswear019: Casual Corner020: Sears021: JAL023: Disney Card024: Maestro (UK Domestic)[^1]025: Sam's Club Consumer026: Sam's Club Business027: Nico's028: Paymentech Bill Me Later029: Bebe030: Restoration Hardware031: Delta Online032: Solo033: Visa Electron. Do not use this value. Use001for all Visa card types.034: Dankort035: Laser036: Cartes Bancaires037: Carta Si038: Pinless Debit039: Encoded account number040: UATP041: HOUSEHOLD042: Maestro (International)[^1]043: GE MONEY044: Korean Cards045: Style Cards046: JCrew047: Payeasecn eWallet048: Payeasecn Bank Transfer049: Meijer050: Hipercard051: Aura052: Redecard053: Orico card054: Elo055: Capitol One Private Label056: Carnet057: Costco Private Label058: Carnet059: ValueLink060: MADA061: RuPay062: China UnionPay063: Falabella Private Label064: Prompt Card065: Korean Domestic066: Banricompras067: MEEZA068: PayPak070: EFTPOS071: Codensa072: Olimpica073: Colsubsidio074: Tuya075: Sodexo076: Naranja077: Cabal078: DINELCO079: PANAL080: EPM081: Jaywan [^1]: For this card type, you must include thepaymentInformation.card.typeorpaymentInformation.tokenizedCard.typefield in your request for an authorization or a stand-alone credit. [^2]: For this card type on Cielo 3.0, you must include thepaymentInformation.card.typeorpaymentInformation.tokenizedCard.typefield in a request for an authorization or a stand-alone credit. This card type is not supported on Cielo 1.5. [^3]: For this card type on Getnet and Rede, you must include thepaymentInformation.card.typeorpaymentInformation.tokenizedCard.typefield in a request for an authorization or a stand-alone credit. [^4]: For this card type, you must include thepaymentInformation.card.typein your request for any payer authentication services.
Used by
Authorization Required for Carte Blanche and JCB. Optional for all other card types.
Card Present reply
This field is included in the reply message when the client software that is installed on the POS terminal uses the token management service (TMS) to retrieve tokenized payment details. You must contact customer support to have your account enabled to receive these fields in the credit reply message. Returned by the Credit service. This reply field is only supported by the following processors:
- American Express Direct
- Credit Mutuel-CIC
- FDC Nashville Global
- OmniPay Direct
- SIX
Google Pay transactions
For PAN-based Google Pay transactions, this field is returned in the API response.
GPX
This field only supports transactions from the following card types:
- Visa
- Mastercard
- AMEX
- Discover
- Diners
- JCB
- Union Pay International
220 221 222 |
# File 'lib/visa_acceptance_merged_spec/models/card4.rb', line 220 def type @type end |
#use_as ⇒ String
Flag that specifies the type of account associated with the card. This field is available only for China UnionPay, Cielo, Comercio Latino and Visa Platform Connect. The cardholder provides this information during the payment process. This field is required for:
- Debit transactions on Cielo and Comercio Latino.
- Transactions with Brazilian-issued cards on Visa Acceptance through VisaNet. China UnionPayCard Transactions on China UnionPay: Possible values:
- C: Domestic credit card
- D: Domestic debit card
- F: International credit card
- I: International debit card When the value is D, the e-commerce indicator and CAVV fields must be included in the authorization request. When the value is C, F or I the card verification number, expiration month and expiration year fields must in included in the authorization request. Cielo and Comercio Latino Credit Card Transactions: On these processors, this field is supported only for authorizations. Possible values:
- CR: Credit card
- DB: Debit card
Visa Platform Connect Credit Card Transactions: This field is supported for all card types on Visa Platform Connect. For combo card present transactions with Mastercard on Brazilian-issued cards, possible values: - CR: Credit card
- DB: Debit Card For combo card not present transactions with Mastercard on Brazilian-issued cards, possible values:
- C: Credit card
- D: Debit card A value of CR or DB in the useAs field takes precedence over any value in the Source Account Type field.
350 351 352 |
# File 'lib/visa_acceptance_merged_spec/models/card4.rb', line 350 def use_as @use_as end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 |
# File 'lib/visa_acceptance_merged_spec/models/card4.rb', line 421 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. number = hash.key?('number') ? hash['number'] : SKIP expiration_month = hash.key?('expirationMonth') ? hash['expirationMonth'] : SKIP expiration_year = hash.key?('expirationYear') ? hash['expirationYear'] : SKIP type = hash.key?('type') ? hash['type'] : SKIP account_encoder_id = hash.key?('accountEncoderId') ? hash['accountEncoderId'] : SKIP issue_number = hash.key?('issueNumber') ? hash['issueNumber'] : SKIP start_month = hash.key?('startMonth') ? hash['startMonth'] : SKIP start_year = hash.key?('startYear') ? hash['startYear'] : SKIP source_account_type = hash.key?('sourceAccountType') ? hash['sourceAccountType'] : SKIP source_account_type_details = hash.key?('sourceAccountTypeDetails') ? hash['sourceAccountTypeDetails'] : SKIP security_code = hash.key?('securityCode') ? hash['securityCode'] : SKIP use_as = hash.key?('useAs') ? hash['useAs'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Card4.new(number: number, expiration_month: expiration_month, expiration_year: expiration_year, type: type, account_encoder_id: account_encoder_id, issue_number: issue_number, start_month: start_month, start_year: start_year, source_account_type: source_account_type, source_account_type_details: source_account_type_details, security_code: security_code, use_as: use_as, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/visa_acceptance_merged_spec/models/card4.rb', line 353 def self.names @_hash = {} if @_hash.nil? @_hash['number'] = 'number' @_hash['expiration_month'] = 'expirationMonth' @_hash['expiration_year'] = 'expirationYear' @_hash['type'] = 'type' @_hash['account_encoder_id'] = 'accountEncoderId' @_hash['issue_number'] = 'issueNumber' @_hash['start_month'] = 'startMonth' @_hash['start_year'] = 'startYear' @_hash['source_account_type'] = 'sourceAccountType' @_hash['source_account_type_details'] = 'sourceAccountTypeDetails' @_hash['security_code'] = 'securityCode' @_hash['use_as'] = 'useAs' @_hash end |
.nullables ⇒ Object
An array for nullable fields
389 390 391 |
# File 'lib/visa_acceptance_merged_spec/models/card4.rb', line 389 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 |
# File 'lib/visa_acceptance_merged_spec/models/card4.rb', line 371 def self.optionals %w[ number expiration_month expiration_year type account_encoder_id issue_number start_month start_year source_account_type source_account_type_details security_code use_as ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
478 479 480 481 482 483 484 485 486 487 |
# File 'lib/visa_acceptance_merged_spec/models/card4.rb', line 478 def inspect class_name = self.class.name.split('::').last "<#{class_name} number: #{@number.inspect}, expiration_month: #{@expiration_month.inspect},"\ " expiration_year: #{@expiration_year.inspect}, type: #{@type.inspect}, account_encoder_id:"\ " #{@account_encoder_id.inspect}, issue_number: #{@issue_number.inspect}, start_month:"\ " #{@start_month.inspect}, start_year: #{@start_year.inspect}, source_account_type:"\ " #{@source_account_type.inspect}, source_account_type_details:"\ " #{@source_account_type_details.inspect}, security_code: #{@security_code.inspect}, use_as:"\ " #{@use_as.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
467 468 469 470 471 472 473 474 475 |
# File 'lib/visa_acceptance_merged_spec/models/card4.rb', line 467 def to_s class_name = self.class.name.split('::').last "<#{class_name} number: #{@number}, expiration_month: #{@expiration_month},"\ " expiration_year: #{@expiration_year}, type: #{@type}, account_encoder_id:"\ " #{@account_encoder_id}, issue_number: #{@issue_number}, start_month: #{@start_month},"\ " start_year: #{@start_year}, source_account_type: #{@source_account_type},"\ " source_account_type_details: #{@source_account_type_details}, security_code:"\ " #{@security_code}, use_as: #{@use_as}, additional_properties: #{@additional_properties}>" end |