Class: VisaAcceptanceMergedSpec::CardVerification
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::CardVerification
- Defined in:
- lib/visa_acceptance_merged_spec/models/card_verification.rb
Overview
CardVerification Model.
Instance Attribute Summary collapse
-
#result_code ⇒ String
CVN result code.
-
#result_code_raw ⇒ String
CVN result code sent directly from the processor.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(result_code: SKIP, result_code_raw: SKIP, additional_properties: nil) ⇒ CardVerification
constructor
A new instance of CardVerification.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(result_code: SKIP, result_code_raw: SKIP, additional_properties: nil) ⇒ CardVerification
Returns a new instance of CardVerification.
44 45 46 47 48 49 50 51 52 |
# File 'lib/visa_acceptance_merged_spec/models/card_verification.rb', line 44 def initialize(result_code: SKIP, result_code_raw: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @result_code = result_code unless result_code == SKIP @result_code_raw = result_code_raw unless result_code_raw == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#result_code ⇒ String
CVN result code.
14 15 16 |
# File 'lib/visa_acceptance_merged_spec/models/card_verification.rb', line 14 def result_code @result_code end |
#result_code_raw ⇒ String
CVN result code sent directly from the processor. Returned only when the processor returns this value. Important Do not use this field to evaluate the result of card verification. Use for debugging purposes only.
21 22 23 |
# File 'lib/visa_acceptance_merged_spec/models/card_verification.rb', line 21 def result_code_raw @result_code_raw end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/visa_acceptance_merged_spec/models/card_verification.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. result_code = hash.key?('resultCode') ? hash['resultCode'] : SKIP result_code_raw = hash.key?('resultCodeRaw') ? hash['resultCodeRaw'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CardVerification.new(result_code: result_code, result_code_raw: result_code_raw, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
24 25 26 27 28 29 |
# File 'lib/visa_acceptance_merged_spec/models/card_verification.rb', line 24 def self.names @_hash = {} if @_hash.nil? @_hash['result_code'] = 'resultCode' @_hash['result_code_raw'] = 'resultCodeRaw' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/visa_acceptance_merged_spec/models/card_verification.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
32 33 34 35 36 37 |
# File 'lib/visa_acceptance_merged_spec/models/card_verification.rb', line 32 def self.optionals %w[ result_code result_code_raw ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
84 85 86 87 88 |
# File 'lib/visa_acceptance_merged_spec/models/card_verification.rb', line 84 def inspect class_name = self.class.name.split('::').last "<#{class_name} result_code: #{@result_code.inspect}, result_code_raw:"\ " #{@result_code_raw.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
77 78 79 80 81 |
# File 'lib/visa_acceptance_merged_spec/models/card_verification.rb', line 77 def to_s class_name = self.class.name.split('::').last "<#{class_name} result_code: #{@result_code}, result_code_raw: #{@result_code_raw},"\ " additional_properties: #{@additional_properties}>" end |