Class: VisaAcceptanceMergedSpec::ConsumerAuthenticationResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::ConsumerAuthenticationResponse
- Defined in:
- lib/visa_acceptance_merged_spec/models/consumer_authentication_response.rb
Overview
ConsumerAuthenticationResponse Model.
Instance Attribute Summary collapse
-
#code ⇒ String
Mapped response code for Visa Secure and American Express SafeKey.
-
#code_raw ⇒ String
Raw response code sent directly from the processor for Visa Secure and American Express SafeKey:.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(code: SKIP, code_raw: SKIP, additional_properties: nil) ⇒ ConsumerAuthenticationResponse
constructor
A new instance of ConsumerAuthenticationResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(code: SKIP, code_raw: SKIP, additional_properties: nil) ⇒ ConsumerAuthenticationResponse
Returns a new instance of ConsumerAuthenticationResponse.
42 43 44 45 46 47 48 49 |
# File 'lib/visa_acceptance_merged_spec/models/consumer_authentication_response.rb', line 42 def initialize(code: SKIP, code_raw: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @code = code unless code == SKIP @code_raw = code_raw unless code_raw == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#code ⇒ String
Mapped response code for Visa Secure and American Express SafeKey.
14 15 16 |
# File 'lib/visa_acceptance_merged_spec/models/consumer_authentication_response.rb', line 14 def code @code end |
#code_raw ⇒ String
Raw response code sent directly from the processor for Visa Secure and American Express SafeKey:
19 20 21 |
# File 'lib/visa_acceptance_merged_spec/models/consumer_authentication_response.rb', line 19 def code_raw @code_raw end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/visa_acceptance_merged_spec/models/consumer_authentication_response.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. code = hash.key?('code') ? hash['code'] : SKIP code_raw = hash.key?('codeRaw') ? hash['codeRaw'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ConsumerAuthenticationResponse.new(code: code, code_raw: code_raw, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/visa_acceptance_merged_spec/models/consumer_authentication_response.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['code'] = 'code' @_hash['code_raw'] = 'codeRaw' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 |
# File 'lib/visa_acceptance_merged_spec/models/consumer_authentication_response.rb', line 38 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 35 |
# File 'lib/visa_acceptance_merged_spec/models/consumer_authentication_response.rb', line 30 def self.optionals %w[ code code_raw ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
80 81 82 83 84 |
# File 'lib/visa_acceptance_merged_spec/models/consumer_authentication_response.rb', line 80 def inspect class_name = self.class.name.split('::').last "<#{class_name} code: #{@code.inspect}, code_raw: #{@code_raw.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
73 74 75 76 77 |
# File 'lib/visa_acceptance_merged_spec/models/consumer_authentication_response.rb', line 73 def to_s class_name = self.class.name.split('::').last "<#{class_name} code: #{@code}, code_raw: #{@code_raw}, additional_properties:"\ " #{@additional_properties}>" end |