Class: VisaAcceptanceMergedSpec::CreateBillingAgreement
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::CreateBillingAgreement
- Defined in:
- lib/visa_acceptance_merged_spec/models/create_billing_agreement.rb
Overview
CreateBillingAgreement Model.
Instance Attribute Summary collapse
-
#aggregator_information ⇒ AggregatorInformation5
TODO: Write general description for this method.
-
#agreement_information ⇒ AgreementInformation6
TODO: Write general description for this method.
-
#buyer_information ⇒ BuyerInformation6
TODO: Write general description for this method.
-
#client_reference_information ⇒ ClientReferenceInformation28
TODO: Write general description for this method.
-
#consumer_authentication_information ⇒ ConsumerAuthenticationInformation2
TODO: Write general description for this method.
-
#device_information ⇒ DeviceInformation5
TODO: Write general description for this method.
-
#installment_information ⇒ InstallmentInformation4
TODO: Write general description for this method.
-
#merchant_information ⇒ MerchantInformation11
TODO: Write general description for this method.
-
#order_information ⇒ OrderInformation20
TODO: Write general description for this method.
-
#payment_information ⇒ PaymentInformation16
TODO: Write general description for this method.
-
#processing_information ⇒ ProcessingInformation19
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(agreement_information: SKIP, client_reference_information: SKIP, aggregator_information: SKIP, consumer_authentication_information: SKIP, device_information: SKIP, installment_information: SKIP, merchant_information: SKIP, order_information: SKIP, payment_information: SKIP, processing_information: SKIP, buyer_information: SKIP, additional_properties: nil) ⇒ CreateBillingAgreement
constructor
A new instance of CreateBillingAgreement.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(agreement_information: SKIP, client_reference_information: SKIP, aggregator_information: SKIP, consumer_authentication_information: SKIP, device_information: SKIP, installment_information: SKIP, merchant_information: SKIP, order_information: SKIP, payment_information: SKIP, processing_information: SKIP, buyer_information: SKIP, additional_properties: nil) ⇒ CreateBillingAgreement
Returns a new instance of CreateBillingAgreement.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/visa_acceptance_merged_spec/models/create_billing_agreement.rb', line 96 def initialize(agreement_information: SKIP, client_reference_information: SKIP, aggregator_information: SKIP, consumer_authentication_information: SKIP, device_information: SKIP, installment_information: SKIP, merchant_information: SKIP, order_information: SKIP, payment_information: SKIP, processing_information: SKIP, buyer_information: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @agreement_information = agreement_information unless agreement_information == SKIP unless client_reference_information == SKIP @client_reference_information = client_reference_information end @aggregator_information = aggregator_information unless aggregator_information == SKIP unless consumer_authentication_information == SKIP @consumer_authentication_information = consumer_authentication_information end @device_information = device_information unless device_information == SKIP @installment_information = installment_information unless installment_information == SKIP @merchant_information = merchant_information unless merchant_information == SKIP @order_information = order_information unless order_information == SKIP @payment_information = payment_information unless payment_information == SKIP @processing_information = processing_information unless processing_information == SKIP @buyer_information = buyer_information unless buyer_information == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#aggregator_information ⇒ AggregatorInformation5
TODO: Write general description for this method
22 23 24 |
# File 'lib/visa_acceptance_merged_spec/models/create_billing_agreement.rb', line 22 def aggregator_information @aggregator_information end |
#agreement_information ⇒ AgreementInformation6
TODO: Write general description for this method
14 15 16 |
# File 'lib/visa_acceptance_merged_spec/models/create_billing_agreement.rb', line 14 def agreement_information @agreement_information end |
#buyer_information ⇒ BuyerInformation6
TODO: Write general description for this method
54 55 56 |
# File 'lib/visa_acceptance_merged_spec/models/create_billing_agreement.rb', line 54 def buyer_information @buyer_information end |
#client_reference_information ⇒ ClientReferenceInformation28
TODO: Write general description for this method
18 19 20 |
# File 'lib/visa_acceptance_merged_spec/models/create_billing_agreement.rb', line 18 def client_reference_information @client_reference_information end |
#consumer_authentication_information ⇒ ConsumerAuthenticationInformation2
TODO: Write general description for this method
26 27 28 |
# File 'lib/visa_acceptance_merged_spec/models/create_billing_agreement.rb', line 26 def consumer_authentication_information @consumer_authentication_information end |
#device_information ⇒ DeviceInformation5
TODO: Write general description for this method
30 31 32 |
# File 'lib/visa_acceptance_merged_spec/models/create_billing_agreement.rb', line 30 def device_information @device_information end |
#installment_information ⇒ InstallmentInformation4
TODO: Write general description for this method
34 35 36 |
# File 'lib/visa_acceptance_merged_spec/models/create_billing_agreement.rb', line 34 def installment_information @installment_information end |
#merchant_information ⇒ MerchantInformation11
TODO: Write general description for this method
38 39 40 |
# File 'lib/visa_acceptance_merged_spec/models/create_billing_agreement.rb', line 38 def merchant_information @merchant_information end |
#order_information ⇒ OrderInformation20
TODO: Write general description for this method
42 43 44 |
# File 'lib/visa_acceptance_merged_spec/models/create_billing_agreement.rb', line 42 def order_information @order_information end |
#payment_information ⇒ PaymentInformation16
TODO: Write general description for this method
46 47 48 |
# File 'lib/visa_acceptance_merged_spec/models/create_billing_agreement.rb', line 46 def payment_information @payment_information end |
#processing_information ⇒ ProcessingInformation19
TODO: Write general description for this method
50 51 52 |
# File 'lib/visa_acceptance_merged_spec/models/create_billing_agreement.rb', line 50 def processing_information @processing_information end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/visa_acceptance_merged_spec/models/create_billing_agreement.rb', line 128 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. agreement_information = AgreementInformation6.from_hash(hash['agreementInformation']) if hash['agreementInformation'] if hash['clientReferenceInformation'] client_reference_information = ClientReferenceInformation28.from_hash(hash['clientReferenceInformation']) end aggregator_information = AggregatorInformation5.from_hash(hash['aggregatorInformation']) if hash['aggregatorInformation'] if hash['consumerAuthenticationInformation'] consumer_authentication_information = ConsumerAuthenticationInformation2.from_hash(hash['consumerAuthenticationInformation']) end device_information = DeviceInformation5.from_hash(hash['deviceInformation']) if hash['deviceInformation'] installment_information = InstallmentInformation4.from_hash(hash['installmentInformation']) if hash['installmentInformation'] merchant_information = MerchantInformation11.from_hash(hash['merchantInformation']) if hash['merchantInformation'] order_information = OrderInformation20.from_hash(hash['orderInformation']) if hash['orderInformation'] payment_information = PaymentInformation16.from_hash(hash['paymentInformation']) if hash['paymentInformation'] processing_information = ProcessingInformation19.from_hash(hash['processingInformation']) if hash['processingInformation'] buyer_information = BuyerInformation6.from_hash(hash['buyerInformation']) if hash['buyerInformation'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CreateBillingAgreement.new(agreement_information: agreement_information, client_reference_information: client_reference_information, aggregator_information: aggregator_information, consumer_authentication_information: consumer_authentication_information, device_information: device_information, installment_information: installment_information, merchant_information: merchant_information, order_information: order_information, payment_information: payment_information, processing_information: processing_information, buyer_information: buyer_information, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/visa_acceptance_merged_spec/models/create_billing_agreement.rb', line 57 def self.names @_hash = {} if @_hash.nil? @_hash['agreement_information'] = 'agreementInformation' @_hash['client_reference_information'] = 'clientReferenceInformation' @_hash['aggregator_information'] = 'aggregatorInformation' @_hash['consumer_authentication_information'] = 'consumerAuthenticationInformation' @_hash['device_information'] = 'deviceInformation' @_hash['installment_information'] = 'installmentInformation' @_hash['merchant_information'] = 'merchantInformation' @_hash['order_information'] = 'orderInformation' @_hash['payment_information'] = 'paymentInformation' @_hash['processing_information'] = 'processingInformation' @_hash['buyer_information'] = 'buyerInformation' @_hash end |
.nullables ⇒ Object
An array for nullable fields
92 93 94 |
# File 'lib/visa_acceptance_merged_spec/models/create_billing_agreement.rb', line 92 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/visa_acceptance_merged_spec/models/create_billing_agreement.rb', line 75 def self.optionals %w[ agreement_information client_reference_information aggregator_information consumer_authentication_information device_information installment_information merchant_information order_information payment_information processing_information buyer_information ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/visa_acceptance_merged_spec/models/create_billing_agreement.rb', line 194 def inspect class_name = self.class.name.split('::').last "<#{class_name} agreement_information: #{@agreement_information.inspect},"\ " client_reference_information: #{@client_reference_information.inspect},"\ " aggregator_information: #{@aggregator_information.inspect},"\ " consumer_authentication_information: #{@consumer_authentication_information.inspect},"\ " device_information: #{@device_information.inspect}, installment_information:"\ " #{@installment_information.inspect}, merchant_information:"\ " #{@merchant_information.inspect}, order_information: #{@order_information.inspect},"\ " payment_information: #{@payment_information.inspect}, processing_information:"\ " #{@processing_information.inspect}, buyer_information: #{@buyer_information.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/visa_acceptance_merged_spec/models/create_billing_agreement.rb', line 180 def to_s class_name = self.class.name.split('::').last "<#{class_name} agreement_information: #{@agreement_information},"\ " client_reference_information: #{@client_reference_information}, aggregator_information:"\ " #{@aggregator_information}, consumer_authentication_information:"\ " #{@consumer_authentication_information}, device_information: #{@device_information},"\ " installment_information: #{@installment_information}, merchant_information:"\ " #{@merchant_information}, order_information: #{@order_information}, payment_information:"\ " #{@payment_information}, processing_information: #{@processing_information},"\ " buyer_information: #{@buyer_information}, additional_properties:"\ " #{@additional_properties}>" end |