Class: VisaAcceptanceMergedSpec::CreditAmountDetails
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::CreditAmountDetails
- Defined in:
- lib/visa_acceptance_merged_spec/models/credit_amount_details.rb
Overview
CreditAmountDetails Model.
Instance Attribute Summary collapse
-
#credit_amount ⇒ String
Amount that was credited to the cardholder’s account.
-
#currency ⇒ String
Currency used for the order.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(credit_amount: SKIP, currency: SKIP, additional_properties: nil) ⇒ CreditAmountDetails
constructor
A new instance of CreditAmountDetails.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(credit_amount: SKIP, currency: SKIP, additional_properties: nil) ⇒ CreditAmountDetails
Returns a new instance of CreditAmountDetails.
71 72 73 74 75 76 77 78 79 |
# File 'lib/visa_acceptance_merged_spec/models/credit_amount_details.rb', line 71 def initialize(credit_amount: SKIP, currency: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @credit_amount = credit_amount unless credit_amount == SKIP @currency = currency unless currency == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#credit_amount ⇒ String
Amount that was credited to the cardholder’s account. Returned by PIN debit credit.
15 16 17 |
# File 'lib/visa_acceptance_merged_spec/models/credit_amount_details.rb', line 15 def credit_amount @credit_amount end |
#currency ⇒ String
Currency used for the order. Use the three-character [ISO Standard Currency Codes.](
Used by
Authorization
Required field.
Authorization Reversal
For an authorization reversal (reversalInformation) or a capture
(processingOptions.capture is set to true), you must use the same
currency that you used in your payment authorization request.
PIN Debit
Currency for the amount you requested for the PIN debit purchase. This value is returned for partial authorizations. The issuing bank can approve a partial amount if the balance on the debit card is less than the requested transaction amount. For the possible values, see the [ISO Standard Currency Codes]( Returned by PIN debit purchase. For PIN debit reversal requests, you must use the same currency that was used for the PIN debit purchase or PIN debit credit that you are reversing. For the possible values, see the [ISO Standard Currency Codes]( Required field for PIN Debit purchase and PIN Debit credit requests. Optional field for PIN Debit reversal requests.
GPX
This field is optional for reversing an authorization or credit.
DCC for First Data
Your local currency.
Tax Calculation
Required for international tax and value added tax only. Optional for U.S. and Canadian taxes. Your local currency.
48 49 50 |
# File 'lib/visa_acceptance_merged_spec/models/credit_amount_details.rb', line 48 def currency @currency end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/visa_acceptance_merged_spec/models/credit_amount_details.rb', line 82 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. credit_amount = hash.key?('creditAmount') ? hash['creditAmount'] : SKIP currency = hash.key?('currency') ? hash['currency'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CreditAmountDetails.new(credit_amount: credit_amount, currency: currency, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
51 52 53 54 55 56 |
# File 'lib/visa_acceptance_merged_spec/models/credit_amount_details.rb', line 51 def self.names @_hash = {} if @_hash.nil? @_hash['credit_amount'] = 'creditAmount' @_hash['currency'] = 'currency' @_hash end |
.nullables ⇒ Object
An array for nullable fields
67 68 69 |
# File 'lib/visa_acceptance_merged_spec/models/credit_amount_details.rb', line 67 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
59 60 61 62 63 64 |
# File 'lib/visa_acceptance_merged_spec/models/credit_amount_details.rb', line 59 def self.optionals %w[ credit_amount currency ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
110 111 112 113 114 |
# File 'lib/visa_acceptance_merged_spec/models/credit_amount_details.rb', line 110 def inspect class_name = self.class.name.split('::').last "<#{class_name} credit_amount: #{@credit_amount.inspect}, currency: #{@currency.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
103 104 105 106 107 |
# File 'lib/visa_acceptance_merged_spec/models/credit_amount_details.rb', line 103 def to_s class_name = self.class.name.split('::').last "<#{class_name} credit_amount: #{@credit_amount}, currency: #{@currency},"\ " additional_properties: #{@additional_properties}>" end |