Class: VisaAcceptanceMergedSpec::EWallet10
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::EWallet10
- Defined in:
- lib/visa_acceptance_merged_spec/models/e_wallet10.rb
Overview
EWallet10 Model.
Instance Attribute Summary collapse
-
#funding_source ⇒ String
Payment mode for the transaction, possible values - INSTANT_TRANSFER - MANUAL_BANK_TRANSFER - DELAYED_TRANSFER - ECHECK.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(funding_source: SKIP, additional_properties: nil) ⇒ EWallet10
constructor
A new instance of EWallet10.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(funding_source: SKIP, additional_properties: nil) ⇒ EWallet10
Returns a new instance of EWallet10.
39 40 41 42 43 44 45 |
# File 'lib/visa_acceptance_merged_spec/models/e_wallet10.rb', line 39 def initialize(funding_source: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @funding_source = funding_source unless funding_source == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#funding_source ⇒ String
Payment mode for the transaction, possible values
- INSTANT_TRANSFER
- MANUAL_BANK_TRANSFER
- DELAYED_TRANSFER
- ECHECK
18 19 20 |
# File 'lib/visa_acceptance_merged_spec/models/e_wallet10.rb', line 18 def funding_source @funding_source end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/visa_acceptance_merged_spec/models/e_wallet10.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. funding_source = hash.key?('fundingSource') ? hash['fundingSource'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. EWallet10.new(funding_source: funding_source, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 |
# File 'lib/visa_acceptance_merged_spec/models/e_wallet10.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['funding_source'] = 'fundingSource' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/visa_acceptance_merged_spec/models/e_wallet10.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
28 29 30 31 32 |
# File 'lib/visa_acceptance_merged_spec/models/e_wallet10.rb', line 28 def self.optionals %w[ funding_source ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
74 75 76 77 78 |
# File 'lib/visa_acceptance_merged_spec/models/e_wallet10.rb', line 74 def inspect class_name = self.class.name.split('::').last "<#{class_name} funding_source: #{@funding_source.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
67 68 69 70 71 |
# File 'lib/visa_acceptance_merged_spec/models/e_wallet10.rb', line 67 def to_s class_name = self.class.name.split('::').last "<#{class_name} funding_source: #{@funding_source}, additional_properties:"\ " #{@additional_properties}>" end |