Class: VisaAcceptanceMergedSpec::EmbeddedActions
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::EmbeddedActions
- Defined in:
- lib/visa_acceptance_merged_spec/models/embedded_actions.rb
Overview
Contains embedded actions, that includes status and response for every actions in the list.
Instance Attribute Summary collapse
-
#capture ⇒ Capture1
TODO: Write general description for this method.
-
#consumer_authentication ⇒ Consumerauthentication
TODO: Write general description for this method.
-
#decision ⇒ Decision
TODO: Write general description for this method.
-
#token_create ⇒ Tokencreate
TODO: Write general description for this method.
-
#token_update ⇒ Tokenupdate
TODO: Write general description for this method.
-
#validate_consumer_authentication ⇒ Validateconsumerauthentication
TODO: Write general description for this method.
-
#watchlist_screening ⇒ Watchlistscreening
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(capture: SKIP, decision: SKIP, consumer_authentication: SKIP, validate_consumer_authentication: SKIP, watchlist_screening: SKIP, token_create: SKIP, token_update: SKIP, additional_properties: nil) ⇒ EmbeddedActions
constructor
A new instance of EmbeddedActions.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(capture: SKIP, decision: SKIP, consumer_authentication: SKIP, validate_consumer_authentication: SKIP, watchlist_screening: SKIP, token_create: SKIP, token_update: SKIP, additional_properties: nil) ⇒ EmbeddedActions
Returns a new instance of EmbeddedActions.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/visa_acceptance_merged_spec/models/embedded_actions.rb', line 73 def initialize(capture: SKIP, decision: SKIP, consumer_authentication: SKIP, validate_consumer_authentication: SKIP, watchlist_screening: SKIP, token_create: SKIP, token_update: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @capture = capture unless capture == SKIP @decision = decision unless decision == SKIP @consumer_authentication = consumer_authentication unless consumer_authentication == SKIP unless validate_consumer_authentication == SKIP @validate_consumer_authentication = validate_consumer_authentication end @watchlist_screening = watchlist_screening unless watchlist_screening == SKIP @token_create = token_create unless token_create == SKIP @token_update = token_update unless token_update == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#capture ⇒ Capture1
TODO: Write general description for this method
15 16 17 |
# File 'lib/visa_acceptance_merged_spec/models/embedded_actions.rb', line 15 def capture @capture end |
#consumer_authentication ⇒ Consumerauthentication
TODO: Write general description for this method
23 24 25 |
# File 'lib/visa_acceptance_merged_spec/models/embedded_actions.rb', line 23 def consumer_authentication @consumer_authentication end |
#decision ⇒ Decision
TODO: Write general description for this method
19 20 21 |
# File 'lib/visa_acceptance_merged_spec/models/embedded_actions.rb', line 19 def decision @decision end |
#token_create ⇒ Tokencreate
TODO: Write general description for this method
35 36 37 |
# File 'lib/visa_acceptance_merged_spec/models/embedded_actions.rb', line 35 def token_create @token_create end |
#token_update ⇒ Tokenupdate
TODO: Write general description for this method
39 40 41 |
# File 'lib/visa_acceptance_merged_spec/models/embedded_actions.rb', line 39 def token_update @token_update end |
#validate_consumer_authentication ⇒ Validateconsumerauthentication
TODO: Write general description for this method
27 28 29 |
# File 'lib/visa_acceptance_merged_spec/models/embedded_actions.rb', line 27 def validate_consumer_authentication @validate_consumer_authentication end |
#watchlist_screening ⇒ Watchlistscreening
TODO: Write general description for this method
31 32 33 |
# File 'lib/visa_acceptance_merged_spec/models/embedded_actions.rb', line 31 def watchlist_screening @watchlist_screening end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/visa_acceptance_merged_spec/models/embedded_actions.rb', line 94 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. capture = Capture1.from_hash(hash['CAPTURE']) if hash['CAPTURE'] decision = Decision.from_hash(hash['DECISION']) if hash['DECISION'] consumer_authentication = Consumerauthentication.from_hash(hash['CONSUMER_AUTHENTICATION']) if hash['CONSUMER_AUTHENTICATION'] if hash['VALIDATE_CONSUMER_AUTHENTICATION'] validate_consumer_authentication = Validateconsumerauthentication.from_hash(hash['VALIDATE_CONSUMER_AUTHENTICATION']) end watchlist_screening = Watchlistscreening.from_hash(hash['WATCHLIST_SCREENING']) if hash['WATCHLIST_SCREENING'] token_create = Tokencreate.from_hash(hash['TOKEN_CREATE']) if hash['TOKEN_CREATE'] token_update = Tokenupdate.from_hash(hash['TOKEN_UPDATE']) if hash['TOKEN_UPDATE'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. EmbeddedActions.new(capture: capture, decision: decision, consumer_authentication: consumer_authentication, validate_consumer_authentication: validate_consumer_authentication, watchlist_screening: watchlist_screening, token_create: token_create, token_update: token_update, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/visa_acceptance_merged_spec/models/embedded_actions.rb', line 42 def self.names @_hash = {} if @_hash.nil? @_hash['capture'] = 'CAPTURE' @_hash['decision'] = 'DECISION' @_hash['consumer_authentication'] = 'CONSUMER_AUTHENTICATION' @_hash['validate_consumer_authentication'] = 'VALIDATE_CONSUMER_AUTHENTICATION' @_hash['watchlist_screening'] = 'WATCHLIST_SCREENING' @_hash['token_create'] = 'TOKEN_CREATE' @_hash['token_update'] = 'TOKEN_UPDATE' @_hash end |
.nullables ⇒ Object
An array for nullable fields
69 70 71 |
# File 'lib/visa_acceptance_merged_spec/models/embedded_actions.rb', line 69 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/visa_acceptance_merged_spec/models/embedded_actions.rb', line 56 def self.optionals %w[ capture decision consumer_authentication validate_consumer_authentication watchlist_screening token_create token_update ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
139 140 141 142 143 144 145 146 147 |
# File 'lib/visa_acceptance_merged_spec/models/embedded_actions.rb', line 139 def inspect class_name = self.class.name.split('::').last "<#{class_name} capture: #{@capture.inspect}, decision: #{@decision.inspect},"\ " consumer_authentication: #{@consumer_authentication.inspect},"\ " validate_consumer_authentication: #{@validate_consumer_authentication.inspect},"\ " watchlist_screening: #{@watchlist_screening.inspect}, token_create:"\ " #{@token_create.inspect}, token_update: #{@token_update.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
129 130 131 132 133 134 135 136 |
# File 'lib/visa_acceptance_merged_spec/models/embedded_actions.rb', line 129 def to_s class_name = self.class.name.split('::').last "<#{class_name} capture: #{@capture}, decision: #{@decision}, consumer_authentication:"\ " #{@consumer_authentication}, validate_consumer_authentication:"\ " #{@validate_consumer_authentication}, watchlist_screening: #{@watchlist_screening},"\ " token_create: #{@token_create}, token_update: #{@token_update}, additional_properties:"\ " #{@additional_properties}>" end |