Class: VisaAcceptanceMergedSpec::ErrorInformation1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::ErrorInformation1
- Defined in:
- lib/visa_acceptance_merged_spec/models/error_information1.rb
Overview
ErrorInformation1 Model.
Instance Attribute Summary collapse
-
#details ⇒ Array[Detail]
The detail message related to the status and reason listed above.
-
#message ⇒ String
The detail message related to the status and reason listed above.
-
#reason ⇒ String
The reason of the status.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(reason: SKIP, message: SKIP, details: SKIP, additional_properties: nil) ⇒ ErrorInformation1
constructor
A new instance of ErrorInformation1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(reason: SKIP, message: SKIP, details: SKIP, additional_properties: nil) ⇒ ErrorInformation1
Returns a new instance of ErrorInformation1.
72 73 74 75 76 77 78 79 80 81 |
# File 'lib/visa_acceptance_merged_spec/models/error_information1.rb', line 72 def initialize(reason: SKIP, message: SKIP, details: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @reason = reason unless reason == SKIP @message = unless == SKIP @details = details unless details == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#details ⇒ Array[Detail]
The detail message related to the status and reason listed above.
47 48 49 |
# File 'lib/visa_acceptance_merged_spec/models/error_information1.rb', line 47 def details @details end |
#message ⇒ String
The detail message related to the status and reason listed above.
43 44 45 |
# File 'lib/visa_acceptance_merged_spec/models/error_information1.rb', line 43 def @message end |
#reason ⇒ String
The reason of the status. Possible values:
- AVS_FAILED
- CONTACT_PROCESSOR
- EXPIRED_CARD
- PROCESSOR_DECLINED
- INSUFFICIENT_FUND
- STOLEN_LOST_CARD
- ISSUER_UNAVAILABLE
- UNAUTHORIZED_CARD
- CVN_NOT_MATCH
- EXCEEDS_CREDIT_LIMIT
- INVALID_CVN
- BLOCKED_BY_CARDHOLDER
- BLACKLISTED_CUSTOMER
- SUSPENDED_ACCOUNT
- PAYMENT_REFUSED
- CV_FAILED
- INVALID_ACCOUNT
- GENERAL_DECLINE
- INVALID_MERCHANT_CONFIGURATION
- DECISION_PROFILE_REJECT
- SCORE_EXCEEDS_THRESHOLD
- CONSUMER_AUTHENTICATION_REQUIRED
- ALLOWABLE_PIN_RETRIES_EXCEEDED
- PROCESSOR_ERROR
39 40 41 |
# File 'lib/visa_acceptance_merged_spec/models/error_information1.rb', line 39 def reason @reason end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/visa_acceptance_merged_spec/models/error_information1.rb', line 84 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. reason = hash.key?('reason') ? hash['reason'] : SKIP = hash.key?('message') ? hash['message'] : SKIP # Parameter is an array, so we need to iterate through it details = nil unless hash['details'].nil? details = [] hash['details'].each do |structure| details << (Detail.from_hash(structure) if structure) end end details = SKIP unless hash.key?('details') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ErrorInformation1.new(reason: reason, message: , details: details, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
50 51 52 53 54 55 56 |
# File 'lib/visa_acceptance_merged_spec/models/error_information1.rb', line 50 def self.names @_hash = {} if @_hash.nil? @_hash['reason'] = 'reason' @_hash['message'] = 'message' @_hash['details'] = 'details' @_hash end |
.nullables ⇒ Object
An array for nullable fields
68 69 70 |
# File 'lib/visa_acceptance_merged_spec/models/error_information1.rb', line 68 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
59 60 61 62 63 64 65 |
# File 'lib/visa_acceptance_merged_spec/models/error_information1.rb', line 59 def self.optionals %w[ reason message details ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
123 124 125 126 127 |
# File 'lib/visa_acceptance_merged_spec/models/error_information1.rb', line 123 def inspect class_name = self.class.name.split('::').last "<#{class_name} reason: #{@reason.inspect}, message: #{@message.inspect}, details:"\ " #{@details.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
116 117 118 119 120 |
# File 'lib/visa_acceptance_merged_spec/models/error_information1.rb', line 116 def to_s class_name = self.class.name.split('::').last "<#{class_name} reason: #{@reason}, message: #{@message}, details: #{@details},"\ " additional_properties: #{@additional_properties}>" end |