Class: VisaAcceptanceMergedSpec::GenerateUnifiedCheckoutCaptureContextException
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::GenerateUnifiedCheckoutCaptureContextException
- Defined in:
- lib/visa_acceptance_merged_spec/models/generate_unified_checkout_capture_context_exception.rb
Overview
GenerateUnifiedCheckoutCaptureContextException Model.
Instance Attribute Summary collapse
-
#correlation_id ⇒ String
TODO: Write general description for this method.
-
#details ⇒ Array[Detail66]
TODO: Write general description for this method.
-
#information_link ⇒ String
TODO: Write general description for this method.
-
#message ⇒ String
TODO: Write general description for this method.
-
#reason ⇒ Reason
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(message:, reason:, correlation_id: SKIP, details: SKIP, information_link: SKIP, additional_properties: nil) ⇒ GenerateUnifiedCheckoutCaptureContextException
constructor
A new instance of GenerateUnifiedCheckoutCaptureContextException.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(message:, reason:, correlation_id: SKIP, details: SKIP, information_link: SKIP, additional_properties: nil) ⇒ GenerateUnifiedCheckoutCaptureContextException
Returns a new instance of GenerateUnifiedCheckoutCaptureContextException.
57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/visa_acceptance_merged_spec/models/generate_unified_checkout_capture_context_exception.rb', line 57 def initialize(message:, reason:, correlation_id: SKIP, details: SKIP, information_link: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @correlation_id = correlation_id unless correlation_id == SKIP @details = details unless details == SKIP @information_link = information_link unless information_link == SKIP @message = @reason = reason @additional_properties = additional_properties end |
Instance Attribute Details
#correlation_id ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/visa_acceptance_merged_spec/models/generate_unified_checkout_capture_context_exception.rb', line 14 def correlation_id @correlation_id end |
#details ⇒ Array[Detail66]
TODO: Write general description for this method
18 19 20 |
# File 'lib/visa_acceptance_merged_spec/models/generate_unified_checkout_capture_context_exception.rb', line 18 def details @details end |
#information_link ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/visa_acceptance_merged_spec/models/generate_unified_checkout_capture_context_exception.rb', line 22 def information_link @information_link end |
#message ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/visa_acceptance_merged_spec/models/generate_unified_checkout_capture_context_exception.rb', line 26 def @message end |
#reason ⇒ Reason
TODO: Write general description for this method
30 31 32 |
# File 'lib/visa_acceptance_merged_spec/models/generate_unified_checkout_capture_context_exception.rb', line 30 def reason @reason end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/visa_acceptance_merged_spec/models/generate_unified_checkout_capture_context_exception.rb', line 71 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. = hash.key?('message') ? hash['message'] : nil reason = hash.key?('reason') ? hash['reason'] : nil correlation_id = hash.key?('correlationId') ? hash['correlationId'] : SKIP # Parameter is an array, so we need to iterate through it details = nil unless hash['details'].nil? details = [] hash['details'].each do |structure| details << (Detail66.from_hash(structure) if structure) end end details = SKIP unless hash.key?('details') information_link = hash.key?('informationLink') ? hash['informationLink'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. GenerateUnifiedCheckoutCaptureContextException.new(message: , reason: reason, correlation_id: correlation_id, details: details, information_link: information_link, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/visa_acceptance_merged_spec/models/generate_unified_checkout_capture_context_exception.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['correlation_id'] = 'correlationId' @_hash['details'] = 'details' @_hash['information_link'] = 'informationLink' @_hash['message'] = 'message' @_hash['reason'] = 'reason' @_hash end |
.nullables ⇒ Object
An array for nullable fields
53 54 55 |
# File 'lib/visa_acceptance_merged_spec/models/generate_unified_checkout_capture_context_exception.rb', line 53 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 47 48 49 50 |
# File 'lib/visa_acceptance_merged_spec/models/generate_unified_checkout_capture_context_exception.rb', line 44 def self.optionals %w[ correlation_id details information_link ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
116 117 118 119 120 121 |
# File 'lib/visa_acceptance_merged_spec/models/generate_unified_checkout_capture_context_exception.rb', line 116 def inspect class_name = self.class.name.split('::').last "<#{class_name} correlation_id: #{@correlation_id.inspect}, details: #{@details.inspect},"\ " information_link: #{@information_link.inspect}, message: #{@message.inspect}, reason:"\ " #{@reason.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
108 109 110 111 112 113 |
# File 'lib/visa_acceptance_merged_spec/models/generate_unified_checkout_capture_context_exception.rb', line 108 def to_s class_name = self.class.name.split('::').last "<#{class_name} correlation_id: #{@correlation_id}, details: #{@details}, information_link:"\ " #{@information_link}, message: #{@message}, reason: #{@reason}, additional_properties:"\ " #{@additional_properties}>" end |