Class: VisaAcceptanceMergedSpec::InstrumentIdentifier2
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::InstrumentIdentifier2
- Defined in:
- lib/visa_acceptance_merged_spec/models/instrument_identifier2.rb
Overview
InstrumentIdentifier2 Model.
Instance Attribute Summary collapse
-
#id ⇒ String
Unique identifier for the Instrument Identifier token used in the transaction.
-
#state ⇒ String
Issuers state for the card number.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id: SKIP, state: SKIP, additional_properties: nil) ⇒ InstrumentIdentifier2
constructor
A new instance of InstrumentIdentifier2.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id: SKIP, state: SKIP, additional_properties: nil) ⇒ InstrumentIdentifier2
Returns a new instance of InstrumentIdentifier2.
48 49 50 51 52 53 54 55 |
# File 'lib/visa_acceptance_merged_spec/models/instrument_identifier2.rb', line 48 def initialize(id: SKIP, state: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id unless id == SKIP @state = state unless state == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#id ⇒ String
Unique identifier for the Instrument Identifier token used in the transaction. When you include this value in your request, many of the fields that can be supplied for an authorization or credit become optional.
18 19 20 |
# File 'lib/visa_acceptance_merged_spec/models/instrument_identifier2.rb', line 18 def id @id end |
#state ⇒ String
Issuers state for the card number. Valid values:
- ACTIVE
- CLOSED : The account has been closed.
25 26 27 |
# File 'lib/visa_acceptance_merged_spec/models/instrument_identifier2.rb', line 25 def state @state end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/visa_acceptance_merged_spec/models/instrument_identifier2.rb', line 58 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : SKIP state = hash.key?('state') ? hash['state'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. InstrumentIdentifier2.new(id: id, state: state, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
28 29 30 31 32 33 |
# File 'lib/visa_acceptance_merged_spec/models/instrument_identifier2.rb', line 28 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['state'] = 'state' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/visa_acceptance_merged_spec/models/instrument_identifier2.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
36 37 38 39 40 41 |
# File 'lib/visa_acceptance_merged_spec/models/instrument_identifier2.rb', line 36 def self.optionals %w[ id state ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
86 87 88 89 90 |
# File 'lib/visa_acceptance_merged_spec/models/instrument_identifier2.rb', line 86 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, state: #{@state.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
79 80 81 82 83 |
# File 'lib/visa_acceptance_merged_spec/models/instrument_identifier2.rb', line 79 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, state: #{@state}, additional_properties:"\ " #{@additional_properties}>" end |