Class: VisaAcceptanceMergedSpec::InstrumentIdentifier3
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::InstrumentIdentifier3
- Defined in:
- lib/visa_acceptance_merged_spec/models/instrument_identifier3.rb
Overview
InstrumentIdentifier3 Model.
Instance Attribute Summary collapse
-
#id ⇒ String
Unique identifier for the Instrument Identifier token that was created as part of a bundled TOKEN_CREATE action.
-
#state ⇒ String
Issuers state for the card number.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id: SKIP, state: SKIP, additional_properties: nil) ⇒ InstrumentIdentifier3
constructor
A new instance of InstrumentIdentifier3.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id: SKIP, state: SKIP, additional_properties: nil) ⇒ InstrumentIdentifier3
Returns a new instance of InstrumentIdentifier3.
45 46 47 48 49 50 51 52 |
# File 'lib/visa_acceptance_merged_spec/models/instrument_identifier3.rb', line 45 def initialize(id: SKIP, state: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id unless id == SKIP @state = state unless state == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#id ⇒ String
Unique identifier for the Instrument Identifier token that was created as part of a bundled TOKEN_CREATE action.
15 16 17 |
# File 'lib/visa_acceptance_merged_spec/models/instrument_identifier3.rb', line 15 def id @id end |
#state ⇒ String
Issuers state for the card number. Valid values:
- ACTIVE
- CLOSED : The account has been closed.
22 23 24 |
# File 'lib/visa_acceptance_merged_spec/models/instrument_identifier3.rb', line 22 def state @state end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/visa_acceptance_merged_spec/models/instrument_identifier3.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : SKIP state = hash.key?('state') ? hash['state'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. InstrumentIdentifier3.new(id: id, state: state, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 |
# File 'lib/visa_acceptance_merged_spec/models/instrument_identifier3.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['state'] = 'state' @_hash end |
.nullables ⇒ Object
An array for nullable fields
41 42 43 |
# File 'lib/visa_acceptance_merged_spec/models/instrument_identifier3.rb', line 41 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
33 34 35 36 37 38 |
# File 'lib/visa_acceptance_merged_spec/models/instrument_identifier3.rb', line 33 def self.optionals %w[ id state ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
83 84 85 86 87 |
# File 'lib/visa_acceptance_merged_spec/models/instrument_identifier3.rb', line 83 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, state: #{@state.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
76 77 78 79 80 |
# File 'lib/visa_acceptance_merged_spec/models/instrument_identifier3.rb', line 76 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, state: #{@state}, additional_properties:"\ " #{@additional_properties}>" end |