Class: VisaAcceptanceMergedSpec::Issuer
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::Issuer
- Defined in:
- lib/visa_acceptance_merged_spec/models/issuer.rb
Overview
Issuer Model.
Instance Attribute Summary collapse
-
#discretionary_data ⇒ String
Data defined by the issuer.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(discretionary_data: SKIP, additional_properties: nil) ⇒ Issuer
constructor
A new instance of Issuer.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(discretionary_data: SKIP, additional_properties: nil) ⇒ Issuer
Returns a new instance of Issuer.
40 41 42 43 44 45 46 |
# File 'lib/visa_acceptance_merged_spec/models/issuer.rb', line 40 def initialize(discretionary_data: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @discretionary_data = discretionary_data unless discretionary_data == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#discretionary_data ⇒ String
Data defined by the issuer. The value for this reply field will probably be the same as the value that you submitted in the authorization request, but it is possible for the processor, issuer, or acquirer to modify the value. This field is supported only for Visa transactions on Visa Acceptance through VisaNet.
19 20 21 |
# File 'lib/visa_acceptance_merged_spec/models/issuer.rb', line 19 def discretionary_data @discretionary_data end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/visa_acceptance_merged_spec/models/issuer.rb', line 49 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. discretionary_data = hash.key?('discretionaryData') ? hash['discretionaryData'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Issuer.new(discretionary_data: discretionary_data, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 |
# File 'lib/visa_acceptance_merged_spec/models/issuer.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['discretionary_data'] = 'discretionaryData' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/visa_acceptance_merged_spec/models/issuer.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 |
# File 'lib/visa_acceptance_merged_spec/models/issuer.rb', line 29 def self.optionals %w[ discretionary_data ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 80 |
# File 'lib/visa_acceptance_merged_spec/models/issuer.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} discretionary_data: #{@discretionary_data.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 73 |
# File 'lib/visa_acceptance_merged_spec/models/issuer.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} discretionary_data: #{@discretionary_data}, additional_properties:"\ " #{@additional_properties}>" end |