Class: VisaAcceptanceMergedSpec::Links15
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::Links15
- Defined in:
- lib/visa_acceptance_merged_spec/models/links15.rb
Overview
Links15 Model.
Instance Attribute Summary collapse
-
#mself ⇒ Self
TODO: Write general description for this method.
-
#revoke_agreement ⇒ RevokeAgreement
TODO: Write general description for this method.
-
#status ⇒ Status
TODO: Write general description for this method.
-
#update_agreement ⇒ UpdateAgreement
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(mself: SKIP, update_agreement: SKIP, revoke_agreement: SKIP, status: SKIP, additional_properties: nil) ⇒ Links15
constructor
A new instance of Links15.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(mself: SKIP, update_agreement: SKIP, revoke_agreement: SKIP, status: SKIP, additional_properties: nil) ⇒ Links15
Returns a new instance of Links15.
53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/visa_acceptance_merged_spec/models/links15.rb', line 53 def initialize(mself: SKIP, update_agreement: SKIP, revoke_agreement: SKIP, status: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @mself = mself unless mself == SKIP @update_agreement = update_agreement unless update_agreement == SKIP @revoke_agreement = revoke_agreement unless revoke_agreement == SKIP @status = status unless status == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#mself ⇒ Self
TODO: Write general description for this method
14 15 16 |
# File 'lib/visa_acceptance_merged_spec/models/links15.rb', line 14 def mself @mself end |
#revoke_agreement ⇒ RevokeAgreement
TODO: Write general description for this method
22 23 24 |
# File 'lib/visa_acceptance_merged_spec/models/links15.rb', line 22 def revoke_agreement @revoke_agreement end |
#status ⇒ Status
TODO: Write general description for this method
26 27 28 |
# File 'lib/visa_acceptance_merged_spec/models/links15.rb', line 26 def status @status end |
#update_agreement ⇒ UpdateAgreement
TODO: Write general description for this method
18 19 20 |
# File 'lib/visa_acceptance_merged_spec/models/links15.rb', line 18 def update_agreement @update_agreement end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/visa_acceptance_merged_spec/models/links15.rb', line 66 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. mself = Self.from_hash(hash['self']) if hash['self'] update_agreement = UpdateAgreement.from_hash(hash['updateAgreement']) if hash['updateAgreement'] revoke_agreement = RevokeAgreement.from_hash(hash['revokeAgreement']) if hash['revokeAgreement'] status = Status.from_hash(hash['status']) if hash['status'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Links15.new(mself: mself, update_agreement: update_agreement, revoke_agreement: revoke_agreement, status: status, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/visa_acceptance_merged_spec/models/links15.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['mself'] = 'self' @_hash['update_agreement'] = 'updateAgreement' @_hash['revoke_agreement'] = 'revokeAgreement' @_hash['status'] = 'status' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/visa_acceptance_merged_spec/models/links15.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/visa_acceptance_merged_spec/models/links15.rb', line 39 def self.optionals %w[ mself update_agreement revoke_agreement status ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
101 102 103 104 105 106 |
# File 'lib/visa_acceptance_merged_spec/models/links15.rb', line 101 def inspect class_name = self.class.name.split('::').last "<#{class_name} mself: #{@mself.inspect}, update_agreement: #{@update_agreement.inspect},"\ " revoke_agreement: #{@revoke_agreement.inspect}, status: #{@status.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
93 94 95 96 97 98 |
# File 'lib/visa_acceptance_merged_spec/models/links15.rb', line 93 def to_s class_name = self.class.name.split('::').last "<#{class_name} mself: #{@mself}, update_agreement: #{@update_agreement}, revoke_agreement:"\ " #{@revoke_agreement}, status: #{@status}, additional_properties:"\ " #{@additional_properties}>" end |