Class: VisaAcceptanceMergedSpec::Links19
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::Links19
- Defined in:
- lib/visa_acceptance_merged_spec/models/links19.rb
Overview
Links19 Model.
Instance Attribute Summary collapse
-
#mself ⇒ Self18
TODO: Write general description for this method.
-
#payment_instruments ⇒ PaymentInstruments
TODO: Write general description for this method.
-
#shipping_address ⇒ ShippingAddress11
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(mself: SKIP, payment_instruments: SKIP, shipping_address: SKIP, additional_properties: nil) ⇒ Links19
constructor
A new instance of Links19.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(mself: SKIP, payment_instruments: SKIP, shipping_address: SKIP, additional_properties: nil) ⇒ Links19
Returns a new instance of Links19.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/visa_acceptance_merged_spec/models/links19.rb', line 47 def initialize(mself: SKIP, payment_instruments: SKIP, shipping_address: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @mself = mself unless mself == SKIP @payment_instruments = payment_instruments unless payment_instruments == SKIP @shipping_address = shipping_address unless shipping_address == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#mself ⇒ Self18
TODO: Write general description for this method
14 15 16 |
# File 'lib/visa_acceptance_merged_spec/models/links19.rb', line 14 def mself @mself end |
#payment_instruments ⇒ PaymentInstruments
TODO: Write general description for this method
18 19 20 |
# File 'lib/visa_acceptance_merged_spec/models/links19.rb', line 18 def payment_instruments @payment_instruments end |
#shipping_address ⇒ ShippingAddress11
TODO: Write general description for this method
22 23 24 |
# File 'lib/visa_acceptance_merged_spec/models/links19.rb', line 22 def shipping_address @shipping_address end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/visa_acceptance_merged_spec/models/links19.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. mself = Self18.from_hash(hash['self']) if hash['self'] payment_instruments = PaymentInstruments.from_hash(hash['paymentInstruments']) if hash['paymentInstruments'] shipping_address = ShippingAddress11.from_hash(hash['shippingAddress']) if hash['shippingAddress'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Links19.new(mself: mself, payment_instruments: payment_instruments, shipping_address: shipping_address, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/visa_acceptance_merged_spec/models/links19.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['mself'] = 'self' @_hash['payment_instruments'] = 'paymentInstruments' @_hash['shipping_address'] = 'shippingAddress' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/visa_acceptance_merged_spec/models/links19.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/visa_acceptance_merged_spec/models/links19.rb', line 34 def self.optionals %w[ mself payment_instruments shipping_address ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
91 92 93 94 95 96 |
# File 'lib/visa_acceptance_merged_spec/models/links19.rb', line 91 def inspect class_name = self.class.name.split('::').last "<#{class_name} mself: #{@mself.inspect}, payment_instruments:"\ " #{@payment_instruments.inspect}, shipping_address: #{@shipping_address.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
84 85 86 87 88 |
# File 'lib/visa_acceptance_merged_spec/models/links19.rb', line 84 def to_s class_name = self.class.name.split('::').last "<#{class_name} mself: #{@mself}, payment_instruments: #{@payment_instruments},"\ " shipping_address: #{@shipping_address}, additional_properties: #{@additional_properties}>" end |