Class: VisaAcceptanceMergedSpec::Links66
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::Links66
- Defined in:
- lib/visa_acceptance_merged_spec/models/links66.rb
Overview
Links66 Model.
Instance Attribute Summary collapse
-
#first ⇒ First
TODO: Write general description for this method.
-
#last ⇒ Last
TODO: Write general description for this method.
-
#mnext ⇒ Next
TODO: Write general description for this method.
-
#mself ⇒ Self65
TODO: Write general description for this method.
-
#prev ⇒ Prev
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(mself: SKIP, first: SKIP, prev: SKIP, mnext: SKIP, last: SKIP, additional_properties: nil) ⇒ Links66
constructor
A new instance of Links66.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(mself: SKIP, first: SKIP, prev: SKIP, mnext: SKIP, last: SKIP, additional_properties: nil) ⇒ Links66
Returns a new instance of Links66.
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/visa_acceptance_merged_spec/models/links66.rb', line 59 def initialize(mself: SKIP, first: SKIP, prev: SKIP, mnext: SKIP, last: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @mself = mself unless mself == SKIP @first = first unless first == SKIP @prev = prev unless prev == SKIP @mnext = mnext unless mnext == SKIP @last = last unless last == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#first ⇒ First
TODO: Write general description for this method
18 19 20 |
# File 'lib/visa_acceptance_merged_spec/models/links66.rb', line 18 def first @first end |
#last ⇒ Last
TODO: Write general description for this method
30 31 32 |
# File 'lib/visa_acceptance_merged_spec/models/links66.rb', line 30 def last @last end |
#mnext ⇒ Next
TODO: Write general description for this method
26 27 28 |
# File 'lib/visa_acceptance_merged_spec/models/links66.rb', line 26 def mnext @mnext end |
#mself ⇒ Self65
TODO: Write general description for this method
14 15 16 |
# File 'lib/visa_acceptance_merged_spec/models/links66.rb', line 14 def mself @mself end |
#prev ⇒ Prev
TODO: Write general description for this method
22 23 24 |
# File 'lib/visa_acceptance_merged_spec/models/links66.rb', line 22 def prev @prev end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/visa_acceptance_merged_spec/models/links66.rb', line 73 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. mself = Self65.from_hash(hash['self']) if hash['self'] first = First.from_hash(hash['first']) if hash['first'] prev = Prev.from_hash(hash['prev']) if hash['prev'] mnext = Next.from_hash(hash['next']) if hash['next'] last = Last.from_hash(hash['last']) if hash['last'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Links66.new(mself: mself, first: first, prev: prev, mnext: mnext, last: last, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/visa_acceptance_merged_spec/models/links66.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['mself'] = 'self' @_hash['first'] = 'first' @_hash['prev'] = 'prev' @_hash['mnext'] = 'next' @_hash['last'] = 'last' @_hash end |
.nullables ⇒ Object
An array for nullable fields
55 56 57 |
# File 'lib/visa_acceptance_merged_spec/models/links66.rb', line 55 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 47 48 49 50 51 52 |
# File 'lib/visa_acceptance_merged_spec/models/links66.rb', line 44 def self.optionals %w[ mself first prev mnext last ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
107 108 109 110 111 112 |
# File 'lib/visa_acceptance_merged_spec/models/links66.rb', line 107 def inspect class_name = self.class.name.split('::').last "<#{class_name} mself: #{@mself.inspect}, first: #{@first.inspect}, prev: #{@prev.inspect},"\ " mnext: #{@mnext.inspect}, last: #{@last.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
100 101 102 103 104 |
# File 'lib/visa_acceptance_merged_spec/models/links66.rb', line 100 def to_s class_name = self.class.name.split('::').last "<#{class_name} mself: #{@mself}, first: #{@first}, prev: #{@prev}, mnext: #{@mnext}, last:"\ " #{@last}, additional_properties: #{@additional_properties}>" end |