Class: VisaAcceptanceMergedSpec::MerchantDescriptor11
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::MerchantDescriptor11
- Defined in:
- lib/visa_acceptance_merged_spec/models/merchant_descriptor11.rb
Overview
MerchantDescriptor11 Model.
Instance Attribute Summary collapse
-
#email ⇒ String
Email address of the merchant.
-
#name ⇒ String
Your merchant name.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(name: SKIP, email: SKIP, additional_properties: nil) ⇒ MerchantDescriptor11
constructor
A new instance of MerchantDescriptor11.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name: SKIP, email: SKIP, additional_properties: nil) ⇒ MerchantDescriptor11
Returns a new instance of MerchantDescriptor11.
60 61 62 63 64 65 66 67 |
# File 'lib/visa_acceptance_merged_spec/models/merchant_descriptor11.rb', line 60 def initialize(name: SKIP, email: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @name = name unless name == SKIP @email = email unless email == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#email ⇒ String
Email address of the merchant.
37 38 39 |
# File 'lib/visa_acceptance_merged_spec/models/merchant_descriptor11.rb', line 37 def email @email end |
#name ⇒ String
Your merchant name. Note For Paymentech processor using Visa Acceptance Payouts, the maximum data length is 22.
PIN debit
Your business name. This name is displayed on the cardholder’s statement. When you include more than one consecutive space, extra spaces are removed. When you do not include this value in your PIN debit request, the merchant name from your account is used. Important This value must consist of English characters. Optional field for PIN debit credit or PIN debit purchase requests.
Airline processing
Your merchant name. This name is displayed on the cardholder’s statement. When you include more than one consecutive space, extra spaces are removed. Note Some airline fee programs may require the original ticket number (ticket identifier) or the ancillary service description in positions 13 through 23 of this field. Important This value must consist of English characters. Required for captures and credits.
33 34 35 |
# File 'lib/visa_acceptance_merged_spec/models/merchant_descriptor11.rb', line 33 def name @name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/visa_acceptance_merged_spec/models/merchant_descriptor11.rb', line 70 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : SKIP email = hash.key?('email') ? hash['email'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. MerchantDescriptor11.new(name: name, email: email, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
40 41 42 43 44 45 |
# File 'lib/visa_acceptance_merged_spec/models/merchant_descriptor11.rb', line 40 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash['email'] = 'email' @_hash end |
.nullables ⇒ Object
An array for nullable fields
56 57 58 |
# File 'lib/visa_acceptance_merged_spec/models/merchant_descriptor11.rb', line 56 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
48 49 50 51 52 53 |
# File 'lib/visa_acceptance_merged_spec/models/merchant_descriptor11.rb', line 48 def self.optionals %w[ name email ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
98 99 100 101 102 |
# File 'lib/visa_acceptance_merged_spec/models/merchant_descriptor11.rb', line 98 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, email: #{@email.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
91 92 93 94 95 |
# File 'lib/visa_acceptance_merged_spec/models/merchant_descriptor11.rb', line 91 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, email: #{@email}, additional_properties:"\ " #{@additional_properties}>" end |