Class: VisaAcceptanceMergedSpec::MerchantDescriptor13
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::MerchantDescriptor13
- Defined in:
- lib/visa_acceptance_merged_spec/models/merchant_descriptor13.rb
Overview
MerchantDescriptor13 Model.
Instance Attribute Summary collapse
-
#alternate_name ⇒ String
Alternate contact information for your business,such as an email address or URL.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(alternate_name: SKIP, additional_properties: nil) ⇒ MerchantDescriptor13
constructor
A new instance of MerchantDescriptor13.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(alternate_name: SKIP, additional_properties: nil) ⇒ MerchantDescriptor13
Returns a new instance of MerchantDescriptor13.
40 41 42 43 44 45 46 |
# File 'lib/visa_acceptance_merged_spec/models/merchant_descriptor13.rb', line 40 def initialize(alternate_name: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @alternate_name = alternate_name unless alternate_name == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#alternate_name ⇒ String
Alternate contact information for your business,such as an email address or URL. This value might be displayed on the cardholder’s statement. When you do not include this value in your capture or credit request, the merchant URL from your Visa Acceptance account is used. Important This value must consist of English characters
19 20 21 |
# File 'lib/visa_acceptance_merged_spec/models/merchant_descriptor13.rb', line 19 def alternate_name @alternate_name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/visa_acceptance_merged_spec/models/merchant_descriptor13.rb', line 49 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. alternate_name = hash.key?('alternateName') ? hash['alternateName'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. MerchantDescriptor13.new(alternate_name: alternate_name, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 |
# File 'lib/visa_acceptance_merged_spec/models/merchant_descriptor13.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['alternate_name'] = 'alternateName' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/visa_acceptance_merged_spec/models/merchant_descriptor13.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 |
# File 'lib/visa_acceptance_merged_spec/models/merchant_descriptor13.rb', line 29 def self.optionals %w[ alternate_name ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
75 76 77 78 79 |
# File 'lib/visa_acceptance_merged_spec/models/merchant_descriptor13.rb', line 75 def inspect class_name = self.class.name.split('::').last "<#{class_name} alternate_name: #{@alternate_name.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
68 69 70 71 72 |
# File 'lib/visa_acceptance_merged_spec/models/merchant_descriptor13.rb', line 68 def to_s class_name = self.class.name.split('::').last "<#{class_name} alternate_name: #{@alternate_name}, additional_properties:"\ " #{@additional_properties}>" end |