Class: VisaAcceptanceMergedSpec::MerchantDescriptor30
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::MerchantDescriptor30
- Defined in:
- lib/visa_acceptance_merged_spec/models/merchant_descriptor30.rb
Overview
MerchantDescriptor30 Model.
Instance Attribute Summary collapse
-
#name ⇒ String
Your merchant name.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(name: SKIP, additional_properties: nil) ⇒ MerchantDescriptor30
constructor
A new instance of MerchantDescriptor30.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name: SKIP, additional_properties: nil) ⇒ MerchantDescriptor30
Returns a new instance of MerchantDescriptor30.
54 55 56 57 58 59 60 |
# File 'lib/visa_acceptance_merged_spec/models/merchant_descriptor30.rb', line 54 def initialize(name: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @name = name unless name == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#name ⇒ String
Your merchant name. Note For Paymentech processor using Visa Acceptance Payouts, the maximum data length is 22.
PIN debit
Your business name. This name is displayed on the cardholder’s statement. When you include more than one consecutive space, extra spaces are removed. When you do not include this value in your PIN debit request, the merchant name from your account is used. Important This value must consist of English characters. Optional field for PIN debit credit or PIN debit purchase requests.
Airline processing
Your merchant name. This name is displayed on the cardholder’s statement. When you include more than one consecutive space, extra spaces are removed. Note Some airline fee programs may require the original ticket number (ticket identifier) or the ancillary service description in positions 13 through 23 of this field. Important This value must consist of English characters. Required for captures and credits.
33 34 35 |
# File 'lib/visa_acceptance_merged_spec/models/merchant_descriptor30.rb', line 33 def name @name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/visa_acceptance_merged_spec/models/merchant_descriptor30.rb', line 63 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. MerchantDescriptor30.new(name: name, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
36 37 38 39 40 |
# File 'lib/visa_acceptance_merged_spec/models/merchant_descriptor30.rb', line 36 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash end |
.nullables ⇒ Object
An array for nullable fields
50 51 52 |
# File 'lib/visa_acceptance_merged_spec/models/merchant_descriptor30.rb', line 50 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
43 44 45 46 47 |
# File 'lib/visa_acceptance_merged_spec/models/merchant_descriptor30.rb', line 43 def self.optionals %w[ name ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
88 89 90 91 |
# File 'lib/visa_acceptance_merged_spec/models/merchant_descriptor30.rb', line 88 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 |
# File 'lib/visa_acceptance_merged_spec/models/merchant_descriptor30.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, additional_properties: #{@additional_properties}>" end |