Class: VisaAcceptanceMergedSpec::Partner
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::Partner
- Defined in:
- lib/visa_acceptance_merged_spec/models/partner.rb
Overview
Partner Model.
Instance Attribute Summary collapse
-
#developer_id ⇒ String
Identifier for the developer that helped integrate a partner solution to Visa Acceptance.
-
#original_transaction_id ⇒ String
Value that links the previous transaction to the current follow-on request.
-
#solution_id ⇒ String
Identifier for the partner that is integrated to Visa Acceptance.
-
#third_party_certification_number ⇒ String
Value that identifies the application vendor and application version for a third party gateway.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(original_transaction_id: SKIP, developer_id: SKIP, solution_id: SKIP, third_party_certification_number: SKIP, additional_properties: nil) ⇒ Partner
constructor
A new instance of Partner.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(original_transaction_id: SKIP, developer_id: SKIP, solution_id: SKIP, third_party_certification_number: SKIP, additional_properties: nil) ⇒ Partner
Returns a new instance of Partner.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/visa_acceptance_merged_spec/models/partner.rb', line 91 def initialize(original_transaction_id: SKIP, developer_id: SKIP, solution_id: SKIP, third_party_certification_number: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @original_transaction_id = original_transaction_id unless original_transaction_id == SKIP @developer_id = developer_id unless developer_id == SKIP @solution_id = solution_id unless solution_id == SKIP unless third_party_certification_number == SKIP @third_party_certification_number = third_party_certification_number end @additional_properties = additional_properties end |
Instance Attribute Details
#developer_id ⇒ String
Identifier for the developer that helped integrate a partner solution to Visa Acceptance. Send this value in all requests that are sent through the partner solutions built by that developer. Visa Acceptance assigns the ID to the developer. Note When you see a developer ID of 999 in reports, the developer ID that was submitted is incorrect.
40 41 42 |
# File 'lib/visa_acceptance_merged_spec/models/partner.rb', line 40 def developer_id @developer_id end |
#original_transaction_id ⇒ String
Value that links the previous transaction to the current follow-on request. This value is assigned by the client software that is installed on the POS terminal, which makes it available to the terminal’s software and to Visa Acceptance. Therefore, you can use this value to reconcile transactions between Visa Acceptance and the terminal’s software. Visa Acceptance does not forward this value to the processor. Instead, the value is forwarded to the Visa Acceptance reporting functionality. This field is supported only on these processors:
- American Express Direct
- Credit Mutuel-CIC
- FDC Nashville Global
- OmniPay Direct
- SIX Optional field.
30 31 32 |
# File 'lib/visa_acceptance_merged_spec/models/partner.rb', line 30 def original_transaction_id @original_transaction_id end |
#solution_id ⇒ String
Identifier for the partner that is integrated to Visa Acceptance. Send this value in all requests that are sent through the partner solution. Visa Acceptance assigns the ID to the partner. Note When you see a solutionId of 999 in reports, the solutionId that was submitted is incorrect.
48 49 50 |
# File 'lib/visa_acceptance_merged_spec/models/partner.rb', line 48 def solution_id @solution_id end |
#third_party_certification_number ⇒ String
Value that identifies the application vendor and application version for a third party gateway. Visa Acceptance provides you with this value during testing and validation. This field is supported only on Visa Acceptance through VisaNet.
Used by
Authorization, Authorization Reversal, Capture, Credit, Incremental Authorization, and Void Optional field.
PIN debit
Required field for PIN debit credit, PIN debit purchase, or PIN debit reversal request.
63 64 65 |
# File 'lib/visa_acceptance_merged_spec/models/partner.rb', line 63 def third_party_certification_number @third_party_certification_number end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/visa_acceptance_merged_spec/models/partner.rb', line 108 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. original_transaction_id = hash.key?('originalTransactionId') ? hash['originalTransactionId'] : SKIP developer_id = hash.key?('developerId') ? hash['developerId'] : SKIP solution_id = hash.key?('solutionId') ? hash['solutionId'] : SKIP third_party_certification_number = hash.key?('thirdPartyCertificationNumber') ? hash['thirdPartyCertificationNumber'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Partner.new(original_transaction_id: original_transaction_id, developer_id: developer_id, solution_id: solution_id, third_party_certification_number: third_party_certification_number, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
66 67 68 69 70 71 72 73 74 |
# File 'lib/visa_acceptance_merged_spec/models/partner.rb', line 66 def self.names @_hash = {} if @_hash.nil? @_hash['original_transaction_id'] = 'originalTransactionId' @_hash['developer_id'] = 'developerId' @_hash['solution_id'] = 'solutionId' @_hash['third_party_certification_number'] = 'thirdPartyCertificationNumber' @_hash end |
.nullables ⇒ Object
An array for nullable fields
87 88 89 |
# File 'lib/visa_acceptance_merged_spec/models/partner.rb', line 87 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
77 78 79 80 81 82 83 84 |
# File 'lib/visa_acceptance_merged_spec/models/partner.rb', line 77 def self.optionals %w[ original_transaction_id developer_id solution_id third_party_certification_number ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
143 144 145 146 147 148 149 |
# File 'lib/visa_acceptance_merged_spec/models/partner.rb', line 143 def inspect class_name = self.class.name.split('::').last "<#{class_name} original_transaction_id: #{@original_transaction_id.inspect}, developer_id:"\ " #{@developer_id.inspect}, solution_id: #{@solution_id.inspect},"\ " third_party_certification_number: #{@third_party_certification_number.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
135 136 137 138 139 140 |
# File 'lib/visa_acceptance_merged_spec/models/partner.rb', line 135 def to_s class_name = self.class.name.split('::').last "<#{class_name} original_transaction_id: #{@original_transaction_id}, developer_id:"\ " #{@developer_id}, solution_id: #{@solution_id}, third_party_certification_number:"\ " #{@third_party_certification_number}, additional_properties: #{@additional_properties}>" end |