Class: VisaAcceptanceMergedSpec::Partner1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::Partner1
- Defined in:
- lib/visa_acceptance_merged_spec/models/partner1.rb
Overview
Partner1 Model.
Instance Attribute Summary collapse
-
#developer_id ⇒ String
Identifier for the developer that helped integrate a partner solution to Visa Acceptance.
-
#original_transaction_id ⇒ String
Value that links the previous transaction to the current follow-on request.
-
#solution_id ⇒ String
Identifier for the partner that is integrated to Visa Acceptance.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(original_transaction_id: SKIP, developer_id: SKIP, solution_id: SKIP, additional_properties: nil) ⇒ Partner1
constructor
A new instance of Partner1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(original_transaction_id: SKIP, developer_id: SKIP, solution_id: SKIP, additional_properties: nil) ⇒ Partner1
Returns a new instance of Partner1.
73 74 75 76 77 78 79 80 81 82 |
# File 'lib/visa_acceptance_merged_spec/models/partner1.rb', line 73 def initialize(original_transaction_id: SKIP, developer_id: SKIP, solution_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @original_transaction_id = original_transaction_id unless original_transaction_id == SKIP @developer_id = developer_id unless developer_id == SKIP @solution_id = solution_id unless solution_id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#developer_id ⇒ String
Identifier for the developer that helped integrate a partner solution to Visa Acceptance. Send this value in all requests that are sent through the partner solutions built by that developer. Visa Acceptance assigns the ID to the developer. Note When you see a developer ID of 999 in reports, the developer ID that was submitted is incorrect.
40 41 42 |
# File 'lib/visa_acceptance_merged_spec/models/partner1.rb', line 40 def developer_id @developer_id end |
#original_transaction_id ⇒ String
Value that links the previous transaction to the current follow-on request. This value is assigned by the client software that is installed on the POS terminal, which makes it available to the terminal’s software and to Visa Acceptance. Therefore, you can use this value to reconcile transactions between Visa Acceptance and the terminal’s software. Visa Acceptance does not forward this value to the processor. Instead, the value is forwarded to the Visa Acceptance reporting functionality. This field is supported only on these processors:
- American Express Direct
- Credit Mutuel-CIC
- FDC Nashville Global
- OmniPay Direct
- SIX Optional field.
30 31 32 |
# File 'lib/visa_acceptance_merged_spec/models/partner1.rb', line 30 def original_transaction_id @original_transaction_id end |
#solution_id ⇒ String
Identifier for the partner that is integrated to Visa Acceptance. Send this value in all requests that are sent through the partner solution. Visa Acceptance assigns the ID to the partner. Note When you see a solutionId of 999 in reports, the solutionId that was submitted is incorrect.
48 49 50 |
# File 'lib/visa_acceptance_merged_spec/models/partner1.rb', line 48 def solution_id @solution_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/visa_acceptance_merged_spec/models/partner1.rb', line 85 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. original_transaction_id = hash.key?('originalTransactionId') ? hash['originalTransactionId'] : SKIP developer_id = hash.key?('developerId') ? hash['developerId'] : SKIP solution_id = hash.key?('solutionId') ? hash['solutionId'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Partner1.new(original_transaction_id: original_transaction_id, developer_id: developer_id, solution_id: solution_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
51 52 53 54 55 56 57 |
# File 'lib/visa_acceptance_merged_spec/models/partner1.rb', line 51 def self.names @_hash = {} if @_hash.nil? @_hash['original_transaction_id'] = 'originalTransactionId' @_hash['developer_id'] = 'developerId' @_hash['solution_id'] = 'solutionId' @_hash end |
.nullables ⇒ Object
An array for nullable fields
69 70 71 |
# File 'lib/visa_acceptance_merged_spec/models/partner1.rb', line 69 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
60 61 62 63 64 65 66 |
# File 'lib/visa_acceptance_merged_spec/models/partner1.rb', line 60 def self.optionals %w[ original_transaction_id developer_id solution_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
117 118 119 120 121 122 |
# File 'lib/visa_acceptance_merged_spec/models/partner1.rb', line 117 def inspect class_name = self.class.name.split('::').last "<#{class_name} original_transaction_id: #{@original_transaction_id.inspect}, developer_id:"\ " #{@developer_id.inspect}, solution_id: #{@solution_id.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
109 110 111 112 113 114 |
# File 'lib/visa_acceptance_merged_spec/models/partner1.rb', line 109 def to_s class_name = self.class.name.split('::').last "<#{class_name} original_transaction_id: #{@original_transaction_id}, developer_id:"\ " #{@developer_id}, solution_id: #{@solution_id}, additional_properties:"\ " #{@additional_properties}>" end |