Class: VisaAcceptanceMergedSpec::Partner16
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::Partner16
- Defined in:
- lib/visa_acceptance_merged_spec/models/partner16.rb
Overview
Partner16 Model.
Instance Attribute Summary collapse
-
#solution_id ⇒ String
Identifier for the partner that is integrated to Visa Acceptance.
-
#third_party_certification_number ⇒ String
Value that identifies the application vendor and application version for a third party gateway.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(solution_id: SKIP, third_party_certification_number: SKIP, additional_properties: nil) ⇒ Partner16
constructor
A new instance of Partner16.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(solution_id: SKIP, third_party_certification_number: SKIP, additional_properties: nil) ⇒ Partner16
Returns a new instance of Partner16.
57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/visa_acceptance_merged_spec/models/partner16.rb', line 57 def initialize(solution_id: SKIP, third_party_certification_number: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @solution_id = solution_id unless solution_id == SKIP unless third_party_certification_number == SKIP @third_party_certification_number = third_party_certification_number end @additional_properties = additional_properties end |
Instance Attribute Details
#solution_id ⇒ String
Identifier for the partner that is integrated to Visa Acceptance. Send this value in all requests that are sent through the partner solution. Visa Acceptance assigns the ID to the partner. Note When you see a solutionId of 999 in reports, the solutionId that was submitted is incorrect.
18 19 20 |
# File 'lib/visa_acceptance_merged_spec/models/partner16.rb', line 18 def solution_id @solution_id end |
#third_party_certification_number ⇒ String
Value that identifies the application vendor and application version for a third party gateway. Visa Acceptance provides you with this value during testing and validation. This field is supported only on Visa Acceptance through VisaNet.
Used by
Authorization, Authorization Reversal, Capture, Credit, Incremental Authorization, and Void Optional field.
PIN debit
Required field for PIN debit credit, PIN debit purchase, or PIN debit reversal request.
33 34 35 |
# File 'lib/visa_acceptance_merged_spec/models/partner16.rb', line 33 def third_party_certification_number @third_party_certification_number end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/visa_acceptance_merged_spec/models/partner16.rb', line 71 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. solution_id = hash.key?('solutionId') ? hash['solutionId'] : SKIP third_party_certification_number = hash.key?('thirdPartyCertificationNumber') ? hash['thirdPartyCertificationNumber'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Partner16.new(solution_id: solution_id, third_party_certification_number: third_party_certification_number, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
36 37 38 39 40 41 42 |
# File 'lib/visa_acceptance_merged_spec/models/partner16.rb', line 36 def self.names @_hash = {} if @_hash.nil? @_hash['solution_id'] = 'solutionId' @_hash['third_party_certification_number'] = 'thirdPartyCertificationNumber' @_hash end |
.nullables ⇒ Object
An array for nullable fields
53 54 55 |
# File 'lib/visa_acceptance_merged_spec/models/partner16.rb', line 53 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
45 46 47 48 49 50 |
# File 'lib/visa_acceptance_merged_spec/models/partner16.rb', line 45 def self.optionals %w[ solution_id third_party_certification_number ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
100 101 102 103 104 105 |
# File 'lib/visa_acceptance_merged_spec/models/partner16.rb', line 100 def inspect class_name = self.class.name.split('::').last "<#{class_name} solution_id: #{@solution_id.inspect}, third_party_certification_number:"\ " #{@third_party_certification_number.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
93 94 95 96 97 |
# File 'lib/visa_acceptance_merged_spec/models/partner16.rb', line 93 def to_s class_name = self.class.name.split('::').last "<#{class_name} solution_id: #{@solution_id}, third_party_certification_number:"\ " #{@third_party_certification_number}, additional_properties: #{@additional_properties}>" end |