Class: VisaAcceptanceMergedSpec::PaymentInformation22
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::PaymentInformation22
- Defined in:
- lib/visa_acceptance_merged_spec/models/payment_information22.rb
Overview
PaymentInformation22 Model.
Instance Attribute Summary collapse
-
#bank ⇒ Bank11
TODO: Write general description for this method.
-
#card ⇒ Card10
TODO: Write general description for this method.
-
#e_wallet ⇒ EWallet9
TODO: Write general description for this method.
-
#options ⇒ Options1
TODO: Write general description for this method.
-
#payment_type ⇒ PaymentType
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(card: SKIP, bank: SKIP, e_wallet: SKIP, options: SKIP, payment_type: SKIP, additional_properties: nil) ⇒ PaymentInformation22
constructor
A new instance of PaymentInformation22.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(card: SKIP, bank: SKIP, e_wallet: SKIP, options: SKIP, payment_type: SKIP, additional_properties: nil) ⇒ PaymentInformation22
Returns a new instance of PaymentInformation22.
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/visa_acceptance_merged_spec/models/payment_information22.rb', line 59 def initialize(card: SKIP, bank: SKIP, e_wallet: SKIP, options: SKIP, payment_type: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @card = card unless card == SKIP @bank = bank unless bank == SKIP @e_wallet = e_wallet unless e_wallet == SKIP @options = unless == SKIP @payment_type = payment_type unless payment_type == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#bank ⇒ Bank11
TODO: Write general description for this method
18 19 20 |
# File 'lib/visa_acceptance_merged_spec/models/payment_information22.rb', line 18 def bank @bank end |
#card ⇒ Card10
TODO: Write general description for this method
14 15 16 |
# File 'lib/visa_acceptance_merged_spec/models/payment_information22.rb', line 14 def card @card end |
#e_wallet ⇒ EWallet9
TODO: Write general description for this method
22 23 24 |
# File 'lib/visa_acceptance_merged_spec/models/payment_information22.rb', line 22 def e_wallet @e_wallet end |
#options ⇒ Options1
TODO: Write general description for this method
26 27 28 |
# File 'lib/visa_acceptance_merged_spec/models/payment_information22.rb', line 26 def @options end |
#payment_type ⇒ PaymentType
TODO: Write general description for this method
30 31 32 |
# File 'lib/visa_acceptance_merged_spec/models/payment_information22.rb', line 30 def payment_type @payment_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/visa_acceptance_merged_spec/models/payment_information22.rb', line 73 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. card = Card10.from_hash(hash['card']) if hash['card'] bank = Bank11.from_hash(hash['bank']) if hash['bank'] e_wallet = EWallet9.from_hash(hash['eWallet']) if hash['eWallet'] = Options1.from_hash(hash['options']) if hash['options'] payment_type = PaymentType.from_hash(hash['paymentType']) if hash['paymentType'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PaymentInformation22.new(card: card, bank: bank, e_wallet: e_wallet, options: , payment_type: payment_type, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/visa_acceptance_merged_spec/models/payment_information22.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['card'] = 'card' @_hash['bank'] = 'bank' @_hash['e_wallet'] = 'eWallet' @_hash['options'] = 'options' @_hash['payment_type'] = 'paymentType' @_hash end |
.nullables ⇒ Object
An array for nullable fields
55 56 57 |
# File 'lib/visa_acceptance_merged_spec/models/payment_information22.rb', line 55 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 47 48 49 50 51 52 |
# File 'lib/visa_acceptance_merged_spec/models/payment_information22.rb', line 44 def self.optionals %w[ card bank e_wallet options payment_type ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
108 109 110 111 112 113 |
# File 'lib/visa_acceptance_merged_spec/models/payment_information22.rb', line 108 def inspect class_name = self.class.name.split('::').last "<#{class_name} card: #{@card.inspect}, bank: #{@bank.inspect}, e_wallet:"\ " #{@e_wallet.inspect}, options: #{@options.inspect}, payment_type:"\ " #{@payment_type.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
100 101 102 103 104 105 |
# File 'lib/visa_acceptance_merged_spec/models/payment_information22.rb', line 100 def to_s class_name = self.class.name.split('::').last "<#{class_name} card: #{@card}, bank: #{@bank}, e_wallet: #{@e_wallet}, options:"\ " #{@options}, payment_type: #{@payment_type}, additional_properties:"\ " #{@additional_properties}>" end |