Class: VisaAcceptanceMergedSpec::ProcessingInformation1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::ProcessingInformation1
- Defined in:
- lib/visa_acceptance_merged_spec/models/processing_information1.rb
Overview
ProcessingInformation1 Model.
Instance Attribute Summary collapse
-
#authorization_options ⇒ AuthorizationOptions2
The possible values for the reply field are: -
true: the airline data was included in the request to the processor. -
#bank_transfer_options ⇒ BankTransferOptions1
TODO: Write general description for this method.
-
#capture_options ⇒ CaptureOptions1
The possible values for the reply field are: -
true: the airline data was included in the request to the processor. -
#enhanced_data_enabled ⇒ TrueClass | FalseClass
The possible values for the reply field are: -
true: the airline data was included in the request to the processor. -
#payment_solution ⇒ String
Type of digital payment solution for the transaction.
-
#purchase_options ⇒ PurchaseOptions1
The possible values for the reply field are: -
true: the airline data was included in the request to the processor.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(bank_transfer_options: SKIP, payment_solution: SKIP, enhanced_data_enabled: SKIP, capture_options: SKIP, authorization_options: SKIP, purchase_options: SKIP, additional_properties: nil) ⇒ ProcessingInformation1
constructor
A new instance of ProcessingInformation1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(bank_transfer_options: SKIP, payment_solution: SKIP, enhanced_data_enabled: SKIP, capture_options: SKIP, authorization_options: SKIP, purchase_options: SKIP, additional_properties: nil) ⇒ ProcessingInformation1
Returns a new instance of ProcessingInformation1.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information1.rb', line 100 def initialize(bank_transfer_options: SKIP, payment_solution: SKIP, enhanced_data_enabled: SKIP, capture_options: SKIP, authorization_options: SKIP, purchase_options: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @bank_transfer_options = unless == SKIP @payment_solution = payment_solution unless payment_solution == SKIP @enhanced_data_enabled = enhanced_data_enabled unless enhanced_data_enabled == SKIP @capture_options = unless == SKIP @authorization_options = unless == SKIP @purchase_options = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#authorization_options ⇒ AuthorizationOptions2
The possible values for the reply field are:
true: the airline data was included in the request to the processor.false: the airline data was not included in the request to the processor. Returned by authorization, capture, or credit services.
61 62 63 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information1.rb', line 61 def @authorization_options end |
#bank_transfer_options ⇒ BankTransferOptions1
TODO: Write general description for this method
14 15 16 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information1.rb', line 14 def @bank_transfer_options end |
#capture_options ⇒ CaptureOptions1
The possible values for the reply field are:
true: the airline data was included in the request to the processor.false: the airline data was not included in the request to the processor. Returned by authorization, capture, or credit services.
53 54 55 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information1.rb', line 53 def @capture_options end |
#enhanced_data_enabled ⇒ TrueClass | FalseClass
The possible values for the reply field are:
true: the airline data was included in the request to the processor.false: the airline data was not included in the request to the processor. Returned by authorization, capture, or credit services.
45 46 47 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information1.rb', line 45 def enhanced_data_enabled @enhanced_data_enabled end |
#payment_solution ⇒ String
Type of digital payment solution for the transaction. Possible Values:
visacheckout: Visa Checkout. This value is required for Visa Checkout transactions. For details, seepayment_solutionfield description in [Visa Checkout Using the REST API.](001: Apple Pay.004: Visa Acceptance In-App Solution.005: Masterpass. This value is required for Masterpass transactions on OmniPay Direct.006: Android Pay.007: Chase Pay.008: Samsung Pay.012: Google Pay.013: Visa Acceptance P2PE Decryption014: Mastercard credential on file (COF) payment network token. Returned in authorizations that use a payment network token associated with a TMS token.015: Visa credential on file (COF) payment network token. Returned in authorizations that use a payment network token associated with a TMS token.027: Click to Pay.
37 38 39 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information1.rb', line 37 def payment_solution @payment_solution end |
#purchase_options ⇒ PurchaseOptions1
The possible values for the reply field are:
true: the airline data was included in the request to the processor.false: the airline data was not included in the request to the processor. Returned by authorization, capture, or credit services.
69 70 71 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information1.rb', line 69 def @purchase_options end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information1.rb', line 117 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. = BankTransferOptions1.from_hash(hash['bankTransferOptions']) if hash['bankTransferOptions'] payment_solution = hash.key?('paymentSolution') ? hash['paymentSolution'] : SKIP enhanced_data_enabled = hash.key?('enhancedDataEnabled') ? hash['enhancedDataEnabled'] : SKIP = CaptureOptions1.from_hash(hash['captureOptions']) if hash['captureOptions'] = AuthorizationOptions2.from_hash(hash['authorizationOptions']) if hash['authorizationOptions'] = PurchaseOptions1.from_hash(hash['purchaseOptions']) if hash['purchaseOptions'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProcessingInformation1.new(bank_transfer_options: , payment_solution: payment_solution, enhanced_data_enabled: enhanced_data_enabled, capture_options: , authorization_options: , purchase_options: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
72 73 74 75 76 77 78 79 80 81 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information1.rb', line 72 def self.names @_hash = {} if @_hash.nil? @_hash['bank_transfer_options'] = 'bankTransferOptions' @_hash['payment_solution'] = 'paymentSolution' @_hash['enhanced_data_enabled'] = 'enhancedDataEnabled' @_hash['capture_options'] = 'captureOptions' @_hash['authorization_options'] = 'authorizationOptions' @_hash['purchase_options'] = 'purchaseOptions' @_hash end |
.nullables ⇒ Object
An array for nullable fields
96 97 98 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information1.rb', line 96 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
84 85 86 87 88 89 90 91 92 93 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information1.rb', line 84 def self.optionals %w[ bank_transfer_options payment_solution enhanced_data_enabled capture_options authorization_options purchase_options ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
161 162 163 164 165 166 167 168 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information1.rb', line 161 def inspect class_name = self.class.name.split('::').last "<#{class_name} bank_transfer_options: #{@bank_transfer_options.inspect}, payment_solution:"\ " #{@payment_solution.inspect}, enhanced_data_enabled: #{@enhanced_data_enabled.inspect},"\ " capture_options: #{@capture_options.inspect}, authorization_options:"\ " #{@authorization_options.inspect}, purchase_options: #{@purchase_options.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
152 153 154 155 156 157 158 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information1.rb', line 152 def to_s class_name = self.class.name.split('::').last "<#{class_name} bank_transfer_options: #{@bank_transfer_options}, payment_solution:"\ " #{@payment_solution}, enhanced_data_enabled: #{@enhanced_data_enabled}, capture_options:"\ " #{@capture_options}, authorization_options: #{@authorization_options}, purchase_options:"\ " #{@purchase_options}, additional_properties: #{@additional_properties}>" end |