Class: VisaAcceptanceMergedSpec::ProcessingInformation18
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::ProcessingInformation18
- Defined in:
- lib/visa_acceptance_merged_spec/models/processing_information18.rb
Overview
ProcessingInformation18 Model.
Instance Attribute Summary collapse
-
#action_list ⇒ Array[String]
Array of actions (one or more) to be included in the payment to invoke bundled services along with payment status.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(action_list: SKIP, additional_properties: nil) ⇒ ProcessingInformation18
constructor
A new instance of ProcessingInformation18.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(action_list: SKIP, additional_properties: nil) ⇒ ProcessingInformation18
Returns a new instance of ProcessingInformation18.
51 52 53 54 55 56 57 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information18.rb', line 51 def initialize(action_list: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @action_list = action_list unless action_list == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#action_list ⇒ Array[String]
Array of actions (one or more) to be included in the payment to invoke bundled services along with payment status. Possible values are one or more of follows:
AP_STATUS: Use this when Alternative Payment check status service is requested.AP_SESSION_STATUS: Use this when Alternative Payment check status service for Paypal, Klarna is requested.AP_INITIATE_STATUS: Use this when Alternative Payment check status service for KCP is requested.AP_ORDER_STATUS: Use this when Alternative Payment check status service for order status request.AP_AUTH_STATUS: Use this when Alternative Payment check status service for auth status request.AP_CAPTURE_STATUS: Use this when Alternative Payment check status service for capture status request.AP_REFUND_STATUS: Use this when Alternative Payment check status service for refund status request.
30 31 32 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information18.rb', line 30 def action_list @action_list end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information18.rb', line 60 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. action_list = hash.key?('actionList') ? hash['actionList'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProcessingInformation18.new(action_list: action_list, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information18.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['action_list'] = 'actionList' @_hash end |
.nullables ⇒ Object
An array for nullable fields
47 48 49 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information18.rb', line 47 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
40 41 42 43 44 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information18.rb', line 40 def self.optionals %w[ action_list ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
86 87 88 89 90 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information18.rb', line 86 def inspect class_name = self.class.name.split('::').last "<#{class_name} action_list: #{@action_list.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
79 80 81 82 83 |
# File 'lib/visa_acceptance_merged_spec/models/processing_information18.rb', line 79 def to_s class_name = self.class.name.split('::').last "<#{class_name} action_list: #{@action_list}, additional_properties:"\ " #{@additional_properties}>" end |