Class: VisaAcceptanceMergedSpec::ProcessorInformation4
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::ProcessorInformation4
- Defined in:
- lib/visa_acceptance_merged_spec/models/processor_information4.rb
Overview
ProcessorInformation4 Model.
Instance Attribute Summary collapse
-
#forwarded_acquirer_code ⇒ String
Name of the Japanese acquirer that processed the transaction.
-
#master_card_service_code ⇒ String
Mastercard service that was used for the transaction.
-
#master_card_service_reply_code ⇒ String
Result of the Mastercard card-on-file token service.
-
#network_transaction_id ⇒ String
Same value as
processorInformation.transactionId. -
#provider_response ⇒ String
Processor response to the API request.
-
#response_category_code ⇒ String
Processor-defined response category code.
-
#response_code ⇒ String
For most processors, this is the error message sent directly from the bank.
-
#response_details ⇒ String
This field might contain information about a decline.
-
#transaction_id ⇒ String
Processor transaction ID.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(transaction_id: SKIP, response_code: SKIP, network_transaction_id: SKIP, response_category_code: SKIP, forwarded_acquirer_code: SKIP, master_card_service_code: SKIP, master_card_service_reply_code: SKIP, response_details: SKIP, provider_response: SKIP, additional_properties: nil) ⇒ ProcessorInformation4
constructor
A new instance of ProcessorInformation4.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(transaction_id: SKIP, response_code: SKIP, network_transaction_id: SKIP, response_category_code: SKIP, forwarded_acquirer_code: SKIP, master_card_service_code: SKIP, master_card_service_reply_code: SKIP, response_details: SKIP, provider_response: SKIP, additional_properties: nil) ⇒ ProcessorInformation4
Returns a new instance of ProcessorInformation4.
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/visa_acceptance_merged_spec/models/processor_information4.rb', line 171 def initialize(transaction_id: SKIP, response_code: SKIP, network_transaction_id: SKIP, response_category_code: SKIP, forwarded_acquirer_code: SKIP, master_card_service_code: SKIP, master_card_service_reply_code: SKIP, response_details: SKIP, provider_response: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @transaction_id = transaction_id unless transaction_id == SKIP @response_code = response_code unless response_code == SKIP @network_transaction_id = network_transaction_id unless network_transaction_id == SKIP @response_category_code = response_category_code unless response_category_code == SKIP @forwarded_acquirer_code = forwarded_acquirer_code unless forwarded_acquirer_code == SKIP @master_card_service_code = master_card_service_code unless master_card_service_code == SKIP unless master_card_service_reply_code == SKIP @master_card_service_reply_code = master_card_service_reply_code end @response_details = response_details unless response_details == SKIP @provider_response = provider_response unless provider_response == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#forwarded_acquirer_code ⇒ String
Name of the Japanese acquirer that processed the transaction. Returned only for JCN Gateway. Please contact the Visa Acceptance Japan Support Group for more information.
86 87 88 |
# File 'lib/visa_acceptance_merged_spec/models/processor_information4.rb', line 86 def forwarded_acquirer_code @forwarded_acquirer_code end |
#master_card_service_code ⇒ String
Mastercard service that was used for the transaction. Mastercard provides this value to Visa Acceptance. Possible value:
- 53: Mastercard card-on-file token service
Visa Acceptance through VisaNet
The value for this field corresponds to the following data in the TC 33 capture file:
- Record: CP01 TCR6
- Position: 133-134
- Field: Mastercard Merchant on-behalf service. Note This field is returned only for Visa Acceptance through VisaNet.
100 101 102 |
# File 'lib/visa_acceptance_merged_spec/models/processor_information4.rb', line 100 def master_card_service_code @master_card_service_code end |
#master_card_service_reply_code ⇒ String
Result of the Mastercard card-on-file token service. Mastercard provides this value to Visa Acceptance. Possible values:
C: Service completed successfully.-
F: One of the following:- Incorrect Mastercard POS entry mode. The Mastercard POS entry mode should be 81 for an authorization or authorization reversal.
- Incorrect Mastercard POS entry mode. The Mastercard POS entry mode should be 01 for a tokenized request.
- Token requestor ID is missing or formatted incorrectly.
-
I: One of the following:- Invalid token requestor ID.
- Suspended or deactivated token.
- Invalid token (not in mapping table).
T: Invalid combination of token requestor ID and token.U: Expired token.W: Primary account number (PAN) listed in electronic warning bulletin. Note This field is returned only for Visa Acceptance through VisaNet.
124 125 126 |
# File 'lib/visa_acceptance_merged_spec/models/processor_information4.rb', line 124 def master_card_service_reply_code @master_card_service_reply_code end |
#network_transaction_id ⇒ String
Same value as processorInformation.transactionId
65 66 67 |
# File 'lib/visa_acceptance_merged_spec/models/processor_information4.rb', line 65 def network_transaction_id @network_transaction_id end |
#provider_response ⇒ String
Processor response to the API request.
134 135 136 |
# File 'lib/visa_acceptance_merged_spec/models/processor_information4.rb', line 134 def provider_response @provider_response end |
#response_category_code ⇒ String
Processor-defined response category code. The associated detail error code
is in the processorInformation.responseCode or
issuerInformation.responseCode
field of the service you requested.
This field is supported only for:
- Japanese issuers
- Domestic transactions in Japan
- Comercio Latino—processor transaction ID required for troubleshooting
Maximum length for processors
- Comercio Latino: 36
- All other processors: 3
79 80 81 |
# File 'lib/visa_acceptance_merged_spec/models/processor_information4.rb', line 79 def response_category_code @response_category_code end |
#response_code ⇒ String
For most processors, this is the error message sent directly from the bank. Returned only when the processor returns this value. Important Do not use this field to evaluate the result of the authorization.
PIN debit
Response value that is returned by the processor or bank. Important Do not use this field to evaluate the results of the transaction request. Returned by PIN debit credit, PIN debit purchase, and PIN debit reversal.
AIBMS
If this value is 08, you can accept the transaction if the customer
provides you with identification.
Atos
This value is the response code sent from Atos and it might also include
the response code from the bank.
Format: aa,bb with the two values separated by a comma and where:
aais the two-digit error message from Atos.bbis the optional two-digit error message from the bank.
Comercio Latino
This value is the status code and the error or response code received from
the processor separated by a colon.
Format: [status code]:E[error code] or [status code]:R[response code]
Example 2:R06
JCN Gateway
Processor-defined detail error code. The associated response category code
is in the processorInformation.responseCategoryCode field.
String (3)
paypalgateway
Processor generated ID for the itemized detail.
61 62 63 |
# File 'lib/visa_acceptance_merged_spec/models/processor_information4.rb', line 61 def response_code @response_code end |
#response_details ⇒ String
This field might contain information about a decline. This field is supported only for Visa Acceptance through VisaNet.
130 131 132 |
# File 'lib/visa_acceptance_merged_spec/models/processor_information4.rb', line 130 def response_details @response_details end |
#transaction_id ⇒ String
Processor transaction ID. This value identifies the transaction on a host system. This value is supported only for Moneris. It contains this information:
- Terminal used to process the transaction
- Shift during which the transaction took place
- Batch number
- Transaction number within the batch You must store this value. If you give the customer a receipt, display this value on the receipt. Example For the value 66012345001069003:
- Terminal ID = 66012345
- Shift number = 001
- Batch number = 069
- Transaction number = 003
28 29 30 |
# File 'lib/visa_acceptance_merged_spec/models/processor_information4.rb', line 28 def transaction_id @transaction_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/visa_acceptance_merged_spec/models/processor_information4.rb', line 196 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. transaction_id = hash.key?('transactionId') ? hash['transactionId'] : SKIP response_code = hash.key?('responseCode') ? hash['responseCode'] : SKIP network_transaction_id = hash.key?('networkTransactionId') ? hash['networkTransactionId'] : SKIP response_category_code = hash.key?('responseCategoryCode') ? hash['responseCategoryCode'] : SKIP forwarded_acquirer_code = hash.key?('forwardedAcquirerCode') ? hash['forwardedAcquirerCode'] : SKIP master_card_service_code = hash.key?('masterCardServiceCode') ? hash['masterCardServiceCode'] : SKIP master_card_service_reply_code = hash.key?('masterCardServiceReplyCode') ? hash['masterCardServiceReplyCode'] : SKIP response_details = hash.key?('responseDetails') ? hash['responseDetails'] : SKIP provider_response = hash.key?('providerResponse') ? hash['providerResponse'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProcessorInformation4.new(transaction_id: transaction_id, response_code: response_code, network_transaction_id: network_transaction_id, response_category_code: response_category_code, forwarded_acquirer_code: forwarded_acquirer_code, master_card_service_code: master_card_service_code, master_card_service_reply_code: master_card_service_reply_code, response_details: response_details, provider_response: provider_response, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/visa_acceptance_merged_spec/models/processor_information4.rb', line 137 def self.names @_hash = {} if @_hash.nil? @_hash['transaction_id'] = 'transactionId' @_hash['response_code'] = 'responseCode' @_hash['network_transaction_id'] = 'networkTransactionId' @_hash['response_category_code'] = 'responseCategoryCode' @_hash['forwarded_acquirer_code'] = 'forwardedAcquirerCode' @_hash['master_card_service_code'] = 'masterCardServiceCode' @_hash['master_card_service_reply_code'] = 'masterCardServiceReplyCode' @_hash['response_details'] = 'responseDetails' @_hash['provider_response'] = 'providerResponse' @_hash end |
.nullables ⇒ Object
An array for nullable fields
167 168 169 |
# File 'lib/visa_acceptance_merged_spec/models/processor_information4.rb', line 167 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/visa_acceptance_merged_spec/models/processor_information4.rb', line 152 def self.optionals %w[ transaction_id response_code network_transaction_id response_category_code forwarded_acquirer_code master_card_service_code master_card_service_reply_code response_details provider_response ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/visa_acceptance_merged_spec/models/processor_information4.rb', line 250 def inspect class_name = self.class.name.split('::').last "<#{class_name} transaction_id: #{@transaction_id.inspect}, response_code:"\ " #{@response_code.inspect}, network_transaction_id: #{@network_transaction_id.inspect},"\ " response_category_code: #{@response_category_code.inspect}, forwarded_acquirer_code:"\ " #{@forwarded_acquirer_code.inspect}, master_card_service_code:"\ " #{@master_card_service_code.inspect}, master_card_service_reply_code:"\ " #{@master_card_service_reply_code.inspect}, response_details:"\ " #{@response_details.inspect}, provider_response: #{@provider_response.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
238 239 240 241 242 243 244 245 246 247 |
# File 'lib/visa_acceptance_merged_spec/models/processor_information4.rb', line 238 def to_s class_name = self.class.name.split('::').last "<#{class_name} transaction_id: #{@transaction_id}, response_code: #{@response_code},"\ " network_transaction_id: #{@network_transaction_id}, response_category_code:"\ " #{@response_category_code}, forwarded_acquirer_code: #{@forwarded_acquirer_code},"\ " master_card_service_code: #{@master_card_service_code}, master_card_service_reply_code:"\ " #{@master_card_service_reply_code}, response_details: #{@response_details},"\ " provider_response: #{@provider_response}, additional_properties:"\ " #{@additional_properties}>" end |