Class: VisaAcceptanceMergedSpec::ProcessorInformation6
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::ProcessorInformation6
- Defined in:
- lib/visa_acceptance_merged_spec/models/processor_information6.rb
Overview
ProcessorInformation6 Model.
Instance Attribute Summary collapse
-
#network_transaction_id ⇒ String
Network Transaction Identifier Applicable for online capture transactions only.
-
#provider_response ⇒ String
Processor response to the API request.
-
#response_code ⇒ String
For most processors, this is the error message sent directly from the bank.
-
#response_details ⇒ String
The processor code that describes why the transaction state is pending or reversed.
-
#transaction_id ⇒ String
Processor transaction ID.
-
#update_time_utc ⇒ String
The date and time when the transaction was last updated, in Internet date and time format.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(transaction_id: SKIP, network_transaction_id: SKIP, response_details: SKIP, response_code: SKIP, provider_response: SKIP, update_time_utc: SKIP, additional_properties: nil) ⇒ ProcessorInformation6
constructor
A new instance of ProcessorInformation6.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(transaction_id: SKIP, network_transaction_id: SKIP, response_details: SKIP, response_code: SKIP, provider_response: SKIP, update_time_utc: SKIP, additional_properties: nil) ⇒ ProcessorInformation6
Returns a new instance of ProcessorInformation6.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/visa_acceptance_merged_spec/models/processor_information6.rb', line 111 def initialize(transaction_id: SKIP, network_transaction_id: SKIP, response_details: SKIP, response_code: SKIP, provider_response: SKIP, update_time_utc: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @transaction_id = transaction_id unless transaction_id == SKIP @network_transaction_id = network_transaction_id unless network_transaction_id == SKIP @response_details = response_details unless response_details == SKIP @response_code = response_code unless response_code == SKIP @provider_response = provider_response unless provider_response == SKIP @update_time_utc = update_time_utc unless update_time_utc == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#network_transaction_id ⇒ String
Network Transaction Identifier Applicable for online capture transactions only.
33 34 35 |
# File 'lib/visa_acceptance_merged_spec/models/processor_information6.rb', line 33 def network_transaction_id @network_transaction_id end |
#provider_response ⇒ String
Processor response to the API request.
75 76 77 |
# File 'lib/visa_acceptance_merged_spec/models/processor_information6.rb', line 75 def provider_response @provider_response end |
#response_code ⇒ String
For most processors, this is the error message sent directly from the bank. Returned only when the processor returns this value. Important Do not use this field to evaluate the result of the authorization.
PIN debit
Response value that is returned by the processor or bank. Important Do not use this field to evaluate the results of the transaction request. Returned by PIN debit credit, PIN debit purchase, and PIN debit reversal.
AIBMS
If this value is 08, you can accept the transaction if the customer
provides you with identification.
Atos
This value is the response code sent from Atos and it might also include
the response code from the bank.
Format: aa,bb with the two values separated by a comma and where:
aais the two-digit error message from Atos.bbis the optional two-digit error message from the bank.
Comercio Latino
This value is the status code and the error or response code received from
the processor separated by a colon.
Format: [status code]:E[error code] or [status code]:R[response code]
Example 2:R06
JCN Gateway
Processor-defined detail error code. The associated response category code
is in the processorInformation.responseCategoryCode field.
String (3)
paypalgateway
Processor generated ID for the itemized detail.
71 72 73 |
# File 'lib/visa_acceptance_merged_spec/models/processor_information6.rb', line 71 def response_code @response_code end |
#response_details ⇒ String
The processor code that describes why the transaction state is pending or reversed.
38 39 40 |
# File 'lib/visa_acceptance_merged_spec/models/processor_information6.rb', line 38 def response_details @response_details end |
#transaction_id ⇒ String
Processor transaction ID. This value identifies the transaction on a host system. This value is supported only for Moneris. It contains this information:
- Terminal used to process the transaction
- Shift during which the transaction took place
- Batch number
- Transaction number within the batch You must store this value. If you give the customer a receipt, display this value on the receipt. Example For the value 66012345001069003:
- Terminal ID = 66012345
- Shift number = 001
- Batch number = 069
- Transaction number = 003
28 29 30 |
# File 'lib/visa_acceptance_merged_spec/models/processor_information6.rb', line 28 def transaction_id @transaction_id end |
#update_time_utc ⇒ String
The date and time when the transaction was last updated, in Internet date and time format.
80 81 82 |
# File 'lib/visa_acceptance_merged_spec/models/processor_information6.rb', line 80 def update_time_utc @update_time_utc end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/visa_acceptance_merged_spec/models/processor_information6.rb', line 128 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. transaction_id = hash.key?('transactionId') ? hash['transactionId'] : SKIP network_transaction_id = hash.key?('networkTransactionId') ? hash['networkTransactionId'] : SKIP response_details = hash.key?('responseDetails') ? hash['responseDetails'] : SKIP response_code = hash.key?('responseCode') ? hash['responseCode'] : SKIP provider_response = hash.key?('providerResponse') ? hash['providerResponse'] : SKIP update_time_utc = hash.key?('updateTimeUtc') ? hash['updateTimeUtc'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProcessorInformation6.new(transaction_id: transaction_id, network_transaction_id: network_transaction_id, response_details: response_details, response_code: response_code, provider_response: provider_response, update_time_utc: update_time_utc, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
83 84 85 86 87 88 89 90 91 92 |
# File 'lib/visa_acceptance_merged_spec/models/processor_information6.rb', line 83 def self.names @_hash = {} if @_hash.nil? @_hash['transaction_id'] = 'transactionId' @_hash['network_transaction_id'] = 'networkTransactionId' @_hash['response_details'] = 'responseDetails' @_hash['response_code'] = 'responseCode' @_hash['provider_response'] = 'providerResponse' @_hash['update_time_utc'] = 'updateTimeUtc' @_hash end |
.nullables ⇒ Object
An array for nullable fields
107 108 109 |
# File 'lib/visa_acceptance_merged_spec/models/processor_information6.rb', line 107 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
95 96 97 98 99 100 101 102 103 104 |
# File 'lib/visa_acceptance_merged_spec/models/processor_information6.rb', line 95 def self.optionals %w[ transaction_id network_transaction_id response_details response_code provider_response update_time_utc ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
170 171 172 173 174 175 176 177 |
# File 'lib/visa_acceptance_merged_spec/models/processor_information6.rb', line 170 def inspect class_name = self.class.name.split('::').last "<#{class_name} transaction_id: #{@transaction_id.inspect}, network_transaction_id:"\ " #{@network_transaction_id.inspect}, response_details: #{@response_details.inspect},"\ " response_code: #{@response_code.inspect}, provider_response:"\ " #{@provider_response.inspect}, update_time_utc: #{@update_time_utc.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
161 162 163 164 165 166 167 |
# File 'lib/visa_acceptance_merged_spec/models/processor_information6.rb', line 161 def to_s class_name = self.class.name.split('::').last "<#{class_name} transaction_id: #{@transaction_id}, network_transaction_id:"\ " #{@network_transaction_id}, response_details: #{@response_details}, response_code:"\ " #{@response_code}, provider_response: #{@provider_response}, update_time_utc:"\ " #{@update_time_utc}, additional_properties: #{@additional_properties}>" end |