Class: VisaAcceptanceMergedSpec::PtsV2CreateBillingAgreementPost201Response
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::PtsV2CreateBillingAgreementPost201Response
- Defined in:
- lib/visa_acceptance_merged_spec/models/pts_v2_create_billing_agreement_post201_response.rb
Overview
PtsV2CreateBillingAgreementPost201Response Model.
Instance Attribute Summary collapse
-
#agreement_information ⇒ AgreementInformation7
The status of the billing agreement.
-
#client_reference_information ⇒ ClientReferenceInformation29
The status of the billing agreement.
-
#id ⇒ String
An unique identification number generated by Visa Acceptance to identify the submitted request.
-
#installment_information ⇒ InstallmentInformation5
The status of the billing agreement.
-
#links ⇒ Links15
TODO: Write general description for this method.
-
#processor_information ⇒ ProcessorInformation16
The status of the billing agreement.
-
#reconciliation_id ⇒ String
Reference number for the transaction.
-
#risk_information ⇒ RiskInformation2
The status of the billing agreement.
-
#status ⇒ String
The status of the billing agreement.
-
#submit_time_utc ⇒ String
Time of request in UTC.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, status: SKIP, processor_information: SKIP, installment_information: SKIP, agreement_information: SKIP, client_reference_information: SKIP, risk_information: SKIP, reconciliation_id: SKIP, additional_properties: nil) ⇒ PtsV2CreateBillingAgreementPost201Response
constructor
A new instance of PtsV2CreateBillingAgreementPost201Response.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, status: SKIP, processor_information: SKIP, installment_information: SKIP, agreement_information: SKIP, client_reference_information: SKIP, risk_information: SKIP, reconciliation_id: SKIP, additional_properties: nil) ⇒ PtsV2CreateBillingAgreementPost201Response
Returns a new instance of PtsV2CreateBillingAgreementPost201Response.
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_create_billing_agreement_post201_response.rb', line 144 def initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, status: SKIP, processor_information: SKIP, installment_information: SKIP, agreement_information: SKIP, client_reference_information: SKIP, risk_information: SKIP, reconciliation_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @links = links unless links == SKIP @id = id unless id == SKIP @submit_time_utc = submit_time_utc unless submit_time_utc == SKIP @status = status unless status == SKIP @processor_information = processor_information unless processor_information == SKIP @installment_information = installment_information unless installment_information == SKIP @agreement_information = agreement_information unless agreement_information == SKIP unless client_reference_information == SKIP @client_reference_information = client_reference_information end @risk_information = risk_information unless risk_information == SKIP @reconciliation_id = reconciliation_id unless reconciliation_id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#agreement_information ⇒ AgreementInformation7
The status of the billing agreement. Possible value is:
- PENDING
- REVOKED
- ACTIVE
- FAILED
- EXPIRED
- INACTIVE
74 75 76 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_create_billing_agreement_post201_response.rb', line 74 def agreement_information @agreement_information end |
#client_reference_information ⇒ ClientReferenceInformation29
The status of the billing agreement. Possible value is:
- PENDING
- REVOKED
- ACTIVE
- FAILED
- EXPIRED
- INACTIVE
85 86 87 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_create_billing_agreement_post201_response.rb', line 85 def client_reference_information @client_reference_information end |
#id ⇒ String
An unique identification number generated by Visa Acceptance to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
22 23 24 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_create_billing_agreement_post201_response.rb', line 22 def id @id end |
#installment_information ⇒ InstallmentInformation5
The status of the billing agreement. Possible value is:
- PENDING
- REVOKED
- ACTIVE
- FAILED
- EXPIRED
- INACTIVE
63 64 65 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_create_billing_agreement_post201_response.rb', line 63 def installment_information @installment_information end |
#links ⇒ Links15
TODO: Write general description for this method
14 15 16 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_create_billing_agreement_post201_response.rb', line 14 def links @links end |
#processor_information ⇒ ProcessorInformation16
The status of the billing agreement. Possible value is:
- PENDING
- REVOKED
- ACTIVE
- FAILED
- EXPIRED
- INACTIVE
52 53 54 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_create_billing_agreement_post201_response.rb', line 52 def processor_information @processor_information end |
#reconciliation_id ⇒ String
Reference number for the transaction. Depending on how your Visa Acceptance account is configured, this value could either be provided in the API request or generated by Visa Acceptance. The actual value used in the request to the processor is provided back to you by Visa Acceptance in the response.
105 106 107 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_create_billing_agreement_post201_response.rb', line 105 def reconciliation_id @reconciliation_id end |
#risk_information ⇒ RiskInformation2
The status of the billing agreement. Possible value is:
- PENDING
- REVOKED
- ACTIVE
- FAILED
- EXPIRED
- INACTIVE
96 97 98 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_create_billing_agreement_post201_response.rb', line 96 def risk_information @risk_information end |
#status ⇒ String
The status of the billing agreement. Possible value is:
- PENDING
- REVOKED
- ACTIVE
- FAILED
- EXPIRED
- INACTIVE
41 42 43 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_create_billing_agreement_post201_response.rb', line 41 def status @status end |
#submit_time_utc ⇒ String
Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ
Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57
(10:47:57 p.m.).
The T separates the date and the time. The Z indicates UTC.
Returned by Visa Acceptance for all services.
30 31 32 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_create_billing_agreement_post201_response.rb', line 30 def submit_time_utc @submit_time_utc end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_create_billing_agreement_post201_response.rb', line 169 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. links = Links15.from_hash(hash['_links']) if hash['_links'] id = hash.key?('id') ? hash['id'] : SKIP submit_time_utc = hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP processor_information = ProcessorInformation16.from_hash(hash['processorInformation']) if hash['processorInformation'] installment_information = InstallmentInformation5.from_hash(hash['installmentInformation']) if hash['installmentInformation'] agreement_information = AgreementInformation7.from_hash(hash['agreementInformation']) if hash['agreementInformation'] if hash['clientReferenceInformation'] client_reference_information = ClientReferenceInformation29.from_hash(hash['clientReferenceInformation']) end risk_information = RiskInformation2.from_hash(hash['riskInformation']) if hash['riskInformation'] reconciliation_id = hash.key?('reconciliationId') ? hash['reconciliationId'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PtsV2CreateBillingAgreementPost201Response.new(links: links, id: id, submit_time_utc: submit_time_utc, status: status, processor_information: processor_information, installment_information: installment_information, agreement_information: agreement_information, client_reference_information: client_reference_information, risk_information: risk_information, reconciliation_id: reconciliation_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_create_billing_agreement_post201_response.rb', line 108 def self.names @_hash = {} if @_hash.nil? @_hash['links'] = '_links' @_hash['id'] = 'id' @_hash['submit_time_utc'] = 'submitTimeUtc' @_hash['status'] = 'status' @_hash['processor_information'] = 'processorInformation' @_hash['installment_information'] = 'installmentInformation' @_hash['agreement_information'] = 'agreementInformation' @_hash['client_reference_information'] = 'clientReferenceInformation' @_hash['risk_information'] = 'riskInformation' @_hash['reconciliation_id'] = 'reconciliationId' @_hash end |
.nullables ⇒ Object
An array for nullable fields
140 141 142 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_create_billing_agreement_post201_response.rb', line 140 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_create_billing_agreement_post201_response.rb', line 124 def self.optionals %w[ links id submit_time_utc status processor_information installment_information agreement_information client_reference_information risk_information reconciliation_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_create_billing_agreement_post201_response.rb', line 225 def inspect class_name = self.class.name.split('::').last "<#{class_name} links: #{@links.inspect}, id: #{@id.inspect}, submit_time_utc:"\ " #{@submit_time_utc.inspect}, status: #{@status.inspect}, processor_information:"\ " #{@processor_information.inspect}, installment_information:"\ " #{@installment_information.inspect}, agreement_information:"\ " #{@agreement_information.inspect}, client_reference_information:"\ " #{@client_reference_information.inspect}, risk_information: #{@risk_information.inspect},"\ " reconciliation_id: #{@reconciliation_id.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
214 215 216 217 218 219 220 221 222 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_create_billing_agreement_post201_response.rb', line 214 def to_s class_name = self.class.name.split('::').last "<#{class_name} links: #{@links}, id: #{@id}, submit_time_utc: #{@submit_time_utc}, status:"\ " #{@status}, processor_information: #{@processor_information}, installment_information:"\ " #{@installment_information}, agreement_information: #{@agreement_information},"\ " client_reference_information: #{@client_reference_information}, risk_information:"\ " #{@risk_information}, reconciliation_id: #{@reconciliation_id}, additional_properties:"\ " #{@additional_properties}>" end |