Class: VisaAcceptanceMergedSpec::PtsV2PaymentsOrderPost201Response
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::PtsV2PaymentsOrderPost201Response
- Defined in:
- lib/visa_acceptance_merged_spec/models/pts_v2_payments_order_post201_response.rb
Overview
PtsV2PaymentsOrderPost201Response Model.
Instance Attribute Summary collapse
-
#buyer_information ⇒ BuyerInformation8
An unique identification number generated by Visa Acceptance to identify the submitted request.
-
#client_reference_information ⇒ ClientReferenceInformation3
An unique identification number generated by Visa Acceptance to identify the submitted request.
-
#id ⇒ String
An unique identification number generated by Visa Acceptance to identify the submitted request.
-
#order_information ⇒ OrderInformation25
An unique identification number generated by Visa Acceptance to identify the submitted request.
-
#payment_information ⇒ PaymentInformation21
An unique identification number generated by Visa Acceptance to identify the submitted request.
-
#processing_information ⇒ ProcessingInformation22
An unique identification number generated by Visa Acceptance to identify the submitted request.
-
#processor_information ⇒ ProcessorInformation19
An unique identification number generated by Visa Acceptance to identify the submitted request.
-
#reconciliation_id ⇒ String
Reference number for the transaction.
-
#risk_information ⇒ RiskInformation4
Reference number for the transaction.
-
#status ⇒ String
The status of the submitted transaction.
-
#submit_time_utc ⇒ String
Time of request in UTC.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id: SKIP, client_reference_information: SKIP, processor_information: SKIP, order_information: SKIP, payment_information: SKIP, processing_information: SKIP, buyer_information: SKIP, submit_time_utc: SKIP, status: SKIP, reconciliation_id: SKIP, risk_information: SKIP, additional_properties: nil) ⇒ PtsV2PaymentsOrderPost201Response
constructor
A new instance of PtsV2PaymentsOrderPost201Response.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id: SKIP, client_reference_information: SKIP, processor_information: SKIP, order_information: SKIP, payment_information: SKIP, processing_information: SKIP, buyer_information: SKIP, submit_time_utc: SKIP, status: SKIP, reconciliation_id: SKIP, risk_information: SKIP, additional_properties: nil) ⇒ PtsV2PaymentsOrderPost201Response
Returns a new instance of PtsV2PaymentsOrderPost201Response.
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 144 def initialize(id: SKIP, client_reference_information: SKIP, processor_information: SKIP, order_information: SKIP, payment_information: SKIP, processing_information: SKIP, buyer_information: SKIP, submit_time_utc: SKIP, status: SKIP, reconciliation_id: SKIP, risk_information: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id unless id == SKIP unless client_reference_information == SKIP @client_reference_information = client_reference_information end @processor_information = processor_information unless processor_information == SKIP @order_information = order_information unless order_information == SKIP @payment_information = payment_information unless payment_information == SKIP @processing_information = processing_information unless processing_information == SKIP @buyer_information = buyer_information unless buyer_information == SKIP @submit_time_utc = submit_time_utc unless submit_time_utc == SKIP @status = status unless status == SKIP @reconciliation_id = reconciliation_id unless reconciliation_id == SKIP @risk_information = risk_information unless risk_information == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#buyer_information ⇒ BuyerInformation8
An unique identification number generated by Visa Acceptance to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
66 67 68 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 66 def buyer_information @buyer_information end |
#client_reference_information ⇒ ClientReferenceInformation3
An unique identification number generated by Visa Acceptance to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
26 27 28 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 26 def client_reference_information @client_reference_information end |
#id ⇒ String
An unique identification number generated by Visa Acceptance to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
18 19 20 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 18 def id @id end |
#order_information ⇒ OrderInformation25
An unique identification number generated by Visa Acceptance to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
42 43 44 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 42 def order_information @order_information end |
#payment_information ⇒ PaymentInformation21
An unique identification number generated by Visa Acceptance to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
50 51 52 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 50 def payment_information @payment_information end |
#processing_information ⇒ ProcessingInformation22
An unique identification number generated by Visa Acceptance to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
58 59 60 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 58 def processing_information @processing_information end |
#processor_information ⇒ ProcessorInformation19
An unique identification number generated by Visa Acceptance to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
34 35 36 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 34 def processor_information @processor_information end |
#reconciliation_id ⇒ String
Reference number for the transaction. Depending on how your Visa Acceptance account is configured, this value could either be provided in the API request or generated by Visa Acceptance. The actual value used in the request to the processor is provided back to you by Visa Acceptance in the response.
94 95 96 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 94 def reconciliation_id @reconciliation_id end |
#risk_information ⇒ RiskInformation4
Reference number for the transaction. Depending on how your Visa Acceptance account is configured, this value could either be provided in the API request or generated by Visa Acceptance. The actual value used in the request to the processor is provided back to you by Visa Acceptance in the response.
103 104 105 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 103 def risk_information @risk_information end |
#status ⇒ String
The status of the submitted transaction. Possible values:
- CREATED
- SAVED
- APPROVED
- VOIDED
- COMPLETED
- PAYER_ACTION_REQUIRED
85 86 87 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 85 def status @status end |
#submit_time_utc ⇒ String
Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ
Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57
(10:47:57 p.m.).
The T separates the date and the time. The Z indicates UTC.
Returned by Visa Acceptance for all services.
74 75 76 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 74 def submit_time_utc @submit_time_utc end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 171 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : SKIP if hash['clientReferenceInformation'] client_reference_information = ClientReferenceInformation3.from_hash(hash['clientReferenceInformation']) end processor_information = ProcessorInformation19.from_hash(hash['processorInformation']) if hash['processorInformation'] order_information = OrderInformation25.from_hash(hash['orderInformation']) if hash['orderInformation'] payment_information = PaymentInformation21.from_hash(hash['paymentInformation']) if hash['paymentInformation'] processing_information = ProcessingInformation22.from_hash(hash['processingInformation']) if hash['processingInformation'] buyer_information = BuyerInformation8.from_hash(hash['buyerInformation']) if hash['buyerInformation'] submit_time_utc = hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP reconciliation_id = hash.key?('reconciliationId') ? hash['reconciliationId'] : SKIP risk_information = RiskInformation4.from_hash(hash['riskInformation']) if hash['riskInformation'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PtsV2PaymentsOrderPost201Response.new(id: id, client_reference_information: client_reference_information, processor_information: processor_information, order_information: order_information, payment_information: payment_information, processing_information: processing_information, buyer_information: buyer_information, submit_time_utc: submit_time_utc, status: status, reconciliation_id: reconciliation_id, risk_information: risk_information, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 106 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['client_reference_information'] = 'clientReferenceInformation' @_hash['processor_information'] = 'processorInformation' @_hash['order_information'] = 'orderInformation' @_hash['payment_information'] = 'paymentInformation' @_hash['processing_information'] = 'processingInformation' @_hash['buyer_information'] = 'buyerInformation' @_hash['submit_time_utc'] = 'submitTimeUtc' @_hash['status'] = 'status' @_hash['reconciliation_id'] = 'reconciliationId' @_hash['risk_information'] = 'riskInformation' @_hash end |
.nullables ⇒ Object
An array for nullable fields
140 141 142 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 140 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 123 def self.optionals %w[ id client_reference_information processor_information order_information payment_information processing_information buyer_information submit_time_utc status reconciliation_id risk_information ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 232 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, client_reference_information:"\ " #{@client_reference_information.inspect}, processor_information:"\ " #{@processor_information.inspect}, order_information: #{@order_information.inspect},"\ " payment_information: #{@payment_information.inspect}, processing_information:"\ " #{@processing_information.inspect}, buyer_information: #{@buyer_information.inspect},"\ " submit_time_utc: #{@submit_time_utc.inspect}, status: #{@status.inspect},"\ " reconciliation_id: #{@reconciliation_id.inspect}, risk_information:"\ " #{@risk_information.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
220 221 222 223 224 225 226 227 228 229 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 220 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, client_reference_information: #{@client_reference_information},"\ " processor_information: #{@processor_information}, order_information:"\ " #{@order_information}, payment_information: #{@payment_information},"\ " processing_information: #{@processing_information}, buyer_information:"\ " #{@buyer_information}, submit_time_utc: #{@submit_time_utc}, status: #{@status},"\ " reconciliation_id: #{@reconciliation_id}, risk_information: #{@risk_information},"\ " additional_properties: #{@additional_properties}>" end |