Class: VisaAcceptanceMergedSpec::PtsV2PaymentsPost201Response1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::PtsV2PaymentsPost201Response1
- Defined in:
- lib/visa_acceptance_merged_spec/models/pts_v2_payments_post201_response1.rb
Overview
PtsV2PaymentsPost201Response1 Model.
Instance Attribute Summary collapse
-
#client_reference_information ⇒ ClientReferenceInformation3
Reference number for the transaction.
-
#error_information ⇒ ErrorInformation17
Reference number for the transaction.
-
#id ⇒ String
An unique identification number generated by Visa Acceptance to identify the submitted request.
-
#issuer_information ⇒ IssuerInformation5
Reference number for the transaction.
-
#order_information ⇒ OrderInformation19
Reference number for the transaction.
-
#payment_information ⇒ PaymentInformation15
Reference number for the transaction.
-
#processor_information ⇒ ProcessorInformation15
Time of request in UTC.
-
#reconciliation_id ⇒ String
Reference number for the transaction.
-
#status ⇒ String
The status of the submitted transaction.
-
#submit_time_utc ⇒ String
Time of request in UTC.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id: SKIP, status: SKIP, submit_time_utc: SKIP, processor_information: SKIP, reconciliation_id: SKIP, payment_information: SKIP, order_information: SKIP, client_reference_information: SKIP, issuer_information: SKIP, error_information: SKIP, additional_properties: nil) ⇒ PtsV2PaymentsPost201Response1
constructor
A new instance of PtsV2PaymentsPost201Response1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id: SKIP, status: SKIP, submit_time_utc: SKIP, processor_information: SKIP, reconciliation_id: SKIP, payment_information: SKIP, order_information: SKIP, client_reference_information: SKIP, issuer_information: SKIP, error_information: SKIP, additional_properties: nil) ⇒ PtsV2PaymentsPost201Response1
Returns a new instance of PtsV2PaymentsPost201Response1.
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_post201_response1.rb', line 140 def initialize(id: SKIP, status: SKIP, submit_time_utc: SKIP, processor_information: SKIP, reconciliation_id: SKIP, payment_information: SKIP, order_information: SKIP, client_reference_information: SKIP, issuer_information: SKIP, error_information: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id unless id == SKIP @status = status unless status == SKIP @submit_time_utc = submit_time_utc unless submit_time_utc == SKIP @processor_information = processor_information unless processor_information == SKIP @reconciliation_id = reconciliation_id unless reconciliation_id == SKIP @payment_information = payment_information unless payment_information == SKIP @order_information = order_information unless order_information == SKIP unless client_reference_information == SKIP @client_reference_information = client_reference_information end @issuer_information = issuer_information unless issuer_information == SKIP @error_information = error_information unless error_information == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_reference_information ⇒ ClientReferenceInformation3
Reference number for the transaction. Depending on how your Visa Acceptance account is configured, this value could either be provided in the API request or generated by Visa Acceptance. The actual value used in the request to the processor is provided back to you by Visa Acceptance in the response.
83 84 85 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_post201_response1.rb', line 83 def client_reference_information @client_reference_information end |
#error_information ⇒ ErrorInformation17
Reference number for the transaction. Depending on how your Visa Acceptance account is configured, this value could either be provided in the API request or generated by Visa Acceptance. The actual value used in the request to the processor is provided back to you by Visa Acceptance in the response.
101 102 103 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_post201_response1.rb', line 101 def error_information @error_information end |
#id ⇒ String
An unique identification number generated by Visa Acceptance to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
18 19 20 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_post201_response1.rb', line 18 def id @id end |
#issuer_information ⇒ IssuerInformation5
Reference number for the transaction. Depending on how your Visa Acceptance account is configured, this value could either be provided in the API request or generated by Visa Acceptance. The actual value used in the request to the processor is provided back to you by Visa Acceptance in the response.
92 93 94 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_post201_response1.rb', line 92 def issuer_information @issuer_information end |
#order_information ⇒ OrderInformation19
Reference number for the transaction. Depending on how your Visa Acceptance account is configured, this value could either be provided in the API request or generated by Visa Acceptance. The actual value used in the request to the processor is provided back to you by Visa Acceptance in the response.
74 75 76 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_post201_response1.rb', line 74 def order_information @order_information end |
#payment_information ⇒ PaymentInformation15
Reference number for the transaction. Depending on how your Visa Acceptance account is configured, this value could either be provided in the API request or generated by Visa Acceptance. The actual value used in the request to the processor is provided back to you by Visa Acceptance in the response.
65 66 67 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_post201_response1.rb', line 65 def payment_information @payment_information end |
#processor_information ⇒ ProcessorInformation15
Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ
Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57
(10:47:57 p.m.).
The T separates the date and the time. The Z indicates UTC.
Returned by Visa Acceptance for all services.
47 48 49 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_post201_response1.rb', line 47 def processor_information @processor_information end |
#reconciliation_id ⇒ String
Reference number for the transaction. Depending on how your Visa Acceptance account is configured, this value could either be provided in the API request or generated by Visa Acceptance. The actual value used in the request to the processor is provided back to you by Visa Acceptance in the response.
56 57 58 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_post201_response1.rb', line 56 def reconciliation_id @reconciliation_id end |
#status ⇒ String
The status of the submitted transaction. Possible values:
- AUTHORIZED
- PARTIAL_AUTHORIZED
- AUTHORIZED_PENDING_REVIEW
- AUTHORIZED_RISK_DECLINED
- PENDING_AUTHENTICATION
- PENDING_REVIEW
- DECLINED
- INVALID_REQUEST
31 32 33 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_post201_response1.rb', line 31 def status @status end |
#submit_time_utc ⇒ String
Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ
Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57
(10:47:57 p.m.).
The T separates the date and the time. The Z indicates UTC.
Returned by Visa Acceptance for all services.
39 40 41 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_post201_response1.rb', line 39 def submit_time_utc @submit_time_utc end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_post201_response1.rb', line 165 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP submit_time_utc = hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP processor_information = ProcessorInformation15.from_hash(hash['processorInformation']) if hash['processorInformation'] reconciliation_id = hash.key?('reconciliationId') ? hash['reconciliationId'] : SKIP payment_information = PaymentInformation15.from_hash(hash['paymentInformation']) if hash['paymentInformation'] order_information = OrderInformation19.from_hash(hash['orderInformation']) if hash['orderInformation'] if hash['clientReferenceInformation'] client_reference_information = ClientReferenceInformation3.from_hash(hash['clientReferenceInformation']) end issuer_information = IssuerInformation5.from_hash(hash['issuerInformation']) if hash['issuerInformation'] error_information = ErrorInformation17.from_hash(hash['errorInformation']) if hash['errorInformation'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PtsV2PaymentsPost201Response1.new(id: id, status: status, submit_time_utc: submit_time_utc, processor_information: processor_information, reconciliation_id: reconciliation_id, payment_information: payment_information, order_information: order_information, client_reference_information: client_reference_information, issuer_information: issuer_information, error_information: error_information, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_post201_response1.rb', line 104 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['status'] = 'status' @_hash['submit_time_utc'] = 'submitTimeUtc' @_hash['processor_information'] = 'processorInformation' @_hash['reconciliation_id'] = 'reconciliationId' @_hash['payment_information'] = 'paymentInformation' @_hash['order_information'] = 'orderInformation' @_hash['client_reference_information'] = 'clientReferenceInformation' @_hash['issuer_information'] = 'issuerInformation' @_hash['error_information'] = 'errorInformation' @_hash end |
.nullables ⇒ Object
An array for nullable fields
136 137 138 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_post201_response1.rb', line 136 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_post201_response1.rb', line 120 def self.optionals %w[ id status submit_time_utc processor_information reconciliation_id payment_information order_information client_reference_information issuer_information error_information ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
222 223 224 225 226 227 228 229 230 231 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_post201_response1.rb', line 222 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, status: #{@status.inspect}, submit_time_utc:"\ " #{@submit_time_utc.inspect}, processor_information: #{@processor_information.inspect},"\ " reconciliation_id: #{@reconciliation_id.inspect}, payment_information:"\ " #{@payment_information.inspect}, order_information: #{@order_information.inspect},"\ " client_reference_information: #{@client_reference_information.inspect},"\ " issuer_information: #{@issuer_information.inspect}, error_information:"\ " #{@error_information.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
211 212 213 214 215 216 217 218 219 |
# File 'lib/visa_acceptance_merged_spec/models/pts_v2_payments_post201_response1.rb', line 211 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, status: #{@status}, submit_time_utc: #{@submit_time_utc},"\ " processor_information: #{@processor_information}, reconciliation_id:"\ " #{@reconciliation_id}, payment_information: #{@payment_information}, order_information:"\ " #{@order_information}, client_reference_information: #{@client_reference_information},"\ " issuer_information: #{@issuer_information}, error_information: #{@error_information},"\ " additional_properties: #{@additional_properties}>" end |