Class: VisaAcceptanceMergedSpec::RecurringOptions
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::RecurringOptions
- Defined in:
- lib/visa_acceptance_merged_spec/models/recurring_options.rb
Overview
RecurringOptions Model.
Instance Attribute Summary collapse
-
#first_recurring_payment ⇒ TrueClass | FalseClass
Flag that indicates whether this transaction is the first in a series of recurring payments.
-
#loan_payment ⇒ TrueClass | FalseClass
Flag that indicates whether this is a payment towards an existing contractual loan.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(loan_payment: false, first_recurring_payment: false, additional_properties: nil) ⇒ RecurringOptions
constructor
A new instance of RecurringOptions.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(loan_payment: false, first_recurring_payment: false, additional_properties: nil) ⇒ RecurringOptions
Returns a new instance of RecurringOptions.
53 54 55 56 57 58 59 60 61 |
# File 'lib/visa_acceptance_merged_spec/models/recurring_options.rb', line 53 def initialize(loan_payment: false, first_recurring_payment: false, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @loan_payment = loan_payment unless loan_payment == SKIP @first_recurring_payment = first_recurring_payment unless first_recurring_payment == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#first_recurring_payment ⇒ TrueClass | FalseClass
Flag that indicates whether this transaction is the first in a series of recurring payments. This field is supported only for Atos, FDC Nashville Global, and OmniPay Direct. Possible values:
trueIndicates this is the first payment in a series of recurring paymentsfalse(default) Indicates this is not the first payment in a series of recurring payments.
30 31 32 |
# File 'lib/visa_acceptance_merged_spec/models/recurring_options.rb', line 30 def first_recurring_payment @first_recurring_payment end |
#loan_payment ⇒ TrueClass | FalseClass
Flag that indicates whether this is a payment towards an existing contractual loan. Possible values:
true: Loan paymentfalse: (default) Not a loan payment
18 19 20 |
# File 'lib/visa_acceptance_merged_spec/models/recurring_options.rb', line 18 def loan_payment @loan_payment end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/visa_acceptance_merged_spec/models/recurring_options.rb', line 64 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. loan_payment = hash['loanPayment'] ||= false first_recurring_payment = hash['firstRecurringPayment'] ||= false # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. RecurringOptions.new(loan_payment: loan_payment, first_recurring_payment: first_recurring_payment, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 |
# File 'lib/visa_acceptance_merged_spec/models/recurring_options.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['loan_payment'] = 'loanPayment' @_hash['first_recurring_payment'] = 'firstRecurringPayment' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/visa_acceptance_merged_spec/models/recurring_options.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
41 42 43 44 45 46 |
# File 'lib/visa_acceptance_merged_spec/models/recurring_options.rb', line 41 def self.optionals %w[ loan_payment first_recurring_payment ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
92 93 94 95 96 |
# File 'lib/visa_acceptance_merged_spec/models/recurring_options.rb', line 92 def inspect class_name = self.class.name.split('::').last "<#{class_name} loan_payment: #{@loan_payment.inspect}, first_recurring_payment:"\ " #{@first_recurring_payment.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
85 86 87 88 89 |
# File 'lib/visa_acceptance_merged_spec/models/recurring_options.rb', line 85 def to_s class_name = self.class.name.split('::').last "<#{class_name} loan_payment: #{@loan_payment}, first_recurring_payment:"\ " #{@first_recurring_payment}, additional_properties: #{@additional_properties}>" end |