Class: VisaAcceptanceMergedSpec::ShipTo11
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::ShipTo11
- Defined in:
- lib/visa_acceptance_merged_spec/models/ship_to11.rb
Overview
ShipTo11 Model.
Instance Attribute Summary collapse
-
#address1 ⇒ String
First line of the shipping address.
-
#address2 ⇒ String
Second line of the shipping address.
-
#administrative_area ⇒ String
State or province of the shipping address.
-
#country ⇒ String
Country of the shipping address.
-
#email ⇒ String
Customer's email address, including the full domain name.
-
#first_name ⇒ String
First name of the recipient.
-
#last_name ⇒ String
Last name of the recipient.
-
#locality ⇒ String
City of the shipping address.
-
#method ⇒ String
Shipping method for the product.
-
#phone_number ⇒ String
Phone number associated with the shipping address.
-
#postal_code ⇒ String
Postal code for the shipping address.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(first_name: SKIP, last_name: SKIP, address1: SKIP, address2: SKIP, locality: SKIP, administrative_area: SKIP, postal_code: SKIP, country: SKIP, method: SKIP, email: SKIP, phone_number: SKIP, additional_properties: nil) ⇒ ShipTo11
constructor
A new instance of ShipTo11.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(first_name: SKIP, last_name: SKIP, address1: SKIP, address2: SKIP, locality: SKIP, administrative_area: SKIP, postal_code: SKIP, country: SKIP, method: SKIP, email: SKIP, phone_number: SKIP, additional_properties: nil) ⇒ ShipTo11
Returns a new instance of ShipTo11.
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/visa_acceptance_merged_spec/models/ship_to11.rb', line 174 def initialize(first_name: SKIP, last_name: SKIP, address1: SKIP, address2: SKIP, locality: SKIP, administrative_area: SKIP, postal_code: SKIP, country: SKIP, method: SKIP, email: SKIP, phone_number: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @first_name = first_name unless first_name == SKIP @last_name = last_name unless last_name == SKIP @address1 = address1 unless address1 == SKIP @address2 = address2 unless address2 == SKIP @locality = locality unless locality == SKIP @administrative_area = administrative_area unless administrative_area == SKIP @postal_code = postal_code unless postal_code == SKIP @country = country unless country == SKIP @method = method unless method == SKIP @email = email unless email == SKIP @phone_number = phone_number unless phone_number == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#address1 ⇒ String
First line of the shipping address. Required field for authorization if any shipping address information is included in the request; otherwise, optional.
Tax Calculation
Optional field for U.S. and Canadian taxes. Not applicable to international and value added taxes. Billing address objects will be used to determine the cardholder’s location when shipTo objects are not present.
39 40 41 |
# File 'lib/visa_acceptance_merged_spec/models/ship_to11.rb', line 39 def address1 @address1 end |
#address2 ⇒ String
Second line of the shipping address. Optional field.
Tax Calculation
Optional field for U.S. and Canadian taxes. Not applicable to international and value added taxes. Billing address objects will be used to determine the cardholder’s location when shipTo objects are not present.
49 50 51 |
# File 'lib/visa_acceptance_merged_spec/models/ship_to11.rb', line 49 def address2 @address2 end |
#administrative_area ⇒ String
State or province of the shipping address. Use the [State, Province, and Territory Codes for the United States and Canada]( (maximum length: 2) Required field for authorization if any shipping address information is included in the request and shipping to the U.S. or Canada; otherwise, optional.
Tax Calculation
Optional field for U.S. and Canadian taxes. Not applicable to international and value added taxes. Billing address objects will be used to determine the cardholder’s location when shipTo objects are not present.
74 75 76 |
# File 'lib/visa_acceptance_merged_spec/models/ship_to11.rb', line 74 def administrative_area @administrative_area end |
#country ⇒ String
Country of the shipping address. Use the two-character [ISO Standard Country Codes.]( Required field for authorization if any shipping address information is included in the request; otherwise, optional.
Tax Calculation
Optional field for U.S., Canadian, international tax, and value added taxes. Billing address objects will be used to determine the cardholder’s location when shipTo objects are not present.
112 113 114 |
# File 'lib/visa_acceptance_merged_spec/models/ship_to11.rb', line 112 def country @country end |
#email ⇒ String
Customer's email address, including the full domain name.
129 130 131 |
# File 'lib/visa_acceptance_merged_spec/models/ship_to11.rb', line 129 def email @email end |
#first_name ⇒ String
First name of the recipient.
Litle
Maximum length: 25
All other processors
Maximum length: 60 Optional field.
19 20 21 |
# File 'lib/visa_acceptance_merged_spec/models/ship_to11.rb', line 19 def first_name @first_name end |
#last_name ⇒ String
Last name of the recipient.
Litle
Maximum length: 25
All other processors
Maximum length: 60 Optional field.
28 29 30 |
# File 'lib/visa_acceptance_merged_spec/models/ship_to11.rb', line 28 def last_name @last_name end |
#locality ⇒ String
City of the shipping address. Required field for authorization if any shipping address information is included in the request and shipping to the U.S. or Canada; otherwise, optional.
Tax Calculation
Optional field for U.S. and Canadian taxes. Not applicable to international and value added taxes. Billing address objects will be used to determine the cardholder’s location when shipTo objects are not present.
61 62 63 |
# File 'lib/visa_acceptance_merged_spec/models/ship_to11.rb', line 61 def locality @locality end |
#method ⇒ String
Shipping method for the product. Possible values:
- lowcost: Lowest-cost service
- sameday: Courier or same-day service
- oneday: Next-day or overnight service
- twoday: Two-day service
- threeday: Three-day service
- pickup: Store pick-up
- other: Other shipping method
- none: No shipping method because product is a service or subscription Required for American Express SafeKey (U.S.).
125 126 127 |
# File 'lib/visa_acceptance_merged_spec/models/ship_to11.rb', line 125 def method @method end |
#phone_number ⇒ String
Phone number associated with the shipping address.
133 134 135 |
# File 'lib/visa_acceptance_merged_spec/models/ship_to11.rb', line 133 def phone_number @phone_number end |
#postal_code ⇒ String
Postal code for the shipping address. The postal code must consist of 5 to 9 digits. Required field for authorization if any shipping address information is included in the request and shipping to the U.S. or Canada; otherwise, optional. When the billing country is the U.S., the 9-digit postal code must follow this format: [5 digits][dash][4 digits] Example 12345-6789 When the billing country is Canada, the 6-digit postal code must follow this format: [alpha][numeric][alpha][space][numeric][alpha][numeric] Example A1B 2C3
American Express Direct
Before sending the postal code to the processor, all nonalphanumeric characters are removed and, if the remaining value is longer than nine characters, the value is truncated starting from the right side.
Tax Calculation
Optional field for U.S. and Canadian taxes. Not applicable to international and value added taxes. Billing address objects will be used to determine the cardholder’s location when shipTo objects are not present.
100 101 102 |
# File 'lib/visa_acceptance_merged_spec/models/ship_to11.rb', line 100 def postal_code @postal_code end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/visa_acceptance_merged_spec/models/ship_to11.rb', line 196 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. first_name = hash.key?('firstName') ? hash['firstName'] : SKIP last_name = hash.key?('lastName') ? hash['lastName'] : SKIP address1 = hash.key?('address1') ? hash['address1'] : SKIP address2 = hash.key?('address2') ? hash['address2'] : SKIP locality = hash.key?('locality') ? hash['locality'] : SKIP administrative_area = hash.key?('administrativeArea') ? hash['administrativeArea'] : SKIP postal_code = hash.key?('postalCode') ? hash['postalCode'] : SKIP country = hash.key?('country') ? hash['country'] : SKIP method = hash.key?('method') ? hash['method'] : SKIP email = hash.key?('email') ? hash['email'] : SKIP phone_number = hash.key?('phoneNumber') ? hash['phoneNumber'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ShipTo11.new(first_name: first_name, last_name: last_name, address1: address1, address2: address2, locality: locality, administrative_area: administrative_area, postal_code: postal_code, country: country, method: method, email: email, phone_number: phone_number, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/visa_acceptance_merged_spec/models/ship_to11.rb', line 136 def self.names @_hash = {} if @_hash.nil? @_hash['first_name'] = 'firstName' @_hash['last_name'] = 'lastName' @_hash['address1'] = 'address1' @_hash['address2'] = 'address2' @_hash['locality'] = 'locality' @_hash['administrative_area'] = 'administrativeArea' @_hash['postal_code'] = 'postalCode' @_hash['country'] = 'country' @_hash['method'] = 'method' @_hash['email'] = 'email' @_hash['phone_number'] = 'phoneNumber' @_hash end |
.nullables ⇒ Object
An array for nullable fields
170 171 172 |
# File 'lib/visa_acceptance_merged_spec/models/ship_to11.rb', line 170 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/visa_acceptance_merged_spec/models/ship_to11.rb', line 153 def self.optionals %w[ first_name last_name address1 address2 locality administrative_area postal_code country method email phone_number ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
246 247 248 249 250 251 252 253 254 |
# File 'lib/visa_acceptance_merged_spec/models/ship_to11.rb', line 246 def inspect class_name = self.class.name.split('::').last "<#{class_name} first_name: #{@first_name.inspect}, last_name: #{@last_name.inspect},"\ " address1: #{@address1.inspect}, address2: #{@address2.inspect}, locality:"\ " #{@locality.inspect}, administrative_area: #{@administrative_area.inspect}, postal_code:"\ " #{@postal_code.inspect}, country: #{@country.inspect}, method: #{@method.inspect}, email:"\ " #{@email.inspect}, phone_number: #{@phone_number.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
236 237 238 239 240 241 242 243 |
# File 'lib/visa_acceptance_merged_spec/models/ship_to11.rb', line 236 def to_s class_name = self.class.name.split('::').last "<#{class_name} first_name: #{@first_name}, last_name: #{@last_name}, address1:"\ " #{@address1}, address2: #{@address2}, locality: #{@locality}, administrative_area:"\ " #{@administrative_area}, postal_code: #{@postal_code}, country: #{@country}, method:"\ " #{@method}, email: #{@email}, phone_number: #{@phone_number}, additional_properties:"\ " #{@additional_properties}>" end |