Class: VisaAcceptanceMergedSpec::ShipTo13
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::ShipTo13
- Defined in:
- lib/visa_acceptance_merged_spec/models/ship_to13.rb
Overview
ShipTo13 Model.
Instance Attribute Summary collapse
-
#address1 ⇒ String
First line of the shipping address.
-
#address2 ⇒ String
Second line of the shipping address.
-
#administrative_area ⇒ String
State or province of the shipping address.
-
#country ⇒ String
Country of the shipping address.
-
#first_name ⇒ String
First name of the recipient.
-
#last_name ⇒ String
Last name of the recipient.
-
#locality ⇒ String
City of the shipping address.
-
#postal_code ⇒ String
Postal code for the shipping address.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(first_name: SKIP, last_name: SKIP, address1: SKIP, address2: SKIP, administrative_area: SKIP, locality: SKIP, postal_code: SKIP, country: SKIP, additional_properties: nil) ⇒ ShipTo13
constructor
A new instance of ShipTo13.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(first_name: SKIP, last_name: SKIP, address1: SKIP, address2: SKIP, administrative_area: SKIP, locality: SKIP, postal_code: SKIP, country: SKIP, additional_properties: nil) ⇒ ShipTo13
Returns a new instance of ShipTo13.
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/visa_acceptance_merged_spec/models/ship_to13.rb', line 147 def initialize(first_name: SKIP, last_name: SKIP, address1: SKIP, address2: SKIP, administrative_area: SKIP, locality: SKIP, postal_code: SKIP, country: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @first_name = first_name unless first_name == SKIP @last_name = last_name unless last_name == SKIP @address1 = address1 unless address1 == SKIP @address2 = address2 unless address2 == SKIP @administrative_area = administrative_area unless administrative_area == SKIP @locality = locality unless locality == SKIP @postal_code = postal_code unless postal_code == SKIP @country = country unless country == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#address1 ⇒ String
First line of the shipping address. Required field for authorization if any shipping address information is included in the request; otherwise, optional.
Tax Calculation
Optional field for U.S. and Canadian taxes. Not applicable to international and value added taxes. Billing address objects will be used to determine the cardholder’s location when shipTo objects are not present.
39 40 41 |
# File 'lib/visa_acceptance_merged_spec/models/ship_to13.rb', line 39 def address1 @address1 end |
#address2 ⇒ String
Second line of the shipping address. Optional field.
Tax Calculation
Optional field for U.S. and Canadian taxes. Not applicable to international and value added taxes. Billing address objects will be used to determine the cardholder’s location when shipTo objects are not present.
49 50 51 |
# File 'lib/visa_acceptance_merged_spec/models/ship_to13.rb', line 49 def address2 @address2 end |
#administrative_area ⇒ String
State or province of the shipping address. Use the [State, Province, and Territory Codes for the United States and Canada]( (maximum length: 2) Required field for authorization if any shipping address information is included in the request and shipping to the U.S. or Canada; otherwise, optional.
Tax Calculation
Optional field for U.S. and Canadian taxes. Not applicable to international and value added taxes. Billing address objects will be used to determine the cardholder’s location when shipTo objects are not present.
62 63 64 |
# File 'lib/visa_acceptance_merged_spec/models/ship_to13.rb', line 62 def administrative_area @administrative_area end |
#country ⇒ String
Country of the shipping address. Use the two-character [ISO Standard Country Codes.]( Required field for authorization if any shipping address information is included in the request; otherwise, optional.
Tax Calculation
Optional field for U.S., Canadian, international tax, and value added taxes. Billing address objects will be used to determine the cardholder’s location when shipTo objects are not present.
112 113 114 |
# File 'lib/visa_acceptance_merged_spec/models/ship_to13.rb', line 112 def country @country end |
#first_name ⇒ String
First name of the recipient.
Litle
Maximum length: 25
All other processors
Maximum length: 60 Optional field.
19 20 21 |
# File 'lib/visa_acceptance_merged_spec/models/ship_to13.rb', line 19 def first_name @first_name end |
#last_name ⇒ String
Last name of the recipient.
Litle
Maximum length: 25
All other processors
Maximum length: 60 Optional field.
28 29 30 |
# File 'lib/visa_acceptance_merged_spec/models/ship_to13.rb', line 28 def last_name @last_name end |
#locality ⇒ String
City of the shipping address. Required field for authorization if any shipping address information is included in the request and shipping to the U.S. or Canada; otherwise, optional.
Tax Calculation
Optional field for U.S. and Canadian taxes. Not applicable to international and value added taxes. Billing address objects will be used to determine the cardholder’s location when shipTo objects are not present.
74 75 76 |
# File 'lib/visa_acceptance_merged_spec/models/ship_to13.rb', line 74 def locality @locality end |
#postal_code ⇒ String
Postal code for the shipping address. The postal code must consist of 5 to 9 digits. Required field for authorization if any shipping address information is included in the request and shipping to the U.S. or Canada; otherwise, optional. When the billing country is the U.S., the 9-digit postal code must follow this format: [5 digits][dash][4 digits] Example 12345-6789 When the billing country is Canada, the 6-digit postal code must follow this format: [alpha][numeric][alpha][space][numeric][alpha][numeric] Example A1B 2C3
American Express Direct
Before sending the postal code to the processor, all nonalphanumeric characters are removed and, if the remaining value is longer than nine characters, the value is truncated starting from the right side.
Tax Calculation
Optional field for U.S. and Canadian taxes. Not applicable to international and value added taxes. Billing address objects will be used to determine the cardholder’s location when shipTo objects are not present.
100 101 102 |
# File 'lib/visa_acceptance_merged_spec/models/ship_to13.rb', line 100 def postal_code @postal_code end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/visa_acceptance_merged_spec/models/ship_to13.rb', line 165 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. first_name = hash.key?('firstName') ? hash['firstName'] : SKIP last_name = hash.key?('lastName') ? hash['lastName'] : SKIP address1 = hash.key?('address1') ? hash['address1'] : SKIP address2 = hash.key?('address2') ? hash['address2'] : SKIP administrative_area = hash.key?('administrativeArea') ? hash['administrativeArea'] : SKIP locality = hash.key?('locality') ? hash['locality'] : SKIP postal_code = hash.key?('postalCode') ? hash['postalCode'] : SKIP country = hash.key?('country') ? hash['country'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ShipTo13.new(first_name: first_name, last_name: last_name, address1: address1, address2: address2, administrative_area: administrative_area, locality: locality, postal_code: postal_code, country: country, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/visa_acceptance_merged_spec/models/ship_to13.rb', line 115 def self.names @_hash = {} if @_hash.nil? @_hash['first_name'] = 'firstName' @_hash['last_name'] = 'lastName' @_hash['address1'] = 'address1' @_hash['address2'] = 'address2' @_hash['administrative_area'] = 'administrativeArea' @_hash['locality'] = 'locality' @_hash['postal_code'] = 'postalCode' @_hash['country'] = 'country' @_hash end |
.nullables ⇒ Object
An array for nullable fields
143 144 145 |
# File 'lib/visa_acceptance_merged_spec/models/ship_to13.rb', line 143 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/visa_acceptance_merged_spec/models/ship_to13.rb', line 129 def self.optionals %w[ first_name last_name address1 address2 administrative_area locality postal_code country ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
208 209 210 211 212 213 214 215 |
# File 'lib/visa_acceptance_merged_spec/models/ship_to13.rb', line 208 def inspect class_name = self.class.name.split('::').last "<#{class_name} first_name: #{@first_name.inspect}, last_name: #{@last_name.inspect},"\ " address1: #{@address1.inspect}, address2: #{@address2.inspect}, administrative_area:"\ " #{@administrative_area.inspect}, locality: #{@locality.inspect}, postal_code:"\ " #{@postal_code.inspect}, country: #{@country.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
199 200 201 202 203 204 205 |
# File 'lib/visa_acceptance_merged_spec/models/ship_to13.rb', line 199 def to_s class_name = self.class.name.split('::').last "<#{class_name} first_name: #{@first_name}, last_name: #{@last_name}, address1:"\ " #{@address1}, address2: #{@address2}, administrative_area: #{@administrative_area},"\ " locality: #{@locality}, postal_code: #{@postal_code}, country: #{@country},"\ " additional_properties: #{@additional_properties}>" end |