Class: VisaAcceptanceMergedSpec::TokenizedCard1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::TokenizedCard1
- Defined in:
- lib/visa_acceptance_merged_spec/models/tokenized_card1.rb
Overview
TokenizedCard1 Model.
Instance Attribute Summary collapse
-
#assurance_level ⇒ String
Confidence level of the tokenization.
-
#assurance_method ⇒ String
Confidence level of the tokenization.
-
#expiration_month ⇒ String
One of two possible meanings: - The two-digit month in which a token expires.
-
#expiration_year ⇒ String
One of two possible meanings: - The four-digit year in which a token expires.
-
#prefix ⇒ String
First six digits of token.
-
#requestor_id ⇒ String
Value that identifies your business and indicates that the cardholder’s account number is tokenized.
-
#suffix ⇒ String
Last four digits of token.
-
#type ⇒ String
Three-digit value that indicates the card type.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(prefix: SKIP, suffix: SKIP, type: SKIP, assurance_level: SKIP, expiration_month: SKIP, expiration_year: SKIP, requestor_id: SKIP, assurance_method: SKIP, additional_properties: nil) ⇒ TokenizedCard1
constructor
A new instance of TokenizedCard1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(prefix: SKIP, suffix: SKIP, type: SKIP, assurance_level: SKIP, expiration_month: SKIP, expiration_year: SKIP, requestor_id: SKIP, assurance_method: SKIP, additional_properties: nil) ⇒ TokenizedCard1
Returns a new instance of TokenizedCard1.
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/visa_acceptance_merged_spec/models/tokenized_card1.rb', line 281 def initialize(prefix: SKIP, suffix: SKIP, type: SKIP, assurance_level: SKIP, expiration_month: SKIP, expiration_year: SKIP, requestor_id: SKIP, assurance_method: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @prefix = prefix unless prefix == SKIP @suffix = suffix unless suffix == SKIP @type = type unless type == SKIP @assurance_level = assurance_level unless assurance_level == SKIP @expiration_month = expiration_month unless expiration_month == SKIP @expiration_year = expiration_year unless expiration_year == SKIP @requestor_id = requestor_id unless requestor_id == SKIP @assurance_method = assurance_method unless assurance_method == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#assurance_level ⇒ String
Confidence level of the tokenization. This value is assigned by the token service provider. Note This field is supported only for Visa Acceptance through VisaNet and FDC Nashville Global. Returned by PIN debit credit or PIN debit purchase. Note Merchants supported for Visa Acceptance through VisaNet/Visa Platform Connect are advised not to use this field.
168 169 170 |
# File 'lib/visa_acceptance_merged_spec/models/tokenized_card1.rb', line 168 def assurance_level @assurance_level end |
#assurance_method ⇒ String
Confidence level of the tokenization. This value is assigned by the token service provider. Note This field is supported only for Visa Platform Connect
246 247 248 |
# File 'lib/visa_acceptance_merged_spec/models/tokenized_card1.rb', line 246 def assurance_method @assurance_method end |
#expiration_month ⇒ String
One of two possible meanings:
- The two-digit month in which a token expires.
- The two-digit month in which a card expires.
Format:
MMPossible values:01through12NOTE The meaning of this field is dependent on the payment processor that is returning the value in an authorization reply. Please see the processor-specific details below.
Barclays and Streamline
For Maestro (UK Domestic) and Maestro (International) cards on Barclays
and Streamline, this must be a valid value (01 through 12) but is not
required to be a valid expiration date. In other words, an expiration date
that is in the past does not cause Visa Acceptance to reject your request.
However, an invalid expiration date might cause the issuer to reject your
request.
Encoded Account Numbers
For encoded account numbers (card_type=039), if there is no expiration
date on the card, use 12.
Important It is your responsibility to determine whether a field is
required for the transaction you are requesting.
Samsung Pay and Apple Pay
Month in which the token expires. Visa Acceptance includes this field in the reply message when it decrypts the payment blob for the tokenized transaction.
195 196 197 |
# File 'lib/visa_acceptance_merged_spec/models/tokenized_card1.rb', line 195 def expiration_month @expiration_month end |
#expiration_year ⇒ String
One of two possible meanings:
- The four-digit year in which a token expires.
- The four-digit year in which a card expires.
Format:
YYYYPossible values:1900through3000Data type: Non-negative integer NOTE The meaning of this field is dependent on the payment processor that is returning the value in an authorization reply. Please see the processor-specific details below.
Barclays and Streamline
For Maestro (UK Domestic) and Maestro (International) cards on Barclays and Streamline, this must be a valid value (1900 through 3000) but is not required to be a valid expiration date. In other words, an expiration date that is in the past does not cause Visa Acceptance to reject your request. However, an invalid expiration date might cause the issuer to reject your request.
Encoded Account Numbers
For encoded account numbers (card_ type=039), if there is no expiration
date on the card, use 2021.
FDC Nashville Global and FDMS South
You can send in 2 digits or 4 digits. When you send in 2 digits, they must be the last 2 digits of the year.
Samsung Pay and Apple Pay
Year in which the token expires. Visa Acceptance includes this field in the reply message when it decrypts the payment blob for the tokenized transaction. Important It is your responsibility to determine whether a field is required for the transaction you are requesting.
228 229 230 |
# File 'lib/visa_acceptance_merged_spec/models/tokenized_card1.rb', line 228 def expiration_year @expiration_year end |
#prefix ⇒ String
First six digits of token. Visa Acceptance includes this field in the reply message when it decrypts the payment blob for the tokenized transaction.
16 17 18 |
# File 'lib/visa_acceptance_merged_spec/models/tokenized_card1.rb', line 16 def prefix @prefix end |
#requestor_id ⇒ String
Value that identifies your business and indicates that the cardholder’s account number is tokenized. This value is assigned by the token service provider and is unique within the token service provider’s database. Note This field is supported only for Visa Acceptance through VisaNet and FDC Nashville Global.
PIN debit
Optional field for PIN debit credit or PIN debit purchase transactions that use payment network tokens; otherwise, not used.
240 241 242 |
# File 'lib/visa_acceptance_merged_spec/models/tokenized_card1.rb', line 240 def requestor_id @requestor_id end |
#suffix ⇒ String
Last four digits of token. Visa Acceptance includes this field in the
reply message when it decrypts the payment
blob for the tokenized transaction.
For details, see token_suffix field description in [Google Pay Using the
SCMP API.]
(
25 26 27 |
# File 'lib/visa_acceptance_merged_spec/models/tokenized_card1.rb', line 25 def suffix @suffix end |
#type ⇒ String
Three-digit value that indicates the card type. IMPORTANT It is strongly recommended that you include the card type field in request messages even if it is optional for your processor and card type. Omitting the card type can cause the transaction to be processed with the wrong card type. Possible values:
001: Visa. Use card type value001for Visa Electron.002: Mastercard, Eurocard, which is a European regional brand of Mastercard.003: American Express004: Discover005: Diners Club006: Carte Blanche007: JCB008: Optima009: GE Private Label010: Beneficial Private Label011: Twinpay Credit Card012: Twinpay Debit Card013: WalMart014: Enroute015: Lowe's Consumer016: Home Depot Consumer017: MBNA018: Dick's Sportswear019: Casual Corner020: Sears021: JAL023: Disney Card024: Maestro (UK Domestic)[^1]025: Sam's Club Consumer026: Sam's Club Business027: Nico's028: Paymentech Bill Me Later029: Bebe030: Restoration Hardware031: Delta Online032: Solo033: Visa Electron. Do not use this value. Use001for all Visa card types.034: Dankort035: Laser036: Cartes Bancaires037: Carta Si038: Pinless Debit039: Encoded account number040: UATP041: HOUSEHOLD042: Maestro (International)[^1]043: GE MONEY044: Korean Cards045: Style Cards046: JCrew047: Payeasecn eWallet048: Payeasecn Bank Transfer049: Meijer050: Hipercard051: Aura052: Redecard053: Orico card054: Elo055: Capitol One Private Label056: Carnet057: Costco Private Label058: Carnet059: ValueLink060: MADA061: RuPay062: China UnionPay063: Falabella Private Label064: Prompt Card065: Korean Domestic066: Banricompras067: MEEZA068: PayPak070: EFTPOS071: Codensa072: Olimpica073: Colsubsidio074: Tuya075: Sodexo076: Naranja077: Cabal078: DINELCO079: PANAL080: EPM081: Jaywan [^1]: For this card type, you must include thepaymentInformation.card.typeorpaymentInformation.tokenizedCard.typefield in your request for an authorization or a stand-alone credit. [^2]: For this card type on Cielo 3.0, you must include thepaymentInformation.card.typeorpaymentInformation.tokenizedCard.typefield in a request for an authorization or a stand-alone credit. This card type is not supported on Cielo 1.5. [^3]: For this card type on Getnet and Rede, you must include thepaymentInformation.card.typeorpaymentInformation.tokenizedCard.typefield in a request for an authorization or a stand-alone credit. [^4]: For this card type, you must include thepaymentInformation.card.typein your request for any payer authentication services.
Used by
Authorization Required for Carte Blanche and JCB. Optional for all other card types.
Card Present reply
This field is included in the reply message when the client software that is installed on the POS terminal uses the token management service (TMS) to retrieve tokenized payment details. You must contact customer support to have your account enabled to receive these fields in the credit reply message. Returned by the Credit service. This reply field is only supported by the following processors:
- American Express Direct
- Credit Mutuel-CIC
- FDC Nashville Global
- OmniPay Direct
- SIX
Google Pay transactions
For PAN-based Google Pay transactions, this field is returned in the API response.
GPX
This field only supports transactions from the following card types:
- Visa
- Mastercard
- AMEX
- Discover
- Diners
- JCB
- Union Pay International
158 159 160 |
# File 'lib/visa_acceptance_merged_spec/models/tokenized_card1.rb', line 158 def type @type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/visa_acceptance_merged_spec/models/tokenized_card1.rb', line 300 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. prefix = hash.key?('prefix') ? hash['prefix'] : SKIP suffix = hash.key?('suffix') ? hash['suffix'] : SKIP type = hash.key?('type') ? hash['type'] : SKIP assurance_level = hash.key?('assuranceLevel') ? hash['assuranceLevel'] : SKIP expiration_month = hash.key?('expirationMonth') ? hash['expirationMonth'] : SKIP expiration_year = hash.key?('expirationYear') ? hash['expirationYear'] : SKIP requestor_id = hash.key?('requestorId') ? hash['requestorId'] : SKIP assurance_method = hash.key?('assuranceMethod') ? hash['assuranceMethod'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TokenizedCard1.new(prefix: prefix, suffix: suffix, type: type, assurance_level: assurance_level, expiration_month: expiration_month, expiration_year: expiration_year, requestor_id: requestor_id, assurance_method: assurance_method, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/visa_acceptance_merged_spec/models/tokenized_card1.rb', line 249 def self.names @_hash = {} if @_hash.nil? @_hash['prefix'] = 'prefix' @_hash['suffix'] = 'suffix' @_hash['type'] = 'type' @_hash['assurance_level'] = 'assuranceLevel' @_hash['expiration_month'] = 'expirationMonth' @_hash['expiration_year'] = 'expirationYear' @_hash['requestor_id'] = 'requestorId' @_hash['assurance_method'] = 'assuranceMethod' @_hash end |
.nullables ⇒ Object
An array for nullable fields
277 278 279 |
# File 'lib/visa_acceptance_merged_spec/models/tokenized_card1.rb', line 277 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/visa_acceptance_merged_spec/models/tokenized_card1.rb', line 263 def self.optionals %w[ prefix suffix type assurance_level expiration_month expiration_year requestor_id assurance_method ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
346 347 348 349 350 351 352 353 |
# File 'lib/visa_acceptance_merged_spec/models/tokenized_card1.rb', line 346 def inspect class_name = self.class.name.split('::').last "<#{class_name} prefix: #{@prefix.inspect}, suffix: #{@suffix.inspect}, type:"\ " #{@type.inspect}, assurance_level: #{@assurance_level.inspect}, expiration_month:"\ " #{@expiration_month.inspect}, expiration_year: #{@expiration_year.inspect}, requestor_id:"\ " #{@requestor_id.inspect}, assurance_method: #{@assurance_method.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
337 338 339 340 341 342 343 |
# File 'lib/visa_acceptance_merged_spec/models/tokenized_card1.rb', line 337 def to_s class_name = self.class.name.split('::').last "<#{class_name} prefix: #{@prefix}, suffix: #{@suffix}, type: #{@type}, assurance_level:"\ " #{@assurance_level}, expiration_month: #{@expiration_month}, expiration_year:"\ " #{@expiration_year}, requestor_id: #{@requestor_id}, assurance_method:"\ " #{@assurance_method}, additional_properties: #{@additional_properties}>" end |