Class: VisaAcceptanceMergedSpec::UserInterface
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::UserInterface
- Defined in:
- lib/visa_acceptance_merged_spec/models/user_interface.rb
Overview
UserInterface Model.
Instance Attribute Summary collapse
-
#border_radius ⇒ String
Border Radius, Allowed Values - Number, Chars, SPACE, Percentage(%), DOT(.), Example '25px 10px 25px 10px'; '2em 1em 0.5em 3em'.
-
#color ⇒ Color
UI Theme Name/Design Name - Allowed Chars: Alpha Numeric, Dot (.), Hyphen (-), Underscore (_).
-
#theme ⇒ String
UI Theme Name/Design Name - Allowed Chars: Alpha Numeric, Dot (.), Hyphen (-), Underscore (_).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(border_radius: SKIP, theme: SKIP, color: SKIP, additional_properties: nil) ⇒ UserInterface
constructor
A new instance of UserInterface.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(border_radius: SKIP, theme: SKIP, color: SKIP, additional_properties: nil) ⇒ UserInterface
Returns a new instance of UserInterface.
51 52 53 54 55 56 57 58 59 60 |
# File 'lib/visa_acceptance_merged_spec/models/user_interface.rb', line 51 def initialize(border_radius: SKIP, theme: SKIP, color: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @border_radius = border_radius unless border_radius == SKIP @theme = theme unless theme == SKIP @color = color unless color == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#border_radius ⇒ String
Border Radius, Allowed Values - Number, Chars, SPACE, Percentage(%), DOT(.), Example '25px 10px 25px 10px'; '2em 1em 0.5em 3em'
16 17 18 |
# File 'lib/visa_acceptance_merged_spec/models/user_interface.rb', line 16 def border_radius @border_radius end |
#color ⇒ Color
UI Theme Name/Design Name - Allowed Chars: Alpha Numeric, Dot (.), Hyphen (-), Underscore (_)
26 27 28 |
# File 'lib/visa_acceptance_merged_spec/models/user_interface.rb', line 26 def color @color end |
#theme ⇒ String
UI Theme Name/Design Name - Allowed Chars: Alpha Numeric, Dot (.), Hyphen (-), Underscore (_)
21 22 23 |
# File 'lib/visa_acceptance_merged_spec/models/user_interface.rb', line 21 def theme @theme end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/visa_acceptance_merged_spec/models/user_interface.rb', line 63 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. border_radius = hash.key?('borderRadius') ? hash['borderRadius'] : SKIP theme = hash.key?('theme') ? hash['theme'] : SKIP color = Color.from_hash(hash['color']) if hash['color'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UserInterface.new(border_radius: border_radius, theme: theme, color: color, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 |
# File 'lib/visa_acceptance_merged_spec/models/user_interface.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['border_radius'] = 'borderRadius' @_hash['theme'] = 'theme' @_hash['color'] = 'color' @_hash end |
.nullables ⇒ Object
An array for nullable fields
47 48 49 |
# File 'lib/visa_acceptance_merged_spec/models/user_interface.rb', line 47 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
38 39 40 41 42 43 44 |
# File 'lib/visa_acceptance_merged_spec/models/user_interface.rb', line 38 def self.optionals %w[ border_radius theme color ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
93 94 95 96 97 |
# File 'lib/visa_acceptance_merged_spec/models/user_interface.rb', line 93 def inspect class_name = self.class.name.split('::').last "<#{class_name} border_radius: #{@border_radius.inspect}, theme: #{@theme.inspect}, color:"\ " #{@color.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
86 87 88 89 90 |
# File 'lib/visa_acceptance_merged_spec/models/user_interface.rb', line 86 def to_s class_name = self.class.name.split('::').last "<#{class_name} border_radius: #{@border_radius}, theme: #{@theme}, color: #{@color},"\ " additional_properties: #{@additional_properties}>" end |