Class: VisaAcceptanceMergedSpec::Watchlistscreening
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- VisaAcceptanceMergedSpec::Watchlistscreening
- Defined in:
- lib/visa_acceptance_merged_spec/models/watchlistscreening.rb
Overview
Watchlistscreening Model.
Instance Attribute Summary collapse
-
#message ⇒ String
The message describing the reason of the status.
-
#reason ⇒ String
The reason of the status.
-
#status ⇒ String
The status for the call can be: - COMPLETED - INVALID_REQUEST - DECLINED.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(status: SKIP, reason: SKIP, message: SKIP, additional_properties: nil) ⇒ Watchlistscreening
constructor
A new instance of Watchlistscreening.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(status: SKIP, reason: SKIP, message: SKIP, additional_properties: nil) ⇒ Watchlistscreening
Returns a new instance of Watchlistscreening.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/visa_acceptance_merged_spec/models/watchlistscreening.rb', line 59 def initialize(status: SKIP, reason: SKIP, message: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @status = status unless status == SKIP @reason = reason unless reason == SKIP @message = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#message ⇒ String
The message describing the reason of the status. Value can be
- The customer matched the Denied Parties List
- The Export bill_country/ship_country match
- Export email_country match
- Export hostname_country/ip_country match
34 35 36 |
# File 'lib/visa_acceptance_merged_spec/models/watchlistscreening.rb', line 34 def @message end |
#reason ⇒ String
The reason of the status. Value can be
CUSTOMER_WATCHLIST_MATCHADDRESS_COUNTRY_WATCHLIST_MATCHEMAIL_COUNTRY_WATCHLIST_MATCHIP_COUNTRY_WATCHLIST_MATCHINVALID_MERCHANT_CONFIGURATION
26 27 28 |
# File 'lib/visa_acceptance_merged_spec/models/watchlistscreening.rb', line 26 def reason @reason end |
#status ⇒ String
The status for the call can be:
- COMPLETED
- INVALID_REQUEST
- DECLINED
17 18 19 |
# File 'lib/visa_acceptance_merged_spec/models/watchlistscreening.rb', line 17 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/visa_acceptance_merged_spec/models/watchlistscreening.rb', line 71 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. status = hash.key?('status') ? hash['status'] : SKIP reason = hash.key?('reason') ? hash['reason'] : SKIP = hash.key?('message') ? hash['message'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Watchlistscreening.new(status: status, reason: reason, message: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 |
# File 'lib/visa_acceptance_merged_spec/models/watchlistscreening.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['status'] = 'status' @_hash['reason'] = 'reason' @_hash['message'] = 'message' @_hash end |
.nullables ⇒ Object
An array for nullable fields
55 56 57 |
# File 'lib/visa_acceptance_merged_spec/models/watchlistscreening.rb', line 55 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
46 47 48 49 50 51 52 |
# File 'lib/visa_acceptance_merged_spec/models/watchlistscreening.rb', line 46 def self.optionals %w[ status reason message ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
101 102 103 104 105 |
# File 'lib/visa_acceptance_merged_spec/models/watchlistscreening.rb', line 101 def inspect class_name = self.class.name.split('::').last "<#{class_name} status: #{@status.inspect}, reason: #{@reason.inspect}, message:"\ " #{@message.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
94 95 96 97 98 |
# File 'lib/visa_acceptance_merged_spec/models/watchlistscreening.rb', line 94 def to_s class_name = self.class.name.split('::').last "<#{class_name} status: #{@status}, reason: #{@reason}, message: #{@message},"\ " additional_properties: #{@additional_properties}>" end |